/* Default color scheme */
@define-color bg_color #CBD9D4;
@define-color fg_color #101010;
@define-color base_color #FFF;
@define-color text_color #1A1A1A;
@define-color selected_bg_color #72B49D;
@define-color selected_fg_color #ffffff;
@define-color tooltip_bg_color #DBFFF3;
@define-color tooltip_fg_color #000000;

/* Colormap actually used by the theme, to be overridden in other css files */
@define-color theme_bg_color @bg_color;
@define-color theme_fg_color @fg_color;
@define-color theme_base_color @base_color;
@define-color theme_text_color @text_color;
@define-color theme_shadow_color alpha(#fff, 0.22);
@define-color theme_selected_bg_color  @selected_bg_color;
@define-color theme_selected_fg_color @selected_fg_color;
@define-color theme_selected_shadow_color alpha(#000, 0.18);
@define-color theme_tooltip_bg_color @tooltip_bg_color;
@define-color theme_tooltip_fg_color @tooltip_fg_color;
@define-color menu_bg_color @theme_bg_dark_color;
@define-color menu_fg_color shade(@theme_fg_dark_color, 1.00);
@define-color menu_shadow_color @theme_shadow_color;

/**********************[Green-Submarine]***********************/
@define-color bg_dark_color #1F2724;
@define-color fg_dark_color #CACCCA;
@define-color theme_bg_dark_color @bg_dark_color;
@define-color theme_fg_dark_color @fg_dark_color;
@define-color theme_text_dark_color #E4E6E4;
@define-color theme_shadow_dark_color alpha(#000, 0.30);
@define-color theme_highlight_color alpha(#fff, 0.05);
@define-color theme_button_border_dark shade(@theme_bg_dark_color, 0.68);
@define-color theme_entry_border_dark @theme_button_border_dark;
@define-color theme_path_bg_color shade(@theme_bg_dark_color, 0.90);
@define-color theme_path_active_color shade(@theme_bg_dark_color, 0.78);
@define-color theme_mdi_bg_color shade(@theme_bg_dark_color, 0.90);
@define-color theme_mdi_border_color shade(@theme_bg_dark_color, 0.70);
@define-color theme_dark_dialog_bg_color #1C2723;
@define-color menu_bg_dark_color shade(@theme_bg_dark_color, 0.95);
@define-color menu_fg_dark_color shade(@theme_fg_dark_color, 1.00);
@define-color menu_shadow_dark_color alpha(#000, 0.30);
@define-color menu_line_dark_color shade(@theme_bg_dark_color, 0.78);
@define-color menu_separator shade (@menu_bg_color, 0.96);
/**************************************************************************/

@define-color button_raised_gradient_color_a shade(@theme_bg_dark_color, 1.10);
@define-color button_raised_gradient_color_b shade(@theme_bg_dark_color, 0.90);
@define-color button_raised_linked_shadow alpha(@theme_base_color, 0.70);

@define-color link_color #00CC85;
@define-color frame_color #7F807F;
@define-color inactive_frame_color #B9BBB9;
@define-color warning_color #ABF500;
@define-color error_color #00CC00;
@define-color success_color #4E9A06;

@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (172, 232, 116);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (255, 236, 80);
@define-color question_bg_color rgb (138, 212, 168);
@define-color error_fg_color rgb (255, 236, 80);
@define-color error_bg_color rgb (237, 54, 54);

@define-color os_chrome_bg_color @theme_bg_dark_color;
@define-color os_chrome_fg_color @theme_fg_dark_color; 

@define-color os_chrome_selected_bg_color @theme_selected_bg_color;
@define-color os_chrome_selected_fg_color @theme_selected_fg_color;

@define-color chrome_bg_color @theme_bg_color;
@define-color chrome_fg_color @theme_fg_color;

@define-color entry_text_color @theme_text_color;
@define-color focused_entry_border @theme_selected_bg_color;
@define-color focused_entry_outer  alpha(@theme_selected_bg_color, 0.45);

@define-color entry_text_dark_color @theme_text_color;
@define-color entry_bg_dark_color shade(@theme_base_color, 0.88);
@define-color focused_dark_entry_border shade(@theme_bg_color, 0.45);
@define-color focused_dark_entry_outer alpha(@theme_selected_bg_color, 0.80);

@define-color focused_entry_inset alpha (#E4F1D7, 0.50);

/* @define-color sidebar_background shade(#E1E5E8, 0.95); */
@define-color sidebar_background #E1EAE7;
@define-color sidebar_icon       shade(#E2E8E1, 0.45);
@define-color sidebar_selected_bg shade(@theme_selected_bg_color,1.00);
@define-color sidebar_fg_color @theme_text_color;

@define-color theme_light_unfocused_bg_color @theme_bg_color;

@define-color button_base shade(@theme_bg_color, 1.15);
@define-color button_gradient1 shade(@button_base, 0.98);
@define-color button_gradient2 shade(@button_base, 0.95);
@define-color button_gradient3 shade(@button_base, 0.92);
@define-color button_gradient4 shade(@button_base, 0.89);
@define-color button_bg_active shade(@theme_selected_bg_color, 1.00);
@define-color button_border shade(@theme_bg_color, 0.70);
@define-color button_border_active shade(@button_bg_active, 0.95);

@define-color button_default_border_color shade(@selected_bg_color, 0.87);
@define-color button_default_box_shadow_color shade(@selected_bg_color, 0.87);

@define-color insensitive_bg_color shade(@bg_color, 0.93);
@define-color insensitive_fg_color shade(@bg_color, 0.70);
@define-color insensitive_border_color shade(@bg_color, 0.80);

@define-color trough_bg_color_a shade (@theme_bg_color, 0.88);
@define-color trough_bg_color_b shade (@theme_bg_color, 0.95);

@define-color internal_element_color #636463;
@define-color internal_element_prelight @theme_text_color;
@define-color internal_element_insensitive shade (@internal_element_color, 1.4);

@define-color scale_fill shade(@button_bg_active, 1.00);
@define-color scale_border_a @internal_element_color;
@define-color scale_border_b shade (@internal_element_color, 1.25);
@define-color osd_scale_border alpha (shade (@theme_bg_color, 1.25), 0.4);
@define-color scale_highlight_border @theme_selected_bg_color;
@define-color scale_highlight_bg @theme_selected_bg_color;
@define-color scale_highlight_shadow alpha(white, 0.50);

@define-color progressbar_fill_a @button_bg_active;
@define-color progressbar_fill_b shade(mix(@button_bg_active, green, 0.10), 1.10);

@define-color highlighted_border #8B9081;
@define-color transparent alpha(#000, 0.0);

@define-color notebook_border shade(@theme_bg_color, 0.75);

/* @define-color toolbar_gradient_base shade (mix(#DADED5, @theme_bg_dark_color, 0.75), 0.92); */
@define-color toolbar_gradient_base shade (@theme_bg_dark_color, 1.00);
@define-color toolbar_fg_color shade(@theme_fg_dark_color, 1.00); 
@define-color toolbar_shadow_color @theme_shadow_dark_color;
@define-color toolbar_border_color @theme_button_border_dark;
@define-color primay-toolbar-border shade (#3c3c3c, 1.0);

@define-color toolbar_active_button_color #909081;

@define-color nautilus_cluebar_color shade(@sidebar_background, 1.00);
@define-color treeview_focus_border  @nautilus_cluebar_color;

@define-color calc_display_fg_color #fff;

@define-color expander_row_selected_color #FFF;
@define-color test #f00;

/**************
 * List boxes *
 **************/

@define-color content_view_bg #DBF0C7;
@define-color list_box_bg #fafafa;

/*****************
 * GtkSpinButton *
 *****************/

@define-color inset_light_color alpha(white, 0.45);
@define-color inset_dark_color alpha(black, 0.07);
@define-color inset_link_dark_color alpha(green, 0.37);

/*******
 * OSD *
 *******/
@define-color osd_highlight #ffffff;
@define-color osd_lowlight #515251;
@define-color osd_base @theme_selected_bg_color;

@define-color osd_fg #EBEDEB;
@define-color osd_bg alpha(@osd_base, 0.80);

@define-color osd_bg_backdrop alpha(shade(@osd_base, 1.40), 0.90);

@define-color osd_text_shadow alpha(black, 0.75);

@define-color osd_toolbar_bg_a alpha(@osd_base, 0.80);
@define-color osd_toolbar_bg_b alpha(#101010, 0.80);
@define-color osd_toolbar_bg_c alpha(shade(@osd_base, 1.02), 0.80);

@define-color osd_button_bg_a alpha(@osd_highlight, 0.16);
@define-color osd_button_bg_b alpha(@osd_lowlight, 0.05);
@define-color osd_button_bg_c alpha(@osd_highlight, 0.12);

@define-color osd_button_bg_insensitive alpha(@osd_highlight, 0.25);
@define-color osd_button_bg_insensitive_active alpha(@osd_highlight, 0.16);

@define-color osd_button_bg_hover_a alpha(@osd_highlight, 0.28);
@define-color osd_button_bg_hover_b alpha(@osd_lowlight, 0.14);
@define-color osd_button_bg_hover_c alpha(@osd_highlight, 0.14);

@define-color osd_button_bg_active_a alpha(@osd_lowlight, 0.18);
@define-color osd_button_bg_active_b alpha(@osd_highlight, 0.23);
@define-color osd_button_bg_active_c alpha(@osd_lowlight, 0.17);

@define-color osd_button_bg_backdrop alpha(@osd_highlight, 0.18);
@define-color osd_button_bg_backdrop_hover alpha(@osd_highlight, 0.25);
@define-color osd_button_bg_backdrop_active alpha(@osd_highlight, 0.35);
@define-color osd_button_bg_backdrop_insensitive alpha(@osd_highlight, 0.08);

@define-color osd_button_fg_backdrop shade(@osd_fg, 0.70);
@define-color osd_button_fg_backdrop_active shade(@osd_fg, 0.95);

@define-color osd_button_fg shade(@osd_fg, 0.85);
@define-color osd_button_fg_hover shade(@osd_fg, 0.96);
@define-color osd_button_fg_active shade(@osd_fg, 1.10);
@define-color osd_button_fg_insensitive shade(@osd_fg, 0.70);

@define-color osd_button_border shade (@theme_selected_bg_color, 0.8);
@define-color osd_button_inset shade(@osd_fg, 0.67);
@define-color osd_button_shadow alpha(black, 0.35);

@define-color osd_trough_bg alpha(@osd_button_fg, 0.10);

/* Metacity */
@define-color wm_highlight #ffffff;
@define-color wm_title_highlight #ffffff;

@define-color wm_bg_a shade (@bg_color, 1.1);
@define-color wm_bg_b @bg_color;

@define-color wm_button_bg_a shade (@bg_color, 1.0);
@define-color wm_button_bg_b shade (@bg_color, 0.85);
@define-color wm_button_bg_c shade (@bg_color, 0.8);
@define-color wm_button_bg_d shade (@bg_color, 0.9);

@define-color wm_button_bg_hover_a shade (@wm_button_bg_a, 1.1);
@define-color wm_button_bg_hover_b shade (@wm_button_bg_b, 1.1);
@define-color wm_button_bg_hover_c shade (@wm_button_bg_c, 1.1);
@define-color wm_button_bg_hover_d shade (@wm_button_bg_d, 1.1);

@define-color wm_button_bg_active_a shade (@bg_color, 0.7);
@define-color wm_button_bg_active_b shade (@bg_color, 0.9);
@define-color wm_button_bg_active_c shade (@bg_color, 0.9);

/*************
 * scrollbar *
 *************/

@define-color scrollbar_trough shade(@theme_bg_color, 0.98);
@define-color scrollbar_trough_insensitive shade(@theme_bg_color, 1.0);
@define-color scrollbar_trough_unfocused shade(@theme_unfocused_bg_color, 0.9);
@define-color scrollbar_slider @theme_bg_color;
@define-color scrollbar_slider_prelight mix(@scrollbar_trough, @theme_fg_color, 0.5);
@define-color scrollbar_slider_active @theme_selected_bg_color;
@define-color scrollbar_slider_insensitive alpha(black, 0); /* FIXME should be transparent */
@define-color scrollbar_slider_unfocused @theme_unfocused_bg_color;

/***********
 * Popover *
 ***********/
@define-color osd_popover_bg alpha(@osd_base, 0.90);

/* GTKHeaderBar colours */
@define-color borders_headerbar @theme_bg_dark_color;
@define-color unfocused_borders_headerbar @theme_bg_dark_color;
@define-color theme_unfocused_bg_color @theme_bg_dark_color;
@define-color button_hover_gradient_color_a @button_raised_gradient_color_a;
@define-color button_hover_gradient_color_b @button_raised_gradient_color_b;
@define-color wm_shadow @theme_shadow_dark_color;
@define-color wm_title @theme_fg_dark_color;
@define-color wm_title_shadow @wm_shadow;
@define-color wm_bg_a @theme_bg_dark_color;
@define-color wm_bg_b @theme_bg_dark_color;

@define-color borders shade(@theme_bg_color, 0.75);
@define-color theme_unfocused_selected_bg_color shade(@theme_bg_color, 0.95);
@define-color theme_unfocused_selected_fg_color @theme_selected_fg_color;
@define-color unfocused_borders @borders;
@define-color unfocused_insensitive_borders mix(@theme_unfocused_bg_color, @unfocused_borders, 0.5);
@define-color unfocused_insensitive_fg_color mix(@theme_unfocused_bg_color, @theme_unfocused_fg_color, 0.5);
@define-color unfocused_insensitive_bg_color mix(@theme_unfocused_bg_color, @theme_unfocused_base_color, 0.5);

/* terminal view color*/
@define-color terminal_background_color #343B27;

/* csd border */
@define-color wm_csd_solid_border_color shade (#3c3c3c, 1.2);

/************************
 * overshoot/undershoot *
 ************************/

@define-color overshoot_bg_color alpha (@theme_selected_bg_color, 0.55);
@define-color overshoot_backdrop_bg_color #C8FA96;

/* inactive-pane caja */
@define-color inactive-pane_bg_color #E5E5E5;

@import url("gtk-widgets.css");
@import url("gtk-widgets-assets.css");
@import url("menu.css");
@import url("scrollbar.css");
@import url("sidebar.css");
@import url("gnome-applications.css");
@import url("other-applications.css");
@import url("mate-applications.css");

