/* nemo */

/* NemoTrashBar, NemoXContentBar, NemoQueryEditor */
.nemo-window-pane > notebook box.vertical box.vertical infobar.horizontal.info revealer .horizontal,
.nemo-window-pane box.vertical.toolbar.primary-toolbar {
    background-color: shade (@theme_bg_color, 1.05);
    border-radius: 0px;
    border-width: 0px 0px 1px 0px;
    border-style: solid;
    border-color: transparent;
    box-shadow: inset  0px  1px alpha(#fff, 0.06),
                inset  1px  0px alpha(#fff, 0.06),
                inset -1px  0px alpha(#fff, 0.06),
                inset  0px -1px alpha(#fff, 0.06);
}

.nemo-window-pane > notebook box.vertical box.vertical infobar.horizontal.info revealer .horizontal label {
    color: shade(@theme_text_color, 1.00);
    text-shadow: 0px 1px @theme_shadow_color;
}

.nemo-window-pane > notebook box.vertical box.vertical infobar.horizontal.info revealer .horizontal label:disabled {
    color: mix(@nautilus_cluebar_color, @theme_fg_color, 0.50);
}

/* disable radius for nemo, looks strange */
.nemo-window .sidebar treeview.view {
    border-radius: 0px;
}

.nemo-window .sidebar treeview.view:selected,
.nemo-window .sidebar treeview.view:selected:hover {
    background-image: linear-gradient(to bottom,
                                      shade (@theme_selected_bg_color, 1.2),
                                      shade (@theme_selected_bg_color, 0.7));
    color: @theme_selected_fg_color;
    border-radius: 0px;
}

.nemo-window toolbar.primary-toolbar button image {
    color: @theme_fg_dark_color;
}

.nemo-window toolbar.primary-toolbar .raised button,
.nemo-window toolbar.primary-toolbar .raised.linked button,
.nemo-window toolbar.primary-toolbar .raised button:hover,
.nemo-window toolbar.primary-toolbar .raised.linked button:hover,
.nemo-window toolbar.primary-toolbar .raised.linked button:focus,
.nemo-window toolbar.primary-toolbar .raised.linked button:checked:hover:active,
.nemo-window toolbar.primary-toolbar .raised.linked button:focus:checked:hover:active {
    padding: 4px 7px;
}

.nemo-window toolbar.primary-toolbar entry {
    padding: 3px 4px;
}

/* pathbar */
.nemo-window toolbar.primary-toolbar widget.raised.linked > button:first-child widget {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
    color: @menu_fg_dark_color;
}

.nemo-window toolbar.primary-toolbar widget.raised.linked > button:last-child widget {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    color: @menu_fg_dark_color;
}

.nemo-window toolbar.primary-toolbar widget.raised.linked > button:disabled:first-child widget,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button:disabled:last-child widget {
    color: @insensitive_fg_color;
}

.nemo-window toolbar.primary-toolbar widget.raised.linked > button:hover:first-child widget,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button:hover:last-child widget {
    color: shade (@theme_selected_bg_color, 1.2);
   -gtk-icon-shadow:  0px  1px shade (@menu_fg_dark_color, 1.0),
                      1px  0px shade (@menu_fg_dark_color, 1.0),
                     -1px  0px shade (@menu_fg_dark_color, 1.0),
                      0px -1px shade (@menu_fg_dark_color, 1.0);
}

/* this makes the arrow a bit bigger */
.nemo-window toolbar.primary-toolbar widget.raised.linked > button:first-child {
   margin: 0px 0px 0px -1px;
   padding: 0px;
}

.nemo-window toolbar.primary-toolbar widget.raised.linked > button:last-child {
   margin: 0px -1px 0px 0px;
   padding: 0px;
}

.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:hover,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:focus,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:backdrop,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:checked,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:checked:hover,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:checked:hover:active,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:disabled,
.nemo-window toolbar.primary-toolbar widget.raised.linked > button.text-button.toggle:focus:hover:active {
   margin: 0px 0px 0px 0px;
   padding: 0px;
   padding: 0px 6px;
}

/* Nemo statusbar */
.nemo-window box.toolbar.horizontal {
    background-image: none;
    background-color: @theme_bg_color;
    border-top-width: 0;
    border-bottom-width: 0;
    box-shadow: none;
    padding: 0px;
}

.nemo-window box.toolbar.horizontal button {
    padding: 6px;
}

/* kill unwanted colors */
.nemo-window .nemo-window-pane notebook {
    background-color: @theme_bg_color;
}

/* this sets the bg color for scrolledwindow junction, the little square beside the scrollbars */
.nemo-window .nemo-window-pane > notebook box.vertical > overlay scrolledwindow {
    background-color: @theme_bg_color;
}

/* treewiew, view and compact view */
.nemo-window .nemo-window-pane > notebook box.vertical > overlay > scrolledwindow.view,
.nemo-window .nemo-window-pane > notebook box.vertical > overlay > scrolledwindow > treeview.view {
    background-color: @theme_base_color;
}

.nemo-canvas-item {
    border-radius: 3px;
}

/* desktop mode */
.nemo-desktop.nemo-canvas-item {
    color: white;
    text-shadow: 1px 1px black;
}

.nemo-desktop.nemo-canvas-item:active,
.nemo-desktop.nemo-canvas-item:checked {
    background-image: none;
    color: @theme_text_color;
}

.nemo-desktop.nemo-canvas-item:selected {
    color: @theme_selected_fg_color;
}

.nemo-desktop.nemo-canvas-item:active,
.nemo-desktop.nemo-canvas-item:checked,
.nemo-desktop.nemo-canvas-item:hover,
.nemo-desktop.nemo-canvas-item:selected,
.nemo-desktop.nemo-canvas-item:checked {
    text-shadow: none;
}

/* stack-switcher ie. nemo preferences */
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar {
    background-color: transparent;
    border-color: @primay-toolbar-border;
    border-width: 1px 0px;
    padding: 1px 0px;
}

.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:focus {
    color: @menu_fg_dark_color;
    text-shadow: none;
    box-shadow: none;
    padding: 5px 2px;
    background-image: none;
}

.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:hover,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:checked,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:checked:hover {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

/* middle most button */
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:focus,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:hover,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:checked {
    border-right-width: 0px;
    border-left-width:  0px;
    border-radius: 0px;
}

/* left most button */
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:first-child,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:focus:first-child,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:hover:first-child,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:checked:first-child {
    border-radius: 5px 0 0 5px;
    border-width: 1px;
    border-right-width: 0px;
}

/* right most button */
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:last-child,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:focus:last-child,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:hover:last-child,
.nemo-properties-dialog box.vertical.dialog-vbox toolbar.horizontal.primary-toolbar stackswitcher.horizontal.linked.stack-switcher button.text-button.radio:checked:last-child {
    border-radius: 0 5px 5px 0;
    border-width: 1px;
    border-left-width: 0px;
}

.nemo-properties-dialog box.vertical.dialog-vbox frame.view {
    background-color: shade (@theme_bg_color, 1.1);
    border-color: @borders;
}

.nemo-properties-dialog box.vertical.dialog-vbox frame.view  viewport.frame {
    background-color: shade (@theme_bg_color, 1.1);
}

.nemo-properties-dialog box.vertical.dialog-vbox frame.view stack  viewport.frame .vertical separator.horizontal {
    border-color: @borders;
    border-width: 0 0 1px 0;
}

.nemo-properties-dialog box.vertical.dialog-vbox frame.view stack  viewport.frame .vertical .vertical .vertical checkbutton.text-button {
    background-color: transparent;
}

.nemo-properties-dialog box.vertical.dialog-vbox frame.view stack  viewport.frame .vertical .vertical .vertical checkbutton.text-button:hover {
    background-color: shade (@theme_bg_color, 1.05);
    border-radius: 4px;
}

/* Cinnamon-Settings */

toolbar.cs-header {
    background-color: transparent;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@button_base, 1.00)),
                                     to (shade(@button_base, 0.93)));
    border-style: solid;
    border-radius: 3px 3px 0px 0px;
    border-top-color:    shade(@button_border, 1.05);
    border-left-color:   shade(@button_border, 1.05);
    border-right-color:  shade(@button_border, 1.05);
    border-bottom-color: shade(@button_border, 0.95);
    box-shadow: inset  0px  1px alpha(#fff, 0.09),
                inset  1px  0px alpha(#fff, 0.07),
                inset -1px  0px alpha(#fff, 0.07),
                inset  0px -1px alpha(#fff, 0.05);
    border-width: 1px;
    margin: -2px  -2px  0px  -2px;
}


/* CompizConfigManager */

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook {
    background-color: shade (@theme_bg_color, 1.1);
}

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook box.vertical frame {
    background-color: shade (@theme_bg_color, 1.14);
}

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook box.vertical frame frame {
    background-color: shade (@theme_bg_color, 1.17);
}

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook box.vertical frame expander scrolledwindow {
    border-color: @notebook_border;
    border-style: solid;
    border-width: 1px;
}

/* treeview header */
.ccsm-window notebook.frame scrolledwindow viewport widget.notebook box.vertical frame expander scrolledwindow treeview.view button {
    border-color: @notebook_border;
    border-style: solid;
    border-width: 0px 1px 1px 0px;
}

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook box.vertical frame expander scrolledwindow treeview.view button:first-child {
    border-width: 0px 1px 1px 0px;
}

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook box.vertical frame expander scrolledwindow treeview.view button:last-child {
    border-width: 0px 0px 1px 0px;;
}

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook  spinbutton.horizontal > entry {
   padding: 0px 2px 0px 3px;
}

.ccsm-window notebook.frame scrolledwindow viewport widget.notebook  spinbutton.horizontal > button {
    padding: 0px 8px;
}

/* virtual-manager detail view, hopefully only */
window.background box.vertical notebook box.horizontal box.vertical notebook {
    border-style: none;
}

/* meld */

#meldapp > box.vertical > notebook.frame {
    border-width: 0px;
    background-color: shade (@theme_bg_color, 1.0);
}

#meldapp > box.vertical > notebook.frame > header.top {
    border-radius: 0px;
}

#meldapp > box.vertical > notebook.frame > header.top tab {
    padding: 2px 4px;
}

#meldapp > box.vertical > notebook.frame > header.top tab:checked,
#meldapp > box.vertical > notebook.frame > header.top tab:checked:hover {
    background-image: linear-gradient(to bottom,
                                      shade(@theme_bg_color, 1.18),
                                      shade(@theme_bg_color, 1.0));
}

/* FIXME, does not work */
#meldapp box.vertical notebook.frame box.vertical grid.horizontal toolbar.horizontal.meld-notebook-toolbar {
    border-width: 0px;
    border-style: none;
    border-color: rgba(0,0,0,0);
}

.meld-notebook-toolbar > toolitem > filechooserbutton > button.file > box > label {
    color:             @theme_fg_color;
    text-shadow: none;
}

.meld-notebook-toolbar > toolbutton > button.flat {
    padding: 6px;
}

.meld-notebook-toolbar > toolbutton > button.flat,
.meld-notebook-toolbar > toolitem > filechooserbutton > button.file {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (@button_gradient1),
                                     color-stop (0.50, @button_gradient3),
                                     to   (@button_gradient4));
    border-width: 1px;
    border-radius: 5px;
    border-style: solid;
    /* outer */
    border-top-color:    transparent;
    border-left-color:   alpha (#000, 0.01);
    border-right-color:  alpha (#000, 0.01);
    border-bottom-color: alpha (#000, 0.03);
    box-shadow: inset  0px  1px alpha(shade(@button_border, 1.00), 0.70),
                inset  1px  0px alpha(shade(@button_border, 0.94), 0.80),
                inset -1px  0px alpha(shade(@button_border, 0.94), 0.80),
                inset  0px -1px alpha(shade(@button_border, 0.88), 0.90);
}

.meld-notebook-toolbar > toolbutton > button.flat:hover,
.meld-notebook-toolbar > toolitem > filechooserbutton > button.file:hover {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@button_gradient1, 1.03)),
                                     to   (shade(@button_gradient4, 1.01)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

.meld-notebook-toolbar > toolitem > filechooserbutton > button.file:focus {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (@button_gradient1),
                                     color-stop (0.50, @button_gradient3),
                                     to   (@button_gradient4));
    /* outer */
    border-top-color:    transparent;
    border-left-color:   alpha (#000, 0.01);
    border-right-color:  alpha (#000, 0.01);
    border-bottom-color: alpha (#000, 0.03);
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

.meld-notebook-toolbar > toolbutton > button.flat:disabled {
    background-image: none;
    background-color: @insensitive_bg_color;
    border-color: @insensitive_border_color;
    border-image: none;
    box-shadow: inset  0px  1px @insensitive_border_color,
                inset  1px  0px @insensitive_border_color,
                inset -1px  0px @insensitive_border_color,
                inset  0px -1px @insensitive_border_color;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical {
    border-width: 1px;
    border-style: solid;
    border-color: @notebook_border;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow {
    border-width: 1px 0px 0px 0px;
    border-style: solid;
    border-color: @notebook_border;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.vertical.left {
    border-width: 0px 1px 1px 0px;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.vertical.right {
    border-width: 0px 0px 1px 1px;
}

/*************
 * Yumex-DNF *
 *************/

window.background.yumex-dnf-window > box.vertical > box.horizontal {
   background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@theme_bg_dark_color, 1.00)),
                                     to   (shade(@theme_bg_dark_color, 0.95)));
    border-width: 0px 0px 1px 0px;
    border-style: solid;
    border-color: @primay-toolbar-border;
}

window.background.yumex-dnf-window > box.vertical > box.horizontal button,
window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio {
    background-image: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: @theme_fg_dark_color;
    border-width: 1px;
    border-radius: 5px;
    box-shadow: none;
}

window.background.yumex-dnf-window > box.vertical > box.horizontal button:hover,
window.background.yumex-dnf-window > box.vertical > box.horizontal button:checked,
window.background.yumex-dnf-window > box.vertical > box.horizontal button:hover:active,
window.background.yumex-dnf-window > box.vertical > box.horizontal button:checked:hover,
window.background.yumex-dnf-window > box.vertical > box.horizontal button:checked:hover:active,
window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio:hover,
window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio:checked,
window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio:hover:active,
window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio:checked:hover,
window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio:checked:hover:active {
    color: shade (@theme_selected_bg_color, 1.6);
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    border-top-color: shade(@button_raised_gradient_color_a, 0.50);
    border-bottom-color: shade(@button_raised_gradient_color_a, 0.50);
    border-right-color: shade(@button_raised_gradient_color_a, 0.50);
    border-left-color: shade(@button_raised_gradient_color_a, 0.50);
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio {
    border-right-width: 0px;
    border-left-width:  0px;
    border-radius: 0px;
}

window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio:first-child {
    border-radius: 5px 0 0 5px;
    border-width: 1px;
    border-right-width: 0px;
}

window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio:last-child {
    border-radius: 0 5px 5px 0;
    border-width: 1px;
    border-left-width: 0px;
}

window.background.yumex-dnf-window > box.vertical > box.horizontal button:disabled {
    color: @theme_text_dark_color;
    background-color: transparent;
    background-image: none;
    background-color: @theme_bg_dark_color;
    border-color: @theme_button_border_dark;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
}

/* info sidebar */
window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > box.horizontal > box.vertical list.sidebar row.activatable {
   background-image: none;
    background-color: transparent;
    border-radius: 4px;
}

window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > box.horizontal > box.vertical list.sidebar row.activatable:hover {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@button_gradient1, 1.03)),
                                     color-stop (0.50, shade(@button_gradient3, 1.03)),
                                     to   (shade(@button_gradient4, 1.01)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > box.horizontal > box.vertical list.sidebar row.activatable:hover:active {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade (@theme_bg_color, 1.20)),
                                     color-stop (0.50, shade (@theme_bg_color, 1.00)),
                                     color-stop (0.50, shade (@theme_bg_color, 0.99)),
                                     to (shade (@theme_bg_color, 0.80)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

/* list sidebar row */
window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > stack > box.vertical > box.horizontal > box.vertical list.sidebar {
    background-color: shade (@theme_bg_color, 1.08);
    border-color: @notebook_border;
    border-style: solid;
    border-width: 1px 0px 0px 0px;
}

window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > stack > box.vertical > box.horizontal > box.vertical list.sidebar row.activatable {
    background-color: shade (@theme_bg_color, 1.08);
    border-radius: 4px;
}

/****************
 * pavu-control *
 ****************/

window.background > box.vertical > notebook button.flat.toggle:focus,
window.background.csd > box.vertical > notebook button.flat.toggle:focus,
window.background.ssd > box.vertical > notebook button.flat.toggle:focus,
window.background.solid-csd > box.vertical > notebook button.flat.toggle:focus {
    box-shadow: none;
}

window.background > box.vertical > notebook button.flat.toggle:checked,
window.background.csd > box.vertical > notebook button.flat.toggle:checked,
window.background.ssd > box.vertical > notebook button.flat.toggle:checked,
window.background.solid-csd > box.vertical > notebook button.flat.toggle:checked {
    border-top-color:    transparent;
    border-left-color:   alpha (#000, 0.01);
    border-right-color:  alpha (#000, 0.01);
    border-bottom-color: alpha (#000, 0.03);
    box-shadow: inset  0px  1px alpha(shade(@button_border, 1.00), 0.70),
                inset  1px  0px alpha(shade(@button_border, 0.94), 0.80),
                inset -1px  0px alpha(shade(@button_border, 0.94), 0.80),
                inset  0px -1px alpha(shade(@button_border, 0.88), 0.90);
}

window.background > box.vertical > notebook button.flat.toggle:checked:focus,
window.background.csd > box.vertical > notebook button.flat.toggle:checked:focus,
window.background.ssd > box.vertical > notebook button.flat.toggle:checked:focus,
window.background.solid-csd > box.vertical > notebook button.flat.toggle:checked:focus {
    box-shadow: inset  0px  1px shade (@theme_selected_bg_color, 1.3),
                inset  1px  0px shade (@theme_selected_bg_color, 1.3),
                inset -1px  0px shade (@theme_selected_bg_color, 1.3),
                inset  0px -1px shade (@theme_selected_bg_color, 1.3);
}

window.background > box.vertical > notebook scrolledwindow,
window.background.csd > box.vertical > notebook button.flat.toggle:checked:focus,
window.background.ssd > box.vertical > notebook button.flat.toggle:checked:focus,
window.background.solid-csd > box.vertical > notebook button.flat.toggle:checked:focus {
    background-color: shade (@theme_bg_color, 1.1);
}

window.background > box.vertical > notebook scrolledwindow,
window.background.csd > box.vertical > notebook scrolledwindow viewport,
window.background.ssd > box.vertical > notebook scrolledwindow viewport,
window.background.solid-csd > box.vertical > notebook scrolledwindow viewport {
    border-style: solid;
    border-color: @notebook_border;
    border-width: 1px;
}

window.background > box.vertical > notebook scrolledwindow viewport,
window.background.csd > box.vertical > notebook scrolledwindow viewport,
window.background.ssd > box.vertical > notebook scrolledwindow viewport,
window.background.solid-csd > box.vertical > notebook scrolledwindow viewport {
    background-color: shade (@theme_bg_color, 1.15);
}

/****************
 * virt-manager *
 ****************/

window.background > box.vertical > notebook overlay > scrolledwindow,
window.background > box.vertical > notebook overlay > scrolledwindow viewport {
    border-style: none;
    border-width: 0px;
}

/***********
 * Lightdm *
 ***********/

/* 2.0 */
.lightdm-gtk-greeter #login_window.background,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter,
#login_window.background.lightdm-gtk-greeter box.vertical {
    border-radius: 10px;
    border-style: solid;
    border-width: 2px;
    border-color: shade(@theme_dark_dialog_bg_color, 0.8);
    background-color: @theme_dark_dialog_bg_color;
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #content_frame,
.lightdm-gtk-greeter #login_window.background #buttonbox_frame,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #content_frame,
#login_window.background.lightdm-gtk-greeter #buttonbox_frame {
    border-radius: 0px;
    border-style: none;
    border-width: 0px;
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #user_image_border,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #user_image_border {
    border-style: solid;
    border-width: 1px;
    border-color: shade(@theme_dark_dialog_bg_color, 1.4);
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo,
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo:focus,
.lightdm-gtk-greeter #login_window.background #buttonbox_frame button,
.lightdm-gtk-greeter #login_window.background #buttonbox_frame button:focus,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo,
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo:focus,
#login_window.background.lightdm-gtk-greeter #buttonbox_frame button,
#login_window.background.lightdm-gtk-greeter #buttonbox_frame button:focus {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    box-shadow: none;
    color: @menu_fg_dark_color;
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo cellview,
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo:focus cellview,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo cellview,
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo:focus cellview {
    color: @menu_fg_dark_color;
    text-shadow: none;
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo arrow,
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo:focus arrow,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo arrow,
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo:focus arrow {
    color: @menu_fg_dark_color;
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo:hover,
.lightdm-gtk-greeter #login_window.background #content_frame #user_combobox .linked button.combo:hover:active,
.lightdm-gtk-greeter #login_window.background #buttonbox_frame button:hover,
.lightdm-gtk-greeter #login_window.background #buttonbox_frame button:hover:active,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo:hover,
#login_window.background.lightdm-gtk-greeter #content_frame #user_combobox .linked button.combo:hover:active,
#login_window.background.lightdm-gtk-greeter #buttonbox_frame button:hover,
#login_window.background.lightdm-gtk-greeter #buttonbox_frame button:hover:active {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #content_frame #prompt_entry,
.lightdm-gtk-greeter #login_window.background #content_frame #prompt_entry:focus,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #content_frame #prompt_entry,
#login_window.background.lightdm-gtk-greeter #content_frame #prompt_entry:focus {
    background-color: transparent;
    background-image: -gtk-gradient(linear,
                                    left top, left bottom,
                                    from       (shade(@theme_dark_dialog_bg_color, 1.16)),
                                    color-stop (0.15, shade(@theme_dark_dialog_bg_color, 1.26)),
                                    color-stop (0.50, shade(@theme_dark_dialog_bg_color, 1.28)),
                                    to         (shade(@theme_dark_dialog_bg_color, 1.30)));
    color: shade (@menu_fg_dark_color, 1.0);
    box-shadow: inset  0px  1px shade(@theme_dark_dialog_bg_color, 1.6),
                inset  1px  0px shade(@theme_dark_dialog_bg_color, 1.6),
                inset -1px  0px shade(@theme_dark_dialog_bg_color, 1.6),
                inset  0px -1px shade(@theme_dark_dialog_bg_color, 1.6);
    /* color of the cursor */
	caret-color: shade (@menu_fg_dark_color, 1.0);
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #content_frame #prompt_entry selection,
.lightdm-gtk-greeter #login_window.background #content_frame #prompt_entry selection:focus,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #content_frame #prompt_entry selection,
#login_window.background.lightdm-gtk-greeter #content_frame #prompt_entry selection:focus {
    background-color: shade(@menu_fg_dark_color, 0.4);
    color: shade (@menu_fg_dark_color, 1.2);
}

/* 2.0 */
.lightdm-gtk-greeter #restart_dialog,
.lightdm-gtk-greeter #shutdown_dialog,
/* 1.8.5 */
#restart_dialog.lightdm-gtk-greeter,
#shutdown_dialog.lightdm-gtk-greeter {
    border-radius: 10px;
    border-style: solid;
    border-width: 2px;
    border-color: shade(@theme_dark_dialog_bg_color, 0.8);
    background-color: @theme_dark_dialog_bg_color;
}

/* 2.0 */
.lightdm-gtk-greeter #restart_dialog box.vertical,
.lightdm-gtk-greeter #shutdown_dialog box.vertical,
/* 1.8.5 */
#restart_dialog.lightdm-gtk-greeter .dialog-vbox,
#shutdown_dialog.lightdm-gtk-greeter .dialog-vbox {
    background-color: transparent;
    color: shade (@menu_fg_dark_color, 1.0);
}

/* 2.0 */
.lightdm-gtk-greeter #restart_dialog button,
.lightdm-gtk-greeter #shutdown_dialog button,
/* 1.8.5 */
#restart_dialog.lightdm-gtk-greeter .linked button,
#shutdown_dialog.lightdm-gtk-greeter .linked button {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    box-shadow: none;
    color: @menu_fg_dark_color;
    margin: 0px 0px 0px -1px;
}

/* 2.0 */
.lightdm-gtk-greeter #restart_dialog button:hover,
.lightdm-gtk-greeter #shutdown_dialog button:hover,
.lightdm-gtk-greeter #restart_dialog button:hover:active,
.lightdm-gtk-greeter #shutdown_dialog button:hover:active,
/* 1.8.5 */
#restart_dialog.lightdm-gtk-greeter .linked button:hover:first-child,
#shutdown_dialog.lightdm-gtk-greeter .linked button:hover:first-child,
#restart_dialog.lightdm-gtk-greeter .linked button:hover:active:first-child,
#shutdown_dialog.lightdm-gtk-greeter .linked button:hover:active:first-child,
#restart_dialog.lightdm-gtk-greeter .linked button:hover:last-child,
#shutdown_dialog.lightdm-gtk-greeter .linked button:hover:last-child,
#restart_dialog.lightdm-gtk-greeter .linked button:hover:active:last-child,
#shutdown_dialog.lightdm-gtk-greeter .linked button:hover:active:last-child {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

/* 2.0 */
.lightdm-gtk-greeter #panel_window.background menubar,
/* 1.8.5 */
#panel_window.background.menubar.lightdm-gtk-greeter {
    background-color: @theme_dark_dialog_bg_color;
}

/* 2.0 */
.lightdm-gtk-greeter #panel_window.background menubar label,
/* 1.8.5 */
#panel_window.background.menubar.lightdm-gtk-greeter label {
    color: @fg_dark_color;
}

/* the weird panel */
/* 2.0 */
.lightdm-gtk-greeter #panel_window.background menubar separator {
    border-style: none;
    border-width: 0px;
}

/* emoji-picker */
popover.emoji-picker > box.vertical > scrolledwindow > viewport.frame {
    border-radius: 0px;
}

popover.emoji-picker > box.vertical > box.horizontal > button.flat.emoji-section {
    color: @theme_dark_fg_color;
}

popover.emoji-picker > box.vertical > box.horizontal > button.flat.emoji-section:focus,
popover.emoji-picker > box.vertical > box.horizontal > button.flat.emoji-section:hover,
popover.emoji-picker > box.vertical > box.horizontal > button.flat.emoji-section:focus:hover,
popover.emoji-picker > box.vertical > box.horizontal > button.flat.emoji-section:focus:hover:active {
    border-radius: 3px;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    box-shadow: inset  0px  1px shade (@theme_selected_bg_color, 1.3),
                inset  1px  0px shade (@theme_selected_bg_color, 1.3),
                inset -1px  0px shade (@theme_selected_bg_color, 1.3),
                inset  0px -1px shade (@theme_selected_bg_color, 1.3);
}

