/* common color definitions to the light and dark variations */

/******************************
 * Destructive action buttons *
 ******************************/
@define-color destructive_action_button_a #e03d3d;
@define-color destructive_action_button_b #ef2929;
@define-color destructive_action_button_border #9d4242;
@define-color destructive_action_button_fg #ffffff;
@define-color destructive_action_button_shadow shade(@destructive_action_button_border, 1.15);

/*******
 * OSD *
 *******/
@define-color osd_highlight #ffffff;
@define-color osd_lowlight #525252;
@define-color osd_base #212526;
@define-color osd_base_backdrop shade(@osd_base, 1.40);

@define-color osd_fg #ededed;
@define-color osd_bg alpha(@osd_base, 0.80);
@define-color osd_bg_backdrop alpha(@osd_base_backdrop, 0.90);

@define-color osd_text_shadow alpha(black, 0.75);

@define-color osd_toolbar_bg_a alpha(@osd_base, 0.80);
@define-color osd_toolbar_bg_b alpha(#101010, 0.80);
@define-color osd_toolbar_bg_c alpha(shade(@osd_base, 1.02), 0.80);

@define-color osd_button_bg_a alpha(@osd_highlight, 0.16);
@define-color osd_button_bg_b alpha(@osd_lowlight, 0.05);
@define-color osd_button_bg_c alpha(@osd_highlight, 0.12);

@define-color osd_button_bg_insensitive alpha(@osd_bg, 0.25);
@define-color osd_button_bg_insensitive_active alpha(@osd_bg, 0.16);

@define-color osd_button_bg_hover_a alpha(@osd_highlight, 0.28);
@define-color osd_button_bg_hover_b alpha(@osd_lowlight, 0.14);
@define-color osd_button_bg_hover_c alpha(@osd_highlight, 0.14);

@define-color osd_button_bg_active_a alpha(black, .9);
@define-color osd_button_bg_active_b alpha(black, 0.4);
@define-color osd_button_bg_active_c alpha(black, 0);

@define-color osd_button_bg_backdrop alpha(@osd_bg, 0.18);
@define-color osd_button_bg_backdrop_hover alpha(@osd_bg, 0.25);
@define-color osd_button_bg_backdrop_active alpha(@osd_bg, 0.35);
@define-color osd_button_bg_backdrop_insensitive alpha(@osd_bg, 0.08);

@define-color osd_button_fg_backdrop shade(@osd_fg, 0.70);
@define-color osd_button_fg_backdrop_active shade(@osd_fg, 0.95);

@define-color osd_button_fg shade(@osd_fg, 0.80);
@define-color osd_button_fg_hover shade(@osd_fg, 0.96);
@define-color osd_button_fg_active shade(@osd_fg, 1.10);
@define-color osd_button_fg_insensitive shade(@osd_fg, 0.70);

@define-color osd_button_border alpha(@osd_highlight, 0.40);
@define-color osd_button_border_active alpha(@osd_highlight, 0.8);
@define-color osd_button_inset shade(@osd_fg, 0.67);
@define-color osd_button_shadow alpha(black, 0.35);

@define-color osd_trough_bg alpha(@osd_button_fg, 0.10);

@define-color osd_view_bg alpha(@osd_bg, 0.60);
@define-color osd_view_bg_backdrop alpha(@osd_bg_backdrop, 0.60);

@define-color osd_scrollbar_trough shade(@osd_base, 1.70);
@define-color osd_scrollbar_trough_backdrop shade(@osd_base_backdrop, 1.40);

@define-color osd_scrollbar_slider shade(@osd_scrollbar_trough, 1.50);
@define-color osd_scrollbar_slider_prelight shade(@osd_scrollbar_trough, 1.80);
@define-color osd_scrollbar_slider_active shade(@osd_scrollbar_trough, 2.10);
@define-color osd_scrollbar_slider_backdrop shade(@osd_scrollbar_trough_backdrop, 1.50);

/***********
 * Popover *
 ***********/
@define-color osd_popover_bg alpha(@osd_base, 0.90);

/*********************
 * Error/Warning/... *
 *********************/
@define-color link_color #4a90d9;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #064E9A;

@define-color infobar_fg_color white;
@define-color infobar_text_shadow alpha(black, 0.3);

/*****************
 * Fallback Mode *
 *****************/
@define-color os_chrome_bg_color black;
@define-color os_chrome_fg_color #ccc;
@define-color os_chrome_selected_bg_color #333;
@define-color os_chrome_selected_fg_color white;

/************
 * Tooltips *
 ************/
@define-color theme_tooltip_bg_color #F5F5B5;
@define-color theme_tooltip_fg_color #2c2c2c;
