##########################################
# CAJA	
##########################################
gtk_color_scheme = "fg_color:#101010\nbg_color:#E9EFE7"

style "caja-handle"
{
	GtkPaned::handle-size = 0
	xthickness = 0
	ythickness = 0
	base[NORMAL] = @bg_color
}

style "caja-sidebar"
{

	text[NORMAL] = @fg_color
	base[NORMAL] = @bg_color
	font_name = "Regular"

	GtkTreeView::odd_row_color = @bg_color
	GtkTreeView::even_row_color = @bg_color

      # padding from the left edge
	GtkTreeView::horizontal_separator = 15
      	xthickness = 0
	ythickness = 0
}

style "caja-extra-view"
{

	xthickness		= 0
	ythickness		= 0

	bg[NORMAL] = @bg_color
}


style "caja-view"
{
	xthickness		= 0
	ythickness		= 0
	bg[NORMAL]	= "#F1F7EF"
	base[NORMAL]	= "#F1F7EF"

}
style "caja-statusbar"
{
	xthickness		= 4
	ythickness		= 1
}
style "caja-window-base"
{
	#bg[NORMAL]	= @bg_color

}

style "caja-location" {

	bg[NORMAL]  = mix (0.60, shade (1.05, "#E9EFE7"), "#E9EFE7")
}


# CAJA
widget_class	"*Caja*Window*"		style "caja-window-base"
widget_class	"*Caja*Places*Sidebar*"	style "caja-sidebar"
widget_class	"*Caja*View*"		style "caja-view"
widget		"*Caja*Splitter"		style "caja-handle"
widget_class	"*Caja*Statusbar*"		style "caja-statusbar"
# For Elementay Caja
widget_class	"*Caja*GtkToolbar*"		style "murrine-togglebutton"

widget "*.caja-extra-view-widget" 		style : highest "caja-location"
