/*********************
 * CAJA File manager *
 *********************/

/**** Window ***/

/* icon and list view */
.caja-notebook .view,
.caja-notebook scrolledwindow.frame {
    border-style: none;
}

/* override for previous setting */
.caja-notebook scrolledwindow.frame .view.dnd {
    border-style: solid;
}

/* list view */
.caja-notebook treeview.view {
    padding: 0px;
}

/* inactive-pane caja */
.caja-notebook .view:disabled {
    background-color: @inactive-pane_bg_color;
}

/* to avoid white pixels from base color */
.caja-notebook {
    background-color: @theme_bg_color;
}

/* caja sidebar */
.caja-side-pane notebook treeview.view,
.caja-side-pane notebook textview.view text,
.caja-side-pane notebook viewport.frame,
.caja-side-pane notebook widget .vertical {
    background-color: shade (@theme_bg_color, 1.08);
}

.caja-side-pane > notebook {
   border-style: solid;
   border-width: 1px;
   border-color: @notebook_border;
}

/* .caja-side-pane alone does not work here to override settings in notebook */
paned.horizontal > box.vertical.caja-side-pane > notebook scrolledwindow.frame {
   border-style: none;
   border-width: 0px;
}

.caja-side-pane treeview,
.caja-side-pane treeview > header > button {
    padding: 0px 0px 0px 0px;
}

/* selected item in sidebar */
.caja-side-pane treeview:selected,
.caja-side-pane treeview:selected:hover {
    background-image: -gtk-gradient (linear,
                                     left top,
                                     left bottom,
                                     from (shade(@sidebar_selected_bg, 0.90)),
                                     color-stop (0.40, shade (@sidebar_selected_bg, 0.98)),
                                     to (shade(@sidebar_selected_bg, 1.05)));
    color:  @theme_selected_fg_color;
    border-radius: 3px;
    border-style: solid;
    border-width: 1px 0px 0px 0px;
    border-color: shade (@sidebar_selected_bg, 0.90) #bbb shade (@sidebar_selected_bg, 1.05);
    text-shadow: none;
}

/* mouse hover item in sidebar */
.caja-side-pane treeview:hover {
    background-image: -gtk-gradient (linear,
                                     left top,
                                     left bottom,
                                     from (shade(@theme_bg_color, 1.05)),
                                     color-stop (0.40, shade (@theme_bg_color, 1.13)),
                                     to (shade(@theme_bg_color, 1.10)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
    color: shade (@theme_fg_color, 0.90);
    border-radius: 3px;
    text-shadow: none;
}

/* Caja places bar */
.caja-side-pane button.flat,
.caja-side-pane button.flat.toggle {
    border-style: none;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (@button_gradient1),
                                     to   (@button_gradient4));
    color: shade(@theme_fg_color, 1.00);
    text-shadow: 0px 1px @theme_shadow_color;
}

.caja-side-pane button.flat {
    padding: 3px;
}

.caja-side-pane button.flat.toggle {
    padding: 0px 3px 0px 6px;
}

.caja-side-pane button.flat.toggle:first-child {
    border-radius: 4px 0 0 4px;
    border-width: 1px 0px 1px 1px;
/* remove left shadow */
    box-shadow: inset  0px  2px alpha(#fff, 0.11),
                inset  2px  0px alpha(#fff, 0.09),
                inset -2px  0px rgba(255,255,255,0), 0 1px rgba(255,255,255,0),
                inset  0px -2px alpha(#fff, 0.07),
                inset  0px  1px alpha(shade(@button_border, 1.00), 0.70),
                inset  1px  0px alpha(shade(@button_border, 0.94), 0.80),
                inset -1px  0px rgba(255,255,255,0), 0 1px rgba(255,255,255,0),
                inset  0px -1px alpha(shade(@button_border, 0.88), 0.90);
}

.caja-side-pane button.flat:last-child {
    border-radius: 0 4px 4px 0;
    border-width: 1px 1px 1px 0px;
    box-shadow: inset  0px  2px alpha(#fff, 0.11),
                inset  2px  0px alpha(#fff, 0.09),
                inset -2px  0px alpha(#fff, 0.09),
                inset  0px -2px alpha(#fff, 0.07),
                inset  0px  1px alpha(shade(@button_border, 1.00), 0.70),
                inset  1px  0px alpha(shade(@button_border, 0.94), 0.80),
                inset -1px  0px alpha(shade(@button_border, 0.94), 0.80),
                inset  0px -1px alpha(shade(@button_border, 0.88), 0.90);
}

.caja-side-pane button.flat:checked:last-child,
.caja-side-pane button.flat.toggle:checked:first-child {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade (@theme_bg_color, 1.20)),
                                     color-stop (0.50, shade (@theme_bg_color, 1.00)),
                                     color-stop (0.50, shade (@theme_bg_color, 0.99)),
                                     to (shade (@theme_bg_color, 0.80)));
}

.caja-side-pane button.flat:hover:last-child,
.caja-side-pane button.flat.toggle:hover:first-child {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@button_gradient1, 1.03)),
                                     to   (shade(@button_gradient4, 1.01)));
}

.caja-side-pane button.flat.toggle:hover:first-child,
.caja-side-pane button.flat.toggle:checked:first-child {
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px rgba(255,255,255,0), 0 1px rgba(255,255,255,0),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

.caja-side-pane button.flat:hover:last-child,
.caja-side-pane button.flat:checked:last-child {
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

.caja-side-pane button.flat.toggle:focus:first-child {
    box-shadow: inset  0px  1px shade(rgb(0,204,133), 1.00),
                inset  1px  0px shade(rgb(0,204,133), 1.00),
                inset -1px  0px rgba(255,255,255,0), 0 1px rgba(255,255,255,0),
                inset  0px -1px shade(rgb(0,204,133), 1.00);
}

.caja-side-pane button.flat:focus:last-child {
    box-shadow: inset  0px  1px shade(rgb(0,204,133), 1.00),
                inset  1px  0px shade(rgb(0,204,133), 1.00),
                inset -1px  0px shade(rgb(0,204,133), 1.00),
                inset  0px -1px shade(rgb(0,204,133), 1.00);
}

/* pathpar toggle button */
.caja-navigation-window button.toggle.image-button,
.caja-navigation-window button.toggle.image-button:checked {
    padding: 4px 4px;
    border-radius: 5px;
}

/* pathbar buttons */
.caja-pathbar button {
    padding: 3px 4px;
}

/* arrow button */
.caja-pathbar button.slider-button:focus,
.caja-pathbar button.slider-button:hover {
    box-shadow: inset  0px  1px shade(rgb(0,204,133), 1.00),
                inset  1px  0px shade(rgb(0,204,133), 1.00),
                inset -1px  0px shade(rgb(0,204,133), 1.00),
                inset  0px -1px shade(rgb(0,204,133), 1.00);
}

.caja-pathbar button.slider-button:nth-child(odd) {
    border-radius: 5px 0px 0px 5px;
    border-width: 1px 0px 1px 1px;
    margin: 0px -2px 0px 3px;
}

.caja-pathbar button.slider-button:nth-child(even) {
    border-radius:  0px 5px 5px 0px;
    border-width: 1px 1px 1px 0px;
    margin: 0px 3px 0px -2px;
}

/* folder buttons */
.caja-pathbar button.toggle.text-button:focus,
.caja-pathbar button.toggle.text-button.image-button:focus,
.caja-pathbar button.toggle.text-button:hover,
.caja-pathbar button.toggle.text-button.image-button:hover {
    box-shadow: inset  0px  1px shade(rgb(0,204,133), 1.00),
                inset  1px  0px shade(rgb(0,204,133), 1.00),
                inset -1px  0px shade(rgb(0,204,133), 1.00),
                inset  0px -1px shade(rgb(0,204,133), 1.00);
}

.caja-pathbar button.toggle.text-button,
.caja-pathbar button.toggle.text-button.image-button {
    margin: 0px -2px 0px -2px;
    border-width: 1px 0px;
    border-radius: 0px;
    padding: 3px 6px;
}

.caja-search-bar entry,
.caja-location-entry {
    padding: 3px;
    border-style: none;
    box-shadow: inset  0px  1px shade (@theme_bg_color, 0.80),
                inset  1px  0px shade (@theme_bg_color, 0.80),
                inset -1px  0px shade (@theme_bg_color, 0.80),
                inset  0px -1px shade (@theme_bg_color, 0.80);
}

.caja-search-bar entry:focus,
.caja-location-entry:focus {
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

/* eventbars, ie. search results */
.caja-notebook box.vertical frame {
    background-color: shade (@theme_bg_color, 1.02);
}

/* needed as this is used for firefox locationbar */
.caja-notebook box.vertical > frame > border {
    border-style: none;
    border-radius: 0px;
}

.caja-notebook #caja-extra-view-widget {
    background-color: shade (@theme_bg_color, 1.05);
    border-color: @notebook_border;
    border-width: 1px 1px 0px 1px;
    border-style: solid;
}

.caja-notebook #caja-extra-view-widget button.flat {
    padding: 4px;
    border-radius: 5px;
}

/* primary-toolbar */
/* zoom buttons */
.caja-navigation-window toolbar.primary-toolbar #Zoom button.flat {
    border-radius: 0px;
    border-style: solid;
    border-width: 1px 0px 1px 0px;
    padding: 0px 4px;
}

.caja-navigation-window toolbar.primary-toolbar #Zoom button.flat:first-child {
    border-radius: 5px 0px 0px 5px;
    border-style: solid;
    border-width: 1px 0px 1px 1px;
    padding: 0px 5px;
}

.caja-navigation-window toolbar.primary-toolbar #Zoom button.flat:last-child {
    border-radius: 0px  5px 5px 0px;
    border-style: solid;
    border-width: 1px 1px 1px 0px;
    padding: 0px 5px;
}

/* ComboBox views */
.caja-navigation-window toolbar.primary-toolbar combobox > .linked > button.combo,
.caja-navigation-window toolbar.primary-toolbar combobox > .linked > button.combo:hover,
.caja-navigation-window toolbar.primary-toolbar combobox > .linked > button.combo:hover:checked {
    padding: 7px 2px 7px 5px;
}

.caja-navigation-window toolbar.primary-toolbar combobox > .linked > button.combo:hover,
.caja-navigation-window toolbar.primary-toolbar combobox > .linked > button.combo:checked {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
}

/* navigation buttons */
.caja-navigation-window toolbar.primary-toolbar #Back button.image-button,
.caja-navigation-window toolbar.primary-toolbar #Forward button.image-button {
    border-radius: 5px 0px 0px 5px;
    border-width: 1px 0px 1px 1px;
}

/* navigation dropdown-menu buttons */
.caja-navigation-window toolbar.primary-toolbar toolbutton button.toggle.popup {
    border-radius: 0px  5px 5px 0px;
    border-width: 1px 1px 1px 0px;
}

.caja-property-browser scrolledwindow viewport.frame {
    background-color: shade (@theme_bg_color, 1.1);
}

/* EelEditableLabel (icon labels) */
.caja-navigation-window .view .entry,
.caja-navigation-window .view .entry:focus,
.caja-desktop.view .entry,
.caja-desktop.view .entry:focus {
   border-image: none;
   border-style: solid;
   border-width: 1px;
   border-color: @theme_fg_color;
   box-shadow: none;
   border-radius: 3px;
   text-shadow: none;
   background-image: -gtk-gradient(linear,
                                   left top, left bottom,
                                   from       (shade(@theme_base_color, 0.86)),
                                   color-stop (0.15, shade(@theme_base_color, 0.96)),
                                   color-stop (0.50, shade(@theme_base_color, 0.98)),
                                   to         (shade(@theme_base_color, 1.00)));
}

.caja-canvas-item {
    border-radius: 4px;
}

/* desktop mode */
.caja-desktop.caja-canvas-item {
    color: white;
    text-shadow: 1px 1px alpha (#000000, 0.8);
}

.caja-desktop.caja-canvas-item:active,
.caja-desktop.caja-canvas-item:hover,
.caja-desktop.caja-canvas-item:selected {
    text-shadow: none;
}

/****************
 * Mate-Panel *
 ****************/

/* first make all transparent */
.mate-panel-menu-bar,
.mate-panel-menu-bar menubar,
.mate-panel-menu-bar menuitem,
#PanelPlug,
#PanelApplet button,
PanelToplevel.background {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: none;
    padding: 0px;
}

/* let's started */
/* the panel bar itself */
#PanelPlug,
.mate-panel-menu-bar,
PanelToplevel.background {
    background-color: @theme_bg_dark_color;
    background-image: none;
    /* normal panel */
    color: @menu_fg_dark_color;
    /* transparent panel light desktop background*/
/*    color: @theme_fg_color; */
    text-shadow: none;
}

PanelToplevel.horizontal.top > grid {
    border-style: outset;
    border-width: 0px 0px 1px 0px;
    border-color: rgba(102, 102, 102, 0.33);
}

PanelToplevel.horizontal.bottom > grid {
    border-style: outset;
    border-width: 1px 0px 0px 0px;
    border-color: rgba(102, 102, 102, 0.33);
}

PanelToplevel.vertical.left > grid {
    border-style: outset;
    border-width: 0px 1px 0px 0px;
    border-color: rgba(102, 102, 102, 0.33);
}

PanelToplevel.vertical.right > grid {
    border-style: outset;
    border-width: 0px 0px 0px 1px;
    border-color: rgba(102, 102, 102, 0.33);
}

/* panel grip */
/* FIXME, border-radius doesn't work any more */
PanelToplevel.background {
    border-radius: 3px;
}

/* hide buttons */
/* horizontal panel */
PanelToplevel.horizontal > grid > button:first-child {
    border-radius: 3px 0px 0px 3px;
}

PanelToplevel.horizontal > grid > button {
    border-radius: 0px 3px 3px 0px;
}

/* vertical panel */
PanelToplevel.vertical > grid > button:first-child {
    border-radius: 3px 3px 0px 0px;
}

PanelToplevel.vertical > grid > button {
    border-radius: 0px 0px 3px 3px;
}

PanelToplevel > grid > button {
    color: @menu_fg_dark_color;
    background-image: none;
    background: transparent;
    border-style: none;
    border-radius: 3px;
    padding: 0px;
    box-shadow: inset  0px  1px alpha(shade(@menu_fg_dark_color, 0.70), 0.80),
                inset  1px  0px alpha(shade(@menu_fg_dark_color, 0.70), 0.80),
                inset -1px  0px alpha(shade(@menu_fg_dark_color, 0.70), 0.80),
                inset  0px -1px alpha(shade(@menu_fg_dark_color, 0.70), 0.80);
}

PanelToplevel > grid > button:hover,
PanelToplevel > grid > button:hover:active {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    text-shadow: none;
    color: shade (@theme_selected_bg_color, 1.6);
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
    border-style: none;
}

PanelSeparator {
    border-width: 0;
    color: transparent;
    background-image: -gtk-scaled(url("assets/panel-grid.svg"));
    background-color: transparent;
    background-repeat: no-repeat;
    background-position: center;
}

/* the grid left from wnckpager and wncktasklist */
MatePanelAppletFrameDBus > MatePanelAppletFrameDBus {
    background-image: -gtk-scaled(url("assets/panel-grid.svg"));
    background-color: transparent;
    background-repeat: no-repeat;
    background-position: left;
}

/* this makes text readable with all kind of wallpapers if using a transparent panel */
#PanelApplet label,
.mate-panel-menu-bar menubar > menuitem {
    color: @menu_fg_dark_color;
    text-shadow: 1px 1px alpha (#000000, 0.8);
}

/* outlines */
window.background, /* selector where outlines are writen on GtkTrayIcon */
.mate-panel-menu-bar menubar,
.mate-panel-menu-bar button,
.mate-panel-menu-bar PanelApplet {
    outline-style: solid;
    outline-offset: -2px;
    outline-color: shade (@theme_selected_bg_color, 1.3);
}

/* menubar */
.mate-panel-menu-bar menu > menuitem,
.mate-panel-menu-bar menubar > menuitem {
    padding: 4px;
}

.mate-panel-menu-bar menubar > menuitem:hover {
    color: shade (@theme_selected_bg_color, 1.3);
}

/* checkboxes in applet popup menu */
.mate-panel-menu-bar menu > menuitem > box > menuitem {
    padding: 0px 0px 0px 4px;
}

/* most applets */
#PanelApplet button,
#PanelApplet button.flat,
#PanelApplet button.toggle
#PanelApplet button.flat.toggle {
    background-image: none;
    background-color: transparent;
    border-color: transparent;
    border-style: solid;
    border-radius: 5px;
    border-width: 1px;
    /* normal panel */
    color: @menu_fg_dark_color;
    /* transparent panel light desktop background*/
/*    color: @theme_fg_color; */
    text-shadow: none;
    box-shadow: none;
    padding: 4px;
}

#PanelApplet button:hover:active,
#PanelApplet button:checked,
#PanelApplet button:checked:hover,
#PanelApplet button.flat:hover:active,
#PanelApplet button.flat:checked,
#PanelApplet button.flat:checked:hover,
#PanelApplet button.toggle:hover:active,
#PanelApplet button.toggle:checked,
#PanelApplet button.toggle:checked:hover,
#PanelApplet button.flat.toggle:hover:active,
#PanelApplet button.flat.toggle:checked,
#PanelApplet button.flat.toggle:checked:hover{
    background-image: none;
    border-color: shade (@theme_selected_bg_color, 1.10);
    background-color: shade (@theme_selected_bg_color, 0.70);
    border-radius: 5px;
    border-width: 1px;
    color: shade (@theme_text_dark_color, 0.90);
    text-shadow: none;
    padding: 4px;
}

#PanelApplet button:hover,
#PanelApplet button.flat:hover,
#PanelApplet button.toggle:hover,
#PanelApplet button.flat.toggle:hover {
    background-image: none;
    border-color: shade (@theme_selected_bg_color, 1.30);
    background-color: shade (@theme_selected_bg_color, 0.90);
    border-radius: 5px;
    border-width: 1px;
    color: @selected_fg_color;
    text-shadow: none;
    padding: 4px;
}

#PanelApplet  #showdesktop-button.toggle,
#PanelApplet  #showdesktop-button.toggle:hover,
#PanelApplet  #showdesktop-button.toggle:hover:active,
#PanelApplet  #showdesktop-button.toggle:checked,
#PanelApplet  #showdesktop-button.toggle:checked:hover,
#PanelApplet  #showdesktop-button.toggle:checked:hover:active {
    padding: 4px 2px;
}

/* dictionary applet */
#PanelApplet entry {
    border-width: 1px;
    margin: 3px 0px;
}

/* clock-applet */
#clock-applet-button.flat.toggle > box.horizontal > label {
    font-weight: normal;
}

#MatePanelPopupWindow {
    border-radius: 4px 4px 4px 4px;
    border-style: none;
    border-width: 0px;
    background-color: rgba(0,0,0,0.5);
}

#MatePanelPopupWindow frame {
    background-color: transparent;
    color: @menu_fg_dark_color;
}

#MatePanelPopupWindow frame > border {
    border-radius: 4px 4px 4px 4px;
    border-style: solid;
    border-width: 1px;
    border-color: shade(@theme_selected_bg_color, 1.3);
}

#MatePanelPopupWindow frame label {
    text-shadow: 1px 1px alpha (#000000, 0.8);
    color: @menu_fg_dark_color;
}

#MatePanelPopupWindow frame image {
    -gtk-icon-shadow: 1px 1px alpha (#000000, 0.8);
}

#MatePanelPopupWindow calendar.view {
    border-color: shade(@theme_selected_bg_color, 1.3);
}

#MatePanelPopupWindow calendar .header {
    background-color:transparent;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (alpha(shade(@theme_bg_dark_color, 1.00) ,0.8)),
                                     to   (alpha(shade(@theme_bg_dark_color, 0.95) ,0.8)));
}

#MatePanelPopupWindow calendar .header {  /* month/year label */
    color: @menu_fg_dark_color;
    text-shadow: 1px 1px alpha (#000000, 0.8);
}

#MatePanelPopupWindow calendar.button {
    color: @menu_fg_dark_color;
    -gtk-icon-shadow: 1px 1px alpha (#000000, 0.8);
}

#MatePanelPopupWindow calendar.button:hover {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (alpha(shade(@menu_bg_dark_color, 2.03), 0.6)),
                                     to   (alpha(shade(@menu_bg_dark_color, 1.17), 0.6)));
    color: shade (@theme_selected_bg_color, 1.3);
}

#MatePanelPopupWindow frame button {
    background-color:transparent;
    background-image: none;
    color: @menu_fg_dark_color;
    text-shadow: 1px 1px alpha (#000000, 0.8);
}

#MatePanelPopupWindow frame button:hover {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (alpha(shade(@menu_bg_dark_color, 2.03), 0.6)),
                                     to   (alpha(shade(@menu_bg_dark_color, 1.17), 0.6)));
    color: shade (@theme_selected_bg_color, 1.3);
}

#MatePanelPopupWindow frame button:hover label {
    color: shade (@theme_selected_bg_color, 1.3);
}

#MatePanelPopupWindow frame expander {
    color: @menu_fg_dark_color;
    text-shadow: 1px 1px alpha (#000000, 0.8);
}

/* Weird, this sets the border color of the clockmap */
#MatePanelPopupWindow > frame > box > box > box > widget {
    color: shade(@theme_selected_bg_color, 1.5);
}

/* drivebutton */
#PanelApplet > grid > button,
#PanelApplet > grid > button:hover {
    padding: 4px;
}

/* window-menu applet, hover is checked !! */
#window-menu-applet-button menubar menuitem {
    padding: 4px 8px;
}

#window-menu-applet-button > menubar > menuitem:hover  {
    background-image: none;
    border-color: shade (@theme_selected_bg_color, 1.30);
    background-color: shade (@theme_selected_bg_color, 0.90);
    border-radius: 5px;
    border-width: 1px;
    color: shade (@theme_text_dark_color, 0.90);
    text-shadow: none;
}

/* WnckPager */
PanelApplet.wnck-applet .wnck-pager {
    background-image: none;
    border-color: transparent;
    background-color: transparent;
    text-shadow: none;
    outline-offset: -1px;
    outline-color: shade (@theme_selected_bg_color, 1.3);
}

/* selected WnckPager */
PanelApplet.wnck-applet .wnck-pager:selected {
    background-image: linear-gradient(to bottom,
                                      @theme_selected_bg_color,
                                      shade (@theme_selected_bg_color, 0.36));
}

/* hover of WnckPager */
PanelApplet.wnck-applet .wnck-pager:hover {
    background-image: linear-gradient(to bottom,
                                      shade (@theme_selected_bg_color, 0.56),
                                      @theme_selected_bg_color);
}

na-tray-applet {
    -NaTrayApplet-icon-padding: 1px; /*any more and outlines get cut off*/
}

/* remove right space a bit */
na-tray-applet > widget > box {
    margin: 1px 3px 1px 1px;
}

/* system-monitor-applet */
.multiload-applet > box.horizontal > box.vertical > frame {
    box-shadow: inset  0px  1px shade (@menu_bg_dark_color, 1.4),
                inset  1px  0px shade (@menu_bg_dark_color, 1.4),
                inset -1px  0px shade (@menu_bg_dark_color, 1.4),
                inset  0px -1px shade (@menu_bg_dark_color, 1.4);
    border-radius: 3px;
}

/* kill light frame border */
.multiload-applet > box.horizontal > box.vertical > frame > border {
    border-color: transparent;
}

/* volume applet */
.mate-panel-applet-slider,
.mate-panel-applet-slider.background {
    background: transparent;
}

.mate-panel-applet-slider frame {
    background-color: rgba(0,0,0,0.5);
    padding: 1px;
    margin: 0px;
    border-radius:4px;
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

.mate-panel-applet-slider frame border {
    border-image: none;
    border-style: none;
}

.mate-panel-applet-slider frame frame {
    background-color:transparent;
    box-shadow: none;
}

/* brightness applet */
.mate-panel-applet-slider frame button {
    padding: 4px 0px;
    background-image: none;
    background-color: transparent;
    border-style: none;
    border-radius:4px;
    color: @theme_fg_dark_color;
    margin: 0px;
}

.mate-panel-applet-slider frame button:disabled {
    box-shadow: none;
}

.mate-panel-applet-slider frame button:hover {
    padding: 4px 0px;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (alpha(shade(@theme_selected_bg_color, 1.43) ,0.6)),
                                     to   (alpha(shade(@menu_bg_dark_color, 0.57) ,0.6)));
}

/* xrandr applet */
.mate-panel-menu-bar menuitem.xrandr-applet:disabled > box > label {
	background-color: transparent;
    color: @menu_fg_dark_color;
    border-color: transparent;
}

/* mate-menu, mintmenu */
#mintmenu.background,
#mate-menu.background {
    background-color: @menu_bg_dark_color;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 1.03)),
                                     to   (shade(@menu_bg_dark_color, 0.97)));
    border-color: shade(@menu_fg_dark_color, 0.3);
    border-width: 1px;
    border-style: solid;
    border-radius:2px;
}

#mintmenu.background viewport,
#mintmenu.background > widget > box > widget > box,
#mate-menu.background viewport,
#mate-menu.background > widget > box > widget > box {
    background-color: @menu_bg_dark_color;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 1.03)),
                                     to   (shade(@menu_bg_dark_color, 0.97)));
}

#mintmenu.background viewport,
#mintmenu.background notebook,
#mate-menu.background viewport,
#mate-menu.background notebook  {
    color: @menu_fg_dark_color;
    border-radius: 0px;
    border-width: 0px;
    border-style: none;
}

#mintmenu.background scrolledwindow,
#mate-menu.background scrolledwindow {
    border-color: shade(@menu_fg_dark_color, 0.3);
    border-width: 1px;
    border-style: solid;
    border-radius: 0px;
}

#mintmenu.background label,
#mate-menu.background label {
    color: @menu_fg_dark_color;
}

#mintmenu.background button,
#mintmenu.background button.flat,
#mate-menu.background button,
#mate-menu.background button.flat {
    color: @menu_fg_dark_color;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
}

#mintmenu.background viewport button:not(.flat) label,
#mintmenu.background button:hover label,
#mintmenu.background viewport button:not(.flat),
#mintmenu.background button:hover,
#mintmenu.background button.flat:hover,
#mate-menu.background viewport button:not(.flat) label,
#mate-menu.background button:hover label,
#mate-menu.background viewport button:not(.flat),
#mate-menu.background button:hover,
#mate-menu.background button.flat:hover {
    color: shade (@theme_selected_bg_color, 2.0);
}

#mintmenu.background viewport button:not(.flat),
#mintmenu.background button:hover,
#mintmenu.background button.flat:hover,
#mate-menu.background viewport button:not(.flat),
#mate-menu.background button:hover,
#mate-menu.background button.flat:hover {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (alpha(shade(@menu_bg_dark_color, 2.03), 0.6)),
                                     to   (alpha(shade(@menu_bg_dark_color, 1.17), 0.6)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

#mintmenu.background button,
#mintmenu.background button.flat,
#mate-menu.background button,
#mate-menu.background button.flat {
    padding: 4px;
}

#mintmenu.background separator,
#mate-menu.background separator {
    border-width: 1px 0px 0px 0px;
    min-height: 1px;
    background-color: shade(@menu_fg_dark_color, 0.3);
    border-image: -gtk-gradient (linear,
                                 left top, right top,
                                 from (alpha (#000, 0.00)),
                                 color-stop (0.25, alpha (#000, 0.03)),
                                 color-stop (0.85, alpha (#000, 0.03)),
                                 to (alpha (#000, 0.00))) 1;
}

#mintmenu.background scrollbar,
#mate-menu.background scrollbar {
    background-image: none;
    border-style: solid;
    border-color: shade(@menu_fg_dark_color, 0.3);
}

#mintmenu.background scrollbar.vertical trough,
#mate-menu.background scrollbar.vertical trough {
    background-image: none;
}

#mintmenu.background scrollbar.vertical slider,
#mate-menu.background scrollbar.vertical slider {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@menu_bg_dark_color, 1.75)),
                                     to (shade (@menu_bg_dark_color, 1.3)));
    border-color: shade(@menu_fg_dark_color, 0.3);
}

#mintmenu.background scrollbar.vertical slider:hover,
#mintmenu.background scrollbar.vertical slider:hover:active,
#mate-menu.background scrollbar.vertical slider:hover,
#mate-menu.background scrollbar.vertical slider:hover:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@menu_bg_dark_color, 1.3)),
                                     to (shade (@menu_bg_dark_color, 1.75)));
    border-color: shade(@menu_fg_dark_color, 0.3);
}

#mintmenu.background scrollbar.vertical.fine-tune slider:hover:active,
#mintmenu.background scrollbar.vertical.fine-tune .slider:hover:active,
#mate-menu.background scrollbar.vertical.fine-tune slider:hover:active,
#mate-menu.background scrollbar.vertical.fine-tune .slider:hover:active {
    background-image: url("assets/slider_fine_vertical.svg"),
                      linear-gradient(to left,
                                      shade(@menu_bg_dark_color, 1.75),
                                      shade(@menu_bg_dark_color, 1.525) 55%,
                                      shade(@menu_bg_dark_color, 1.3));
    background-repeat: no-repeat;
    background-position: center;
    border-color: shade(@menu_fg_dark_color, 0.3);
}

#mintmenu.background scrollbar.vertical button,
#mate-menu.background scrollbar.vertical button {
    padding: 0px;
}

#mintmenu.background scrollbar.vertical button:disabled,
#mate-menu.background scrollbar.vertical button:disabled {
    background-color: transparent;
    color: shade (@insensitive_fg_color, 0.6);
}

#mintmenu.background entry,
#mate-menu.background entry {
    background-color: transparent;
    background-image: -gtk-gradient(linear,
                                    left top, left bottom,
                                    from       (shade(@menu_bg_dark_color, 1.16)),
                                    color-stop (0.15, shade(@menu_bg_dark_color, 1.26)),
                                    color-stop (0.50, shade(@menu_bg_dark_color, 1.28)),
                                    to         (shade(@menu_bg_dark_color, 1.30)));
    color: shade (@menu_fg_dark_color, 1.0);
}

#mintmenu.background entry,
#mintmenu.background entry:focus,
#mate-menu.background entry,
#mate-menu.background entry:focus {
    box-shadow: inset  0px  1px shade(@menu_fg_dark_color, 0.3),
                inset  1px  0px shade(@menu_fg_dark_color, 0.3),
                inset -1px  0px shade(@menu_fg_dark_color, 0.3),
                inset  0px -1px shade(@menu_fg_dark_color, 0.3);
    /* color of the cursor */
	caret-color: shade (@menu_fg_dark_color, 1.0);
}

#mintmenu.background entry selection,
#mintmenu.background entry selection:focus,
#mate-menu.background entry selection,
#mate-menu.background entry selection:focus {
    background-color: shade(@menu_fg_dark_color, 0.4);
    color: shade (@menu_fg_dark_color, 1.2);
}

#mintmenu.background entry menuitem:hover label,
#mate-menu.background entry menuitem:hover label {
    color: shade (@theme_selected_bg_color, 2.0);
}

#mintmenu.background entry menuitem:disabled label,
#mate-menu.background entry menuitem:disabled label {
    color: mix (@menu_fg_dark_color, @menu_bg_dark_color, 0.4);
}

/* globalmenu (vala-panel-appmenu) */
#PanelApplet > .-vala-panel-appmenu-core > scrolledwindow > viewport.frame {
    background-color: transparent;
}

/****************
 * Mate-terminal *
 ****************/

.mate-terminal notebook {
    border-color: @menu_bg_dark_color;
}

/* override for pavu-control */
window.background.mate-terminal > box.vertical > notebook,
window.background.mate-terminal > box.vertical > notebook > header.top,
window.background.mate-terminal > box.vertical > notebook > stack > box {
    border-style: none;
    border-width: 0px;
}

window.background.mate-terminal > box.vertical > notebook > header.top tab,
window.background.mate-terminal > box.vertical > notebook > header.top tab:hover,
window.background.mate-terminal > box.vertical > notebook > header.top tab:checked,
window.background.mate-terminal > box.vertical > notebook > header.top tab:checked:hover {
    margin: 0px -1px 0px -1px;
    border-width: 1px 1px 0 1px;
}

vte-terminal {
    -TerminalWindow-background-darkness: 0.95;
    background-color: @terminal_background_color;
    color: @selected_fg_color;
}

/****************
 * Pluma        *
 ****************/

/* pluma line numbers */
.pluma-window textview {
    background-color: shade (@bg_color, 1.07);
}

/* notebook in view, avoids white pixels from base color */
.pluma-window paned.horizontal > paned.vertical > notebook > header.top {
    border-radius: 0px;
}

/* Pluma status bar */
.pluma-window statusbar.horizontal frame button.flat.toggle {
    border-style: none;
    border-image: none;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@nautilus_cluebar_color, 1.08)),
                                     color-stop (0.45, shade(@nautilus_cluebar_color, 1.00)),
                                     color-stop (0.52, shade(@nautilus_cluebar_color, 0.99)),
                                     to   (shade(@nautilus_cluebar_color, 0.92)));
    box-shadow: inset  0px  2px alpha(#fff, 0.09),
                inset  2px  0px alpha(#fff, 0.07),
                inset -2px  0px alpha(#fff, 0.07),
                inset  0px -2px alpha(#fff, 0.05),
                inset  0px  1px shade(@nautilus_cluebar_color, 0.80),
                inset  1px  0px shade(@nautilus_cluebar_color, 0.70),
                inset -1px  0px shade(@nautilus_cluebar_color, 0.70),
                inset  0px -1px shade(@nautilus_cluebar_color, 0.60);
    border-radius: 4px;
    padding: 2px 5px;
}

.pluma-window statusbar.horizontal frame button.flat.toggle:hover {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@button_gradient1, 1.03)),
                                     color-stop (0.48, shade(@button_gradient2, 1.03)),
                                     color-stop (0.52, shade(@button_gradient3, 1.03)),
                                     to   (shade(@button_gradient4, 1.01)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
    color: shade(@theme_fg_color, 1.00);
}

.pluma-window statusbar.horizontal frame button.flat.toggle:focus {
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}
/* Printpreview */
.pluma-print-preview toolbar.horizontal {
   background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@theme_bg_dark_color, 1.00)),
                                     to   (shade(@theme_bg_dark_color, 0.95)));
    border-image: none;
    border-width: 0px 0px 1px 0px;
    border-radius: 0px;
    border-style: solid;
    border-color: transparent;
    padding: 3px;
    box-shadow: none;
    -GtkWidget-window-dragging: true;
    -GtkToolbar-button-relief: normal;
    color: @theme_fg_dark_color;
}

.pluma-print-preview toolbar.horizontal button {
    box-shadow: none;
}

.pluma-print-preview toolbar.horizontal button:hover {
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

.pluma-print-preview toolbar.horizontal toolbutton button.text-button {
    padding: 0px 10px;
}

.pluma-print-preview toolbar.horizontal toolbutton button.text-button label {
    color: @theme_fg_dark_color;
}

.pluma-print-preview toolbar.horizontal toolitem entry {
    margin: 4px 0px;
}

/* sidebar file-browser */
.pluma-window > box.vertical > paned.horizontal > box.vertical {
    background-image: linear-gradient(to bottom,
                                      shade(@theme_bg_color, 1.14),
                                      shade(@theme_bg_color, 1.1));
    border-radius: 4px 4px 0px 0px;
    border-width: 1px 0px 0px 0px;
    border-style: solid;
    border-color: @notebook_border;
    box-shadow: none;
}

.pluma-window > box.vertical > paned.horizontal > box.vertical > notebook.frame {
    border-radius: 0px;
    border-style: none;
}

/* document notebook */
.pluma-window > box.vertical > paned.horizontal > box.vertical > notebook.frame > stack > box.vertical > scrolledwindow.frame {
    border-bottom-style: none;
}

.pluma-window > box.vertical > paned.horizontal > box.vertical > notebook.frame > stack > box.vertical > toolbar.horizontal button {
    padding: 6px 3px ;
    box-shadow: none;
    border-style:none;
}

.pluma-window > box.vertical > paned.horizontal > box.vertical > notebook.frame > stack > box.vertical > toolbar.horizontal button:hover {
    border-style:none;
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@menu_bg_dark_color, 2.03)),
                                     to   (shade(@menu_bg_dark_color, 1.17)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

/* textview */
.pluma-window paned.horizontal paned.vertical notebook {
    border-style: none;
}

.pluma-window paned.horizontal paned.vertical notebook box.vertical {
    border-style: none;
}

#caja-tab-close-button.flat,
.pluma-window notebook button.flat {
    border-image: none;
    background-image: none;
    background-color: transparent;
    border-radius: 4px;
    border-style: solid;
    border-color: transparent;
    border-width: 1px;
    padding: 1px;
    -gtk-icon-shadow: none;
}

/***********************
 * Mate-Control-Center *
 ***********************/

#MyControlCenter button.flat {
    border-image: none;
    border-radius: 5px;
    padding: 4px;
    outline-style: solid;
    outline-color: shade(@theme_selected_bg_color, 0.93);
    -gtk-outline-radius: 5px;
    outline-offset: -2px;
}

#MyControlCenter button.flat:focus {
    box-shadow: none;
}

/*********
 * Atril *
 *********/

.atril-window paned.horizontal notebook scrolledwindow {
    border-style: none;
}

/* broken text selection */
.atril-window scrolledwindow.frame > widget:selected {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}

.atril-window scrolledwindow.frame > widget:active {
	background-color: shade(@theme_light_unfocused_bg_color, 0.94);
	color: @theme_fg_color;
}

/* atril and eom */
EggToolbarEditor.vertical scrolledwindow {
    border-color: @notebook_border;
    border-width: 1px;
    border-radius: 0px;
    border-style: solid;
}

EggToolbarEditor.vertical scrolledwindow viewport.frame {
    background-color: shade (@base_color, 1.0);
}

/**************
 * mate-media *
 **************/

GvcMixerDialog box.horizontal {
    margin: 0px -3px 0px -3px;
}

GvcMixerDialog box.horizontal box.horizontal frame {
    background-color: shade (@theme_bg_color, 1.1);
    border-color: @notebook_border;
}

GvcMixerDialog box.horizontal box.horizontal frame label {
    padding: 0px 0px 0px 14px;
}

GvcMixerDialog notebook.frame:nth-child(even) {
    border-radius: 3px 3px 0px 0px;
}

GvcMixerDialog notebook.frame frame {
    border-style: none;
}

/* fix weird borders in application page */
GvcMixerDialog notebook.frame scrolledwindow.frame {
    border-style: none;
}

GvcMixerDialog notebook.frame scrolledwindow.frame viewport.frame {
    background-color: shade (@theme_bg_color, 1.1);
}
 /* needed because of 'border-style: none' for application page */
GvcMixerDialog notebook.frame box.vertical frame scrolledwindow.frame {
    border-color: @notebook_border;
    border-style: solid;
}

GvcMixerDialog notebook.frame box.vertical box.horizontal frame label {
    padding: 0px 0px 0px 6px;
}

GvcMixerDialog notebook.frame box.vertical box.horizontal box.horizontal label {
    padding: 0px 0px 0px 6px;
}

GvcMixerDialog notebook.frame box.vertical box.horizontal box.horizontal frame box.horizontal box.horizontal label {
    padding: 0px 0px 0px 10px;
}

/********************************
 * mate-screensaver lock dialog *
 ********************************/

.lock-dialog.background {
    border-radius: 10px;
    border-style: solid;
    border-width: 2px;
    border-color: shade(@theme_dark_dialog_bg_color, 0.8);
    background-color: @theme_dark_dialog_bg_color;
}

.lock-dialog frame border {
    border-radius: 10px;
    border-style: none;
    border-width: 0px;
}

.lock-dialog notebook {
    background-color: @theme_dark_dialog_bg_color;
    color: @theme_text_dark_color;
}

.lock-dialog entry,
.lock-dialog entry:focus,
.lock-dialog textview text {
    background-color: transparent;
    background-image: -gtk-gradient(linear,
                                    left top, left bottom,
                                    from       (shade(@theme_dark_dialog_bg_color, 1.16)),
                                    color-stop (0.15, shade(@theme_dark_dialog_bg_color, 1.26)),
                                    color-stop (0.50, shade(@theme_dark_dialog_bg_color, 1.28)),
                                    to         (shade(@theme_dark_dialog_bg_color, 1.30)));
    color: shade (@menu_fg_dark_color, 1.0);
    box-shadow: inset  0px  1px shade(@theme_dark_dialog_bg_color, 1.6),
                inset  1px  0px shade(@theme_dark_dialog_bg_color, 1.6),
                inset -1px  0px shade(@theme_dark_dialog_bg_color, 1.6),
                inset  0px -1px shade(@theme_dark_dialog_bg_color, 1.6);
    /* color of the cursor */
    caret-color: shade (@theme_text_dark_color, 1.0);
}

.lock-dialog button {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@bg_dark_color, 2.03)),
                                     to   (shade(@bg_dark_color, 1.17)));
    box-shadow: none;
    color: @theme_text_dark_color;
}

.lock-dialog button:hover,
.lock-dialog button.default,
.lock-dialog button:hover:active,
.lock-dialog button:focus {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (shade(@bg_dark_color, 2.03)),
                                     to   (shade(@bg_dark_color, 1.17)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
}

.lock-dialog button,
.lock-dialog button:hover:active {
    border-radius: 0px;
    border-width: 1px 0px 1px 0px;
    margin: 0px -3px 0px -2px;
}

.lock-dialog button:nth-child(first),
.lock-dialog button:nth-child(first):hover:active {
    border-radius: 5px 0px 0px 5px;
    border-width: 1px 1px 1px 1px;
    margin: 0px -4px 0px 0px;
}

.lock-dialog button:nth-child(last),
.lock-dialog button:nth-child(last):hover:active {
    border-radius:  0px 5px 5px 0px;
    border-width: 1px 1px 1px 1px;
    margin: 0px 0px 0px -3px;
}

/******************
 * multimedia OSD *
 ******************/

MsdOsdWindow.background.osd {
    border-radius: 30px;
    border-style: solid;
    border-width: 1px;
}

MsdOsdWindow.background.osd .trough {
    background-color: @osd_trough_bg;
    border-radius: 2px;
}

MsdOsdWindow.background.osd .progressbar {
    background-color: transparent;
    border-radius: 2px;
    border-color: transparent;
    background-image: linear-gradient(to right,
                                      alpha (#000, 0.00),
                                      alpha (#000, 0.00) 48%,
                                      alpha (#004, 0.12) 48%,
                                      alpha (#004, 0.12) 50%,
                                      alpha (#000, 0.00) 50%,
                                      alpha (#000, 0.00) 98%,
                                      alpha (#004, 0.12) 98%,
                                      alpha (#004, 0.12)),
                      linear-gradient(to bottom,
                                      alpha (#000, 0.20),
                                      alpha (#000, 0.05) 50%,
                                      alpha (#000, 0.00)),
                      linear-gradient(to right,
                                      @progressbar_fill_a,
                                      @progressbar_fill_b);
    background-size: 40px auto, auto, auto;
}

/*For mate-settings-daemon noncomposited osd windows*/
MsdOsdWindow.background.osd.msd-osd-window-solid {
	border-radius: 0px;
	border-width: 2px;
	border-style:solid;
	border-color: shade(@button_border_active, 1.10);
}

MsdOsdWindow.background.osd.msd-osd-window-solid progressbar,
MsdOsdWindow.background.osd.msd-osd-window-solid progressbar trough {
	border-radius: 3px;
}

/* mate-keyboard-layout-view, mate-keyboard-layout-chooser */
/* this way it styles only the border of the keys, the bg of the map itself
   use the .view class, and use old and new selectors for a while */
matekbd-keyboard-drawing,
.gswitchit-layout-view > box.dialog-vbox > box.vertical > widget,
#xkb-layout-chooser > box.dialog-vbox > box.vertical > box.vertical > frame > widget {
    background-color: shade (@theme_bg_color, 1.0);
}

#xkb-layout-chooser > box.dialog-vbox > box.vertical > box.vertical > frame > border {
    border-radius: 0px;
}

/* fix for some maximized windows 
   https://github.com/mate-desktop/mate-desktop/issues/291
   FIXME Sadly pluma ignore doesn't show the maximised style class */

window.background.maximized.engrampa-window > grid.horizontal > paned.horizontal > scrolledwindow.frame,
window.background.maximized.atril-window > box.vertical > paned.horizontal > box.vertical > scrolledwindow.frame,
window.background.pluma-window > box.vertical > paned.horizontal > paned.vertical > notebook box.vertical > scrolledwindow.frame,
window.background.maximized.logview-window > box.vertical > paned.horizontal > box.vertical > scrolledwindow.frame,
window.background.maximized.caja-navigation-window notebook.caja-notebook scrolledwindow.frame {
    border-right-width: 0px;
}

/************
 * engrampa *
 ************/

.engrampa-window toolbar toolitem entry:disabled {
    box-shadow: none;
}

/***************************
 * mate-display-properties *
 ***************************/

foo-scroll-area:selected,
foo-scroll-area:selected:focus,
foo-scroll-area:selected:backdrop {
	background-color: @theme_selected_bg_color;
}

