style "theme-panel"
{
	xthickness = 4 # The spacing (padding) inside and between applets. Add a lower value for a more compact look.
	ythickness = 0

# Disable for normal backgrounds and transparancy panel with dark DE backgrounds.
#	bg_pixmap[NORMAL] = "/Panel/panel-bg.png" 

	base[NORMAL]        = @bg_color
	base[PRELIGHT]      = shade (1.06, @bg_color)
	base[INSENSITIVE]   = @bg_color
	bg[NORMAL]          = @bg_color_dark
	bg[PRELIGHT]        = shade (2.60, @bg_color_dark)
#	bg[SELECTED]        = shade (0.90, @selected_bg_color)
	bg[INSENSITIVE]     = @bg_color
#	bg[ACTIVE]          = shade (0.8, @bg_color_dark)
	fg[NORMAL]          = "#f5f5f5"
	fg[PRELIGHT]        = shade (1.60, @selected_bg_color)
	fg[INSENSITIVE]     = shade (0.75, @text_color_dark)
	fg[ACTIVE]          = "#f5f5f5"
	text[NORMAL]        = "#CFCFCF"
	text[PRELIGHT]      = shade (1.60, @selected_bg_color)
	text[INSENSITIVE]   = shade (0.75, @text_color_dark)
	text[ACTIVE]        = "#f5f5f5"

	engine "murrine" {

	}
}

style "theme-panel-light"
{
	xthickness = 1
	ythickness = 0

	fg[NORMAL] = @fg_color

	engine "murrine" {
		textstyle = 0
		roundness = 0
	}
}

style "theme-panel-buttons"
{
	engine "pixmap" {
		image {
			function	= BOX
			recolorable	= TRUE
			state		= NORMAL
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= PRELIGHT
			file		= "Panel/panel-button-hover.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= ACTIVE
			file		= "Panel/panel-button-active.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= SELECTED
			file		= "Panel/panel-button-active.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= INSENSITIVE
		}
		image {
			function	= ARROW
			recolorable	= TRUE
			arrow_direction	= DOWN
		}
	}
}

style "theme-panel-text"
{
	bg[NORMAL]        = @bg_color_dark
	fg[NORMAL]        = "#f5f5f5"
	fg[PRELIGHT]      = shade (1.60, @selected_bg_color)
	fg[INSENSITIVE]   = shade (0.75, @text_color_dark)
	fg[ACTIVE]        = "#f5f5f5"
	text[NORMAL]      = "#f5f5f5"
	text[PRELIGHT]    = "#ffffff"
	text[INSENSITIVE] = shade (0.75, @text_color_dark)
	text[ACTIVE]      = "#f5f5f5"
}

style "theme-main-menu-text" = "theme-panel-text"
{
	bg[NORMAL]			= @bg_color_dark
	fg[NORMAL]			= "#f5f5f5"
	fg[PRELIGHT]		= "#ffffff"
	fg[INSENSITIVE]		= shade (0.75, @text_color_dark)
	fg[ACTIVE]			= "#f5f5f5"
	text[NORMAL]		= "#f5f5f5"
	text[PRELIGHT]		= "#ffffff"
	text[INSENSITIVE] 	= shade (0.75, @text_color_dark)
	text[ACTIVE]		= "#f5f5f5"
}

style "theme-panel-handle" 
{
	engine "pixmap" {    
		image {
			function = HANDLE
		}    
		image {
			function = HANDLE
		}
	}
}

style "workspace-switcher"
{
	bg[SELECTED] = shade (1.1, @selected_bg_color)
	bg[PRELIGHT] = shade (1.4, @selected_bg_color)
}

# syncronize panel menus
style "applet"
{
}

widget "*PanelWidget*"			style "theme-panel"
#widget "*PanelApplet*"			style "theme-panel"
widget "*fast-user-switch*"		style "theme-panel"
widget "*CPUFreq*Applet*"		style "theme-panel"
widget "*indicator-applet*"		style "theme-panel"
class "PanelApp*"			style "theme-panel"
class "PanelToplevel*"			style "theme-panel"
widget_class "*PanelToplevel*"		style "theme-panel"
widget_class "*notif*"			style "theme-panel"
widget_class "*Notif*"			style "theme-panel"
widget_class "*Tray*"			style "theme-panel" 
widget_class "*tray*"			style "theme-panel"
widget_class "*computertemp*"		style "theme-panel"
widget_class "*Applet*Tomboy*"		style "theme-panel"
widget_class "*Applet*Netstatus*"	style "theme-panel"
widget "*WnckPager*"	    	    style "workspace-switcher"

# syncronize panel menus
widget_class "*MatePanelAppletFrameDBus*" style "applet"
widget "*PanelApplet*"				style "applet"

# Fixes for tooltip text in some apps.
widget_class "*Notif*Beagle*"	style "theme-panel-light"
widget_class "*Notif*Brasero*"	style "theme-panel-light"

# XFCE panel theming.
widget "*Xfce*Panel*"	style "theme-panel"
class "*Xfce*Panel*"	style "theme-panel"

# Panel buttons
widget_class "*Panel*GtkToggleButton"	style:highest "theme-panel-buttons"
#widget_class "*Panel*GtkButton"		style:highest "theme-panel-buttons"

# XFCE panel buttons
widget "*Xfce*Panel*Button*"		style:highest "theme-panel-buttons"
class "*Xfce*Panel*Button*"		style:highest "theme-panel-buttons"

# lxpanel and fbpanel
widget "*.tclock.*"		style "theme-panel"
widget "*.taskbar.*"		style "theme-panel"
widget_class "*GtkBgbox*"	style "theme-panel"

# Make sure panel text color doesn't change
widget_class "*Panel*MenuBar*"		style "theme-main-menu-text"
widget_class "*Panel*<GtkMenuBar>*"	style "theme-main-menu-text"
widget "*.clock-applet-button.*"	style "theme-panel-text"
widget "*PanelApplet*"			style "theme-panel-text"

# Hide ugly handle
class "PanelAppletFrame" style:highest "theme-panel-handle"

# The following removes the arrows from the panel

style "panel-arrow-remove" {
engine "pixmap" {
	image {
		function	= ARROW
		recolorable	= TRUE
		overlay_file	= "Panel/arrow-blank.png"
		overlay_border	= {2,2,2,2}
		overlay_stretch	= FALSE
		arrow_direction	= UP
		}
	image {
		function	= ARROW
		recolorable	= TRUE
		overlay_file	= "Panel/arrow-blank.png"
		overlay_border	= {2,2,2,2}
		overlay_stretch	= FALSE
		arrow_direction	= DOWN
		}
	}
}

widget_class "*PanelToplevel*" style "panel-arrow-remove"

# Fix xfce-notifyd button
style "xfce-notifyd-button" {
	fg[NORMAL]	= @text_color
	fg[PRELIGHT]	= @text_color
	fg[ACTIVE]	= @text_color
}
