/* ###################################################################
 * Section common with Gnome Shell
 * ... contains a few cinnamon specific styles (rare occurences) 
 * ###################################################################*/

stage {
	font-family: /*cantarell, */sans-serif;
	font-size: 9pt;
	color: #fff;
}

.cinnamon-link {
	color: #0000ff;
	text-decoration: underline;
}

.cinnamon-link:hover {
	color: #565656;
}

.label-shadow {
	color: rgba(0,0,0,0);
}

StScrollBar {
	padding: 0px;
}

StScrollView.vfade {
	-st-vfade-offset: 21px;
}

StScrollView StScrollBar {
	min-width: 8px;
	min-height: 16px;
}

StScrollBar StBin#trough {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(0,0,0,0.6);
	background-gradient-end: rgba(150,150,150,0.6);
	border-radius: 4px;
}


StScrollBar StButton#vhandle
{
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(250,250,250,0.9);
	background-gradient-end: rgba(50,50,50,0.7);
	border-radius: 4px;
}

StScrollBar StButton#hhandle
{
	background-gradient-direction: vertical;
	background-gradient-start: rgba(250,250,250,0.9);
	background-gradient-end: rgba(50,50,50,0.7);
	border-radius: 4px;
}

StScrollBar StButton#vhandle:hover
{
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(250,250,250,0.9);
	background-gradient-end: rgba(100,100,100,0.9);
}

StScrollBar StButton#hhandle:hover
{
	background-gradient-direction: vertical;
	background-gradient-start: rgba(250,250,250,0.9);
	background-gradient-end: rgba(100,100,100,0.9);
}

#Tooltip {
	border-radius: 4px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.8);
	background-gradient-end: rgba(0,0,0,0.7);
	border: 1px solid rgba(0,0,0,0.3);
	color: rgba(255,255,255,0.98);
	padding: 4px;
	font-family: "Bitstream Charter", serif;
	font-size: 10pt; /*8.5pt;*/
	font-weight: bold;
	font-style: italic;
	text-align: center;
}

/* ===================================================================
 * Shared button properties 
 * ===================================================================*/

.notification-button,
.notification-icon-button,
.hotplug-notification-item,
.modal-dialog-button {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(150, 150, 150, 0.7);
	background-gradient-end: rgba(0, 0, 0, 0.7);
	border: 1px solid rgba(0, 0, 0, 0.2);
	border-radius: 4px;
	font-weight: bold;
	font-size: 8.5pt;
	padding: 4px 15px 4px;
	text-align: center;
	transition-duration: 100;
	text-shadow: rgba(0,0,0,0.9) 0px 1px 0px;
}

.notification-button:hover,
.notification-icon-button:hover,
.hotplug-notification-item:hover,
.modal-dialog-button:hover {
	background-gradient-start: rgba(102, 102, 102, 0.7);
	background-gradient-end: rgba(26, 26, 26, 0.7);
}

.notification-button:focus,
.notification-icon-button:focus,
.hotplug-notification-item:focus,
.modal-dialog-button:focus {
	box-shadow: inset 1px 1px 2px 0px rgba(255,255,255,0.43);
	border: 1px solid rgba(0, 0, 0, 0.0);
}

.hotplug-resident-eject-button {
	padding: 7px;
	border-radius: 5px;
	color: #ccc;
	transition-duration: 100;
}

.hotplug-resident-eject-button:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(102, 102, 102, 0.7);
	background-gradient-end: rgba(26, 26, 26, 0.7);
}

.notification-button:active,
.notification-icon-button:active,
.hotplug-notification-item:active,
.hotplug-resident-eject-button:active,
.modal-dialog-button:active,
.modal-dialog-button:pressed {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0, 0, 0, 0.7);
	background-gradient-end: rgba(150, 150, 150, 0.7);
}

/* ===================================================================
 * PopupMenu (popupMenu.js) 
 * ===================================================================*/
/* .popup-menu-boxpointer and .popup-menu are kept for compatibility
    with cinnamon version under 3.2. Use .menu in version 3.2 and above */
.popup-menu-boxpointer {
	-arrow-border-radius: 16px;
	-arrow-background-color: rgba(0,0,0,0.0);
	-arrow-border-color: rgba(0,0,0,0.0);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(50,50,50,0.7);
	background-gradient-end: rgba(0,0,0,0.7);
	box-shadow: 1px 4px 10px 4px rgba(0,0,0,0.6);
	padding: 2px 0px 0px 2px;
}

.popup-menu {
	color: #ffffff;
	font-size: 8pt;
	min-width: 85px;
	border-radius: 5px;
	padding: 4px;
}

.menu {
	background-color: rgba(0,0,0,0.0);
	border-color: rgba(0,0,0,0.0);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(50,50,50,0.7);
	background-gradient-end: rgba(0,0,0,0.7);
	box-shadow: 1px 4px 10px 4px rgba(0,0,0,0.6);
	padding: 2px 0px 0px 2px;
	color: #ffffff;
	font-size: 8pt;
	min-width: 85px;
	border-radius: 5px;
	padding: 4px;
}


.popup-submenu-menu-item:open {
	background-color: transparent;
}

.popup-sub-menu {
	background-color: rgba(0,0,0,0.5);
	font-weight: bold;
	text-align: center;
	border-radius: 4px;
	border: 1px solid rgba(255,255,255,0.5);
}

.popup-sub-menu .popup-menu-item:ltr {
	padding-right: 0em;
}

.popup-sub-menu .popup-menu-item:rtl {
	padding-left: 0em;
}

.popup-sub-menu StScrollBar {
	padding: 4px;
}

.popup-sub-menu StScrollBar StBin#trough {
	border-width: 0px;
}

.popup-sub-menu StScrollBar StBin#vhandle {
	background-color: #4c4c4c;
	border-width: 0px;
}

.popup-combo-menu {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(101,101,101,0.9);
	background-gradient-end: rgba(0,0,0,0.9);
	color: #ffffff;
	border: 1px solid rgba(169,169,169,0.7);
	border-radius: 4px;
	padding: 4px;
	/*box-shadow: 0px 0px 10px 4px rgba(0,0,0,0.6);*/
}


.popup-menu-item.status-chooser-combo
 {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(150,150,150,0.5);
	background-gradient-end: rgba(0,0,0,0.3);
	/*font-size: 8.5pt;
	font-weight: bold;
	color: #ffffff;*/
	border-radius: 4px;
	/* don't move when hovering */
	border: 1px solid rgba(0,0,0,0.3);
	box-shadow: inset 0px 1px 1px 0px rgba(255,255,255,0.5);
	/*padding: 0.4em 1.4em;*/
}

/* The remaining popup-menu sizing is all done in ems, so that if you
 * override .popup-menu.font-size, everything else will scale with it.
 */
.popup-menu-content {
	padding: 0.3em 0.3em;
	padding-left: 0.2em;
	padding-right: 0.2em;
}

.popup-menu-item {
	color: #ffffff;
	font-size: 8.5pt;
	font-weight: bold;
	padding: 0.5em 1.5em;
	spacing: 1em;
}

.popup-menu-item:active {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.9);
	background-gradient-end: rgba(128,128,128,0.8);
	color: #000000;
	border-radius: 4px;
	border: 1px solid rgba(0,0,0,0.1);
	box-shadow: inset 0px 1px 1px 0px rgba(255,255,255,0.5);
	padding: 0.4em 1.4em;
}

.popup-menu-item:insensitive {
	color: #9f9f9f;
}

.popup-image-menu-item {
}

.popup-combobox-item {
	spacing: 1em;
}

.popup-separator-menu-item {
	-gradient-height: 1px;
	-gradient-start: rgba(255,255,255,0.0);
	-gradient-end: rgba(255,255,255,0.3);
	-margin-horizontal: 0.5em;
	height: 1em; 
}

.popup-alternating-menu-item:alternate {
	font-weight: bold;
}

.popup-slider-menu-item {
	height: 1em;
	min-width: 13em;
	-slider-height: 0.3em;
	-slider-background-color: rgba(0,0,0,0.7);
	-slider-border-color: rgba(255,255,255,0.6);
	-slider-active-background-color: rgba(255,255,255,0.8);
	-slider-active-border-color: rgba(255,255,255,0.4);
	-slider-border-width: 1px;
	-slider-handle-radius: 0.5em;
}

.popup-device-menu-item {
	spacing: .5em;
}

.popup-inactive-menu-item {
	font-weight: normal;
	color: #999;
}

.popup-subtitle-menu-item {
	font-weight: bold;
}

.popup-menu-icon {
	icon-size: 1.14em;
}

/* Switches (to be used in menus) */
.toggle-switch {
	width: 65px;
	height: 22px;
}

.toggle-switch-us {
	background-image: url("toggle-off-us.png");
	background-size: contain;
}
.toggle-switch-us:checked {
	background-image: url("toggle-on-us.png");
	background-size: contain;
}

.toggle-switch-intl {
	background-image: url("toggle-off-intl.png");
	background-size: contain;
}
.toggle-switch-intl:checked {
	background-image: url("toggle-on-intl.png");
	background-size: contain;
}

.nm-menu-item-icons {
	spacing: .3em;
}

/* ===================================================================
 * Panel (panel.js)
 * ===================================================================*/

#panel {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(88,88,88,0.7);
	background-gradient-end: rgba(0,0,0,0.6);
	color: rgba(255,255,255,0.98);
	border-left: 0px;
	border-right: 0px;
	height: 24px;
	font-family: "Bitstream Charter", serif;
	font-size: 10pt;
}

#panelLeft,
#panelCenter {
	spacing: 4px;
	font-weight: bold;
}

#panelLeft:dnd {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,0,0,0.05);
	background-gradient-end: rgba(255,0,0,0.2);
}

#panelCenter:dnd {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,255,0,0.05);
	background-gradient-end: rgba(0,255,0,0.2);
}

#panelRight:dnd {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,255,0.05);
	background-gradient-end: rgba(0,0,255,0.2);
}

#panelLeft:ltr {
	padding-right: 4px;
}

#panelLeft:rtl {
	padding-left: 4px;
}

#panelRight:ltr { 
	padding-left: 4px;
}

#panelRight:rtl {
	padding-left: 4px;
}

.panel-top {
	box-shadow: 0px 3px 12px rgba(0,0,0,0.9);
	border-top: 0px;
}

.panel-bottom {
	background-gradient-start: rgba(80,80,80,0.7);
	background-gradient-end: rgba(0,0,0,0.8);
	box-shadow: 0px -3px 12px rgba(0,0,0,0.9);
	border-bottom: 0px;
}

.panel-status-button {
	-natural-hpadding: 5px;
	-minimum-hpadding: 5px;
	font-weight: bold;
	height: 16px;
	transition-duration: 100;
}

.panel-status-button:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
}

.system-status-icon {
	icon-size: 1.14em;
}

.panel-corner {
	-panel-corner-radius: 0px;
	-panel-corner-inner-border-width: 0px;
	-panel-corner-outer-border-width: 0px;
}

.panel-corner:active,
.panel-corner:overview,
.panel-corner:focus {
}

#appMenu {
	spacing: 4px;
}

.panel-button #appMenuIcon {
	app-icon-bottom-clip: 0px;
}

.panel-button:active #appMenuIcon,
.panel-button:checked #appMenuIcon,
.panel-button:focus #appMenuIcon {
	app-icon-bottom-clip: 1px;
}

.panel-button {
	-natural-hpadding: 9px;
	-minimum-hpadding: 4px;
	transition-duration: 100;
	border-radius: 3px;
}

.panel-button:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	transition-duration: 250;
}

.panel-button:active,
.panel-button:overview,
.panel-button:focus {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.4);
	background-gradient-end: rgba(255,255,255,0.4);
	box-shadow: inset 0px 1px 3px 0px rgba(0,0,0,0.2);
	color: white;
	text-shadow: rgba(0,0,0,0.2) 0px -1px 0px;
}

.panel-status-button:active,
.panel-status-button:checked,
.panel-status-button:focus {
	background-image: url("panel-button-highlight-narrow.svg");
}

.panel-button:active > .system-status-icon,
.panel-button:checked > .system-status-icon,
.panel-button:focus > .system-status-icon {
	icon-shadow: black 0px 2px 2px;
}

/* specifying -boxpointer-gap here doesn't work */
.panel-menu {
	-boxpointer-gap: 2px
}

.popup-menu-item-dot {
}

.system-status-icon {
	icon-size: 1.14em;
}

/* ===================================================================
 * Overview 
 * ===================================================================*/

#overview {
	spacing: 12px;
}

.window-caption {
	spacing: 50px;
	-shell-caption-spacing: 10px;
	background-gradient-direction: vertical;
	background-gradient-end: rgba(255,255,255,0.04);
	background-gradient-start: rgba(255,255,255,0.5);
	border-radius: 4px;
	border: 1px solid rgba(0,0,0,0.1);
	box-shadow: inset 0px 1px 1px 0px rgba(255,255,255,0.2);
	color: rgba(255,255,255,0.8);
	font-size: 8.5pt;
	font-weight: bold;
	padding: 4px 15px;
	text-align: center;
	text-shadow: rgba(0,0,0,0.4) 0px 1px 0px;
}

.window-caption#selected {
	background-gradient-start: rgba(130,130,130,0.7);
	background-gradient-end: rgba(255,255,255,0.8);
	border: 1px solid rgba(255,255,255,0.4);
	box-shadow: inset 0px 1px 1px 0px rgba(255,255,255,0.4);
	color: black;
}

.workspace-controls {
	visible-height: 20px; /* Amount visible before hovering */
}

.workspace-thumbnails-background {
	padding: 10px;
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(255,255,255,0.1);
	background-gradient-end: rgba(255,255,255,0.2);
	border: 1px solid rgba(0,0,0,0.2);
	box-shadow: inset 1px 0px 0px 0px rgba(255,255,255,0.2);
	border-radius: 4px 0px 0px 4px;
	border-right:none;
}

.workspace-thumbnails-background:rtl {
	border-right: 1px;
	border-left: 0px;
	border-radius: 0px 4px 4px 0px;
}

.workspace-thumbnails {
	spacing: 14px;
}

.workspace-add-button {
	background-image: url("add-workspace.png");
	height: 200px;
	width: 35px;
	transition-duration: 300;
}

.workspace-add-button:hover {
	background-image: url("add-workspace-hover.png");
	transition-duration: 300;
}

.workspace-close-button,
.window-close {
	background-image: url("close.svg");
	height: 34px;
	width: 34px;
	transition-duration: 100;
	-cinnamon-close-overlap: 20px;
}

.window-close:rtl {
	-st-background-image-shadow: 2px 2px 6px rgba(0,0,0,0.5);
}

.window-close-area {
	background-image: url("trash-icon.png");
	background-color: rgba(0, 0, 0, 0.6);
	border: 1px solid rgba(30,30,30,0.5);
	border-bottom-width: 0px;
	border-radius: 20px 20px 0px 0px;
	height: 120px;
	width: 400px;
}

.icon-grid {
	spacing: 36px;
	-cinnamon-grid-item-size: 100px;
}

.icon-grid .overview-icon {
	icon-size: 64px;
}

.overview-icon {
	border-radius: 4px;
	padding: 3px;
	border: 1px rgba(0,0,0,0);
	font-size: 7.5pt;
	color: white;
	transition-duration: 100;
	text-align: center;
}

.expo-background {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.6);
	background-gradient-end: rgba(0,0,0,0.6);
}

/* ===================================================================
 * ViewSelector 
 * ===================================================================*/
#viewSelector {
	spacing: 1em;
	font-size: 12pt;
}

#viewSelectorTabBar {
	padding: 1em;
}

.view-tab-title {
	color: #8a8a8a;
	font-weight: bold;
	padding: 0px 0.75em;
	height: 1.5em;
}

.view-tab-title:hover {
	color: #bbb;
}

.view-tab-title:selected {
	color: #000000;
	background-color: #cdcdcd;
	border-radius: 3px;
}

/* ===================================================================
 * Looking Glass 
 * ===================================================================*/

#LookingGlassDialog {
	background-color: rgba(0,0,0,0.85);
	spacing: 4px;
	padding: 4px;
	border: 2px solid rgba(255,255,255,0.3);
	border-radius: 4px;
	color: #88ff66;
}

#LookingGlassDialog > #Toolbar {
	border: 1px solid grey;
	border-radius: 4px;
}

#LookingGlassDialog .labels {
	spacing: 4px;
}

#LookingGlassDialog .notebook-tab {
	-natural-hpadding: 12px;
	-minimum-hpadding: 6px;
	font-weight: bold;
	padding-left: .4em;
	padding-right: .4em;
}

#LookingGlassDialog .notebook-tab:hover {
	color: white;
}

#LookingGlassDialog .notebook-tab:selected {
	border: 1px solid #88ff66;
	border-radius: 2px;
	padding: 2px 3px;
}

#LookingGlassDialog .lg-inspector-title {
	font-weight: bold;
	padding-bottom: 8px;
}

.lg-dialog StLabel {
	color: white;
}

.lg-dialog StEntry {
	color: #88ff66;
	selection-background-color: #88ff66;
	selected-color: black;
}

.lg-obj-inspector-title {
	spacing: 4px;
}

.lg-obj-inspector-button {
	border: 1px solid #88ff66;
	padding: 4px;
	border-radius: 4px;
}

.lg-obj-inspector-button:hover {
	border: 1px solid white;
}

.lg-dialog .cinnamon-link {
	color: #79c3ff;
}

.lg-dialog .cinnamon-link:hover {
	color: #dddddd;
}

#LookingGlassDialog StBoxLayout#EvalBox {
	padding: 4px;
	spacing: 4px;
}

#LookingGlassDialog StBoxLayout#ResultsArea {
	spacing: 4px;
}

#lookingGlassExtensions {
	padding: 4px;
}

.lg-extension-list {
	padding: 4px;
	spacing: 6px;
}

.lg-extension {
	border: 1px solid #6f6f6f;
	border-radius: 4px;
	padding: 4px
}

.lg-extension-name {
	font-weight: bold;
}

.lg-extension-meta {
	spacing: 6px;
}

#LookingGlassPropertyInspector {
	background: rgba(0, 0, 0, 0.9);
	border: 2px solid grey;
	border-radius: 4px;
	padding: 6px;
	color: #88ff66;
}

/* ===================================================================
 * Date applet 
 * ===================================================================*/

.calendar {
	padding: .2em .2em;
	spacing-rows: 2px;
	spacing-columns: 2px;
}

.calendar-month-label {
	color: rgba(255,255,255,0.9);
	font-size: 8pt;
	font-weight: bold;
	text-shadow: rgba(0,0,0,0.7) 1px 1px 0px;
}

.calendar-change-month-back {
	background-image: url("calendar-arrow-left.svg");
	height: 20px;
	width: 20px;
	border-radius: 3px;
}

.calendar-change-month-back:rtl {
	background-image: url("calendar-arrow-right.svg");
}

.calendar-change-month-back:hover {
	background-color: rgba(255,255,255,0.2);
}

.calendar-change-month-back:active {
	background-color: rgba(255,255,255,0.3);
}

.calendar-change-month-forward {
	background-image: url("calendar-arrow-right.svg");
	height: 20px;
	width: 20px;
	border-radius: 3px;
}

.calendar-change-month-forward:rtl {
	background-image: url("calendar-arrow-left.svg");
}


.calendar-change-month-forward:hover {
	background-color: rgba(255,255,255,0.2);
}

.calendar-change-month-forward:active {
	background-color: rgba(255,255,255,0.3);
}

.datemenu-date-label {
	color: rgba(255,255,255,0.6);
	font-size: 8pt;
	font-weight: bold;
	padding: 0.4em 0.4em;
}

.calendar-day-base {
	border-radius: 4px;
	color: rgba(255,255,255,1);
	font-size: 8pt;
	height: 2.3em;
	width: 2.3em;
	text-align: center;
}

.calendar-day-base:hover {
	background: rgba(255,255,255,0.7);
	color: #000;
}

.calendar-day-base:active {
	background: rgba(255,255,255,0.9);
	color: #000;
}

.calendar-day-heading {
	font-weight: bold;
	color: rgba(255,255,255,0.8);
	text-shadow: rgba(0,0,0,0.7) 1px 1px 0px;
}

.calendar-week-number {
	color: rgba(255,255,255,0.8);
	font-size: 7pt;
}

/* Hack used in lieu of border-collapse - see calendar.js */
.calendar-day {
	border: 1px solid rgba(0,0,0,0.3);
	color: rgba(255,255,255,0.9);
	border-top-width: 0;
	border-left-width: 0;
	font-weight: bold;
	border-radius: 4px;
	box-shadow: inset 0px 1px 1px 0px rgba(255,255,255,0.3);
	text-shadow: rgba(0,0,0,0.5) 0px -1px 0px;
}

.calendar-day-top {
	border-top-width: 1px;
}

.calendar-day-left {
	border-left-width: 1px;
}

.calendar-work-day {
}

.calendar-nonwork-day {
	background-color: rgba(255,255,255,0.1);
}

.calendar-today {
	color: #ffffff;
	font-weight: bold;
	background-color: rgba(170,170,170,0.7);
	border-radius: 4px;
}

.calendar-other-month-day {
	color: rgba(255,255,255,0.4);
	font-weight: bold;
	font-size: 7pt;
}

.calendar-day-with-events {
	font-weight: bold;
}

/* ===================================================================
 * Notifications
 * ===================================================================*/

#notification {
	background-gradient-direction: vertical;
	background-gradient-end: rgba(0,0,0,0.7);
	background-gradient-start: rgba(0,0,0,0.8);
	/*box-shadow: inset 0px 1px 1px 0px rgba(153,153,153,0.5);*/
	border: 1px solid rgba(70,70,70,0.7);
	border-radius: 5px;
	padding: 10px;
	spacing-rows: 10px;
	spacing-columns: 10px;
	width: 34em;
	margin-from-right-edge-of-screen: 30px;
	color: white;
}

#notification.multi-line-notification {
	padding-bottom: 8px;
	color: white;
}

/* We use row-span = 2 for the image cell, which prevents its height preferences to be
	taken into account during allocation, so its height ends up being limited by the height
	of the content in the other rows. To avoid showing a stretched image, we set the minimum
	height of the table to be ICON_SIZE + IMAGE_SIZE + spacing-rows = 24 + 125 + 10 = 159 */
.notification-with-image {
	min-height: 159px;
	color: white;
}

#notification-scrollview {
	max-height: 10em;
}

#notification-scrollview > .top-shadow, #notification-scrollview > .bottom-shadow {
	height: 1em;
}

#notification-scrollview:ltr > StScrollBar {
	padding-left: 5px;
}

#notification-scrollview:rtl > StScrollBar {
	padding-right: 5px;
}

#notification-body {
	spacing: 5px;
}

#notification-actions {
	spacing: 10px;
}

.notification-button {
	border-radius: 3px;
	padding: 5px 30px;
}

.notification-button:focus {
}

.notification-icon-button {
	border-radius: 3px;
	padding: 5px;
}

.notification-icon-button:focus {
}

.notification-icon-button > StIcon {
	icon-size: 36px;
}

.hotplug-transient-box {
	spacing: 6px;
	padding: 2px 72px 2px 12px;
}

.hotplug-notification-item {
	padding: 2px 10px;
	border-radius: 18px;
	font-size: 10.5pt;
}

.hotplug-notification-item:focus {
	padding: 1px 71px 1px 11px;
}

.hotplug-notification-item-icon {
	icon-size: 24px;
	padding: 2px 5px;
}

.hotplug-resident-box {
	spacing: 8px;
}

.hotplug-resident-mount {
	spacing: 8px;
	border-radius: 4px;
	color: #ccc;
}

.hotplug-resident-mount:hover {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(255, 255, 255, 0.1);
	background-gradient-end: rgba(255, 255, 255, 0);
	color: #fff;
}

.hotplug-resident-mount-label {
	color: inherit;
	padding-left: 6px;
}

.hotplug-resident-mount-icon {
	icon-size: 24px;
	padding-left: 6px;
}

.hotplug-resident-eject-icon {
	icon-size: 16px;
}

.hotplug-resident-eject-button {
	padding: 7px;
	border-radius: 5px;
	color: #ccc;
}

#notification StEntry {
	padding: 4px 7px;
	border-radius: 15px;
	color: #a6a6a6;
	selected-color: black;
	border: 1px solid rgba(0,0,0,0.1);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.7);
	background-gradient-end: rgba(89,89,89,0.7);
	transition-duration: 300;

	caret-color: #666666;
	caret-size: 1px;
}

#notification StEntry:focus {
	color: #ffffff;
	background-gradient-start: rgba(0,0,0,0.7);
	background-gradient-end: rgba(102,102,102,0.7);
	box-shadow: inset 0px -1px 1px 0px rgba(255,255,255,0.3);

	caret-color: #a8a8a8;
	selection-background-color: #808080;
}

/* ===================================================================
 * Alt Tab
 * ===================================================================*/

#altTabPopup {
	padding: 8px;
	spacing: 16px;
}

.switcher-list {
	background-color: rgba(0,0,0,0.85);
	border: 1px solid rgba(255,255,255,0.1);
	border-radius: 3px;
	padding: 20px;
}

.switcher-list-item-container {
	spacing: 8px;
}

.thumbnail-scroll-gradient-left {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(0,0,0,0);
	background-gradient-end: rgba(0,0,0,0.3);
	border: 1px solid rgba(255,255,255,0.1);
	border-radius: 3px;
	border-radius-topright: 0px;
	border-radius-bottomright: 0px;
	width: 60px;
}

.thumbnail-scroll-gradient-right {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(0,0,0,0);
	background-gradient-end: rgba(0,0,0,0.3);
	border: 1px solid rgba(255,255,255,0.1);
	border-radius: 3px;
	border-radius-topleft: 0px;
	border-radius-bottomleft: 0px;
	width: 60px;
}

.switcher-list .item-box {
	padding: 8px;
	border-radius: 3px;
}

.switcher-list .item-box:outlined {
	padding: 6px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.3);
	background-gradient-end: rgba(0,0,0,0.15);
}

.switcher-list .item-box:selected {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	box-shadow: inset 0px 1px 3px 0px rgba(255,255,255,0.3);
}

.switcher-list .thumbnail-box {
	padding: 2px;
	spacing: 5px;
}

.switcher-list .thumbnail {
	width: 256px;
}

.switcher-list .separator {
	width: 1px;
	background-color: rgba(255,255,255,0.21);
}

.ripple-box {
	width: 104px;
	height: 104px;
	background-image: url("corner-ripple.png");
}

.ripple-box:rtl {
	background-image: url("corner-ripple.png");
}

.switcher-arrow {
	border-color: rgba(0,0,0,0);
	color: #888;
}

.switcher-arrow:highlighted {
	border-color: rgba(0,0,0,0);
}

.switcher-preview-backdrop {
   background-color: rgba(0,0,0,0.6);
}

/* ===================================================================
 * Modal dialogs
 * ===================================================================*/

.modal-dialog {
	background-color: rgba(0,0,0,0.72);
	border: 1px solid rgba(255,255,255,0.1);
	border-radius: 3px;
	transition-duration: 100;
	padding-right: 40px;
	padding-left: 40px;
	padding-bottom: 30px;
	padding-top: 30px;
}

.modal-dialog-button-box {
	spacing: 21px;
}

.modal-dialog-button {
	border-radius: 3px;
	margin-left: 10px;
	margin-right: 10px;
	padding: 5px 30px;
}

.modal-dialog-button:disabled {
	color: rgb(60,60,60);
}

.modal-dialog-button:focus {
}

/* ===================================================================
 * Run dialog
 * ===================================================================*/

.run-dialog-label {
	font-family: "Bitstream Charter", serif;
	font-size: 11pt; /*9pt;*/
	font-weight: bold;
	font-style: italic;
	color: rgba(255,255,255,0.8);
	text-align: center;
	padding-bottom: 10px;
	padding-right: 20px;
	padding-left: 20px;
}

.run-dialog-error-label {
	font-size: 8pt;
	color: rgba(255,255,255,0.8);
	text-shadow: rgba(0,0,0,0.5) 0px 1px 0px;
}

.run-dialog-error-box {
	padding-top: 15px;
	spacing: 5px;
}

.run-dialog-entry {
	font-size: 10pt;
	font-weight: bold;
	color: rgba(255,255,255,0.8);
	border-radius: 15px;
	border: 1px solid rgba(0,0,0,0.1);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.8);
	background-gradient-end: rgba(77,77,77,0.7);
	box-shadow: inset 0px -1px 1px 0px rgba(255,255,255,0.3);
	padding: 4px 7px;

	caret-color: #a8a8a8;
	caret-size: 1px;
	selection-background-color: #808080;
}

.run-dialog {
	padding: 15px;
	border-radius: 9px 9px 0px 0px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(120,120,120,0.8);
	background-gradient-end: rgba(10,10,10,0.7);
	border: 1px solid rgba(0,0,0,0.2);
	box-shadow: 2px 4px 10px 4px rgba(0,0,0,0.8);
}

.lightbox {
	background-color: rgba(0, 0, 0, 0.3);
}

/* ===================================================================
 * End session dialog
 * ===================================================================*/

.end-session-dialog {
	spacing: 42px;
}

.end-session-dialog-subject {
	font-size: 11pt;;
	font-weight: bold;
	padding-top: 10px;
	padding-left: 17px;
	padding-bottom: 30px;
}

.end-session-dialog-subject:rtl {
	padding-left: 0px;
	padding-right: 17px;
}

.end-session-dialog-description {
	font-size: 10pt;
	padding-left: 17px;
	width: 28em;
}

.end-session-dialog-description:rtl {
	padding-right: 17px;
}

.end-session-dialog-logout-icon {
	border: 1px solid rgba(255,255,255,0.1);
	border-radius: 3px;
	width: 32px;
	height: 32px;
}

.end-session-dialog-shutdown-icon {
	width: 32px;
	height: 32px;
}

.end-session-dialog-app-list {
	font-size: 10pt;
	max-height: 200px;
	padding-top: 42px;
	padding-left: 49px;
	padding-right: 32px;
}

.end-session-dialog-app-list:rtl {
	padding-right: 49px;
	padding-left: 32px;
}

.end-session-dialog-app-list-item {
	transition-duration: 100;
}

.end-session-dialog-app-list-item:hover {
}

.end-session-dialog-app-list-item:ltr {
	padding-right: 1em;
}

.end-session-dialog-app-list-item:rtl {
	padding-left: 1em;
}

.end-session-dialog-app-list-item-icon:ltr {
	padding-right: 17px;
}

.end-session-dialog-app-list-item-icon:rtl {
	padding-left: 17px;
}

.end-session-dialog-app-list-item-name {
	font-size: 10pt;
}

.end-session-dialog-app-list-item-description {
	font-size: 8pt;
}

/* CinnamonMountOperation Dialogs */
.cinnamon-mount-operation-icon {
	icon-size: 48px;
}

.mount-password-reask {
	color: red;
}

.show-processes-dialog,
.mount-question-dialog {
	spacing: 24px;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject {
	font-size: 11pt;;
	font-weight: bold;
	padding-top: 10px;
	padding-left: 17px;
	padding-bottom: 6px;
}

.show-processes-dialog-subject:rtl,
.mount-question-dialog-subject:rtl {
	padding-left: 0px;
	padding-right: 17px;
}

.show-processes-dialog-description,
.mount-question-dialog-description {
	font-size: 10pt;
	padding-left: 17px;
	width: 28em;
}

.show-processes-dialog-description:rtl,
.mount-question-dialog-description:rtl {
	padding-right: 17px;
}

.show-processes-dialog-app-list {
	font-size: 10pt;
	max-height: 200px;
	padding-top: 24px;
	padding-left: 49px;
	padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
	padding-right: 49px;
	padding-left: 32px;
}

.show-processes-dialog-app-list-item {
	transition-duration: 100;
}

.show-processes-dialog-app-list-item:hover {
}

.show-processes-dialog-app-list-item:ltr {
	padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
	padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
	padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
	padding-left: 17px;
}

.show-processes-dialog-app-list-item-name {
	font-size: 10pt;
}

/* ===================================================================
 * Policykit authentication dialog
 * ===================================================================*/

.polkit-dialog {
	/* this is the width of the entire modal popup */
	width: 500px;
}

.polkit-dialog-main-layout {
	spacing: 24px;
	padding: 10px;
}

.polkit-dialog-message-layout {
	spacing: 16px;
}

.polkit-dialog-headline {
	font-size: 11pt;;
	font-weight: bold;
}

.polkit-dialog-description {
	font-size: 10pt;
}

.polkit-dialog-user-layout {
	padding-left: 10px;
	spacing: 10px;
}

.polkit-dialog-user-layout:rtl {
	padding-left: 0px;
	padding-right: 10px;
}

.polkit-dialog-user-root-label {
	color: #f00;
}

.polkit-dialog-password-label {
}

.polkit-dialog-password-label:ltr {
	padding-right: 0.5em;
}

.polkit-dialog-password-label:rtl {
	padding-left: 0.5em;
}

.polkit-dialog-password-entry {
	color: #000;
	background-color: rgba(255,255,255,0.72);
	box-shadow: inset 0px 1px 3px 0px rgba(0,0,0,0.3);
	border: 1px solid rgba(0,0,0,0.2);
	border-radius: 3px;
	padding: 5px 10px;
	selected-color: #fff;
	selection-background-color: rgba(255,255,255,0.4);
	caret-color: #666;
	caret-size: 1px;
	transition-duration: 100;
}

.polkit-dialog-password-entry:focus {
	border: 1px solid rgba(170,240,120,0.6);
}

.polkit-dialog-password-entry .capslock-warning {
	icon-size: 16px;
	warning-color: rgba(240,170,0,1.0);
	padding: 0px 5px;
}

.polkit-dialog-error-label {
	font-size: 10pt;
	color: #ff0;
	padding-bottom: 8px;
}

.polkit-dialog-info-label {
	font-size: 10pt;
	padding-bottom: 8px;
}

/* intentionally left transparent to avoid dialog changing size */
.polkit-dialog-null-label {
	color: rgba(0,0,0,0);
	padding-bottom: 8px;
}

.network-dialog-show-password-checkbox {
	padding-top: 5px;
	padding-bottom: 5px;
	spacing: 10px;
}

.network-dialog-secret-table {
	spacing-rows: 15px;
}

/* ===================================================================
 * Magnifier
 * ===================================================================*/

.magnifier-zoom-region {
	border: 2px solid rgba(128, 0, 0, 255);
}

.magnifier-zoom-region.full-screen {
	border-width: 0px;
}

/* ===================================================================
 * On screen keyboard
 * ===================================================================*/

#keyboard {
	background-color: rgba(0,0,0,0.72);
}

.keyboard-layout {
	spacing: 10px;
	padding: 10px;
}

.keyboard-row {
	spacing: 15px;
}

.keyboard-key {
	background-color: rgba(0,0,0,0.85);
	border: 1px solid rgba(255,255,255,0.1);
	border-radius: 3px;
	min-height: 30px;
	min-width: 30px;
	font-size: 14pt;
	font-weight: bold;
	transition-duration: 100;
}

.keyboard-key:grayed {
	color: #666;
	border: 1px solid rgba(255,255,255,0.1);
}

.keyboard-key:checked,
.keyboard-key:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	box-shadow: inset 0px 1px 3px 0px rgba(255,255,255,0.3);
}

.keyboard-key:active {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.4);
	background-gradient-end: rgba(255,255,255,0.4);
}

.keyboard-subkeys {
	-arrow-border-radius: 3px;
	-arrow-background-color: rgba(0,0,0,0.85);
	-arrow-border-width: 1px;
	-arrow-border-color: rgba(255,255,255,0.1);
	-arrow-base: 21px;
	-arrow-rise: 10px;
	-boxpointer-gap: 12px;
}

/* ###################################################################
 * Cinnamon Specific Section 
 * ###################################################################*/

/* ===================================================================
 * Menu (menu.js)
 * ===================================================================*/

/* Main menu title */
.menu-favorites-box {
	background-color: rgba(0,0,0,0.72);
	border: 1px solid rgba(255,255,255,0.1);
	margin: auto;
	padding: 3px;
	border-radius: 4px;
}

.menu-favorites-button {
	padding-top: 10px;
	padding-left: 10px;
	padding-right: 10px;
	padding-bottom: 10px;
}

.menu-favorites-button:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	border-radius: 4px;
	transition-duration: 100;
}

.menu-places-box {
	margin: auto;
	padding: 3px;
	border-radius: 4px;
}

.menu-places-button {
	padding-top: 10px;
	padding-left: 10px;
	padding-right: 10px;
	padding-bottom: 10px;
}

.menu-categories-box {
	padding-top: 10px;
	padding-left: 15px;
	padding-right: 15px;
	padding-bottom: 10px;
}

.menu-applications-box {
	padding-top: 10px;
	padding-left: 10px;
	padding-right: 10px;
	padding-bottom: 0px;
}

.menu-application-button {
	padding-top: 5px;
	padding-left: 5px;
	padding-right: 5px;
	padding-bottom: 5px;
}

.menu-application-button-selected {
	padding-top: 5px;
	padding-left: 5px;
	padding-right: 5px;
	padding-bottom: 5px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.9);
	background-gradient-end: rgba(128,128,128,0.8);
	color: black;
	border-radius: 4px;
}

.menu-application-button-label:ltr { 
	padding-left: 5px;
}

.menu-application-button-label:rtl { 
	padding-right: 5px;
}

.menu-category-button {
	padding-top: 5px;
	padding-left: 5px;
	padding-right: 5px;
	padding-bottom: 5px;
	transition-duration: 100;
}

.menu-category-button-greyed {
	padding-top: 5px;
	padding-left: 5px;
	padding-right: 5px;
	padding-bottom: 5px;
	color: #9C9C9C;
	font-style: italic;
}

.menu-category-button-selected {
	padding-top: 5px;
	padding-left: 5px;
	padding-right: 5px;
	padding-bottom: 5px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.9);
	background-gradient-end: rgba(128,128,128,0.8);
	color: black;
	border-radius: 4px;
	transition-duration: 100;
}

.menu-category-button-label:ltr { 
	padding-left: 5px;
}

.menu-category-button-label:rtl { 
	padding-right: 5px;
}

.menu-category-button-button:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	border-radius: 4px;
}

/* Name and description of the currently hovered item in the menu
 * This appears on the bottom right hand corner of the menu*/
.menu-selected-app-box {
	padding-right: 30px;
	padding-left: 28px;
	text-align: right;
}

.menu-selected-app-box:rtl {
	padding-top: 10px;
	height: 30px;
}

.menu-selected-app-title {
	font-weight: bold;
}

.menu-selected-app-description {
	max-width: 150px;
}

.menu-search-box:ltr {
	padding-left: 30px;
}

.menu-search-box:rtl {
	padding-right: 30px;
}

#menu-search-entry {
	padding: 4px 7px;
	border-radius: 15px;
	color: #A6A6A6;
	selected-color: black;
	border: 1px solid rgba(0,0,0,0.1);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.7);
	background-gradient-end: rgba(89,89,89,0.7);
	transition-duration: 300;

	caret-color: #666666;
	caret-size: 1px;

	width: 300px;
	transition-duration: 100;
}

#menu-search-entry:focus,
#menu-search-entry:hover {
	color: #ffffff;
	background-gradient-start: rgba(0,0,0,0.7);
	background-gradient-end: rgba(102,102,102,0.7);
	box-shadow: inset 0px -1px 1px 0px rgba(255,255,255,0.3);

	caret-color: #a8a8a8;
	selection-background-color: #808080;
	transition-duration: 100;
}

.menu-search-entry-icon {
	icon-size: 1em;
	color: #fff;
}

/* Context menu */
.menu-context-menu {
}

/* ===================================================================
 * Window list (windowList.js)
 * ===================================================================*/

.window-list-box {
	spacing: 3px;
	padding: 0px;
}

.window-list-item-label {
	font-weight: bold;
	width: 15em;
	min-width: 5px;
}

.window-list-item-box {
	padding-left: 3px;
	padding-right: 3px;
	background-color: transparent;
	transition-duration: 100;
	color: rgba(255,255,255,0.8);
}

.window-list-item-box:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	border-radius: 3px;
	color: white;
}

.window-list-item-box:active,
.window-list-item-box:checked,
.window-list-item-box:focus {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.4);
	background-gradient-end: rgba(255,255,255,0.6);
	box-shadow: inset 0px -1px 1px 0px rgba(0,0,0,0.4);
	text-shadow: rgba(0,0,0,0.8) 0px 1px 0px;
	border-radius: 3px;
	color: white;
}

.window-list-item-demands-attention {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(146,146,146,0.7);
	background-gradient-end: rgba(255,255,255,0.8);
	border-radius: 3px;
	color: black;
}

/* ===================================================================
 * Sound Applet (status/volume.js)
 * ===================================================================*/

.sound-button-container {
	padding-right: 3px;
	padding-left: 3px;
}

.sound-button {
	width: 21px;
	height: 12px;
	border-radius: 3px;
	padding: 5px;
}

.sound-button:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	box-shadow: inset 0px 1px 3px 0px rgba(255,255,255,0.3);
}

.sound-button StIcon {
	icon-size: 1.4em;
}

.sound-track-infos {
	padding-right: 5px;
	padding-left: 5px;
	padding-top: 5px;
	padding-bottom: 5px;
}

.sound-track-info {
	padding-bottom: 4px;
	padding-top: 2px;
	padding-bottom: 2px;
}

.sound-track-info StIcon {
	icon-size: 1em;
}

.sound-track-info StLabel {
	padding-left: 5px;
	padding-right: 5px;
}

.sound-track-box {
	padding-left: 15px;
	padding-right: 15px;
	max-width: 200px;
}

.sound-volume-menu-item {
	padding: .3em 1.75em;
}

.sound-volume-menu-item StIcon {
	icon-size: 1.14em;
	padding-left: 8px;
	padding-right: 8px;
}

.sound-playback-control {
	padding-top: 5px;
	padding-bottom: 10px;
}

/* ===================================================================
 * Workspace Switcher applet (workspaceSwitcher.js)
 * ===================================================================*/

#workspaceSwitcher {
	spacing: 0px;
	padding: 0px;
}

.workspace-button {
	background-color: rgba(0,0,0,0.72);
	width: 20px;
	padding: 2px;
	border: 1px solid rgba(255,255,255,0.3);
	transition-duration: 100;
}

.workspace-button:outlined,
.workspace-button:outlined:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.5);
	background-gradient-end: rgba(255,255,255,0.6);
	border: 1px solid rgba(20,20,20,0.4);
	box-shadow: inset 0px 1px 1px 0px rgba(0,0,0,0.3);
}

.workspace-button:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.6);
	background-gradient-end: rgba(0,0,0,0.5);
}
/* ===================================================================
 * Panel Launchers Applet (panelLaunchers.js)
 * ===================================================================*/

.panel-launchers {
	spacing: 2px;
	padding-left: 0px;
}

.launcher,
.panel-launcher {
	margin: 0px;
	padding-right: 4px;
	padding-left: 4px;
	transition-duration: 100;
}

.launcher:hover,
.panel-launcher:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	border-radius: 3px;
}

.panel-launcher-add-dialog-content-box {
	padding: 5px;
	spacing: 20px;
}

.panel-launcher-add-dialog-content-box-left {
	padding: 6px;
	spacing: 20px;
}

.panel-launcher-add-dialog-content-box-right {
	padding: 6px;
	spacing: 10px;
}

.panel-launcher-add-dialog-entry {
	color: #000;
	background-color: rgba(255,255,255,0.72);
	box-shadow: inset 0px 1px 3px 0px rgba(0,0,0,0.3);
	border: 1px solid rgba(0,0,0,0.2);
	border-radius: 3px;
	padding: 5px 10px;
	selected-color: #fff;
	selection-background-color: rgba(255,255,255,0.4);
	caret-color: #666;
	caret-size: 1px;
	width: 300px;
	transition-duration: 100;
}

.panel-launcher-add-dialog-entry:focus,
.panel-launcher-add-dialog-entry:hover {
	border: 1px solid rgba(0,0,0,0.6);
}

.panel-launcher-add-dialog-entry:focus {
	font-weight: bold;
}

/* ===================================================================
 * Overview corner
 * ===================================================================*/

#overview-corner {
	background-image: url("overview.png");
}

#overview-corner:hover {
}

/* ===================================================================
 * Applets (applet.js) 
 * ===================================================================*/

.applet-box {
	padding-left: 7px;
	padding-right: 7px;
	min-width: 1em;
	transition-duration: 100;
}

.applet-box:hover {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(71,71,71,0.4);
	border-radius: 3px;
}

.applet-box:active {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.4);
	background-gradient-end: rgba(255,255,255,0.4);
	box-shadow: inset 0px 1px 1px 0px rgba(0,0,0,0.2);
	text-shadow: rgba(0,0,0,0.8) 0px 1px 0px;
	border-radius: 3px;
	color: white;
}

.applet-label {	
	font-weight: bold; 
}

.applet-label:hover,
.applet-box:hover > .applet-label {
}

.applet-icon {
}

.applet-icon:hover,
.applet-box:hover > .applet-icon {
}

/* ===================================================================
 * Workspace OSD
 * ===================================================================*/

.workspace-osd {
	color: #fff;
	text-shadow: black 5px 5px 5px;
	font-weight: bold;
	font-size: 48pt;
}

.expo-workspaces-name-entry {
	padding: 5px;
	border-radius: 4px;
	color: white;
	border: 2px solid rgba(0,0,0,0);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(100,100,100,0.8);
	background-gradient-end: rgba(0,0,0,0.6);
	caret-color: #a8a8a8;
	caret-size: 1px;
	width: 250px;
	height: 15px;
	text-align: center;
	selected-color: black;
}

.expo-workspaces-name-entry#selected {
	color: black;
	border: 2px solid rgb(138,138,138);
	background-gradient-start: rgb(200,200,200);
	background-gradient-end: white;
	caret-color: #575757;
	selected-color: white;
	box-shadow: inset 0px 2px 4px rgba(0,0,0,0.6);
}

.expo-workspaces-name-entry:focus {
	font-weight: bold;
	transition-duration: 300;
}

/* ===================================================================
 * Notification Applet
 * ===================================================================*/

.notification-applet-padding {
	padding: .5em 1em;
}

.notification-applet-container {
	max-height: 100px;
}

/* Check Boxes */
.check-box CinnamonGenericContainer {
    spacing: .2em;
    min-height: 30px;
    padding-top: 2px;
}

.check-box StBin {
    width: 24px;
    height: 18px;
    background-image: url("checkbox-off.svg");
}

.check-box:focus StBin {
    background-image: url("checkbox-off-focused.svg");
}

.check-box:checked StBin {
    background-image: url("checkbox.svg");
}

.check-box:focus:checked StBin {
    background-image: url("checkbox-focused.svg");
}

.check-box StLabel {
   font-weight: normal;
}

.radiobutton CinnamonGenericContainer {
    spacing: .2em;
    height: 26px;
    padding-top: 2px;
}

.radiobutton StBin {
    width: 22px;
    height: 22px;
    background-image: url("radiobutton-off.svg");
    border-radius: 15px;
}

.radiobutton:focus StBin {
    background-image: url("radiobutton-off.svg");
}

.radiobutton:checked StBin {
    background-image: url("radiobutton.svg");
}

.radiobutton:focus:checked StBin {
    background-image: url("radiobutton.svg");
}

.radiobutton StLabel {
   padding-top: 4px;
   font-size: 0.9em;
   box-shadow: none;
}
