style "theme-panel"
{
	xthickness = 4 # The spacing (padding) inside and between applets. Add a lower value for a more compact look.
	ythickness = 0

# Disable (comment out) for normal panel backgrounds or to get a transparancy panel.
	bg_pixmap[NORMAL] = "/Panel/panel-bg.png"

	base[NORMAL]		= @bg_color
	base[PRELIGHT]		= shade (1.06, @bg_color)
	base[INSENSITIVE]	= @bg_color
	bg[NORMAL]			= @bg_color
	bg[PRELIGHT]		= shade (1.20, @bg_color)
	bg[SELECTED]		= @bg_color
	bg[INSENSITIVE]		= @bg_color
	bg[ACTIVE]			= shade (0.8, @bg_color)
	fg[NORMAL]			= "#000000"
	fg[PRELIGHT]		= "#000000"
	fg[SELECTED]		= @selected_fg_color
	fg[ACTIVE]			= "#ffffff"
	fg[INSENSITIVE]		= "#f0f0f0"
	text[NORMAL]		= "#000000"
	text[PRELIGHT]		= "#000000"
	text[ACTIVE]		= "#ffffff"
	text[SELECTED]		= @selected_fg_color
	text[INSENSITIVE]	= "#f0f0f0"
 	
	engine "murrine" {
	}
}

style "theme-panel-buttons"
{
# Disable (comment out) for normal panel backgrounds or to get a transparancy panel.
	#bg_pixmap[NORMAL] = "/Panel/panel-bg.png"
	
	engine "pixmap" {
		image {
			function	= BOX
			recolorable	= TRUE
			state		= NORMAL
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= PRELIGHT
			file		= "Panel/panel-button-hover.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= ACTIVE
			file		= "Panel/panel-button-active.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= SELECTED
			file		= "Panel/panel-button-active.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= INSENSITIVE
		}
		image {
			function	= ARROW
			recolorable	= TRUE
			arrow_direction	= DOWN
		}
	}
}

style "theme-applet"
{
  fg[NORMAL] = "#000000"
  bg[NORMAL] = @base_color
}

style "theme-panel-light"
{
	xthickness = 1
	ythickness = 0

	fg[NORMAL] = @fg_color

	engine "murrine" {
		textstyle = 0
		roundness = 0
	}
}

# disable for syncronize menu selected fonts
#style "theme-panel-text"
#{
#	fg[NORMAL]	= "#000000"
#	fg[PRELIGHT]	= "#000000"
#	fg[ACTIVE]	= "#ffffff"
#	text[NORMAL]	= "#000000"
#	text[PRELIGHT]	= "#000000"
#	text[ACTIVE]	= "#ffffff"
#}

style "theme-main-menu-text" = "theme-panel-text"
{
	fg[PRELIGHT]	= "#ffffff"
	text[PRELIGHT]	= "#ffffff"
}

style "theme-panel-handle" 
{
	engine "pixmap" {    
		image {
			function = HANDLE
		}    
		image {
			function = HANDLE
		}
	}
}

style "workspace-switcher"
{
	bg[SELECTED] = shade (1.0, @selected_bg_color)
	bg[PRELIGHT] = shade (1.2, @selected_bg_color)
}

widget "*PanelWidget*"			style "theme-panel"
#widget "*PanelApplet*"			style "theme-panel"
widget "*fast-user-switch*"		style "theme-panel"
widget "*CPUFreq*Applet*"		style "theme-panel"
widget "*indicator-applet*"		style "theme-panel"
#class "PanelApp*"			style "theme-panel"
class "PanelToplevel*"			style "theme-panel"
widget_class "*MatePanelAppletFrameDBus*" style "theme-applet"
widget_class "*PanelToplevel*"		style "theme-panel"
widget_class "*PanelFrame*" 		style "theme-panel"
widget_class "*PanelAppletFrame*" 	style "theme-panel"
widget_class "*PanelWidget*.*"		style "theme-panel"
#widget_class "*notif*"			style "theme-panel"
#widget_class "*Notif*"			style "theme-panel"
widget_class "*Tray*"			style "theme-panel" 
widget_class "*tray*"			style "theme-panel"
widget_class "*computertemp*"		style "theme-panel"
widget_class "*Applet*Tomboy*"		style "theme-panel"
widget_class "*Applet*Netstatus*"	style "theme-panel"
widget "*WnckPager*"	    	    style "workspace-switcher"

# Fixes for tooltip text in some apps.
widget_class "*Notif*Beagle*"	style "theme-panel-light"
widget_class "*Notif*Brasero*"	style "theme-panel-light"

# XFCE panel theming.
widget "*Xfce*Panel*"	style "theme-panel"
class "*Xfce*Panel*"	style "theme-panel"

# Panel buttons
widget_class "*Panel*GtkToggleButton"	style:highest "theme-panel-buttons"
#widget_class "*Panel*GtkButton"	style:highest "theme-panel-buttons"

# XFCE panel buttons
widget "*Xfce*Panel*Button*"	style:highest "theme-panel-buttons"
class "*Xfce*Panel*Button*"	style:highest "theme-panel-buttons"
widget_class "*LauncherPlugin*"	style:highest "theme-panel-buttons"
widget_class "*ActionsPlugin*"	style:highest "theme-panel-buttons"

# lxpanel and fbpanel
widget "*.tclock.*"		style "theme-panel-buttons"
widget "*.taskbar.*"		style "theme-panel-buttons"
widget_class "*GtkBgbox*"	style "theme-panel-buttons"

# Make sure panel text color doesn't change
widget_class "*Panel*MenuBar*"		style "theme-main-menu-text"
widget_class "*Panel*<GtkMenuBar>*"	style "theme-main-menu-text"
#widget "*.clock-applet-button.*"	style "theme-panel-text"
#widget "*PanelApplet*"			style "theme-panel-text"

# Hide ugly handle
class "PanelAppletFrame" style:highest "theme-panel-handle"

# The following removes the arrows from the panel

style "panel-arrow-remove" {
engine "pixmap" {
	image {
		function	= ARROW
		recolorable	= TRUE
		overlay_file	= "Panel/arrow-blank.png"
		overlay_border	= {2,2,2,2}
		overlay_stretch	= FALSE
		arrow_direction	= UP
		}
	image {
		function	= ARROW
		recolorable	= TRUE
		overlay_file	= "Panel/arrow-blank.png"
		overlay_border	= {2,2,2,2}
		overlay_stretch	= FALSE
		arrow_direction	= DOWN
		}
	}
}

widget_class "*PanelToplevel*" style "panel-arrow-remove"

# Fix xfce-notifyd button
style "xfce-notifyd-button" {
	fg[NORMAL]	= @text_color
	fg[PRELIGHT]	= @text_color
	fg[ACTIVE]	= @text_color
}

widget_class "XfceNotifyWindow.*.GtkButton*" style "xfce-notifyd-button"
