 /********
 * Nemo *
 ********/

.nemo-window-pane notebook scrolledwindow {
    background-color: shade(@base_color, 1.04);
    border-width: 0px 1px 1px 1px;
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
}

.nemo-window-pane treeview.view {
    padding: 0px;
}

/* this sets the bg color for scrolledwindow junction, the little square besides the scrollbars */
.nemo-window .nemo-window-pane > notebook box.vertical > overlay scrolledwindow {
    background-color: rgba(204,221,199,1.0);
}

/* treewiew, view and compact view */
.nemo-window .nemo-window-pane > notebook box.vertical > overlay > scrolledwindow.view,
.nemo-window .nemo-window-pane > notebook box.vertical > overlay > scrolledwindow > treeview.view {
    background-color: rgba(241,246,239,1.0);
}

/* inactive pane */
/* bug in gtk+, .view writes no bg color in all browsers */
.nemo-inactive-pane .view,
.nemo-inactive-pane scrolledwindow,
.nemo-inactive-pane scrolledwindow treeview {
    background-color: shade(@theme_bg_color, 0.9);
}

.nemo-inactive-pane notebook {
    background-color: shade(@theme_bg_color, 0.9);
}

.nemo-inactive-pane notebook tab.top:checked {
    background-image: linear-gradient(to bottom,
                                      shade(@theme_bg_color, 0.8),
                                      shade(@theme_bg_color, 0.86) 40%,
                                      shade(@theme_bg_color, 0.88) 70%,
                                      shade(@theme_bg_color, 0.9));
}

.nemo-inactive-pane notebook scrollbar button:disabled {
    background-color: shade(@theme_bg_color, 0.9);
    border-radius: 0px;
}

.nemo-window-pane expander column:sorted:selected,
.nemo-window-pane expander column:sorted:selected:hover {
    background-image: none;
    background-color: transparent;
}

.nemo-window statusbar {
    font-style: italic;
}

/* weird line between views and statusbar */
.nemo-window grid.vertical separator {
    background-color: transparent;
}

.nemo-window-pane .question,
.nemo-window-pane .info {
    background-color: @theme_bg_color;
    border-radius: 0px;
}

/* query-editor */
.nemo-window-pane  notebook box.vertical.toolbar.primary-toolbar {
    background-color: @theme_bg_color;
    padding: 5px 7px;
    border-width: 0px 0px 1px 0px;
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
}

.nemo-window .sidebar scrolledwindow {
    border-width: 0px 1px 1px 1px;
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
}

/* remove unwanted border from desktop window */
.nemo-desktop-window box.nemo-window-pane scrolledwindow {
    border-width: 0px;
    border-style: none;
}

.nemo-canvas-item {
    border-radius: 5px;
}

.nemo-desktop.nemo-canvas-item {
    color: @theme_bg_color;
    text-shadow: 1px 1px black;
}

.nemo-desktop.nemo-canvas-item:active {
    color: @theme_text_color;
}

.nemo-desktop.nemo-canvas-item:selected {
    color: @theme_selected_fg_color;
}

.nemo-desktop.nemo-canvas-item:active,
.nemo-desktop.nemo-canvas-item:hover,
.nemo-desktop.nemo-canvas-item:selected {
    text-shadow: none;
}

.nemo-desktop.view .entry,
.nemo-desktop.view .entry:focus,
.nemo-desktop.view .entry:active,
.nemo-desktop.view .entry:backdrop,
.nemo-window-pane .view .entry,
.nemo-window-pane .view .entry:focus,
.nemo-window-pane .view .entry:active,
.nemo-window-pane .view .entry:backdrop {
   background-image: -gtk-gradient(linear,
                                   left top, left bottom,
                                   from       (shade(@theme_base_color, 0.86)),
                                   color-stop (0.15, shade(@theme_base_color, 0.96)),
                                   color-stop (0.50, shade(@theme_base_color, 0.98)),
                                   to         (shade(@theme_base_color, 1.00)));
   border-image: none;
   border-style: solid;
   border-width: 1px;
   border-color: @theme_fg_color;
   box-shadow: none;
   border-radius: 3px;
   text-shadow: none;
}

.nemo-desktop.view .entry:selected,
.nemo-desktop.view .entry:focus:selected,
.nemo-desktop.view .entry:focus:active,
.nemo-desktop.view .entry:backdrop:selected,
.nemo-window-pane .view .entry:selected,
.nemo-window-pane .view .entry:focus:active,
.nemo-window-pane .view .entry:focus:selected,
.nemo-window-pane .view .entry:backdrop:selected {
    background-color: @theme_selected_bg_color;
    color: @theme_selected_fg_color;
    text-shadow: none;
}

/* parole madia list, hopefuly that styles no other things */
paned.horizontal > notebook  box.horizontal > box.vertical > notebook,
paned.horizontal > notebook  box.horizontal > box.vertical > notebook  scrolledwindow.frame {
    border-style: none;
    border-width: 0px;
    border-radius: 0px;
    padding: 0;
}

paned.horizontal > notebook box.horizontal > box.vertical > toolbar.horizontal.inline-toolbar {
    border-width: 1px 0px 0px  0px;
    padding: 0;
}

/* meld */

#meldapp > box.vertical > notebook.frame {
    background-color: shade (@theme_bg_color, 1.0);
    border-radius: 0px 0px 6px 6px;
}

#meldapp > box.vertical > notebook.frame > header.top {
    border-radius: 0px;
}

.meld-notebook-toolbar > toolbutton > button.flat,
.meld-notebook-toolbar > toolitem > filechooserbutton > button.file {
    background-image: linear-gradient(to bottom,
                                      @button_gradient_color_a,
                                      @button_gradient_color_b);
    border-image: url("assets/button-border.svg") 3 / 3px stretch;
}

.meld-notebook-toolbar > toolbutton > button.flat:hover,
.meld-notebook-toolbar > toolitem > filechooserbutton > button.file:hover {
    border-style: solid;
    border-color: shade(@button_border, 1.1);
    background-image: linear-gradient(to bottom,
                                      @button_hover_gradient_color_a,
                                      @button_hover_gradient_color_b);
    border-image: url("assets/button-active-border.svg") 3 3 3 3 / 3px 3px 3px 3px stretch;
}

.meld-notebook-toolbar > toolbutton > button.flat:disabled {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                                      alpha(@button_gradient_color_a, 0.5),
                                      alpha(@button_gradient_color_b, 0.5));
    border-image: none;
    border-style: solid;
    border-color: shade(@button_border, 1.2);
    color: @insensitive_fg_color;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical {
    border-width: 0px 1px 1px 1px;
    border-style: solid;
    border-color: @notebook_border;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow {
    border-width: 1px 0px 0px 0px;
    border-style: solid;
    border-color: @notebook_border;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar {
    border-style: solid;
    border-color: shade(@theme_bg_color, 0.75);
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.vertical.left {
    border-width: 0px 1px 1px 0px;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.vertical.right {
    border-width: 0px 0px 1px 1px;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.horizontal {
    border-width: 1px 0px 0px 0px;
}

#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.vertical trough,
#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.vertical button,
#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.horizontal trough ,
#meldapp > box.vertical > notebook.frame box.vertical > grid.horizontal > box.vertical > scrolledwindow > scrollbar.horizontal button {
    border-width: 0px;
}

/*************
 * Yumex-DNF *
 *************/

/* list sidebar row */
window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > stack > box.vertical > box.horizontal > box.vertical list.sidebar {
    border-color: @notebook_border;
    border-style: solid;
    border-width: 1px 0px 0px 0px;
}

/****************
 * pavu-control *
 ****************/

window.background > box.vertical > notebook button.flat.toggle,
window.background.csd > box.vertical > notebook button.flat.toggle,
window.background.ssd > box.vertical > notebook button.flat.toggle,
window.background.solid-csd > box.vertical > notebook button.flat.toggle {
    border-width: 1px;
    border-style: solid;
    border-color: transparent;
}

window.background > box.vertical > notebook scrolledwindow,
window.background.csd > box.vertical > notebook scrolledwindow viewport,
window.background.ssd > box.vertical > notebook scrolledwindow viewport,
window.background.solid-csd > box.vertical > notebook scrolledwindow viewport {
    border-style: solid;
    border-color: @notebook_border;
    border-width: 1px;
}

window.background > box.vertical > notebook scrolledwindow viewport,
window.background.csd > box.vertical > notebook scrolledwindow viewport,
window.background.ssd > box.vertical > notebook scrolledwindow viewport,
window.background.solid-csd > box.vertical > notebook scrolledwindow viewport {
    background-color: shade (@theme_bg_color, 1.04);
}

/****************
 * virt-manager *
 ****************/

window.background > box.vertical > notebook overlay > scrolledwindow,
window.background > box.vertical > notebook overlay > scrolledwindow viewport {
    border-style: none;
    border-width: 0px;
}

/***********
 * Lightdm *
 ***********/

/* 2.0 */
.lightdm-gtk-greeter #login_window.background,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter,
#login_window.background.lightdm-gtk-greeter box.vertical {
	border-radius: 12px;
    border-style: solid;
    border-width: 1px;
    border-color: shade(@theme_bg_color, 0.4);
}

/* 2.0 */
.lightdm-gtk-greeter #login_window.background #user_image_border,
/* 1.8.5 */
#login_window.background.lightdm-gtk-greeter #user_image_border {
    border-style: solid;
    border-width: 1px;
    border-color: shade(@theme_bg_color, 0.8);
}

/* 2.0 */
.lightdm-gtk-greeter #panel_window.background menubar separator {
    background-color: @theme_bg_color;
    background-image: none;
    color: @theme_fg_color;
}

