/***********
 * Sidebar *
 ***********/

.sidebar {
    -GtkTreeView-horizontal-separator: 6px;
    -GtkTreeView-vertical-separator: 1px;
}

.sidebar,
.sidebar .view,
.sidebar .view:hover {
    border-radius: 0px;
    color: @sidebar_fg_color;
    text-shadow: 0px 1px @theme_shadow_color;
    background-color: @sidebar_background;
}

.sidebar-button {
    background-color: transparent;
    background-image: none;
    border-style: none;
    border-image: none;
    border-width: 0px;
    border-color: transparent;
    box-shadow: none;
}

/* dialog open */
placessidebar.sidebar.frame viewport.frame list,
placessidebar.sidebar.frame viewport.frame list row.activatable.sidebar-row {
     background-color: @sidebar_background;
}

placessidebar.sidebar.frame viewport.frame list row.activatable.sidebar-row:selected {
     border-radius: 6px;
}

placessidebar.sidebar.frame viewport.frame list row.activatable.sidebar-row revealer.sidebar-revealer image.sidebar-icon {
     padding: 4px 8px 4px 6px;
}

placessidebar.sidebar.frame viewport.frame list row.activatable.sidebar-row revealer.sidebar-revealer label.sidebar-label {
     padding: 4px 0px 4px 1px;
}

placessidebar.sidebar.frame viewport.frame list row.activatable.sidebar-row revealer.sidebar-revealer button.sidebar-button.image-button {
    background-color: transparent;
    background-image: none;
    border-image:none;
    box-shadow: none;
    padding: 4px 12px 4px 0px;
}

.sidebar .view:selected,
.sidebar .view:selected:hover {
    border-style: solid;
    border-width: 1px 0px 0px 0px;
    border-color: shade (@sidebar_selected_bg, 0.90) #bbb shade (@sidebar_selected_bg, 1.05);
    border-radius: 3px;
    background-image: -gtk-gradient (linear,
                                     left top,
                                     left bottom,
                                     from (shade(@sidebar_selected_bg, 0.90)),
                                     color-stop (0.40, shade (@sidebar_selected_bg, 0.98)),
                                     to (shade(@sidebar_selected_bg, 1.05)));
    color: @theme_selected_fg_color;
    text-shadow: 0px 1px @theme_selected_shadow_color;
}

.sidebar row:hover,
.sidebar .view row:hover,
.sidebar treeview row:hover {
    background-image: -gtk-gradient (linear,
                                     left top,
                                     left bottom,
                                     from (shade(@theme_bg_color, 1.05)),
                                     color-stop (0.40, shade (@theme_bg_color, 1.13)),
                                     to (shade(@theme_bg_color, 1.10)));
    box-shadow: inset  0px  1px shade(@selected_bg_color, 1.05),
                inset  1px  0px shade(@selected_bg_color, 0.97),
                inset -1px  0px shade(@selected_bg_color, 0.93),
                inset  0px -1px shade(@selected_bg_color, 0.93);
    color: shade (@theme_fg_color, 0.90);
    border-radius: 3px;
    text-shadow: none;
}

.sidebar radio,
.sidebar radio:focus,
.sidebar radio:selected {
    background-image: none;
    background-color: alpha(@theme_base_color, 0.0);
}

