### Styles pluma. Removes the ugly frame etc. ###

style "pluma-frame" {	
	engine "pixmap" {
 		image {
			function = SHADOW
		}
	}
}

style "pluma-statusbar" {	
	ythickness = 0

	engine "pixmap" {
		image
		{
		function        = HANDLE
		recolorable     = TRUE
		file            = "Handles/resize-grip.png"
		state           = NORMAL
		stretch         = TRUE
		border          = { 0, 0, 1, 0 }
		}
	}
}

style "pluma-notebook" = "murrine-notebook-bg" {
	xthickness = 0 # Width of tabs and notebook borders.
	ythickness = 1 # Height of tabs and notebook borders.
}

widget_class "*Pluma*.<GtkFrame>*"		style "pluma-frame"
widget_class "*Pluma*.<GtkScrolledWindow>"	style "murrine-thin"
widget_class "*Pluma*.<GtkNotebook>"		style "pluma-notebook"
widget_class "*Pluma*.<GtkArrow>*"		style:highest "murrine-default"
widget_class "*Pluma*.<GtkStatusbar>*"		style "pluma-statusbar"
