UnityPanelWidget,
.unity-panel {
	background-image: linear-gradient(to bottom,
		@wm_bg_a,
		@wm_bg_b);
	border-width: 0;
	color: @theme_fg_color;
}

.unity-panel.menubar,
.unity-panel .menubar {
	color: @theme_fg_color;
	text-shadow: 0 1px @button_text_shadow;
}

.unity-panel.menuitem,
.unity-panel .menuitem {
	border-width: 1px 1px 0 1px;
	text-shadow: 0 1px @button_text_shadow;
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
	background-image: linear-gradient(to bottom,
		shade (@theme_selected_bg_color, 0.96),
		shade (@theme_selected_bg_color, 1.15));
	color: @theme_selected_fg_color;
}

/* This will theme the top decoration, so the whole space above the window */
UnityDecoration.top {
	border: 0px solid shade (@theme_bg_color, 0.5);
	border-bottom-width: 0;
	border-radius: 6px 6px 0 0; /* Corner radius, only the top ones should be */
	padding: 1px 8px 0 8px; /* This padding will be applied to the content of the top layout */
	background-color: @theme_bg_color; /* Decoration background */
	background-image: linear-gradient(to bottom,
		@wm_bg_a,
		@wm_bg_b);
	color: @theme_fg_color; /* The foreground color will be used to paint the text */
	text-shadow: 0 1px @wm_title_shadow;
	box-shadow: inset 0 1px alpha(@theme_base_color, 0.6);
}

/* Top decoration for inactive windows */
/*
UnityDecoration.top:backdrop {
	border: 0px solid @theme_bg_color;
	border-bottom-width: 0;
	background-color: @theme_bg_color;
	color: @theme_unfocused_fg_color;
}
*/
/* Left decoration, it themes only the space at the left of the window */
UnityDecoration.left,
/* Right decoration, it themes only the space at the right of the window */
UnityDecoration.right,
/* Bottom decoration, it themes all the space below the window */
UnityDecoration.bottom {
	background-color: @theme_bg_color;
}

/* Left, right and bottom decorations themes for inactive windows */
/*
UnityDecoration.left:backdrop,
UnityDecoration.right:backdrop,
UnityDecoration.bottom:backdrop {
	background-color: @theme_bg_color;
}
*/
