/* Copyright 2011, Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

/* Login Dialog */

.login-dialog-title {
    font-size: 14pt;
    font-weight: bold;
    color: #666666;
    padding-bottom: 2em;
}

.login-dialog {
    border-radius: 16px;
    min-height: 150px;
    max-height: 700px;
    min-width: 350px;
}

.login-dialog-prompt-fingerprint-message {
    font-size: 10.5pt;
}

.login-dialog-user-list-view {
    -st-vfade-offset: 1em;
}

.login-dialog-user-list {
    spacing: 12px;
}

.login-dialog-user-list-item {
    color: #666666;
}

.login-dialog-user-list-item:ltr {
    padding-right: 1em;
}

.login-dialog-user-list-item:rtl {
    padding-left: 1em;
}

.login-dialog-user-list-item .login-dialog-user-list-item-name {
    font-size: 20pt;
    padding-left: 1em;
    color: #666666;
}

.login-dialog-user-list-item:hover .login-dialog-user-list-item-name {
    color: white;
}

.login-dialog-user-list-item:focus .login-dialog-user-list-item-name {
    color: white;
    text-shadow: black 0px 2px 2px;
}

.login-dialog-user-list-item-vertical-layout {
    spacing: 2px;
}

.login-dialog-user-list-item .login-dialog-user-list-item-focus-bin {
    background-color: rgba(0,0,0,0.0);
    height: 2px;
}

.login-dialog-user-list-item:focus .login-dialog-user-list-item-focus-bin {
    background-color: #666666;
}

.login-dialog-user-list-item-icon {
    border: 2px solid #8b8b8b;
    border-radius: 8px;
    width: 64px;
    height: 64px;
}

.login-dialog-not-listed-button {
    padding-top: 2em;
}
.login-dialog-not-listed-label {
    font-size: 14pt;
    font-weight: bold;
    color: #666666;
}

.login-dialog-not-listed-button:hover .login-dialog-not-listed-label {
    color: white;
}

.login-dialog-prompt-layout {
    padding-bottom: 32px;
}
.login-dialog-prompt-label {
    color: white;
    font-size: 20pt;
}

.login-dialog-prompt-entry {
    padding: 4px;
    border-radius: 4px;
    border: 2px solid #5656cc;
    color: black;
    background-color: white;
    caret-color: black;
    caret-size: 1px;
    width: 15em;
}

.login-dialog-prompt-entry .capslock-warning {
    icon-size: 16px;
    warning-color: #999;
}

.login-dialog-prompt-entry:insensitive {
    color: rgba(0,0,0,0.7);
    border: 2px solid #565656;
}

.login-dialog-session-list {
    color: #ffffff;
    font-size: 10.5pt;
}

.login-dialog-session-list-button {
    padding: 4px;
}

.login-dialog-session-list-button:focus {
    background-color: #4c4c4c;
}

.login-dialog-session-list-button:active {
    background-color: #4c4c4c;
}

.login-dialog-session-list-button:hover {
    font-weight: bold;
}

.login-dialog-session-list-scroll-view {
    background-gradient-start: rgba(80,80,80,0.3);
    background-gradient-end: rgba(80,80,80,0.7);
    background-gradient-direction: vertical;
    box-shadow: inset 0px 2px 4px rgba(0,0,0,0.9);
    border-radius: 8px;
    border: 1px solid rgba(80,80,80,1.0);
    padding: .5em;
}

.login-dialog-session-list-item:focus {
    background-color: #666666;
}

.login-dialog-session-list-triangle {
    padding-right: .5em;
}

.login-dialog-session-list-item-box {
    spacing: .25em;
}

.login-dialog-session-list-item-dot {
    width: .75em;
    height: .75em;
}
