/*************************
 * Check and Radio items *
 *************************/

check,
.check,
.view.check,
.view.cell check,
check row:selected,
check row:selected:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked.png"));
}

check:disabled,
.check:disabled,
.view.check:disabled,
check row:selected:disabled,
check row:selected:focus:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive.png"));
    background-color: transparent;
}

check:checked,
.check:checked,
.view.check:checked,
check row:selected:checked,
check row:selected:focus:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked.png"));

}

check:checked:disabled,
.check:checked:disabled,
.view.check:checked:disabled,
check row:selected:checked:disabled,
check row:selected:focus:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive.png"));
    background-color: transparent;
}

check:indeterminate,
.check:indeterminate,
.view.check:indeterminate,
check row:selected:indeterminate,
check row:selected:focus:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed.png"));

}

check:indeterminate:disabled,
.check:indeterminate:disabled,
.view.check:indeterminate:disabled,
check row:selected:indeterminate:disabled,
check row:selected:focus:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive.png"));

}

radio,
.radio,
.view.radio,
.view.cell radio,
radio row:selected,
radio row:selected:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected.png"));
}

radio:disabled,
.radio:disabled,
.view.radio:disabled,
radio row:selected:disabled,
radio row:selected:focus:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-insensitive.png"));
}

radio:checked,
.radio:checked,
.view.radio:checked,
.view.cell radio:checked,
radio row:selected:checked,
radio row:selected:focus:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected.png"));
}

radio:checked:disabled,
.radio:checked:disabled,
.view.radio:checked:disabled,
radio row:selected:checked:disabled,
radio row:selected:focus:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected-insensitive.png"));
}

radio:indeterminate,
.radio:indeterminate,
.view.radio:indeterminate,
radio row:selected:indeterminate,
radio row:selected:focus:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed.png"));

}

radio:indeterminate,
.radio:indeterminate,
.view.radio:indeterminate,
radio row:selected:indeterminate,
radio row:selected:focus:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive.png"));
    background-color: transparent;
}

.sidebar radio:checked,
.sidebar radio:checked:focus,
.sidebar radio:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-checked.svg"));
}

.sidebar radio:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-prelight.svg"));
}

.sidebar radio:selected:checked,
.sidebar radio:selected:checked:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-selected.svg"));
}

.sidebar radio:selected:hover,
.sidebar radio:selected:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-selected-prelight.svg"));
}

/* Now draw menu check and radio items */

menuitem radio:hover,
menuitem radio:disabled,
menuitem check:hover,
menuitem check:disabled {
    background-color: transparent;
    background: none;
    border-style: none;
    border-image: none;
}

menuitem radio,
menuitem .radio {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-unselected.svg"));
}

menuitem radio:checked,
menuitem .radio:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked.svg"));
}

menuitem radio:checked:hover,
menuitem .radio:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked-prelight.svg"));
}

menuitem radio:checked:disabled,
menuitem .radio:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked-insensitive.svg"));
}

menuitem radio:indeterminate,
menuitem .radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed.svg"));
}

menuitem radio:indeterminate:hover,
menuitem .radio:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed-prelight.svg"));
}

menuitem radio:indeterminate:disabled,
menuitem .radio:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed-insensitive.svg"));
}

menuitem check,
menuitem .check {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-unchecked.svg"));
}

menuitem check:checked,
menuitem .check:checked{
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked.svg"));
}

menuitem check:checked:hover,
menuitem .check:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked-prelight.svg"));
}

menuitem check:checked:disabled,
menuitem .check:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked-insensitive.svg"));
}

menuitem check:indeterminate,
menuitem .check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed.svg"));
}

menuitem check:indeterminate:hover,
menuitem .check:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed-prelight.svg"));
}

menuitem check:indeterminate:disabled,
menuitem .check:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed-insensitive.svg"));
}

scale.vertical slider,
scale.horizontal slider {
    background-image: -gtk-scaled(url("assets/scale-slider.svg"));
}

scale.vertical slider:hover,
scale.horizontal slider:hover {
    background-image: -gtk-scaled(url("assets/scale-slider-hover.svg"));
}

scale.vertical slider:disabled,
scale.horizontal slider:disabled {
    background-image: -gtk-scaled(url("assets/scale-slider-insensitive.svg"));
}

scale.horizontal.marks-before slider,
scale.horizontal.marks-before slider:hover {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-above-horizontal.png"));
}

scale.horizontal.marks-before slider:disabled {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-above-horizontal-insensitive.png"));
}

scale.vertical.marks-before slider {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-above-vertical.png"));
}

scale.vertical.marks-before slider:disabled {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-above-vertical-insensitive.png"));
}

scale.horizontal.marks-after slider,
scale.horizontal.marks-after slider:hover {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-below-horizontal.png"));
}

scale.horizontal.marks-after slider:disabled {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-below-horizontal-insensitive.png"));
}

scale.vertical.marks-after slider {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-below-vertical.png"));
}

scale.vertical.marks-after slider:disabled {
    background-image: -gtk-scaled(url("assets/scale-slider-marks-below-vertical-insensitive.png"));
}

