/*************
 * rhythmbox *
 *************/

toolbar.primary-toolbar.horizontal > toolitem > grid.horizontal > button.scale.flat,
toolbar.primary-toolbar.horizontal > toolitem > grid.horizontal > button.scale.flat:hover,
toolbar.primary-toolbar.horizontal > toolitem > grid.horizontal > button.scale.flat:hover:active {
    padding: 0px 6px;
}

RBSource .cell.image {
    color: black;
}

/************
 * Nautilus *
 ************/

.nautilus-window > grid.horizontal > paned.horizontal > overlay > notebook header {
    border-width: 0px 1px 0px 1px;
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
    border-radius: 3px 3px 0px 0px;
}

.nautilus-window > grid.horizontal > paned.horizontal > overlay > notebook tab {
    border-width: 0px 1px 1px 1px;
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
    margin: 0px -1px 0px -1px;
    border-radius: 3px 3px 0px 0px;
}

.nautilus-inactive-pane notebook scrollbar.button:disabled {
    background-color: shade(@theme_bg_color, 0.9);
    border-radius: 0px;
}

.nautilus-window .floating-bar {
    font-style: italic;
}

.nautilus-canvas-item {
    border-radius: 5px;
}

.nautilus-desktop.nautilus-canvas-item {
    color: @theme_bg_color;
    text-shadow: 1px 1px black;
}

.nautilus-desktop.nautilus-canvas-item:active {
    color: @theme_text_color;
}

.nautilus-desktop.nautilus-canvas-item:selected {
    color: @theme_selected_fg_color;
}

.nautilus-desktop.nautilus-canvas-item:active,
.nautilus-desktop.nautilus-canvas-item:hover,
.nautilus-desktop.nautilus-canvas-item:selected {
    text-shadow: none;
}

/* nautilus view */
.nautilus-window > grid > paned.horizontal scrolledwindow {
    background-color: shade(@base_color, 1.04);
    -gtk-icon-style: regular;
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
    border-width: 0px 1px 1px 1px;
    border-radius: 2px;
    padding: 0;
}

/* sidebar */
.nautilus-window placessidebar.sidebar.frame {
    border-width: 0px 1px 1px 1px;
}

/*********
 * Gedit *
 *********/

.gedit-side-panel-paned scrolledwindow {
    border-width: 0px 1px 1px 1px;
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
}

/* file-browser */
.gedit-side-panel-paned > box > stack > grid > scrolledwindow {
    border-width: 1px;
}

.gedit-bottom-panel-paned > grid > notebook scrolledwindow {
    background-color: shade(@base_color, 1.04);
    border-style: solid;
    border-color: alpha(@frame_color, 0.6);
    border-width: 0px 1px 1px 1px;
    border-radius: 2px;
    -gtk-icon-style: regular;
    padding: 0;
}

/* gnome-weather */
#weather-page {
    padding: 0px;
    margin: -2px -2px -2px 0px;
}

#weather-page > frame {
    border-radius: 0px;
    margin: 0px 0px 0px -1px;
    border-color: transparent;
}

#weather-page stack > scrolledwindow > .frame {
    background-color: transparent;
}

#weather-page stack > scrolledwindow > .frame > grid > frame {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                                      alpha(shade(@theme_selected_bg_color, 1.2), 0.3),
                                      alpha(shade(@theme_selected_bg_color, 0.95), 0.3));
    border-color: @osd_button_border;
}

#weather-page frame.weather-clear stack > scrolledwindow > .frame {
    color: @theme_fg_color;
    text-shadow: none;
}

#weather-page frame.weather-few-clouds-night .linked.stack-switcher.osd > button label,
#weather-page frame.weather-few-clouds-night .linked.stack-switcher.osd > button:checked,
#weather-page frame.weather-few-clouds-night stack > scrolledwindow > .frame label,
#weather-page frame.weather-clear-night .linked.stack-switcher.osd > button label,
#weather-page frame.weather-clear-night .linked.stack-switcher.osd > button:checked,
#weather-page frame.weather-clear-night stack > scrolledwindow > .frame label,
#weather-page frame.weather-storm .linked.stack-switcher.osd > button label,
#weather-page frame.weather-storm .linked.stack-switcher.osd > button:checked,
#weather-page frame.weather-storm stack > scrolledwindow > .frame label,
#weather-page frame.weather-showers .linked.stack-switcher.osd > button label,
#weather-page frame.weather-showers .linked.stack-switcher.osd > button:checked,
#weather-page frame.weather-showers stack > scrolledwindow > .frame label,
#weather-page frame.weather-overcast .linked.stack-switcher.osd > button label,
#weather-page frame.weather-overcast .linked.stack-switcher.osd > button:checked,
#weather-page frame.weather-overcast stack > scrolledwindow > .frame label {
    color: @osd_button_fg_active;
}

#weather-page button.osd,
#weather-page frame .linked.stack-switcher.osd > button {
    border-image: none;
}

