/********
 * Nemo *
 ********/

.nemo-window > grid> .pane-separator {
	color: shade(@theme_selected_bg_color, 2.0);
	background-repeat: no-repeat;
	background-position: center;
	background-image: url("assets/notebook-pane-separator-grip.svg");
	background-color: @less_dark_color;
}

.nemo-window > grid> .pane-separator:hover,
.nemo-window > grid> .pane-separator:selected {
	background-image: url("assets/notebook-pane-separator-grip-hover.svg");
}

/* is this really needed? */
.nemo-window > grid> .pane-separator.vertical {
	background-image: url("assets/notebook-pane-separator-grip-vertical.svg");
}

.nemo-window > grid> .pane-separator.vertical:hover,
.nemo-window > grid> .pane-separator.vertical:selected {
	background-image: url("assets/notebook-pane-separator-grip-vertical-hover.svg");
}

/**** View ***/

.nemo-window>grid>paned>box>paned>box>notebook>stack>box>*>scrolledwindow {
	background-color: @less_dark_color;
	color: @theme_fg_color;
    border-color: transparent;
	border-style: none;
}

/* can do nothing with this right now 
.nemo-inactive-pane .view {
	background-color: shade(@less_dark_color, 1.3);
}
*/
/* file renaming */
.nemo-window  .entry,
.nemo-window .entry:focus {
	background-image: linear-gradient(to bottom,
	                                  shade(@less_dark_color, 0.2),
	                                  shade(@less_dark_color, 0.5) 10%,
	                                  @less_dark_color 50%,
	                                  shade(@less_dark_color, 1.5));
	border-image: none;
	border-style: solid;
	border-radius: 4px;
	border-color: @theme_selected_bg_color;
	background-color: shade(@theme_selected_bg_color, 0.3);
}


.nemo-window paned {
	background-color: @less_dark_color;
}

.nemo-window scrolledwindow.frame {
	border-style: none;
}

.nemo-window .button {
	border-image: url("assets/button-border-dark1.svg") 3 / 3px stretch;
	background-image: linear-gradient(to bottom,
	                                  shade(@less_dark_color, 1.3),
	                                  shade(@less_dark_color, 0.4));
}

.nemo-window .button:hover {
	background-image: -gtk-gradient (radial,
					0.5 -2.0, 2.0,
					0.5 -2.0, 3.0,
					from (shade(@button_gradient_color_a, 1.5)),
					color-stop (0.42, shade(@button_gradient_color_a, 0.7)),
					color-stop (0.43, @theme_bg_color),
					to (shade(@less_dark_color, 0.4)));

}

.nemo-window .button:checked,
.nemo-window .button:hover:checked,
.nemo-window .button:active,
.nemo-window .button:hover:active {
	background-image: linear-gradient(to bottom,
	                                  shade(@button_gradient_color_b, 0.7),
	                                  @theme_bg_color 40%,
	                                  shade(@less_dark_color, 1.6));
	border-image: url("assets/button-active-border-dark1.svg") 3 / 3px stretch;
}

.nemo-window column-header .button,
.nemo-window column-header .button:hover {
	border-image: none;
	border-width: 0px 0px 1px 1px;
	border-radius: 0;
	border-style: solid;
	border-color: @less_dark_color;
}

.nemo-window .toolbar {
	background-image: linear-gradient(to bottom,
	                                  shade(@less_dark_color, 0.4),
	                                  shade(@less_dark_color, 1.36));
}

.nemo-window .toolbar {
	border-radius: 0px;
}

.nemo-window .scrollbar.slider:hover,
.nemo-window .scrollbar.slider:hover:active,
.nemo-window .scrollbar.slider.vertical:hover,
.nemo-window .scrollbar.slider.vertical:hover:active {
	border-color: shade(@scroll_slider_color, 1.1);
}

.nemo-window .scrollbar.button,
.nemo-window .scrollbar.button.horizontal,
.nemo-window .scrollbar.button.vertical,
.nemo-window .scrollbar.button:disabled,
.nemo-window .scrollbar.button.horizontal:disabled,
.nemo-window .scrollbar.button.vertical:disabled {
	background-image: none;
}

.nemo-window statusbar,
.nemo-window .floating-bar {
	font-style: italic;
}

.nemo-window .floating-bar.right,
.nemo-window .floating-bar.left {
    border-top-right-radius: 3px;
    border-top-left-radius: 3px;
}

/**** Notebook ***/

.nemo-inactive-pane .notebook {
	border-color: @less_dark_color;
}

.nemo-inactive-pane .notebook tab.top:active {
	background-image: linear-gradient(to bottom,
	                                  shade(@less_dark_color, 1.05),
	                                  shade(@less_dark_color, 1.16) 40%,
	                                  shade(@less_dark_color, 1.25) 70%,
	                                  shade(@less_dark_color, 1.3));
}

.nemo-window .notebook .view.rubberband,
.nemo-window .notebook .rubberband {
	background-color: alpha(@theme_selected_bg_color, 0.35);
}

/**** NemoSidebar ***/

.nemo-window>grid>paned>box>scrolledwindow>viewport.frame,
.nemo-window>grid>paned>box>scrolledwindow>viewport treeview.view{
	background-color: shade(@theme_bg_color, 1.08);
}

.nemo-window .sidebar frame {
	border-width: 0px;
}

.nemo-window .sidebar scrollbar button {
	color: @theme_fg_color;
}

.nemo-window .sidebar scrollbar button:hover {
	color: @theme_fg_color;
}

.nemo-window .sidebar .cell,
.nemo-window .sidebar *.cell {
	color: @theme_text_color;
}

.nemo-window .sidebar .cell:hover,
.nemo-window .sidebar *.cell:hover {
	color: @theme_text_color;
}

.nemo-window .sidebar .cell:selected,
.nemo-window .sidebar *.cell:selected {
	background-image: linear-gradient(to bottom,
	                                  shade(@less_dark_color, 1.5),
	                                  shade(@less_dark_color, 0.6));
	color: @theme_text_color;
	border-radius: 2px;
}

.nemo-window .sidebar .cell:selected:focus,
.nemo-window .sidebar *.cell:selected:focus {
	color: @theme_text_color;
	background-image: linear-gradient(to top,
					 shade(@less_dark_color, 1.5),
					 shade(@less_dark_color, 0.6));
}

/**** Infos ***/

.nemo-window .question,
.nemo-window .info,
NemoTrashBar.info,
NemoXContentBar.info,
NemoQueryEditor.info {
	background-color: transparent;
}

NemoSearchBar.info {
	border-radius: 0px;
	background-color: @less_dark_color;
}

.nemo-window NemoQueryEditor .toolbar,
.nemo-window .notebook NemoQueryEditor .toolbar {
	background-image: none;
	background-color: transparent;
	padding: 5px 7px;
}

NemoSearchBar .entry,
NemoQueryEditor .toolbar .entry {
	background-image: linear-gradient(to bottom,
	                                  shade(@less_dark_color, 0.2),
	                                  shade(@less_dark_color, 0.5) 10%,
	                                  @less_dark_color 50%,
	                                  shade(@less_dark_color, 1.5));
	box-shadow: inset 0 -3px alpha(@entry_shadow, 0.03),
	            inset 0 -2px alpha(@entry_shadow, 0.04),
	            inset 0 -1px alpha(@entry_shadow, 0.06);
}

NemoSearchBar .entry:focus,
NemoQueryEditor .toolbar .entry:focus {
	border-color: shade(@less_dark_color, 1.4);
	box-shadow: inset 0 -2px alpha(@entry_shadow, 0.04),
	            inset 0 -1px alpha(@entry_shadow, 0.06);
}

.nemo-canvas-item {
	border-radius: 4px;
}

/**** Desktop Drawn ***/

.nemo-desktop.nemo-canvas-item {
	color: @theme_fg_color;
	text-shadow: none;
}

.nemo-desktop.nemo-canvas-item:active {
	color: @theme_text_color;
}

.nemo-desktop.nemo-canvas-item:selected {
	color: @theme_selected_fg_color;
}

.nemo-desktop.nemo-canvas-item:active,
.nemo-desktop.nemo-canvas-item:hover,
.nemo-desktop.nemo-canvas-item:selected {
	text-shadow: none;
}

/*************
 * Yumex-DNF *
 *************/

window.background.yumex-dnf-window > box.vertical > box.horizontal > box.horizontal > button {
    padding: 4px;
}

window.background.yumex-dnf-window > box.vertical > box.horizontal stackswitcher.linked.stack-switcher > button.text-button.radio {
    padding: 2px 16px;
}

window.background.yumex-dnf-window > box.vertical > box.horizontal > box.horizontal > button:disabled {
	background-color: @insensitive_bg_color;
	background-image: none;
}

/* list sidebar row */
window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > stack > box.vertical > box.horizontal > box.vertical list.sidebar {
    background-image: linear-gradient(to right,
                                                             @toolbar_gradient_base,
                                                             @toolbar_gradient_bottom);
    border-color: @less_dark_color;
    border-style: solid;
    border-width: 1px 0px 0px 0px;
}

window.background.yumex-dnf-window > box.vertical > box.vertical > box.horizontal > paned.vertical > stack > box.vertical > box.horizontal > box.vertical list.sidebar row.activatable {
    background-color: transparent;
    border-radius: 2px;
}

#YumexPackageView.view {
    background-color: shade(@less_dark_color, 2.4);
}

/******************
 * Google Chrome *
 *****************/

.chromium textview.view,
.chromium textview.view text {
    background-color: shade(@theme_bg_color, 1.15);
    color: @theme_selected_fg_color;
}

.chromium menubar:not(:backdrop) {
    background-color: shade(@theme_bg_color, 0.65);
}

