/* Default color scheme */

@define-color base_color #E6EFE3; /* used by some apps */
@define-color bg_color #E6EFE3;
@define-color text_color #000000;
@define-color fg_color #000000;
@define-color selected_bg_color #70816A;
@define-color selected_fg_color #ffffff;

@define-color tooltip_bg_color #EFF5ED; /*#343434;*/
@define-color tooltip_fg_color #000000;

@define-color theme_base_color @base_color;
@define-color theme_bg_color @bg_color;
@define-color theme_text_color @text_color;
@define-color theme_fg_color @fg_color;
@define-color theme_selected_bg_color @selected_bg_color; /* = shade(@bg_color, 0.5)*/
@define-color theme_selected_fg_color @selected_fg_color;

@define-color theme_tooltip_bg_color @tooltip_bg_color;
@define-color theme_tooltip_fg_color @tooltip_fg_color;

@define-color theme_main_color #ffffff;

@define-color keyboard_focus_border shade(@bg_color, 0.8);

@define-color button_gradient_color_a shade(@theme_bg_color, 1.07);
@define-color button_gradient_color_b shade(@theme_bg_color, 0.75);
@define-color button_border #A8ABA8;

@define-color button_hover_gradient_color_a shade(@theme_bg_color, 1.1);
@define-color button_hover_gradient_color_b shade(@theme_bg_color, 0.9);

@define-color insensitive_bg_color #D7E6CF;
@define-color insensitive_fg_color #A8ABA8;
@define-color insensitive_border_color alpha(#ababab, 0.5);

@define-color trough_bg_color_a #C8CCC7;
@define-color trough_bg_color_b #E2E4E1;

@define-color active_switch_bg_color_a #57704F;
@define-color active_switch_bg_color_b #70CB52; /*#BB9B7D*/

@define-color switch_slider_color @button_gradient_color_b;
@define-color switch_slider_border #5D8051;

@define-color progressbar_background_a #C7E3BF;
@define-color progressbar_background_b #A3C898;
@define-color progressbar_border #9FA19F;
@define-color progressbar_pattern #639156;

@define-color scale_fill_a #A1AF9C;
@define-color scale_fill_b #70816A;
@define-color scale_border_a @internal_element_color;
@define-color scale_border_b shade (@internal_element_color, 1.25);
@define-color osd_scale_border alpha (shade (@theme_bg_color, 1.25), 0.4);
@define-color scale_highlight_border @theme_selected_bg_color;
@define-color scale_highlight_bg @theme_selected_bg_color;
@define-color scale_highlight_shadow alpha(white, 0.50);

/*@define-color menu_color #655b56;*/
@define-color menu_controls_color #ffffff;

@define-color borders #A8ABA8;

@define-color highlighted_border #8E8F8E;
@define-color internal_element_color @borders;
@define-color internal_element_prelight @theme_text_color;
@define-color internal_element_insensitive mix(@internal_element_color, @theme_base_color, 0.7);

@define-color notebook_border alpha(@frame_color, 0.6); /*#aeaaa6;*/
@define-color notebook_active_tab_border alpha(@frame_color, 0.6); /*#a6a29e; #9b9b9b;*/
/*@define-color notebook_selected_tab_color #a38972;*/

@define-color toolbar_gradient_base #D4DFD1;

@define-color treeview_odd_row @theme_main_color;
@define-color treeview_even_row shade(@base_color, 1.02);

@define-color expander_row_selected_color #DFF0D9; /*#acccee*/

@define-color link_color #679E36;
@define-color frame_color #A8BD95;
@define-color inactive_frame_color #BECAB4;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (51, 51, 38);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (12, 51, 35);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (255, 255, 255);
@define-color question_bg_color rgb (93, 179, 13);
@define-color error_fg_color rgb (255, 255, 255);
@define-color error_bg_color rgb (191, 44, 44);

@define-color focus_border shade(@bg_color, 0.6);

@define-color theme_unfocused_base_color shade(@insensitive_bg_color, 1.015);
@define-color theme_unfocused_bg_color @theme_bg_color;

@define-color app_notification_a white;
@define-color app_notification_b shade(@theme_bg_color, 1.05);
@define-color app_notification_c @theme_bg_color;
@define-color app_notification_border #939493;

@define-color wnckpager_bg_color #98D437;

/*******
 * OSD *
 *******/
@define-color osd_highlight #ffffff;
@define-color osd_lowlight #515251;
@define-color osd_base @selected_bg_color;

@define-color osd_fg #EBEDEB;
@define-color osd_bg alpha(@osd_base, 0.80);

@define-color osd_text_shadow alpha(black, 0.75);

@define-color osd_toolbar_bg_a alpha(@osd_base, 0.80);
@define-color osd_toolbar_bg_b alpha(#101010, 0.80);
@define-color osd_toolbar_bg_c alpha(shade(@osd_base, 1.02), 0.80);

@define-color osd_button_bg_a alpha(@osd_highlight, 0.16);
@define-color osd_button_bg_b alpha(@osd_lowlight, 0.05);
@define-color osd_button_bg_c alpha(@osd_highlight, 0.12);

@define-color osd_button_bg_insensitive alpha(@osd_highlight, 0.25);
@define-color osd_button_bg_insensitive_active alpha(@osd_highlight, 0.16);

@define-color osd_button_bg_hover_a alpha(@osd_highlight, 0.28);
@define-color osd_button_bg_hover_b alpha(@osd_lowlight, 0.14);
@define-color osd_button_bg_hover_c alpha(@osd_highlight, 0.14);

@define-color osd_button_bg_active_a alpha(@osd_lowlight, 0.18);
@define-color osd_button_bg_active_b alpha(@osd_highlight, 0.23);
@define-color osd_button_bg_active_c alpha(@osd_lowlight, 0.17);

@define-color osd_button_fg shade(@osd_fg, 0.80);
@define-color osd_button_fg_hover shade(@osd_fg, 0.96);
@define-color osd_button_fg_active shade(@osd_fg, 1.10);
@define-color osd_button_fg_insensitive shade(@osd_fg, 0.70);

@define-color osd_button_border alpha(@osd_highlight, 0.40);
@define-color osd_button_inset shade(@osd_fg, 0.67);
@define-color osd_button_shadow alpha(black, 0.35);

@define-color osd_trough_bg alpha(@osd_button_fg, 0.10);

/************************
 * overshoot/undershoot *
 ************************/

@define-color overshoot_bg_color alpha (@theme_selected_bg_color, 0.15);
@define-color overshoot_backdrop_bg_color #C8FA96;

@define-color wm_a shade(@theme_bg_color, 1.05);
@define-color wm_b @theme_bg_color;
@define-color wm_util shade(@theme_bg_color, 1.05);
@define-color wm_unfocus shade(@theme_bg_color, 1.02);
@define-color wm_shadow alpha(black, 0.5);
/* csd border */
@define-color wm_csd_solid_bg shade(@theme_bg_color, 1.02);
@define-color wm_csd_border_color shade (#B4B5B3, 1.35);
@define-color wm_csd_solid_border_color shade (#B4B5B3, 1.2);

/********
 * Misc *
 ********/

@define-color inset_light_color alpha(white, 0.45);
@define-color inset_dark_color alpha(black, 0.07);

@define-color button_text_shadow alpha(white, 0.4);

/* Common color scheme */

@define-color os_chrome_bg_color black;
@define-color os_chrome_fg_color #CACCCA;
@define-color os_chrome_selected_bg_color #323332;
@define-color os_chrome_selected_fg_color white;

@define-color chrome_bg_color #171E1A;
@define-color chrome_fg_color #fff;

@define-color content_view_bg #EFF1EF;

/* inactive-pane caja */
@define-color inactive-pane_bg_color #D9DCD8;

@import url("gtk-widgets.css");
@import url("gtk-widgets-assets.css");
@import url("gnome-applications.css");
@import url("unity.css");
@import url("other-applications.css");
@import url("mate-applications.css");
@import url("window-controls.css");
