/* Default color scheme */
@define-color base_color #3b3b3e; /* used by some apps */
@define-color bg_color #3b3b3e;
@define-color text_color #ffffff;
@define-color fg_color #ffffff;
@define-color selected_bg_color #666669;
@define-color selected_fg_color #ffffff;

@define-color tooltip_bg_color #000000;
@define-color tooltip_fg_color #eeeeee;

@define-color theme_base_color @base_color;
@define-color theme_bg_color @bg_color;
@define-color theme_text_color @text_color;
@define-color theme_fg_color @fg_color;
@define-color theme_selected_bg_color @selected_bg_color;
@define-color theme_selected_fg_color @selected_fg_color;

@define-color theme_tooltip_bg_color @tooltip_bg_color;
@define-color theme_tooltip_fg_color @tooltip_fg_color;

@define-color theme_main_color #000000;

@define-color view_color #ECECEC;

@define-color button_gradient_color_a #69696c; /*shade(@theme_bg_color, 1.75);*/
@define-color button_gradient_color_b shade(@theme_bg_color, 0.35);
@define-color button_border #2a2a2a;

@define-color button_hover_gradient_color_a shade(@button_gradient_color_a, 0.8);
@define-color button_hover_gradient_color_b shade(@button_gradient_color_b, 1.2);

@define-color insensitive_bg_color alpha(#0b0b0d, 0.2);
@define-color insensitive_fg_color alpha(#ababab, 0.7);
@define-color insensitive_border_color alpha(#717171, 0.50);

@define-color frame_color #707070;
@define-color light_frame_color #808080;
@define-color inactive_frame_color shade(@theme_bg_color, 0.8);

@define-color notebook_active_tab_border alpha(@theme_selected_bg_color, 1.0);

@define-color switch_slider_color #737373;
@define-color switch_slider_border #666666;

@define-color entry_shadow #CCCCCC;

@define-color highlighted_border @button_border;
@define-color internal_element_color #8a8a8a;
@define-color internal_element_prelight #a3a3a3;
@define-color internal_element_insensitive shade(@internal_element_color, 0.75);

@define-color progressbar_background_a @less_dark_color;
@define-color progressbar_background_b #636363;
@define-color progressbar_border #a1a1a1;
@define-color progressbar_pattern #000000;

@define-color toolbar_gradient_base #18191a; /*#252624*/
@define-color toolbar_gradient_bottom #66666b;

@define-color scroll_slider_color #3b3b3b;

@define-color scrollbar_trough shade(@less_dark_color, 0.98);

@define-color less_dark_color #4d4d4d; /*shade(@scroll_slider_color, 1.3)*/

@define-color menu_controls_color #ffffff;

@define-color focus_border alpha(@theme_fg_color, 0.30);

@define-color trough_bg_color_a #2F2F30;
@define-color trough_bg_color_b #414243;

@define-color active_switch_bg_color_a @theme_selected_bg_color;
@define-color active_switch_bg_color_b #ffffff;

@define-color borders #ababab;

@define-color theme_unfocused_base_color shade(@insensitive_bg_color, 1.015);

@define-color app_notification_a #656568;
@define-color app_notification_b #39393A;
@define-color app_notification_c #333334;
@define-color app_notification_border black;

@define-color content_view_bg @less_dark_color;

/*******
 * OSD *
 *******/
@define-color osd_highlight #ffffff;
@define-color osd_lowlight #525252;
@define-color osd_base #212526;

@define-color osd_fg #ededed;
@define-color osd_bg alpha(@osd_base, 0.80);

@define-color osd_text_shadow alpha(black, 0.75);

@define-color osd_toolbar_bg_a alpha(@osd_base, 0.60);
@define-color osd_toolbar_bg_b alpha(#101010, 0.60);
@define-color osd_toolbar_bg_c alpha(shade(@osd_base, 1.02), 0.60);

@define-color osd_button_bg_a alpha(@osd_highlight, 0.16);
@define-color osd_button_bg_b alpha(@osd_lowlight, 0.05);
@define-color osd_button_bg_c alpha(@osd_highlight, 0.12);

@define-color osd_button_bg_insensitive alpha(@osd_highlight, 0.25);
@define-color osd_button_bg_insensitive_active alpha(@osd_highlight, 0.16);

@define-color osd_button_bg_hover_a alpha(@osd_highlight, 0.28);
@define-color osd_button_bg_hover_b alpha(@osd_lowlight, 0.14);
@define-color osd_button_bg_hover_c alpha(@osd_highlight, 0.14);

@define-color osd_button_bg_active_a alpha(@osd_lowlight, 0.18);
@define-color osd_button_bg_active_b alpha(@osd_highlight, 0.23);
@define-color osd_button_bg_active_c alpha(@osd_lowlight, 0.17);

@define-color osd_button_fg shade(@osd_fg, 0.80);
@define-color osd_button_fg_hover shade(@osd_fg, 0.96);
@define-color osd_button_fg_active shade(@osd_fg, 1.10);
@define-color osd_button_fg_insensitive shade(@osd_fg, 0.70);

@define-color osd_button_border alpha(@osd_highlight, 0.40);
@define-color osd_button_inset shade(@osd_fg, 0.67);
@define-color osd_button_shadow alpha(black, 0.35);

@define-color osd_trough_bg alpha(@osd_button_fg, 0.10);

@define-color wm_a shade(@theme_bg_color, 1.3);
@define-color wm_b @theme_bg_color;
@define-color wm_util shade(@theme_bg_color, 1.2);
@define-color wm_unfocus shade(@theme_bg_color, 1.05);
@define-color wm_shadow alpha(black, 0.5);
@define-color wm_border alpha(black,0.18);

/* csd border */
@define-color wm_csd_border_color shade (#595959, 1.35);
@define-color wm_csd_solid_border_color shade (#595959, 1.0);

/* FIXME: needs dark colors from here */
@define-color link_color #2EB8E6; /*#4a90d9*/
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (255, 255, 255);
@define-color info_bg_color rgb (61, 116, 189);
@define-color warning_fg_color rgb (255, 255, 255);
@define-color warning_bg_color rgb (252, 128, 0);
@define-color question_fg_color rgb (255, 255, 255);
@define-color question_bg_color rgb (0, 152, 38);
@define-color error_fg_color rgb (255, 255, 255);
@define-color error_bg_color rgb (237, 0, 0);

@define-color os_chrome_bg_color black;
@define-color os_chrome_fg_color #ccc;
@define-color os_chrome_selected_bg_color #333;
@define-color os_chrome_selected_fg_color white;

@define-color chrome_bg_color #1e1a17;
@define-color chrome_fg_color #fff;

@define-color scale_progress_fill #2c85e2;
@define-color scale_progress_border #1864b2;
@define-color scale_progress_border_b #3e90e5;

/************************
 * overshoot/undershoot *
 ************************/

@define-color overshoot_bg_color alpha (@theme_selected_bg_color, 0.35);
@define-color overshoot_backdrop_bg_color #F57900;

/* inactive-pane caja */
@define-color inactive-pane_bg_color #606060;

@import url("gtk-widgets.css");
@import url("gtk-widgets-assets-dark.css");
@import url("unity.css");
@import url("gnome-applications.css");
@import url("other-applications.css");
@import url("mate-applications.css");
@import url("window-controls.css");
