/* Mint-Z Improved Cinnamon theme by http://karashata.deviantart.com */

/* ###################################################################
 * Section common with Gnome Shell
 * ... contains a few cinnamon specific styles (rare occurences) 
 * ###################################################################*/
stage {
	font-family: Ubuntu, Droid Sans, Trebuchet MS, Liberation Sans, sans-serif;
}

* {
	font-size: 9pt; /* The default font size. */
	color: white;
}

/* small fonts */
.run-dialog-label, .run-dialog-error-label {
	font-size: 8pt;
}

/* small 7.5 pt */
.calendar-month-label, .calendar-day-base {
	font-size: 7.5pt;
}

/* small bold fonts */
.window-caption, .switcher-list, .expo-workspaces-name-entry, #Tooltip {
	font-size: 8pt;
	font-weight: bold;
}

.cinnamon-link {
	color: #0000ff;
	text-decoration: underline;
}

.cinnamon-link:hover {
	color: #0000e0;
}

StScrollBar {
	padding: 0px;
}

StScrollView.vfade {
	-st-vfade-offset: 68px;
}

StScrollView.hfade {
	-st-hfade-offset: 68px;
}

StScrollView StScrollBar {
	min-width: 8px;
	min-height: 20px;
}


StScrollBar StBin#trough {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.2);
	background-gradient-end: rgba(255,255,255,0.0);
	box-shadow: inset 2px 2px 2px 0px rgba(0,0,0,0.1) ;
	border: 1px solid rgba(0,0,0,0.2);
	border-radius: 8px;
}

StScrollBar StButton#vhandle {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(255,255,255,0.3);
	border: 1px solid rgba(0,0,0,0.25);
	border-radius: 8px;
}

StScrollBar StButton#hhandle {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(255,255,255,0.5);
	background-gradient-end: rgba(255,255,255,0.6);
	border: 1px solid rgba(0,0,0,0.25);
	border-radius: 8px;
}

StScrollBar StButton#hhandle:hover,
StScrollBar StButton#vhandle:hover {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(255,255,255,0.8);
	background-gradient-end: rgba(255,255,255,0.9);
}

#Tooltip {
	border-radius: 2px;
	padding: 4px 12px;
	background-color: rgba(0,0,0,0.5);
	text-align: center;
}

/* ===================================================================
 * Shared button properties 
 * ===================================================================*/
.notification-button,
.notification-icon-button,
.hotplug-notification-item,
.hotplug-resident-eject-button,
.modal-dialog-button,
.sound-button {
	border-radius: 2px;
	border-width: 1px;
	border-color: rgba(78,78,78,0.9);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(58,58,58,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 3px 1px rgba(0,0,0,0.5);
}

.notification-button:hover,
.notification-icon-button:hover,
.hotplug-notification-item:hover,
.hotplug-resident-eject-button:hover,
.modal-dialog-button:hover,
.sound-button:hover {
	border-color: rgba(98,98,98,0.9);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(68,68,68,1.0);
	background-gradient-end: rgba(58,58,58,1.0);
}

.notification-button:focus,
.notification-icon-button:focus,
.hotplug-notification-item:focus,
.modal-dialog-button:focus,
.sound-button:focus {
	box-shadow: 0px 0px 2px 1px rgba(145,173,117,0.9);
}

.notification-button:active,
.notification-icon-button:active,
.hotplug-notification-item:active,
.hotplug-resident-eject-button:active,
.modal-dialog-button:active,
.modal-dialog-button:pressed,
.sound-button:active {
	border-color: rgba(98,98,98,0.4);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(28,28,28,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: inset 0px 1px 5px rgba(0,0,0,0.35);
}

/* ===================================================================
 * PopupMenu (popupMenu.js) 
 * ===================================================================*/
/* .popup-menu-boxpointer and .popup-menu are kept for compatibility
    with cinnamon version under 3.2. Use .menu in version 3.2 and above */
.popup-menu-boxpointer {
	/* Keeping arrow style for extra effect and less "warning junk" in .xsession-errors */
	/* Border seems to behave strange with single background-color. Background-gradient fixes it. */
	-arrow-border-radius: 0px;
	-arrow-background-color: rgba(48,48,48,0.0);
	-arrow-border-width: 0px;
	-arrow-border-color: rgba(255,255,255,0.0);
	-arrow-base: 4px;
	-arrow-rise: 2px;
	border: 2px solid rgba(255,255,255,0.6);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 2px 1px rgba(0,0,0,0.5);
	border-radius: 0px;
}

.popup-menu {
	color: #fff;
	min-width: 85px;
}

.menu {
	border-radius: 0px;
	background-color: rgba(48,48,48,0.0);
	border-color: rgba(255,255,255,0.0);
	border: 2px solid rgba(255,255,255,0.6);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 2px 1px rgba(0,0,0,0.5);
    color: #fff;
    min-width: 85px;
}

.popup-submenu-menu-item:open {
	background-color: #4c4c4c;
}

.popup-sub-menu { /* Don't use border-radius or box-shadow here. It causes the shell to crash. */
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.0);
	background-gradient-end: rgba(0,0,0,0.0);
}

.popup-sub-menu .popup-menu-item:ltr {
	padding-right: 0em;
}

.popup-sub-menu .popup-menu-item:rtl {
	padding-left: 0em;
}

.popup-sub-menu StScrollBar {
	padding: 2px;
}

.popup-sub-menu StScrollBar StBin#trough {
	border-width: 0px;
}

.popup-sub-menu StScrollBar StBin#vhandle {
	background-color: #4c4c4c;
	border-width: 0px;
}

.popup-combo-menu {
	background-color: rgba(0,0,0,0.9);
	padding: 1em 0em;
	color: #ffffff;
	border: 1px solid #5f5f5f;
	border-radius: 4px;
}

/* The remaining popup-menu sizing is all done in ems, so that if you
 * override .popup-menu.font-size, everything else will scale with it.
 */
.popup-menu-content {
	padding: 0.5em 0em;
}

.popup-menu-item {
	font-weight: normal;
	padding: .4em 1.75em;
	spacing: 1em;
	color: #fff;
	border: 1px solid rgba(172,205,138,0.0);
	border-left-width: 0;
	border-right-width: 0;
}

.popup-menu-item:active {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(172,205,138,0.3);
	background-gradient-end: rgba(172,205,138,0.3);
	color: #fff;
	border: 1px solid rgba(255,255,255,0.35);
	border-left-width: 0;
	border-right-width: 0;
}

.popup-menu-item:insensitive {
	color: #9f9f9f;
}

.popup-image-menu-item {
}

.popup-combobox-item {
	spacing: 1em;
}

.popup-separator-menu-item {
	background-color: rgba(255,255,255,0.1);
	border: 1px solid rgba(0,0,0,0.5);
	border-bottom: 0px;
	border-left: 0px;
	border-right: 0px;
	height: 0.1em;
}

.popup-alternating-menu-item:alternate {
	font-weight: bold;
}

.popup-slider-menu-item {
	height: 1em;
	min-width: 15em;
	-slider-height: 2px;
	-slider-background-color: #333333;
	-slider-border-color: #5f5f5f;
	-slider-active-background-color: rgba(172,205,138,0.9);
	-slider-active-border-color: rgba(145,173,117,0.9);
	-slider-border-width: 1px;
	-slider-handle-radius: 0.5em;
}

.popup-device-menu-item {
	spacing: .5em;
}

.popup-inactive-menu-item {
	font-weight: normal;
	color: #999;
}

.popup-subtitle-menu-item {
	font-weight: bold;
}

.popup-menu-icon {
	icon-size: 1.09em;
}

/* Switches (to be used in menus) */
.toggle-switch {
	width: 32px;
	height: 16px;
	background-color: rgba(0,0,0,0.5);
}

.toggle-switch-us {
	background-image: url("switch-off.png");
	background-size: contain;
}

.toggle-switch-us:checked {
	background-image: url("switch-on.png");
	background-size: contain;
}

.toggle-switch-intl {
	background-image: url("switch-off.png");
	background-size: contain;
}

.toggle-switch-intl:checked {
	background-image: url("switch-on.png");
	background-size: contain;
}

.nm-menu-item-icons {
	spacing: .5em;
}

/* ===================================================================
 * Panel (panel.js)
 * ===================================================================*/
#panel {
	border: 1px solid rgba(255,255,255,0.5);
	border-left: 0px;
	border-right: 0px;
	border-radius: 0px;
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(120,120,120,0.8);
	background-gradient-end: rgba(150,150,150,0.6);
	height: 24px;
	font-weight: normal;
}

#panelLeft, #panelCenter, #panelRight {
	spacing: 2px;
}

#panelLeft:dnd {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,0,0,0.05);
	background-gradient-end: rgba(255,0,0,0.2);
}

#panelCenter:dnd {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,255,0,0.05);
	background-gradient-end: rgba(0,255,0,0.2);
}

#panelRight:dnd {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,255,0.05);
	background-gradient-end: rgba(0,0,255,0.2);
}

#panelLeft:ltr {
	padding-right: 4px;
}

#panelLeft:rtl {
	padding-left: 4px;
}

#panelRight:ltr {
	padding-left: 4px;
}

#panelRight:rtl {
	padding-right: 4px;
}

.panel-button {
	-natural-hpadding: 10px;
	-minimum-hpadding: 6px;
	font-weight: bold;
	color: #fff;
	border: 1px solid rgba(255,255,255,0);
	border-top: 0px;
	border-bottom: 0px;
	transition-duration: 200;
}

.panel-button:hover {
	border: 1px solid rgba(255,255,255,0.4);
	border-top: 0px;
	border-bottom: 0px;
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.3);
	background-gradient-end: rgba(255,255,255,0.2);
}

.panel-button:active,
.panel-button:overview,
.panel-button:focus {
	border: 1px solid rgba(255,255,255,0.1);
	border-top: 0px;
	border-bottom: 0px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.1);
	background-gradient-end: rgba(0,0,0,0.25);
	color: white;
	box-shadow: inset 0px 1px 5px rgba(0,0,0,0.251);
}

.panel-status-button:active,
.panel-status-button:checked,
.panel-status-button:focus {
	border: 1px solid rgba(255,255,255,0.1);
	border-top: 0px;
	border-bottom: 0px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.1);
	background-gradient-end: rgba(0,0,0,0.25);
	color: white;
}

.panel-button:active > .system-status-icon,
.panel-button:checked > .system-status-icon,
.panel-button:focus > .system-status-icon {
	icon-shadow: black 0px 0px 3px;
}

.panel-menu {
	-boxpointer-gap: 3px /* Distance between the menu and panel */
}

.system-status-icon {
	icon-size: 1.09em;
}

/* ===================================================================
 * Overview 
 * ===================================================================*/
#overview {
	spacing: 12px;
	background-color: rgba(100,100,100,0.3);
}

.window-caption {
	color: white;
	spacing: 25px;
}

.workspace-controls {
	visible-width: 32px; /* Amount visible before hovering */
}

.workspace-thumbnails-background {
	background-color: rgba(0,0,0,0.0);
	border: 0px solid rgba(0,0,0,0.0);
	border-right: 0px;
	border-radius: 0px;
	padding: 8px;
}

.workspace-thumbnails-background:rtl {
	border-right: 1px;
	border-left: 0px;
	border-radius: 0px;
}

.workspace-thumbnails {
	spacing: 7px;
}

.workspace-thumbnail-indicator {
	outline: 1px solid rgba(255,255,255,0.2);
	border: 1px solid rgba(255,255,255,0.5);
}

.workspace-add-button {
	background-image: url("add-workspace.png");
	height: 200px;
	width: 35px;
}

.workspace-add-button:hover {	

}

.workspace-close-button {
	background-image: url("close-window.svg");
	background-size: 22px;
	height: 22px;
	width: 22px;
	-cinnamon-close-overlap: 8px;
}

.window-caption {
	background-color: rgba(0,0,0,0.5);
	border: 1px solid rgba(255,255,255,0.25);
	border-radius: 6px;
	color: #fff;
	padding: 6px 8px;
	-cinnamon-caption-spacing: 1px;
}

.window-close {
	background-image: url("close-window.svg");
	background-size: 22px;
	height: 22px;
	width: 22px;
	-cinnamon-close-overlap: 8px;
}

.window-close:hover {
	-st-background-image-shadow: 0px 0px 4px rgba(255,255,255,0.9);
}

.window-close:rtl {
	-st-background-image-shadow: 2px 2px 6px rgba(0,0,0,0.5);
}

/* ===================================================================
 * Looking Glass 
 * ===================================================================*/
#LookingGlassDialog {
	border: 0;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	spacing: 8px;
	padding: 4px;
}

#LookingGlassDialog > #Toolbar {
	border: 1px solid grey;
	border-radius: 2px;
}

#LookingGlassDialog .labels {
	spacing: 4px;
}

#LookingGlassDialog .notebook-tab {
	-natural-hpadding: 12px;
	-minimum-hpadding: 6px;
	font-weight: bold;
	color: #ccc;
	padding-left: .3em;
	padding-right: .3em;
}

#LookingGlassDialog .notebook-tab:hover {
	color: white;
	text-shadow: black 0px 2px 2px;
}

#LookingGlassDialog .notebook-tab:selected {
	border-image: url("panel-button-border.svg") 10 10 0 2;
	background-image: url("panel-button-highlight-wide.svg");
	color: white;
	text-shadow: black 0px 2px 2px;
}

#LookingGlassDialog .lg-inspector-title {
	font-weight: bold;
	padding-bottom: 8px;
}

.lg-dialog StEntry {
	selection-background-color: #bbbbbb;
	selected-color: #333333;
}

.lg-completions-text {
	font-size: .9em;
	font-style: italic;
}

.lg-obj-inspector-title {
	spacing: 4px;
}

.lg-obj-inspector-button {
	border: 1px solid gray;
	padding: 4px;
	border-radius: 4px;
}

.lg-obj-inspector-button:hover {
	border: 1px solid #ffffff;
}

.lg-dialog .shell-link {
	color: #999999;
}

.lg-dialog .shell-link:hover {
	color: #dddddd;
}

#LookingGlassDialog StBoxLayout#EvalBox {
	padding: 4px;
	spacing: 4px;
}

#LookingGlassDialog StBoxLayout#ResultsArea {
	spacing: 4px;
}

#lookingGlassExtensions {
	padding: 4px;
}

.lg-extension-list {
	padding: 4px;
	spacing: 6px;
}

.lg-extension {
	border: 1px solid #6f6f6f;
	border-radius: 4px;
	padding: 4px;
}

.lg-extension-name {
	font-weight: bold;
}

.lg-extension-meta {
	spacing: 6px;
}

#LookingGlassPropertyInspector {
	background: rgba(0, 0, 0, 0.8);
	border: 2px solid grey;
	border-radius: 4px;
	padding: 6px;
}

/* ===================================================================
 * Date applet 
 * ===================================================================*/
.calendar-vertical-separator {
	-stipple-width: 1px;
	-stipple-color: rgba(255,255,255,0.2);
	width: 0.3em;
}

#calendarPopup {
	border: 2px solid rgba(255,255,255,0.6);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 2px 1px rgba(0,0,0,0.5);
	border-radius: 0px;
	color: white;
}

#calendarPopup .calendar {
	padding: 10px;
}

.calendar {
	padding: .4em 1.75em;
	spacing-rows: 0px;
	spacing-columns: 0px;
}

.calendar-month-label {
	color: #e2e2e2;
	padding-bottom: 8px;
	padding-top: 8px;
	font-weight: bold;
}

.calendar-change-month-back {
	width: 18px;
	height: 12px;
	background-image: url("calendar-arrow-left.svg");
	border-radius: 4px;
}

.calendar-change-month-back:rtl {
	background-image: url("calendar-arrow-right.svg");
}

.calendar-change-month-back:hover {
	background-color: rgba(255,255,255,0.1);
}
.calendar-change-month-back:active {
	background-color: rgba(255,255,255,0.1);
}

.calendar-change-month-forward {
	width: 18px;
	height: 12px;
	background-image: url("calendar-arrow-right.svg");
	border-radius: 4px;
}

.calendar-change-month-forward:rtl {
	background-image: url("calendar-arrow-left.svg");
}

.calendar-change-month-forward:hover {
	background-color: rgba(255,255,255,0.1);
}
.calendar-change-month-forward:active {
	background-color: rgba(255,255,255,0.1);
}

.datemenu-date-label {
	padding: .4em 1.75em;
	color: #e2e2e2;
	font-weight: bold;
}

.calendar-day-base {
	text-align: center;
	width: 2.4em;
	height: 2.4em;
}

.calendar-day-base:hover {
	background-color: rgba(255,255,255,0.2);
	color: #fff;
}

.calendar-day-base:active {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.2);
	background-gradient-end: rgba(255,255,255,0.2);
	box-shadow:inset 0px 0px 0px 1px rgba(255,255,255,0.1);
}

.calendar-today.calendar-day-base:active {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(255,255,255,0.4);
	box-shadow:inset 0px 0px 0px 1px rgba(255,255,255,0.2);
}

.calendar-day-heading {
	color: #e2e2e2;
	padding-top: 1em;
}

.calendar-week-number {
	color: #e2e2e2;
	font-weight: bold;
}

/* Hack used in lieu of border-collapse - see calendar.js */
.calendar-day {
	border: 1px solid #333;
	color: #e2e2e2;
	border-top-width: 0;
	border-left-width: 0;
	border-radius: 0px;
	width: 32px;
}
.calendar-day-top {
	border-top-width: 1px;
}
.calendar-day-left {
	border-left-width: 1px;
}

.calendar-work-day {
	border-color: #444;
}

.calendar-nonwork-day {
	background-color: rgba(128,128,128,.1);
	border-color: #555;
}

.calendar-today {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.4);
	background-gradient-end: rgba(255,255,255,0.4);
	box-shadow:inset 0px 0px 0px 1px rgba(255,255,255,0.2);
	color: #ffffff;
	font-weight: bold;
}

.calendar-other-month-day {
	color: #e2e2e2;
}

.calendar-day-with-events {
	font-weight: bold;
	color: #fff;
}

/* ===================================================================
 * Notifications
 * ===================================================================*/
#notification {
	border: 2px solid rgba(255,255,255,0.5);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	border-radius: 0;
	padding: 8px;
	spacing-rows: 10px;
	spacing-columns: 10px;
	width: 34em;
	margin-from-right-edge-of-screen: 8px;
	margin-from-top-edge-of-screen: 8px;
}

/* We use row-span = 2 for the image cell, which prevents its height preferences to be
   taken into account during allocation, so its height ends up being limited by the height
   of the content in the other rows. To avoid showing a stretched image, we set the minimum
   height of the table to be ICON_SIZE + IMAGE_SIZE + spacing-rows = 24 + 125 + 10 = 159 */
.notification-with-image {
	min-height: 159px;
}

#notification-scrollview {
	max-height: 10em;
	-st-vfade-offset: 24px;
}

#notification-scrollview > .top-shadow, #notification-scrollview > .bottom-shadow {
	height: 1em;
}

#notification-scrollview:ltr > StScrollBar {
	padding-left: 6px;
}

#notification-scrollview:rtl > StScrollBar {
	padding-right: 6px;
}

#notification-body {
	spacing: 5px;
}

#notification-actions {
	spacing: 10px;
}

.notification-button {
	padding: 4px 42px 5px;
}

.notification-icon-button {
	border-radius: 2px;
	padding: 5px;
}

.notification-icon-button > StIcon {
	icon-size: 16px;
	padding: 8px;
}

.hotplug-transient-box {
	spacing: 6px;
	padding: 2px 46px 2px 12px;
}

.hotplug-notification-item {
	padding: 2px 10px;
}

.hotplug-notification-item-icon {
	icon-size: 24px;
	padding: 2px 5px;
}

.hotplug-resident-box {
	spacing: 8px;
}

.hotplug-resident-mount {
	color: white;
	border: 1px solid rgba(0,0,0,0.0);
}

.hotplug-resident-mount:hover {
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.12);
	background-gradient-end: rgba(255,255,255,0.05);
	box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.15);
	border: 1px solid rgba(0,0,0,0.15);
	border-radius: 3px;
}

.hotplug-resident-mount-label {
	color: inherit;
	padding-left: 6px;
}

.hotplug-resident-mount-icon {
	icon-size: 24px;
	padding-left: 6px;
}

.hotplug-resident-eject-icon {
	icon-size: 20px;
}

.hotplug-resident-eject-button {
	padding: 7px;
}

.chat-log-message {
	color: #888888;
}

.chat-group-sent, .chat-group-meta {
	padding: 8px 0;
}

.chat-received {
	padding-left: 4px;
}

.chat-received:rtl {
	padding-left: 0px;
	padding-right: 4px;
}

.chat-sent {
	padding-left: 18pt;
	color: #959595;
}

.chat-sent:rtl {
	padding-left: 0px;
	padding-right: 18pt;
}

.chat-meta-message {
	padding-left: 4px;
	color: #bbbbbb;
}

.chat-meta-message:rtl {
	padding-left: 0px;
	padding-right: 4px;
}

.subscription-message {
	font-style: italic;
}

#notification StEntry {
	padding: 4px;
	selected-color: white;
	color: #c0c0c0;
	border: 1px solid rgba(200,200,200,0.12);
	background-color: rgba(0,0,0,0.3);
	box-shadow: inset 0px 1px 2px 0px rgba(0,0,0,0.5);
	border-radius: 2px;
	caret-color: white;
	caret-size: 1px;
}

#notification StEntry:focus {
	color: white;
	border: 1px solid rgba(200,200,200,0.3);

	caret-color: white;
	selection-background-color: #accd8a;
}

/* ===================================================================
 * Alt Tab
 * ===================================================================*/
#altTabPopup {
	padding: 8px;
	spacing: 16px;
}

.switcher-list {
	border: 2px solid rgba(255,255,255,0.6);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 2px 1px rgba(0,0,0,0.5);
	border-radius: 0;
	padding: 20px;
	color: white;
}

.switcher-list-item-container {
	spacing: 8px;
}

.thumbnail-scroll-gradient-left {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(51,51,51,1.0);
	background-gradient-end: rgba(51,51,51,0);
	border-radius: 24px;
	border-radius-topright: 0px;
	border-radius-bottomright: 0px;
	width: 60px;
}

.thumbnail-scroll-gradient-right {
	background-gradient-direction: horizontal;
	background-gradient-start: rgba(51,51,51,0);
	background-gradient-end: rgba(51,51,51,1.0);
	border-radius: 24px;
	border-radius-topleft: 0px;
	border-radius-bottomleft: 0px;
	width: 60px;
}

.switcher-list .item-box {
	padding: 8px;
	border-radius: 8px;
}

.switcher-list .item-box:outlined {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(172,205,138,0.9);
	background-gradient-end: rgba(145,173,117,0.9);
	box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.3);
	border-radius: 3px;
	color: rgba(255,255,255,1.0);
	padding: 6px;
}

.switcher-list .item-box:selected {
	background-gradient-direction: vertical;
	background-gradient-start: rgba(172,205,138,0.9);
	background-gradient-end: rgba(145,173,117,0.9);
	box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.3);
	border-radius: 3px;
	color: rgba(255,255,255,1.0);
}

.switcher-list .thumbnail-box {
	padding: 2px;
	spacing: 4px;
}

.switcher-list .thumbnail {
	width:  256px;
}

.switcher-list .separator {
	width: 1px;
	background: rgba(255,255,255,0.33);
}

.ripple-box {
	width: 52px;
	height: 52px;
	background-image: url("corner-ripple-ltr.png");
	background-size: contain;
}

.ripple-box:rtl {
	background-image: url("corner-ripple-rtl.png");
}

.switcher-arrow {
	border-color: rgba(0,0,0,0);
	color: #808080;
}

.switcher-arrow:highlighted {
	border-color: rgba(0,0,0,0);
	color: white;
}

/* ===================================================================
 * Modal dialogs
 * ===================================================================*/
.show-processes-dialog-subject,
.mount-question-dialog-subject,
.end-session-dialog-subject {
	font-weight: bold;
	color: #fff;
}

.modal-dialog {
	border: 2px solid rgba(255,255,255,0.6);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 2px 1px rgba(0,0,0,0.5);
	border-radius: 0;
	color: #fff;

	padding-right: 42px;
	padding-left: 42px;
	padding-bottom: 30px;
	padding-top: 30px;
}

.modal-dialog-button-box {
	spacing: 21px;
}

.modal-dialog-button {
	margin-left: 10px;
	margin-right: 10px;
	padding: 4px 32px 5px;
}

.modal-dialog-button:disabled {
	color: rgb(60,60,60);
}

/* ===================================================================
 * Run dialog
 * ===================================================================*/
.run-dialog-error-box {
	padding-top: 15px;
	spacing: 5px;
}

.run-dialog-entry {
	font-weight: normal;
	width: 23em;
	selection-background-color: #accd8a;
	selected-color: white;
	border-radius: 2px;
	padding: 4px;
	color: white;
	border: 1px solid rgba(200,200,200,0.12);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.3);
	background-gradient-end: rgba(0,0,0,0.3);
	box-shadow: inset 0px 1px 2px 0px rgba(0,0,0,0.5);
	caret-size: 1px;
}

.run-dialog {
	border: 2px solid rgba(255,255,255,0.5);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 1px 1px rgba(0,0,0,0.3);
	border-radius: 0;

	padding-right: 21px;
	padding-left: 21px;
	padding-bottom: 15px;
	padding-top: 15px;
}

.lightbox {
	background-color: rgba(160,160,160,0.0);
}

.flashspot {
	background-color: white;
}

/* ===================================================================
 * End session dialog
 * ===================================================================*/
.end-session-dialog {
	spacing: 42px;
}

.end-session-dialog-subject {
	font-weight: bold;
	color: #fff;
	padding-top: 10px;
	padding-left: 17px;
	padding-bottom: 30px;
}

.end-session-dialog-subject:rtl {
	padding-left: 0px;
	padding-right: 17px;
}

.end-session-dialog-description {
	padding-left: 17px;
	width: 28em;
}

.end-session-dialog-description:rtl {
	padding-right: 17px;
}

.end-session-dialog-logout-icon {
	border: 1px solid rgba(255,255,255,0.3);
	border-radius: 0;
	width: 32px;
	height: 32px;
}

.end-session-dialog-shutdown-icon {
	color: #bebebe;
	width: 32px;
	height: 32px;
}

.end-session-dialog-app-list {
	max-height: 200px;
	padding-top: 42px;
	padding-left: 49px;
	padding-right: 32px;
}

.end-session-dialog-app-list:rtl {
	padding-right: 49px;
	padding-left: 32px;
}

.end-session-dialog-app-list-item {
	color: #ccc;
}

.end-session-dialog-app-list-item:hover {
	color: white;
}

.end-session-dialog-app-list-item:ltr {
	padding-right: 1em;
}

.end-session-dialog-app-list-item:rtl {
	padding-left: 1em;
}

.end-session-dialog-app-list-item-icon:ltr {
	padding-right: 17px;
}

.end-session-dialog-app-list-item-icon:rtl {
	padding-left: 17px;
}

.end-session-dialog-app-list-item-name {
}

.end-session-dialog-app-list-item-description {
	color: #444444;
}

/* CinnamonMountOperation Dialogs */
.cinnamon-mount-operation-icon {
	icon-size: 48px;
}

.mount-password-reask {
	color: red;
}

.show-processes-dialog,
.mount-question-dialog {
	spacing: 24px;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject {
	padding-top: 10px;
	padding-left: 17px;
	padding-bottom: 6px;
}

.mount-question-dialog-subject {
	max-width: 500px;
}

.show-processes-dialog-subject:rtl,
.mount-question-dialog-subject:rtl {
	padding-left: 0px;
	padding-right: 17px;
}

.show-processes-dialog-description,
.mount-question-dialog-description {
	padding-left: 17px;
	width: 28em;
}

.show-processes-dialog-description:rtl,
.mount-question-dialog-description:rtl {
	padding-right: 17px;
}

.show-processes-dialog-app-list {
	max-height: 200px;
	padding-top: 24px;
	padding-left: 49px;
	padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
	padding-right: 49px;
	padding-left: 32px;
}

.show-processes-dialog-app-list-item {
	color: #ccc;
}

.show-processes-dialog-app-list-item:hover {
	color: white;
}

.show-processes-dialog-app-list-item:ltr {
	padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
	padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
	padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
	padding-left: 17px;
}

.show-processes-dialog-app-list-item-name {
}

/* ===================================================================
 * Policykit authentication dialog
 * ===================================================================*/
.polkit-dialog-user-layout {
	padding-left: 10px;
	spacing: 10px;
}

.polkit-dialog-user-layout:rtl {
	padding-left: 0px;
	padding-right: 10px;
}

.polkit-dialog-user-root-label {
	color: #ff0000;
}

/* ===================================================================
 * Magnifier
 * ===================================================================*/

.magnifier-zoom-region {
	border: 2px solid rgba(128, 0, 0, 255);
}

.magnifier-zoom-region.full-screen {
	border-width: 0px;
}

/* ===================================================================
 * On screen keyboard
 * ===================================================================*/

#keyboard {
	background: rgba(0,0,0,0.8);
}

.keyboard-layout {
	spacing: 10px;
	padding: 10px;
}

.keyboard-row {
	spacing: 15px;
}

.keyboard-key {
	min-height: 30px;
	min-width: 30px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(78,78,78,0.5);
	background-gradient-end: rgba(78,78,78,0.5);
	font-size: 14pt;
	font-weight: bold;
	border-radius: 2px;
	border: 1px solid rgba(78,78,78,0.9);
	color: white;
}

.keyboard-key:grayed {
	color: #808080;
	border-color: #808080;
}

.keyboard-key:checked,
.keyboard-key:hover {
	background: #303030;
	border: 3px solid white;
}

.keyboard-key:active {
	background: #808080;
}

.keyboard-subkeys {
	color: white;
	padding: 5px;
	-arrow-border-radius: 10px;
	-arrow-background-color: #090909;
	-arrow-border-width: 2px;
	-arrow-border-color: white;
	-arrow-base: 20px;
	-arrow-rise: 10px;
	-boxpointer-gap: 5px;
}

/* ###################################################################
 * Cinnamon Specific Section 
 * ###################################################################*/
/* ===================================================================
 * Menu (menu.js)
 * ===================================================================*/
/* Main menu title */

.menu-favorites-box {
	width: 70%;
	margin: auto;
	padding: 10px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(172,205,138,0.1);
	background-gradient-end: rgba(172,205,138,0.1);
	border: 1px solid rgba(255,255,255,0.2);
	border-radius: 0px;
	transition-duration: 300;
}

.menu-favorites-button {
	padding-top: 10px;
	padding-left: 10px;
	padding-right: 10px;
	padding-bottom: 10px;
	border: 1px solid rgba(0,0,0,0);
}

.menu-favorites-button:hover {
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.12);
	background-gradient-end: rgba(255,255,255,0.05);
	box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.15);
	border: 1px solid rgba(0,0,0,0.15);
	border-radius: 3px;
}

.menu-places-box {
	width: 70%;
	margin: auto;
	padding: 10px;
	border: 0px solid #666;
}

.menu-places-button {
	padding-top: 10px;
	padding-left: 10px;
	padding-right: 10px;
	padding-bottom: 10px;
}

.menu-categories-box {
	padding-top: 10px;
	padding-left: 30px;
	padding-right: 30px;
	padding-bottom: 10px;
}

.menu-applications-box {
	padding-top: 10px;
	padding-left: 10px;
	padding-right: 10px;
	padding-bottom: 0px;
}

.menu-application-button {
	width: 20em;
	height: 2.85em;
	border: 1px solid rgba(0,0,0,0);
}

.menu-application-button:hover {
	width: 20em;
	height: 2.85em;
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.12);
	background-gradient-end: rgba(255,255,255,0.05);
	box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.15);
	border: 1px solid rgba(0,0,0,0.15);
	border-radius: 3px;
}

.menu-application-button-selected {
	width: 20em;
	height: 2.85em;
	color: #ffffff;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(172,205,138,0.9);
	background-gradient-end: rgba(145,173,117,0.9);
	box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.3);
	border: 1px solid rgba(0,0,0,0.15);
	border-radius: 3px;
}

.menu-application-button-label:ltr { 
	padding-left: 5px		
}

.menu-application-button-label:rtl { 
	padding-right: 5px		
}

.menu-category-button {
	width: 12em;
	height: 2.85em;
	border: 1px solid rgba(0,0,0,0);
}

.menu-category-button-greyed {
	width: 12em;
	height: 2.85em;
	color: #9C9C9C;
	font-style: italic;
	border: 1px solid rgba(0,0,0,0);
}

.menu-category-button-selected {
	width: 12em;
	height: 2.85em;
	color: #ffffff;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(172,205,138,0.9);
	background-gradient-end: rgba(145,173,117,0.9);
	box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.3);
	border: 1px solid rgba(0,0,0,0.15);
	border-radius: 3px;
}

.menu-category-button-label:ltr { 
	padding-left: 5px		
}

.menu-category-button-label:rtl { 
	padding-right: 5px		
}

.menu-category-button-button:hover {
	background-color: #969696;
	border-radius: 8px;
}

.menu-application-button:ltr,
.menu-application-button:hover:ltr,
.menu-application-button-selected:ltr,
.menu-category-button:ltr,
.menu-category-button-greyed:ltr,
.menu-category-button-selected:ltr {
	padding-left: 7px;
}

.menu-application-button:rtl,
.menu-application-button:hover:rtl,
.menu-application-button-selected:rtl,
.menu-category-button:rtl,
.menu-category-button-greyed:rtl,
.menu-category-button-selected:rtl {
	padding-right: 7px;
}

/* Name and description of the currently hovered item in the menu
 * This appears on the bottom right hand corner of the menu*/
.menu-selected-app-box {
	padding-right: 30px;
	padding-left: 28px;
	text-align: right;
}

.menu-selected-app-box:rtl {
	padding-top: 10px;
	height: 30px;
}

.menu-selected-app-title {
	font-weight: bold;
}

.menu-selected-app-description {
	max-width: 150px;
}

.menu-search-box:ltr {
	padding-left: 30px;
}

.menu-search-box:rtl {
	padding-right: 30px;
}

#menu-search-entry {
	font-weight: normal;
	width: 23em;
	selection-background-color: #accd8a;
	selected-color: white;
	border-radius: 2px;
	padding: 4px;
	color: white;
	border: 1px solid rgba(200,200,200,0.12);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.3);
	background-gradient-end: rgba(0,0,0,0.3);
	box-shadow: inset 0px 1px 2px 0px rgba(0,0,0,0.5);
	caret-size: 1px;
}

.menu-search-entry-icon {
	icon-size: 1em;
	color: #c0c0c0;
}

/* Context menu (at the moment only for favorites) */
.menu-context-menu {
}

/* ===================================================================
 * Window list (windowList.js)
 * ===================================================================*/
.window-list-box {
	spacing: 2px;
}

.window-list-item-label {
	font-weight: bold;
	width: 15em;
	min-width: 5px;
}

.window-list-item-box {
	padding-left: 6px;
	padding-right: 6px;
	font-weight: bold;
	color: #fff;
	border: 1px solid rgba(255,255,255,0);
	border-top: 0px;
	border-bottom: 0px;
	transition-duration: 200;
}

.window-list-item-box:active,
.window-list-item-box:checked,
.window-list-item-box:focus { 
	border: 1px solid rgba(255,255,255,0.1);
	border-top: 0px;
	border-bottom: 0px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.1);
	background-gradient-end: rgba(0,0,0,0.25);
	color: white;
	box-shadow: inset 0px 1px 5px rgba(0,0,0,0.251);
}

.window-list-item-box:hover { 
	border: 1px solid rgba(255,255,255,0.4);
	border-top: 0px;
	border-bottom: 0px;
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.3);
	background-gradient-end: rgba(255,255,255,0.2);
}

.window-list-item-demands-attention {
	border: 1px solid rgba(255,52,52,0.4);
	border-top: 0px;
	border-bottom: 0px;
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,52,52,0.3);
	background-gradient-end: rgba(255,52,52,0.2);
}

/* ===================================================================
 * Sound Applet (status/volume.js)
 * ===================================================================*/
.sound-button-container {
	padding-right: 3px;
	padding-left: 3px;
}

.sound-button {
	padding: 4px 7px 5px;
}

.sound-button StIcon {
	icon-size: 1.4em;
}

.sound-track-infos {
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 5px;
	padding-bottom: 5px;
}

.sound-track-info {
	padding-top: 2px;
	padding-bottom: 2px;
}

.sound-track-info StIcon {
	icon-size: 1em;
}

.sound-track-info StLabel {
	padding-left: 5px;
	padding-right: 5px;
}

.sound-track-box {	
	padding-left: 15px;
	padding-right: 15px;	
	max-width: 220px;
}

.sound-volume-menu-item {
	padding: .4em 1.75em;
}

.sound-volume-menu-item StIcon {
	icon-size: 1.14em;
	padding-left: 8px;
	padding-right: 8px;
}

.sound-playback-control {
	padding-top: 5px;
	padding-bottom: 10px;
	padding-left: 10px;
	padding-right: 10px;
}

/* ===================================================================
 * Workspace Switcher applet (workspaceSwitcher.js)
 * ===================================================================*/
#workspaceSwitcher {
	spacing: 0px;
	padding: 3px;
	
}

.workspace-button {
	width: 20px;
	height: 10px;
	color: #cccccc;
	border: 1px;
	border-color: #a6a6a6;
	padding: 2px;
	transition-duration: 300;
}

.workspace-button:outlined {
	padding: 1px;
	background: #cccccc;
	color: #555555;
	box-shadow: inset 0px 0px 8px 1px rgba(255,255,255, 0.7);
}

/* ===================================================================
 * Workspace OSD
 * ===================================================================*/

.workspace-osd {
	border: 2px solid rgba(255,255,255,0.6);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(32,32,32,1.0);
	background-gradient-end: rgba(32,32,32,1.0);
	box-shadow: 0px 0px 2px 1px rgba(0,0,0,0.5);
	border-radius: 0;
	font-size: 16pt;
	font-weight: bold;
	color: #fff;

	padding-right: 42px;
	padding-left: 42px;
	padding-bottom: 30px;
	padding-top: 30px;
}

.expo-workspaces-name-entry {
	background-color: rgba(0,0,0,0.5);
	border: 1px solid rgba(255,255,255,0.25);
	border-radius: 6px;
	color: #fff;
	padding: 6px 8px;
	spacing: 25px;
	-cinnamon-caption-spacing: 1px;
}

/* ===================================================================
 * Notification Applet
 * ===================================================================*/

.notification-applet-padding {
	padding: .5em 1em;
}

.notification-applet-container {
	max-height: 100px;
}

/* ===================================================================
 * Panel Launchers Applet (panelLaunchers.js)
 * ===================================================================*/

.panel-launchers {
	spacing: 2px;
}

.launcher,
.panel-launcher {
	border: 1px solid rgba(255,255,255,0);
	border-top: 0px;
	border-bottom: 0px;
	padding-left: 1px;
	padding-right: 1px;
	transition-duration: 200;
}

.launcher:hover,
.panel-launcher:hover {
	border: 1px solid rgba(255,255,255,0.4);
	border-top: 0px;
	border-bottom: 0px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.3);
	background-gradient-end: rgba(255,255,255,0.2);
}

.panel-launcher-add-dialog-content-box {
	padding: 6px;
	spacing: 20px;
}

.panel-launcher-add-dialog-content-box-left {
	padding: 6px;
	spacing: 20px;
}

.panel-launcher-add-dialog-content-box-right {
	padding: 6px;
	spacing: 10px;
}

.panel-launcher-add-dialog-entry {
	font-weight: normal;
	width: 23em;
	selection-background-color: #accd8a;
	selected-color: white;
	border-radius: 2px;
	padding: 4px;
	color: white;
	border: 1px solid rgba(200,200,200,0.12);
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.3);
	background-gradient-end: rgba(0,0,0,0.3);
	box-shadow: inset 0px 1px 2px 0px rgba(0,0,0,0.5);
	caret-size: 1px;
}

/* ===================================================================
 * Overview corner
 * ===================================================================*/
#overview-corner {
	background-image: url("overview1.png");
}

#overview-corner:hover {
	background-image: url("overview2.png");
}

/* ===================================================================
 * Applets (applet.js) 
 * ===================================================================*/
.applet-box {
	padding-left: 6px;
	padding-right: 6px;
	font-weight: bold;
	color: #fff;
	border: 1px solid rgba(255,255,255,0);
	border-top: 0px;
	border-bottom: 0px;
	transition-duration: 200;
}

.applet-box:hover {
	border: 1px solid rgba(255,255,255,0.4);
	border-top: 0px;
	border-bottom: 0px;
	color: white;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(255,255,255,0.3);
	background-gradient-end: rgba(255,255,255,0.2);
}

.applet-box:active {
	border: 1px solid rgba(255,255,255,0.1);
	border-top: 0px;
	border-bottom: 0px;
	background-gradient-direction: vertical;
	background-gradient-start: rgba(0,0,0,0.1);
	background-gradient-end: rgba(0,0,0,0.25);
	color: white;
	box-shadow: inset 0px 1px 5px rgba(0,0,0,0.251);
}
