entry,
toolbar entry {
    border-image: url("assets/entry-border-normal.svg") 3 / 3px stretch;
}

scale slider,
scale slider.horizontal {
    background-image: url("assets/scale-slider-horizontal.svg");
}

scale slider:disabled,
scale slider.horizontal:disabled {
    background-image: url("assets/scale-slider-horizontal-insensitive.svg");
}

scale.vertical slider {
    background-image: url("assets/scale-slider-vertical.svg");
}

scale.vertical slider:disabled {
    background-image: url("assets/scale-slider-vertical-insensitive.svg");
}

scale.horizontal.marks-after slider,
scale.horizontal.marks-after slider:hover {
    background-image: url("assets/scale-slider-marks-below-horizontal.svg");
}

scale.horizontal.marks-after slider:disabled {
    background-image: url("assets/scale-slider-marks-below-horizontal-insensitive.svg");
}

scale.vertical.marks-after slider,
scale.vertical.marks-after slider:hover {
    background-image: url("assets/scale-slider-marks-below-vertical.svg");
}

scale.vertical.marks-after slider:disabled {
    background-image: url("assets/scale-slider-marks-below-vertical-insensitive.svg");
}

scale.horizontal.marks-before slider,
scale.horizontal.marks-before slider:hover {
    background-image: url("assets/scale-slider-marks-above-horizontal.svg");
}

scale.horizontal.marks-before slider:disabled {
    background-image: url("assets/scale-slider-marks-above-horizontal-insensitive.svg");
}

scale.vertical.marks-before slider {
    background-image: url("assets/scale-slider-marks-above-vertical.svg");
}

scale.vertical.marks-before slider:disabled {
    background-image: url("assets/scale-slider-marks-above-vertical-insensitive.svg");
}

.cursor-handle.top {
    background-image: url("assets/scale-slider-marks-above-horizontal-dark.svg");
}

.cursor-handle.bottom {
    background-image: url("assets/scale-slider-marks-below-horizontal-dark.svg");
}

button {
    border-image: url("assets/button-border.svg") 3 / 3px stretch;
}

button:hover,
button.flat:hover,
button:checked,
button:hover:active,
toolbar button:hover,
toolbar button:checked,
toolbar button:hover:active,
toolbar.primary-toolbar button:hover,
toolbar.primary-toolbar button:checked,
toolbar.primary-toolbar button:hover:active,
list row button:hover,
list row button:selected,
list row button:selected:hover {
    border-image: url("assets/button-active-border.svg") 3 3 3 3 / 3px 3px 3px 3px stretch;
}

button.default {
    border-image: url("assets/button-default-border.svg") 3 3 3 3 / 3px 3px 3px 3px stretch;
}

button.default:hover,
button.default:checked {
    border-image: url("assets/button-default-active-border.svg") 3 3 3 3 / 3px 3px 3px 3px stretch;
}

/* overrride for osd */
toolbar.osd button:hover,
toolbar.osd button:checked,
toolbar.osd button:hover:first-child,
toolbar.osd button:checked:first-child,
toolbar.osd button:hover:last-child,
toolbar.osd button:checked:last-child {
    border-image: none;
}

switch:checked {
    border-image: url("assets/switch-trough-border-active.svg") 3 3 3 3 / 3px 3px 3px 3px stretch;
}

popover.scale-popup button.flat.image-button:disabled {
   background-image: none;
   background-color: transparent;
   border-image: none;
   border-color: transparent;
}

popover.scale-popup button.flat.image-button {
   background-image: none;
   border-image: url("assets/button-border.svg") 3 3 3 3 / 3px 3px 3px 3px stretch;
}

popover.scale-popup button.flat.image-button:hover {
   border-image: url("assets/button-active-border.svg") 3 3 3 3 / 3px 3px 3px 3px stretch;
    -gtk-icon-effect: highlight;
}

/*************************
 * Check and Radio items *
 *************************/

/* mix of old and new syntax is for broken firefox */

menuitem radio,
menuitem radio:hover,
menuitem radio:disabled,
menuitem check,
menuitem check:hover,
menuitem check:disabled,
menu menuitem .radio,
menu menuitem .radio:hover,
menu menuitem .radio:disabled,
menu menuitem .check,
menu menuitem .check:hover,
menu menuitem .check:disabled {
	background-color: transparent;
	background-image: none;
	border-style: none;
	border-image: none;
	min-height: 12px;
    min-width: 12px;
}

menuitem radio,
menu menuitem .radio {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-unselected.svg"));
}

menuitem radio:checked,
menu menuitem .radio:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked.svg"));
}

menuitem radio:checked:hover,
menu menuitem .radio:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked-prelight.svg"));
}

menuitem radio:checked:disabled,
menu menuitem .radio:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked-insensitive.svg"));
}

menuitem radio:indeterminate,
menu menuitem .radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed.svg"));
}

menuitem radio:indeterminate:hover,
menu menuitem .radio:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed-prelight.svg"));
}

menuitem radio:indeterminate:disabled,
menu menuitem .radio:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed-insensitive.svg"));
}

menuitem check,
menu menuitem .check {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-unchecked.svg"));
}

menuitem check:checked,
menu menuitem .check:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked.svg"));
}

menuitem check:checked:hover,
menu menuitem .check:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked-prelight.svg"));
}

menuitem check:disabled,
menu menuitem .check:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-unchecked-insensitive.svg"));
}

menuitem check:checked:disabled,
menu menuitem .check:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked-insensitive.svg"));
}

menuitem check:indeterminate,
menu menuitem .check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed.svg"));
}

menuitem check:indeterminate:hover,
menu menuitem .check:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed-prelight.svg"));
}

menuitem check:indeterminate:disabled,
menu menuitem .check:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed-insensitive.svg"));
}

/* draw regular check and radio items using our SVG assets */
check,
check row:selected,
check row:selected:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked.svg"));
}

check:disabled,
check row:selected:disabled,
check row:selected:focus:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive.svg"));
}

check:checked,
check row:selected:checked,
check row:selected:focus:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked.svg"));
}

check:checked:disabled,
check row:selected:checked:disabled,
check row:selected:focus:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive.svg"));
}

check:indeterminate,
check row:selected:indeterminate,
check row:selected:focus:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed.svg"));
}

check:indeterminate:disabled,
check row:selected:indeterminate:disabled,
check row:selected:focus:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive.svg"));
}

radio,
radio row:selected,
radio row:selected:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected.svg"));
}

radio:disabled,
radio row:selected:disabled,
radio row:selected:focus:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-insensitive.svg"));
}

radio:checked,
radio row:selected:checked,
radio row:selected:focus:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected.svg"));
}

radio:checked:disabled,
radio row:selected:checked:disabled,
radio row:selected:focus:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected-insensitive.svg"));
}

radio:indeterminate,
radio row:selected:indeterminate,
radio row:selected:focus:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed.svg"));
}

radio:indeterminate:disabled,
radio row:selected:indeterminate:disabled,
radio row:selected:focus:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive.svg"));
}

