/*************************
 * Check and Radio items *
 *************************/

/* First draw regular check and radio items */
/* mix of old and new syntax is for broken firefox */

check,
.check,
check row:selected,
check row:selected:focus {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-dark.svg"));
}

notebook check,
notebook check row:selected,
notebook check row:selected:focus,
treeview check,
treeview check row:selected,
treeview check row:selected:focus {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-lessdark.svg"));
}

check:disabled,
.check:disabled,
check row:selected:disabled,
check row:selected:focus:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-dark.svg"));
}

check:checked,
.check:checked,
check row:selected:checked,
check row:selected:active,
check row:selected:focus:checked,
check row:selected:focus:active {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-dark.svg"));
}

notebook check:checked,
notebook check row:selected:checked,
notebook check row:selected:focus:checked,
treeview check:checked,
treeview check row:selected:checked,
treeview check row:selected:focus:checked,
notebook check row:selected:active,
notebook check row:selected:focus:active,
treeview check row:selected:active,
treeview check row:selected:focus:active {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-lessdark.svg"));
}

check:checked:disabled,
.check:checked:disabled,
check row:selected:checked:disabled,
check row:selected:focus:checked:disabled,
check row:selected:active:disabled,
check row:selected:focus:active:disabled
{
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-dark.svg"));
}

check:indeterminate,
.check:indeterminate,
check row:selected:indeterminate,
check row:selected:focus:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-dark.svg"));
}

notebook check:indeterminate,
notebook check row:selected:indeterminate,
notebook check row:selected:focus:indeterminate,
treeview check:indeterminate,
treeview check row:selected:indeterminate,
treeview check row:selected:focus:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-lessdark.svg"));
}

check:indeterminate:disabled,
.check:indeterminate:disabled,
check row:selected:indeterminate:disabled,
check row:selected:focus:indeterminate:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-dark.svg"));
}

radio,
.radio,
radio row:selected,
radio row:selected:focus {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-dark.svg"));
}

notebook radio,
notebook radio row:selected,
notebook radio row:selected:focus,
treeview radio,
treeview radio row:selected,
treeview radio row:selected:focus {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-lessdark.svg"));
}

radio:disabled,
.radio:disabled,
radio row:selected:disabled,
radio row:selected:focus:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-insensitive-dark.svg"));
}

radio:checked,
.radio:checked,
radio row:selected:checked,
radio row:selected:active,
radio row:selected:focus:checked,
radio row:selected:focus:active {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-selected-dark.svg"));
}

notebook radio:checked,
notebook  radio row:selected:checked,
notebook  radio row:selected:focus:checked,
treeview radio:checked,
treeview radio row:selected:checked,
treeview radio row:selected:focus:checked,
notebook  radio row:selected:active,
notebook  radio row:selected:focus:active,
treeview radio row:selected:active,
treeview radio row:selected:focus:active {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-selected-lessdark.svg"));
}

radio:checked:disabled,
.radio:checked:disabled,
radio row:selected:checked:disabled,
radio row:selected:focus:checked:disabled,
radio row:selected:active:disabled,
 adio row:selected:focus:active:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-selected-insensitive-dark.svg"));
}

radio:indeterminate,
.radio:indeterminate,
radio row:selected:indeterminate,
radio row:selected:focus:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-dark.svg"));
}

notebook radio:indeterminate,
notebook radio row:selected:indeterminate,
notebook radio row:selected:focus:indeterminate,
treeview radio:indeterminate,
treeview radio row:selected:indeterminate,
treeview radio row:selected:focus:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-lessdark.svg"));
}

radio:indeterminate:disabled,
.radio:indeterminate:disabled,
radio row:selected:indeterminate:disabled,
radio row:selected:focus:indeterminate:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-dark.svg"));
}

sidebar radio:checked,
sidebar radio:checked:focus,
sidebar radio:checked:hover {
	-gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-checked-dark.svg"));
}

sidebar  radio:hover {
	-gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-prelight.svg"));
}

sidebar radio:checked:selected,
sidebar radio:checked:selected:focus {
	-gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-selected-dark.svg"));
}

sidebar radio:selected:hover,
sidebar radio:selected:focus {
	-gtk-icon-source: -gtk-scaled(url("assets/sidebar-radio-selected-prelight.svg"));
}

/* Now draw menu check and radio items */
/* mix of old and new syntax is for broken firefox */

menuitem radio,
menuitem radio:hover,
menuitem radio:disabled,
menuitem check,
menuitem check:hover,
menuitem check:disabled,
menu menuitem .radio,
menu menuitem .radio:hover,
menu menuitem .radio:disabled,
menu menuitem .check,
menu menuitem .check:hover,
menu menuitem .check:disabled {
	background-color: transparent;
	background-image: none;
	border-style: none;
	border-image: none;
	min-height: 12px;
  	min-width: 12px;
}

menuitem radio,
menu menuitem .radio {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-lessdark.svg"));
}

menuitem radio:checked,
menu menuitem .radio:checked {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked.svg"));
}

menuitem radio:checked:hover,
menu menuitem .radio:checked:hover {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked-prelight.svg"));
}

menuitem radio:checked:disabled,
menu menuitem .radio:checked:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-checked-insensitive.svg"));
}

menuitem radio:indeterminate,
menu menuitem .radio:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed.svg"));
}

menuitem radio:indeterminate:hover,
menu menuitem .radio:indeterminate:hover {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed-prelight.svg"));
}

menuitem radio:indeterminate:disabled,
menu menuitem .radio:indeterminate:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-mixed-insensitive.svg"));
}

menuitem check,
menu menuitem .check {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-lessdark.svg"));
}

menuitem check:checked,
menu menuitem .check:checked {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked.svg"));
}

menuitem check:checked:hover,
menu menuitem .check:checked:hover {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked-prelight.svg"));
}

menuitem check:checked:disabled,
menu menuitem .check:checked:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-checked-insensitive.svg"));
}

menuitem check:indeterminate,
menu menuitem .check:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed.svg"));
}

menuitem check:indeterminate:hover,
menu menuitem .check:indeterminate:hover {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed-prelight.svg"));
}

menuitem check:indeterminate:disabled,
menu menuitem .check:indeterminate:disabled {
	-gtk-icon-source: -gtk-scaled(url("assets/checkbox-menuitem-mixed-insensitive.svg"));
}

/***********
 * Entries *
 ***********/

/*.entry:focus {
    border-image: url("assets/entry-border-focused-dark.svg") 3 / 3px stretch;
}*/

primary-toolbar combobox.combobox-entry  button:checked,
primary-toolbar combobox.combobox-entry  button:hover:checked,
primary-toolbar combobox.combobox-entry  button:active,
primary-toolbar combobox.combobox-entry  button:hover:active,
primary-toolbar combobox.combobox-entry  button,
combobox.combobox-entry  button:checked,
combobox.combobox-entry  button:hover:checked,
combobox.combobox-entry  button:active,
combobox.combobox-entry  button:hover:active,
combobox.combobox-entry  button {
	border-image: url("assets/entry-border-normal-dark.svg") 3 / 3px stretch;
}

/***********
 * Sliders *
 ***********/

scale slider,
scale slider.horizontal {
	background-image: url("assets/scale-slider-horizontal-dark.svg");
	min-width: 16px;
	min-height: 16px;
}

scale slider:disabled,
scale slider.horizontal:disabled {
	background-image: url("assets/scale-slider-horizontal-insensitive-dark.svg");
}

scale slider.vertical {
	background-image: url("assets/scale-slider-vertical-dark.svg");
	min-width: 16px;
	min-height: 16px;
}

scale slider.vertical:disabled {
	background-image: url("assets/scale-slider-vertical-insensitive-dark.svg");
}

scale.scale-has-marks-above slider.horizontal {
	background-image: url("assets/scale-slider-marks-above-horizontal-dark.svg");
}

scale.scale-has-marks-above slider.horizontal:disabled {
	background-image: url("assets/scale-slider-marks-above-horizontal-insensitive-dark.svg");
}

scale.scale-has-marks-above slider.vertical {
	background-image: url("assets/scale-slider-marks-above-vertical-dark.svg");
}

scale.scale-has-marks-above slider.vertical:disabled {
	background-image: url("assets/scale-slider-marks-above-vertical-insensitive-dark.svg");
}

scale.scale-has-marks-below slider.horizontal {
	background-image: url("assets/scale-slider-marks-below-horizontal-dark.svg");
}

scale.scale-has-marks-below slider.horizontal:disabled {
	background-image: url("assets/scale-slider-marks-below-horizontal-insensitive-dark.svg");
}

scale.scale-has-marks-below slider.vertical {
	background-image: url("assets/scale-slider-marks-below-vertical-dark.svg");
}

scale.scale-has-marks-below slider.vertical:disabled {
	background-image: url("assets/scale-slider-marks-below-vertical-insensitive-dark.svg");
}

.cursor-handle.top {
	background-image: url("assets/scale-slider-marks-above-horizontal-dark.svg");
}

.cursor-handle.bottom {
	background-image: url("assets/scale-slider-marks-below-horizontal-dark.svg");
}

/*the little usefull helper*/

grip {
background-color: transparent;
background-image: url("assets/resize-grip.svg");
}

/***********
 * Buttons *
 ***********/

button {
	border-image: url("assets/button-border-dark.svg") 3 / 3px stretch;
}

button:checked,
button:hover:checked,
button:active,
button:hover:active
list-row button:hover,
list-row button:selected,
list-row button:selected:hover {
	border-image: url("assets/button-active-border-dark.svg") 3 / 3px stretch;
}

button:focus,
notebook  button:focus,
button.default,
notebook  button.default {
	border-image: url("assets/button-default-border-dark.svg") 3 / 3px stretch;
}

button.default:checked,
notebook  button.default:checked,
button.default:active,
notebook  button.default:active {
	border-image: url("assets/button-default-active-border-dark.svg") 3 / 3px stretch;
}

toolbar  button:checked,
primary-toolbar button:checked,
primary-toolbar toolbar button:checked,
primary-toolbar.toolbar button:checked,
toolbar  button:active,
primary-toolbar button:active,
primary-toolbar toolbar button:active,
primary-toolbar toolbar button:active,
toolbar combobox button,
primary-toolbar toolbar combobox button,
primary-toolbar.toolbar combobox button/*,
toolbar  button:active:hover,
primary-toolbar .toolbar  button:active:hover,
primary-toolbar.toolbar  button:active:hover,
primary-toolbar .toolbar combobox  button:hover,
primary-toolbar.toolbar combobox  button:hover*/ {
	border-image: url("assets/primary-toolbar-button-active-border-dark.svg") 3 / 3px stretch;
}

/**************
 * Tree Views *
 **************/

treeview row:selected {
	border-image: url("assets/treeview-border-dark.svg") 3 / 3px stretch;
}

treeview row:selected:focus {
	border-image: url("assets/treeview-focus-border-dark.svg") 3 / 3px stretch;
}

/* menuitem :hover,
.menu  menuitem :hover {
	border-image: url("assets/menu-border-dark.svg") 3 / 3px stretch;
}*/


/*********************
 * Notebook and Tabs *
 *********************/

notebook tab:checked {
	border-image: url("assets/tab-active-border.svg") 3 3 0 3 / 3px 3px 0px 3px stretch;
}

notebook tab.bottom:checked {
	border-image: url("assets/tab-bottom-active-border.svg") 0 3 3 3 / 0px 3px 3px 3px stretch;
}

notebook tab.left:checked {
	border-image: url("assets/tab-left-active-border.svg") 3 0 3 3 / 3px 0px 3px 3px stretch;
}

notebook tab.right:checked {
	border-image: url("assets/tab-right-active-border.svg") 3 3 3 0 / 3px 3px 3px 0px stretch;
}

/*********************
 * Scrollbar buttons *
 *********************/
scrollbar.vertical button.up {
    -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
    -gtk-icon-effect: highlight;
}

scrollbar.vertical button.down {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
    -gtk-icon-effect: highlight;
}

scrollbar.horizontal button.up {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
    -gtk-icon-effect: highlight;
}

scrollbar.horizontal button.down {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    -gtk-icon-effect: highlight;
}
