### This file styles Caja. ###

style "caja-window-base" { bg[NORMAL] = @bg_color }

style "caja-sidebar" = "murrine-sidebar" {
	GtkTreeView::horizontal_separator = 15
	GtkTreeView::vertical_separator = 2
	text[NORMAL] = @fg_color
	bg[NORMAL]  = mix (0.60, shade (1.15, @bg_color), @bg_color)

	GtkTreeView::odd_row_color = mix (0.60, shade (1.15, @bg_color), @bg_color)
	GtkTreeView::even_row_color = mix (0.60, shade (1.15, @bg_color), @bg_color)
}

style "caja-view" {
	xthickness = 0
	ythickness = 0
}

style "caja-handle" {
	GtkPaned::handle-size = 1
	
	engine "pixmap" {
		# for the thin gray line separating the sidepane and viewpane
		image {
			function	= HANDLE
			recolorable	= TRUE
			file		= "Handles/handle-caja.png"
			stretch		= TRUE
			border		= { 0, 0, 0, 0 }
		}
	}
}

style "caja-statusbar"
{
	bg[NORMAL]  = mix (0.60, shade (1.10, @bg_color), @bg_color)
	base[NORMAL] = @base_color
	fg[NORMAL] = shade (1.2, @fg_color)

	engine "pixmap" {
		image
		{
		function        = HANDLE
		recolorable     = TRUE
		file            = "Handles/resize-grip.png"
		state           = NORMAL
		stretch         = TRUE
		border          = { 0, 0, 1, 0 }
		}
	}
}

style "caja-location"
{
	bg[NORMAL]  = mix (0.60, shade (1.05, @bg_color), @bg_color)
}

style "caja-pathbar"
{	
    bg[PRELIGHT] 	= shade(0.91, @bg_color)
    bg[ACTIVE] 		= shade(0.76, @bg_color)
	bg[SELECTED] 	= shade(0.80, @selected_bg_color)
	bg[INSENSITIVE] = shade(0.83, @bg_color)

    fg[NORMAL]          = @fg_color
	fg[PRELIGHT]	    = @fg_color
	fg[ACTIVE]	        = @fg_color
	fg[SELECTED]	    = @fg_color_dark
}

# workaround for toolbar dropdown menu and toolbar button
style "caja-toolbar-button"
{
    xthickness	= 3
    ythickness	= 2

	bg[NORMAL]		= shade(0.80, @bg_color_dark)
    bg[PRELIGHT] 	= shade(0.91, @bg_color_dark)
    bg[ACTIVE] 		= shade(0.76, @bg_color_dark)
	bg[SELECTED] 	= shade(0.80, @selected_bg_color)
	bg[INSENSITIVE] = shade(0.83, @bg_color_dark)

	fg[NORMAL]          = @fg_color_dark
	fg[PRELIGHT]	    = @selected_fg_color
	fg[ACTIVE]	        = @fg_color_dark
	fg[SELECTED]	    = @fg_color_dark

    text[NORMAL]        = @fg_color_dark
	text[PRELIGHT]	    = @selected_fg_color
	text[ACTIVE]	    = @fg_color_dark
	text[SELECTED]	    = @fg_color_dark

	engine "murrine" {
		gradient_shades     	= {2.63,1.17,1.17,1.17}
		border_shades           = {5.10, 5.00}
		contrast                = 0.80
		roundness               = 5 # 0 = squared
		lightborderstyle        = 1
		lightborder_shade       = 1.1
		glow_shade              = 1.0
		textstyle               = 1
		text_shade			    = 1.15
	}
}

############################################
# CAJA
# Order of assignment is important
#############################################

widget_class "*CajaSidePane.*"                 style "caja-sidebar"
widget_class "*Caja*Places*Sidebar*"           style "caja-sidebar"
widget_class "*Caja*Side*.GtkWidget"           style "caja-sidebar"
widget_class "*Caja*Side*Title*"               style "caja-sidebar"

widget "*CajaNavigationWindow"                 style "caja-window-base"

widget_class "*Caja*Scrollbar"                 style "murrine-scrollbar"
widget_class "*CajaSidePane.*Scrollbar"        style:highest "murrine-scrollbar"
widget_class "*Caja*Statusbar*"                style "caja-statusbar"

widget "*Caja*Splitter"                        style "caja-handle"
widget_class "*Caja*View*"                     style "caja-view"
widget_class "*Caja*Notebook"                  style "murrine-notebook"

widget_class "*Caja*<GtkTreeView>.<GtkButton>" style "murrine-treeview-header"
widget_class "*Caja*<GtkCTree>.<GtkButton>"    style "murrine-treeview-header"
widget_class "*Caja*<GtkList>.<GtkButton>"     style "murrine-treeview-header"
widget_class "*Caja*<GtkCList>.<GtkButton>"    style "murrine-treeview-header"

widget_class "*CajaPathBar*"                   style "caja-pathbar" 
widget "*.caja-extra-view-widget" 		       style : highest "caja-location"

# workaround for toolbar dropdown menu and toolbar button
widget_class "*Caja*Toolbar*Button" style "caja-toolbar-button"
widget_class "*Caja*Toolbar*.<GtkComboBox>.<GtkCellView>" style "caja-toolbar-button"

