style "terminal"
{
	
	bg[NORMAL]	= @bg_color
	bg[ACTIVE]	= @bg_color
	bg[PRELIGHT]	= @bg_color
	bg[SELECTED]	= @bg_color
	base[NORMAL]	= @bg_color
}

style "terminal-scrollbar" = "scrollbar"
{

}

style "terminal-screen"
{
	text[NORMAL] = @selected_fg_color
	base[NORMAL] = "#32424C"

	TerminalScreen::background-darkness = 0.95
}

widget "*TerminalWindow.*.TerminalScreen*"              style "terminal-screen"

style "terminal-notebook"  
{
	bg[NORMAL]		= shade( 0.85, @sidebar_background)
	bg[ACTIVE]		= shade( 0.70, @sidebar_background)
	fg[NORMAL]      = shade (0.80, @text_color) # text selected tab
	fg[ACTIVE] 		= shade( 0.28, @sidebar_background)	# text unselected tab

	engine "murrine"
	{
		gradient_shades		= {1.00,0.96,0.92,0.88}
		highlight_shade     = 1.03
		roundness       	= 0
		contrast        	= 0.0	
		
		## things that don't work:
		#glow_shade	= 0.8
		#glowstyle           = 2
		#focusstyle	    = 3
		#glazestyle          = 3
		#border_shades	= { 0.45, 2.5 }
		#prelight_shade	= 1.5
	}
}

style "notebook-button" {
    xthickness		= 0
    ythickness		= 0
	bg[ACTIVE]		= shade (0.68, @sidebar_background)    
    bg[PRELIGHT]    = shade (0.75, @sidebar_background)
	engine "murrine"
	{
		gradient_shades		= {1.00,1.00,1.00,1.00}
		contrast        	= 0.6
		roundness       	= 0
	}    
}

class "*TerminalWindow"										style "terminal"
widget_class "TerminalWindow*GtkNotebook"					style "terminal-notebook"
widget_class "TerminalWindow*<GtkNotebook>*<GtkLabel>" 	style "terminal-notebook"
widget_class "TerminalWindow*<GtkNotebook>*<GtkButton>" 	style "notebook-button"
# widget "*TerminalWindow.*.GtkVScrollbar"					style "terminal-scrollbar"


