style "gmusicbrowser-handle"
{
	GtkPaned::handle-size	= 1
}

widget "Shimmer Desktop.VBMain.HPMain"	style "gmusicbrowser-handle"
widget_class "Shimmer Desktop.VBMain.VBTop.HBTop.*" style "murrine-toolbar"
