/*************** core colors * */
/* Core colors are only used in the current file, as bases for other color declarations. */
/* Core color for blue widgets in TraditionalOK. */
/* Core color for gray widgets in TraditionalOK. */
/* hover */
/* active */
/* insensitive */
/* active insensitive */
/* primary toolbar focus */
/* primary toolbar focus hover */
/*************************** Check and Radio buttons * */
* { padding: 0; -GtkToolButton-icon-spacing: 4; -GtkTextView-error-underline-color: #c7162b; -GtkScrolledWindow-scrollbar-spacing: 0; -GtkToolItemGroup-expander-size: 11; -GtkWidget-text-handle-width: 20; -GtkWidget-text-handle-height: 24; -GtkDialog-button-spacing: 4; -GtkDialog-action-area-border: 0; outline-color: alpha(currentColor,0.3); outline-style: dashed; outline-offset: -3px; outline-width: 1px; -gtk-outline-radius: 2px; -gtk-secondary-caret-color: #89addb; }

/*************** Base States * */
.background { color: #000000; background-color: #edeceb; }

.background:backdrop { color: #2f2f2f; background-color: #edeceb; text-shadow: none; -gtk-icon-shadow: none; }

/* These wildcard seems unavoidable, need to investigate. Wildcards are bad and troublesome, use them with care, or better, just don't. Everytime a wildcard is used a kitten dies, painfully. */
*:disabled { -gtk-icon-effect: dim; }

.gtkstyle-fallback { color: #000000; background-color: #edeceb; }

.gtkstyle-fallback:hover { color: #000000; background-color: white; }

.gtkstyle-fallback:active { color: #000000; background-color: #d5d3d0; }

.gtkstyle-fallback:disabled { color: #a9a5a2; background-color: #edeceb; }

.gtkstyle-fallback:selected { color: #ffffff; background-color: #89addb; }

.view, iconview, .view text, iconview text, textview text { color: #1a1a1a; background-color: #ffffff; }

.view:backdrop, iconview:backdrop, .view text:backdrop, iconview text:backdrop, textview text:backdrop { color: rgba(26, 26, 26, 0.69); background-color: #fcfcfc; }

.view:backdrop:disabled, iconview:backdrop:disabled, .view text:backdrop:disabled, iconview text:backdrop:disabled, textview text:backdrop:disabled { color: #c9c6c3; }

.view:disabled, iconview:disabled, .view text:disabled, iconview text:disabled, textview text:disabled { color: #a9a5a2; background-color: #edeceb; }

.view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected, .view text:selected:focus, iconview text:selected:focus, textview text:selected:focus, .view text:selected, iconview text:selected, textview text:selected { border-radius: 3px; }

textview border { background-color: #f6f6f5; }

.rubberband, rubberband, flowbox rubberband, treeview.view rubberband, .content-view rubberband, .content-view .rubberband { border: 1px solid #6292d0; background-color: rgba(98, 146, 208, 0.2); }

flowbox flowboxchild { padding: 3px; }

flowbox flowboxchild:selected { outline-offset: -2px; }

.content-view .tile { margin: 2px; background-color: transparent; border-radius: 0; padding: 0; }

.content-view .tile:backdrop { background-color: transparent; }

.content-view .tile:active, .content-view .tile:selected { background-color: transparent; }

.content-view .tile:disabled { background-color: transparent; }

label { caret-color: currentColor; }

label selection { background-color: #89addb; color: #ffffff; }

label:disabled { color: #a9a5a2; }

button label:disabled { color: inherit; }

label:disabled:backdrop { color: #c9c6c3; }

button label:disabled:backdrop { color: inherit; }

label.error { color: #c7162b; }

label.error:disabled { color: rgba(199, 22, 43, 0.5); }

label.error:disabled:backdrop { color: rgba(199, 22, 43, 0.4); }

.dim-label, label.separator, .titlebar:not(headerbar) .subtitle, headerbar .subtitle { opacity: 0.55; text-shadow: none; }

assistant .sidebar { background-color: #ffffff; border-top: 1px solid #a29e9b; }

assistant .sidebar:backdrop { background-color: #fcfcfc; border-color: #b1aeab; }

assistant.csd .sidebar { border-top-style: none; }

assistant .sidebar label { padding: 6px 12px; }

assistant .sidebar label.highlight { background-color: #bebdbc; }

.csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier, .csd popover.background.osd, popover.background.osd, .app-notification, .app-notification.frame, .osd .scale-popup, .osd { color: #eeeeec; border: none; background-color: rgba(37, 38, 33, 0.8); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

popover.background.touch-selection:backdrop, popover.background.magnifier:backdrop, popover.background.osd:backdrop, .app-notification:backdrop, .osd .scale-popup:backdrop, .osd:backdrop { text-shadow: none; -gtk-icon-shadow: none; }

/********************* Spinner Animation * */
@keyframes spin { to { -gtk-icon-transform: rotate(1turn); } }

spinner { background: none; opacity: 0; -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }

spinner:backdrop { color: #2f2f2f; }

spinner:checked { opacity: 1; animation: spin 1s linear infinite; }

spinner:checked:disabled { opacity: 0.5; }

/********************** General Typography * */
.large-title { font-weight: 300; font-size: 24pt; }

.title-1 { font-weight: 800; font-size: 20pt; }

.title-2 { font-weight: 800; font-size: 15pt; }

.title-3 { font-weight: 700; font-size: 15pt; }

.title-4 { font-weight: 700; font-size: 13pt; }

.heading { font-weight: 700; font-size: 11pt; }

.body { font-weight: 400; font-size: 11pt; }

.caption-heading { font-weight: 700; font-size: 9pt; }

.caption { font-weight: 400; font-size: 9pt; }

/**************** Text Entries * */
spinbutton:not(.vertical), entry { min-height: 32px; padding-left: 8px; padding-right: 8px; border: 1px solid; border-radius: 4px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: #1a1a1a; border-color: #a29e9b; background-color: #ffffff; box-shadow: inset 0 0 0 1px rgba(162, 158, 155, 0); }

spinbutton:not(.vertical) image.left, entry image.left { margin-right: 6px; }

spinbutton:not(.vertical) image.right, entry image.right { margin-left: 6px; }

spinbutton.flat:focus:not(.vertical), spinbutton.flat:backdrop:not(.vertical), spinbutton.flat:disabled:not(.vertical), spinbutton.flat:backdrop:disabled:not(.vertical), spinbutton.flat:not(.vertical), entry.flat:focus, entry.flat:backdrop, entry.flat:disabled, entry.flat:backdrop:disabled, entry.flat { min-height: 0; padding: 2px; background-color: transparent; border-color: transparent; border-radius: 0; }

spinbutton:focus:not(.vertical), entry:focus { box-shadow: inset 0px 1px #e1ecfa, inset 1px 0px #e1ecfa, inset -1px 0px #e1ecfa, inset 0px -1px #e1ecfa; border-color: #456081; }

spinbutton:disabled:not(.vertical), entry:disabled { color: #a9a5a2; border-color: #a29e9b; background-color: #edeceb; box-shadow: none; }

spinbutton:backdrop:not(.vertical), entry:backdrop { color: rgba(26, 26, 26, 0.69); border-color: #b1aeab; background-color: #fcfcfc; box-shadow: none; transition: 200ms ease-out; }

spinbutton:backdrop:disabled:not(.vertical), entry:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-color: #edeceb; box-shadow: none; }

spinbutton.error:not(.vertical), entry.error { color: #c7162b; border-color: #c7162b; }

spinbutton.error:focus:not(.vertical), entry.error:focus { box-shadow: inset 0px 1px #e1ecfa, inset 1px 0px #e1ecfa, inset -1px 0px #e1ecfa, inset 0px -1px #e1ecfa; border-color: #456081; }

spinbutton.error:not(.vertical) selection, entry.error selection { background-color: #c7162b; }

spinbutton.warning:not(.vertical), entry.warning { color: #f99b11; border-color: #f99b11; }

spinbutton.warning:focus:not(.vertical), entry.warning:focus { box-shadow: inset 0px 1px #e1ecfa, inset 1px 0px #e1ecfa, inset -1px 0px #e1ecfa, inset 0px -1px #e1ecfa; border-color: #456081; }

spinbutton.warning:not(.vertical) selection, entry.warning selection { background-color: #f99b11; }

spinbutton:not(.vertical) image, entry image { color: #333333; }

spinbutton:not(.vertical) image:hover, entry image:hover { color: #000000; }

spinbutton:not(.vertical) image:active, entry image:active { color: #89addb; }

spinbutton:not(.vertical) image:backdrop, entry image:backdrop { color: #585858; }

spinbutton:drop(active):focus:not(.vertical), spinbutton:drop(active):not(.vertical), entry:drop(active):focus, entry:drop(active) { border-color: #93af66; box-shadow: inset 0 0 0 1px #93af66; }

.osd spinbutton:not(.vertical), .osd entry { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:focus:not(.vertical), .osd entry:focus { color: white; border-color: #89addb; background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: inset 0 0 0 1px #a29e9b; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:backdrop:not(.vertical), .osd entry:backdrop { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd spinbutton:disabled:not(.vertical), .osd entry:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(37, 38, 33, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

spinbutton:not(.vertical) progress, entry progress { margin: 2px -6px; background-color: transparent; background-image: none; border-radius: 0; border-width: 0 0 2px; border-color: #4893f2; border-style: solid; box-shadow: none; }

spinbutton:not(.vertical) progress:backdrop, entry progress:backdrop { background-color: transparent; }

.linked:not(.vertical) > spinbutton:focus:not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:focus:not(.vertical) + button, .linked:not(.vertical) > spinbutton:focus:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > entry:focus + spinbutton:not(.vertical), .linked:not(.vertical) > entry:focus + button, .linked:not(.vertical) > entry:focus + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:focus:not(.vertical) + entry, .linked:not(.vertical) > entry:focus + entry { border-left-color: #a29e9b; }

.linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + button, .linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > entry:focus.error + spinbutton:not(.vertical), .linked:not(.vertical) > entry:focus.error + button, .linked:not(.vertical) > entry:focus.error + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + entry, .linked:not(.vertical) > entry:focus.error + entry { border-left-color: #c7162b; }

.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > entry:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) > entry:drop(active) + button, .linked:not(.vertical) > entry:drop(active) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + entry, .linked:not(.vertical) > entry:drop(active) + entry { border-left-color: #93af66; }

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled), .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):not(.vertical) { border-top-color: #e3e2e1; }

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled):backdrop, .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):backdrop:not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled):backdrop, .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):backdrop:not(.vertical) { border-top-color: #e6e5e4; }

.linked.vertical > spinbutton:disabled:not(.vertical) + spinbutton:disabled:not(.vertical), .linked.vertical > spinbutton:disabled:not(.vertical) + entry:disabled, .linked.vertical > entry:disabled + spinbutton:disabled:not(.vertical), .linked.vertical > entry:disabled + entry:disabled { border-top-color: #e3e2e1; }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus:not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:focus:not(:only-child), .linked.vertical > entry + spinbutton:focus:not(:only-child):not(.vertical), .linked.vertical > entry + entry:focus:not(:only-child) { border-top-color: #a29e9b; }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus.error:not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:focus.error:not(:only-child), .linked.vertical > entry + spinbutton:focus.error:not(:only-child):not(.vertical), .linked.vertical > entry + entry:focus.error:not(:only-child) { border-top-color: #c7162b; }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:drop(active):not(:only-child), .linked.vertical > entry + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > entry + entry:drop(active):not(:only-child) { border-top-color: #93af66; }

.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:focus:not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:focus:not(:only-child) + entry, .linked.vertical > entry:focus:not(:only-child) + button, .linked.vertical > entry:focus:not(:only-child) + combobox > box > button.combo { border-top-color: #a29e9b; }

.linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:focus.error:not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:focus.error:not(:only-child) + entry, .linked.vertical > entry:focus.error:not(:only-child) + button, .linked.vertical > entry:focus.error:not(:only-child) + combobox > box > button.combo { border-top-color: #c7162b; }

.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:drop(active):not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:drop(active):not(:only-child) + entry, .linked.vertical > entry:drop(active):not(:only-child) + button, .linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo { border-top-color: #93af66; }

spinbutton.error:not(.vertical), entry.error { color: #c7162b; }

treeview entry:focus:dir(rtl), treeview entry:focus:dir(ltr) { background-color: #ffffff; transition-property: color, background; }

treeview entry.flat, treeview entry { border-radius: 0; background-image: none; background-color: #ffffff; }

treeview entry.flat:focus, treeview entry:focus { border-color: #89addb; }

.entry-tag { padding: 5px; margin-top: 2px; margin-bottom: 2px; border-style: none; color: #ffffff; background-color: #89addb; }

:dir(ltr) .entry-tag { margin-left: 8px; margin-right: -5px; }

:dir(rtl) .entry-tag { margin-left: -5px; margin-right: 8px; }

.entry-tag:hover { background-color: #b0c8e7; }

:backdrop .entry-tag { color: #fcfcfc; background-color: #89addb; }

.entry-tag.button { background-color: transparent; color: rgba(255, 255, 255, 0.7); }

:not(:backdrop) .entry-tag.button:hover { border: 1px solid #89addb; color: #ffffff; }

:not(:backdrop) .entry-tag.button:active { background-color: #89addb; color: rgba(255, 255, 255, 0.7); }

/*********** Buttons * */
@keyframes needs_attention { from { background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(#89addb), to(transparent)); }
  to { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#89addb), to(transparent)); } }

notebook > header > tabs > arrow, button { min-height: 24px; min-width: 16px; padding: 3px 8px; border: 1px solid; border-radius: 4px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

notebook > header > tabs > arrow, button.sidebar-button, notebook > header > tabs > arrow.flat, button.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; transition: none; }

notebook > header > tabs > arrow:hover, button.sidebar-button:hover, notebook > header > tabs > arrow.flat:hover, button.flat:hover { transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-duration: 500ms; }

notebook > header > tabs > arrow:hover:active, button.sidebar-button:hover:active, notebook > header > tabs > arrow.flat:hover:active, button.flat:hover:active { transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

notebook > header > tabs > arrow:hover, button:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); -gtk-icon-effect: highlight; }

notebook > header > tabs > arrow:active, notebook > header > tabs > arrow:checked, button:active, button:checked { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; transition-duration: 50ms; }

notebook > header > tabs > arrow:backdrop.flat, notebook > header > tabs > arrow:backdrop, button:backdrop.flat, button:backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); transition: 200ms ease-out; -gtk-icon-effect: none; }

notebook > header > tabs > arrow:backdrop.flat:active, notebook > header > tabs > arrow:backdrop.flat:checked, notebook > header > tabs > arrow:backdrop:active, notebook > header > tabs > arrow:backdrop:checked, button:backdrop.flat:active, button:backdrop.flat:checked, button:backdrop:active, button:backdrop:checked { color: #2f2f2f; border-color: #b1aeab; background-image: image(#dddbd8); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow:backdrop.flat:disabled, notebook > header > tabs > arrow:backdrop:disabled, button:backdrop.flat:disabled, button:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow:backdrop.flat:disabled:active, notebook > header > tabs > arrow:backdrop.flat:disabled:checked, notebook > header > tabs > arrow:backdrop:disabled:active, notebook > header > tabs > arrow:backdrop:disabled:checked, button:backdrop.flat:disabled:active, button:backdrop.flat:disabled:checked, button:backdrop:disabled:active, button:backdrop:disabled:checked { color: #c9c6c3; border-color: #b1aeab; background-image: image(#dddbd8); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow:backdrop, button.sidebar-button:backdrop, notebook > header > tabs > arrow:disabled, button.sidebar-button:disabled, notebook > header > tabs > arrow:backdrop:disabled, button.sidebar-button:backdrop:disabled, notebook > header > tabs > arrow.flat:backdrop, notebook > header > tabs > arrow.flat:disabled, notebook > header > tabs > arrow.flat:backdrop:disabled, button.flat:backdrop, button.flat:disabled, button.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

notebook > header > tabs > arrow:disabled, button:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow:disabled:active, notebook > header > tabs > arrow:disabled:checked, button:disabled:active, button:disabled:checked { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #e9e7e6, #f1f1f0 3px, #f4f3f2 4px, #efeeed 50%, #ebeae9 50%, #e4e3e1); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow.image-button, button.image-button { min-width: 24px; padding-left: 5px; padding-right: 5px; }

notebook > header > tabs > arrow.text-button, button.text-button { padding-left: 16px; padding-right: 16px; }

notebook > header > tabs > arrow.text-button.image-button, button.text-button.image-button { padding-left: 8px; padding-right: 8px; }

notebook > header > tabs > arrow.text-button.image-button label, button.text-button.image-button label { padding-left: 8px; padding-right: 8px; }

combobox:drop(active) button.combo, notebook > header > tabs > arrow:drop(active), button:drop(active) { color: #93af66; border-color: #93af66; box-shadow: inset 0 0 0 1px #93af66; }

row:selected button { border-color: #5a85bb; }

row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled), row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled) { color: #ffffff; border-color: transparent; }

row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop, row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop { color: #fcfcfc; }

button.osd { min-width: 26px; min-height: 32px; color: #eeeeec; border-radius: 5px; color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(61, 63, 54, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); border: none; box-shadow: none; }

button.osd.image-button { min-width: 34px; }

button.osd:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(69, 71, 61, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); border: none; box-shadow: none; }

button.osd:active, button.osd:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(0, 0, 0, 0.7)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); border: none; box-shadow: none; }

button.osd:disabled:backdrop, button.osd:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; border: none; }

button.osd:backdrop { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; border: none; }

.csd popover.background.touch-selection button, .csd popover.background.magnifier button, popover.background.touch-selection button, popover.background.magnifier button, .app-notification button, .app-notification.frame button, .osd button { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(61, 63, 54, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

popover.background.touch-selection button:hover, popover.background.magnifier button:hover, .app-notification button:hover, .osd button:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(69, 71, 61, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

popover.background.touch-selection button:active:backdrop, popover.background.magnifier button:active:backdrop, .app-notification button:active:backdrop, popover.background.touch-selection button:active, popover.background.magnifier button:active, .app-notification button:active, popover.background.touch-selection button:checked:backdrop, popover.background.magnifier button:checked:backdrop, .app-notification button:checked:backdrop, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, .app-notification button:checked, .osd button:active:backdrop, .osd button:active, .osd button:checked:backdrop, .osd button:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(0, 0, 0, 0.7)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); }

popover.background.touch-selection button:disabled:backdrop, popover.background.magnifier button:disabled:backdrop, .app-notification button:disabled:backdrop, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, .app-notification button:disabled, .osd button:disabled:backdrop, .osd button:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

popover.background.touch-selection button:backdrop, popover.background.magnifier button:backdrop, .app-notification button:backdrop, .osd button:backdrop { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

popover.background.touch-selection button.flat, popover.background.magnifier button.flat, .app-notification button.flat, .osd button.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; box-shadow: none; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

popover.background.touch-selection button.flat:hover, popover.background.magnifier button.flat:hover, .app-notification button.flat:hover, .osd button.flat:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(69, 71, 61, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

popover.background.touch-selection button.flat:disabled, popover.background.magnifier button.flat:disabled, .app-notification button.flat:disabled, .osd button.flat:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; background-image: none; border-color: transparent; box-shadow: none; }

popover.background.touch-selection button.flat:backdrop, popover.background.magnifier button.flat:backdrop, .app-notification button.flat:backdrop, .osd button.flat:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

popover.background.touch-selection button.flat:active, popover.background.magnifier button.flat:active, .app-notification button.flat:active, popover.background.touch-selection button.flat:checked, popover.background.magnifier button.flat:checked, .app-notification button.flat:checked, .osd button.flat:active, .osd button.flat:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(0, 0, 0, 0.7)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); }

button.suggested-action { color: #000000; outline-color: #a29e9b; border-color: #79944d; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

button.suggested-action.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #93af66; }

button.suggested-action:hover { color: #000000; outline-color: #a29e9b; border-color: #79944d; border-bottom-color: #5e733c; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

button.suggested-action:active, button.suggested-action:checked { color: #000000; outline-color: #a29e9b; border-color: #79944d; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

button.suggested-action:backdrop, button.suggested-action.flat:backdrop { color: #e9efe0; border-color: #93af66; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.suggested-action:backdrop:active, button.suggested-action:backdrop:checked, button.suggested-action.flat:backdrop:active, button.suggested-action.flat:backdrop:checked { color: #e9efe0; border-color: #90ad62; background-image: image(#90ad62); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.suggested-action:backdrop:disabled, button.suggested-action.flat:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.suggested-action:backdrop:disabled:active, button.suggested-action:backdrop:disabled:checked, button.suggested-action.flat:backdrop:disabled:active, button.suggested-action.flat:backdrop:disabled:checked { color: #b7ca99; border-color: #90ad62; background-image: image(#90ad62); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.suggested-action.flat:backdrop, button.suggested-action.flat:disabled, button.suggested-action.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(147, 175, 102, 0.8); }

button.suggested-action:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.suggested-action:disabled:active, button.suggested-action:disabled:checked { color: #d3dec0; border-color: #79944d; background-image: linear-gradient(to bottom, #e9e7e6, #f1f1f0 3px, #f4f3f2 4px, #efeeed 50%, #ebeae9 50%, #e4e3e1); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.osd button.suggested-action { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(147, 175, 102, 0.5)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd button.suggested-action:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(147, 175, 102, 0.7)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd button.suggested-action:active:backdrop, .osd button.suggested-action:active, .osd button.suggested-action:checked:backdrop, .osd button.suggested-action:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(#93af66); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); }

.osd button.suggested-action:disabled:backdrop, .osd button.suggested-action:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd button.suggested-action:backdrop { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(147, 175, 102, 0.5)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

button.destructive-action { color: #000000; outline-color: #a29e9b; border-color: #991121; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

button.destructive-action.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #c7162b; }

button.destructive-action:hover { color: #000000; outline-color: #a29e9b; border-color: #991121; border-bottom-color: #6b0c17; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

button.destructive-action:active, button.destructive-action:checked { color: #000000; outline-color: #a29e9b; border-color: #991121; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

button.destructive-action:backdrop, button.destructive-action.flat:backdrop { color: #f4d0d5; border-color: #c7162b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.destructive-action:backdrop:active, button.destructive-action:backdrop:checked, button.destructive-action.flat:backdrop:active, button.destructive-action.flat:backdrop:checked { color: #f0d5d8; border-color: #b42c3c; background-image: image(#b42c3c); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.destructive-action:backdrop:disabled, button.destructive-action.flat:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.destructive-action:backdrop:disabled:active, button.destructive-action:backdrop:disabled:checked, button.destructive-action.flat:backdrop:disabled:active, button.destructive-action.flat:backdrop:disabled:checked { color: #ce7680; border-color: #b42c3c; background-image: image(#b42c3c); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.destructive-action.flat:backdrop, button.destructive-action.flat:disabled, button.destructive-action.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(199, 22, 43, 0.8); }

button.destructive-action:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

button.destructive-action:disabled:active, button.destructive-action:disabled:checked { color: #e1aab1; border-color: #991121; background-image: linear-gradient(to bottom, #e9e7e6, #f1f1f0 3px, #f4f3f2 4px, #efeeed 50%, #ebeae9 50%, #e4e3e1); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.osd button.destructive-action { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(199, 22, 43, 0.5)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd button.destructive-action:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(199, 22, 43, 0.7)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd button.destructive-action:active:backdrop, .osd button.destructive-action:active, .osd button.destructive-action:checked:backdrop, .osd button.destructive-action:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(#c7162b); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); }

.osd button.destructive-action:disabled:backdrop, .osd button.destructive-action:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd button.destructive-action:backdrop { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(199, 22, 43, 0.5)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.stack-switcher > button { outline-offset: -3px; }

.stack-switcher > button > label { padding-left: 6px; padding-right: 6px; }

.stack-switcher > button > image { padding-left: 6px; padding-right: 6px; padding-top: 3px; padding-bottom: 3px; }

.stack-switcher > button.text-button { padding-left: 10px; padding-right: 10px; }

.stack-switcher > button.image-button { padding-left: 2px; padding-right: 2px; }

.stack-switcher > button.needs-attention:active > label, .stack-switcher > button.needs-attention:active > image, .stack-switcher > button.needs-attention:checked > label, .stack-switcher > button.needs-attention:checked > image { animation: none; background-image: none; }

button.font separator, button.file separator { background-color: transparent; }

button.font > box > box > label { font-weight: bold; }

.primary-toolbar button { -gtk-icon-shadow: none; }

button.circular { border-radius: 9999px; -gtk-outline-radius: 9999px; padding: 4px; /* circles instead of ellipses */ background-origin: padding-box, border-box; background-clip: padding-box, border-box; }

button.circular label { padding: 0; }

button.circular:not(.flat):not(.osd):not(:checked):not(:active):not(:disabled):not(:backdrop) { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); background-image: image(rgba(199, 22, 43, 0.5)), linear-gradient(to top, #b3afab 25%, #a29e9b 50%); border-color: transparent; }

button.circular:hover:not(.osd):not(:checked):not(:active):not(:disabled):not(:backdrop) { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); background-image: image(rgba(199, 22, 43, 0.5)), linear-gradient(to top, #b3afab 25%, #a29e9b 50%); border-color: transparent; }

.stack-switcher > button.needs-attention > label, .stack-switcher > button.needs-attention > image, stacksidebar row.needs-attention > label { animation: needs_attention 150ms ease-in; background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#89addb), to(transparent)), -gtk-gradient(radial, center center, 0, center center, 0.5, to(rgba(255, 255, 255, 0.769231)), to(transparent)); background-size: 6px 6px, 6px 6px; background-repeat: no-repeat; background-position: right 3px, right 4px; }

.stack-switcher > button.needs-attention > label:backdrop, .stack-switcher > button.needs-attention > image:backdrop, stacksidebar row.needs-attention > label:backdrop { background-size: 6px 6px, 0 0; }

.stack-switcher > button.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > image:dir(rtl), stacksidebar row.needs-attention > label:dir(rtl) { background-position: left 3px, left 4px; }

.inline-toolbar toolbutton > button { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

.inline-toolbar toolbutton > button:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

.inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.inline-toolbar toolbutton > button:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #e9e7e6, #f1f1f0 3px, #f4f3f2 4px, #efeeed 50%, #ebeae9 50%, #e4e3e1); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked { color: #2f2f2f; border-color: #b1aeab; background-image: image(#dddbd8); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:disabled:active, .inline-toolbar toolbutton > button:backdrop:disabled:checked { color: #c9c6c3; border-color: #b1aeab; background-image: image(#dddbd8); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

toolbar.inline-toolbar toolbutton > button.flat, .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) > entry, .inline-toolbar button, .linked > button, filechooser .path-bar.linked > button, .linked:not(.vertical) > combobox > box > button.combo { border-right-style: none; border-radius: 0; -gtk-outline-radius: 0; }

toolbar.inline-toolbar toolbutton:first-child > button.flat, .linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) > entry:first-child, .inline-toolbar button:first-child, .linked > button:first-child, filechooser .path-bar.linked > button:dir(ltr):first-child, filechooser .path-bar.linked > button:dir(rtl):last-child, combobox.linked button:nth-child(2):dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.combo { border-top-left-radius: 4px; border-bottom-left-radius: 4px; -gtk-outline-top-left-radius: 4px; -gtk-outline-bottom-left-radius: 4px; }

toolbar.inline-toolbar toolbutton:last-child > button.flat, .linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) > entry:last-child, .inline-toolbar button:last-child, .linked > button:last-child, filechooser .path-bar.linked > button:dir(ltr):last-child, filechooser .path-bar.linked > button:dir(rtl):first-child, combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > combobox:last-child > box > button.combo { border-right-style: solid; border-top-right-radius: 4px; border-bottom-right-radius: 4px; -gtk-outline-top-right-radius: 4px; -gtk-outline-bottom-right-radius: 4px; }

toolbar.inline-toolbar toolbutton:only-child > button.flat, .linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) > entry:only-child, .inline-toolbar button:only-child, .linked > button:only-child, filechooser .path-bar.linked > button:only-child, .linked:not(.vertical) > combobox:only-child > box > button.combo { border-style: solid; border-radius: 4px; -gtk-outline-radius: 4px; }

.linked.vertical > spinbutton:not(.vertical), .linked.vertical > entry, .linked.vertical > button, .linked.vertical > combobox > box > button.combo { border-style: solid solid none solid; border-radius: 0; -gtk-outline-radius: 0; }

.linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical > entry:first-child, .linked.vertical > button:first-child, .linked.vertical > combobox:first-child > box > button.combo { border-top-left-radius: 4px; border-top-right-radius: 4px; -gtk-outline-top-left-radius: 4px; -gtk-outline-top-right-radius: 4px; }

.linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical > entry:last-child, .linked.vertical > button:last-child, .linked.vertical > combobox:last-child > box > button.combo { border-bottom-style: solid; border-bottom-left-radius: 4px; border-bottom-right-radius: 4px; -gtk-outline-bottom-left-radius: 4px; -gtk-outline-bottom-right-radius: 4px; }

.linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical > entry:only-child, .linked.vertical > button:only-child, .linked.vertical > combobox:only-child > box > button.combo { border-style: solid; border-radius: 4px; -gtk-outline-radius: 4px; }

modelbutton.flat, .menuitem.button.flat, modelbutton.flat:backdrop, modelbutton.flat:backdrop:hover, .menuitem.button.flat:backdrop, .menuitem.button.flat:backdrop:hover, list row button.image-button:not(.flat), button:link, button:visited, button:link:hover, button:link:active, button:link:checked, button:visited:hover, button:visited:active, button:visited:checked, calendar.button, .scale-popup button:hover, .scale-popup button:backdrop:hover, .scale-popup button:backdrop:disabled, .scale-popup button:backdrop { background-color: transparent; background-image: none; border-color: transparent; box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

/* menu buttons */
modelbutton.flat, .menuitem.button.flat { min-height: 26px; padding-left: 5px; padding-right: 5px; border-radius: 3px; outline-offset: -2px; }

modelbutton.flat:hover, .menuitem.button.flat:hover { box-shadow: inset 0px 1px #4b6e9b, inset 0px -1px #4b6e9b; border-style: solid; background-image: linear-gradient(to bottom, #a4c2e8, #96b8e2 50%, #91b4df 50%, #84a9d9); background-color: #89addb; color: #ffffff; }

modelbutton.flat arrow { background: none; }

modelbutton.flat arrow:hover { background: none; }

modelbutton.flat arrow.left { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

modelbutton.flat arrow.right { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

button.color { padding: 4px; }

button.color colorswatch:only-child { box-shadow: 0 1px rgba(255, 255, 255, 0.769231); }

button.color colorswatch:only-child, button.color colorswatch:only-child overlay { border-radius: 0; }

.osd button.color colorswatch:only-child { box-shadow: none; }

.osd button.color:disabled colorswatch:only-child, .osd button.color:backdrop colorswatch:only-child, .osd button.color:active colorswatch:only-child, .osd button.color:checked colorswatch:only-child, button.color:disabled colorswatch:only-child, button.color:backdrop colorswatch:only-child, button.color:active colorswatch:only-child, button.color:checked colorswatch:only-child { box-shadow: none; }

/* list buttons */
/* tone down as per new designs, see issue #1473, #1748 */
list row button.image-button:not(.flat) { border: 1px solid rgba(162, 158, 155, 0.5); }

list row button.image-button:not(.flat):hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

list row button.image-button:not(.flat):active, list row button.image-button:not(.flat):checked { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

/********* Links * */
button:link, button:visited, button:link > label, button:visited > label, *:link { color: #0000ee; }

button:visited, button:link > label:visited, button:visited > label:visited, *:link:visited { color: #551a8b; }

*:selected button:visited, *:selected button:link > label:visited, *:selected button:visited > label:visited, *:selected *:link:visited { color: #bba3d1; }

button:hover:link, button:hover:visited, button:link > label:hover, button:visited > label:hover, *:link:hover { color: #2222ff; }

*:selected button:hover:link, *:selected button:hover:visited, *:selected button:link > label:hover, *:selected button:visited > label:hover, *:selected *:link:hover { color: #e9e9ff; }

button:active:link, button:active:visited, button:link > label:active, button:visited > label:active, *:link:active { color: #0000ee; }

*:selected button:active:link, *:selected button:active:visited, *:selected button:link > label:active, *:selected button:visited > label:active, *:selected *:link:active { color: #ccccfc; }

button:disabled:link, button:disabled:visited, button:link > label:disabled, button:visited > label:disabled, button:disabled:backdrop:link, button:disabled:backdrop:visited, button:link > label:disabled:backdrop, button:visited > label:disabled:backdrop, *:link:disabled, *:link:disabled:backdrop { color: rgba(119, 119, 119, 0.8); }

button:backdrop:backdrop:hover:link, button:backdrop:backdrop:hover:visited, button:link > label:backdrop:backdrop:hover, button:visited > label:backdrop:backdrop:hover, button:backdrop:backdrop:hover:selected:link, button:backdrop:backdrop:hover:selected:visited, button:link > label:backdrop:backdrop:hover:selected, button:visited > label:backdrop:backdrop:hover:selected, button:backdrop:link, button:backdrop:visited, button:link > label:backdrop, button:visited > label:backdrop, *:link:backdrop:backdrop:hover, *:link:backdrop:backdrop:hover:selected, *:link:backdrop { color: rgba(0, 0, 238, 0.9); }

.selection-mode headerbar .subtitle:link, headerbar.selection-mode .subtitle:link, .selection-mode .titlebar .subtitle:link, .titlebar.selection-mode .subtitle:link, button:selected:link, button:selected:visited, button:link > label:selected, button:visited > label:selected, *:selected button:link, *:selected button:visited, *:selected button:link > label, *:selected button:visited > label, *:link:selected, *:selected *:link { color: #ccccfc; }

button:link, button:visited { text-shadow: none; }

button:link:hover, button:link:active, button:link:checked, button:visited:hover, button:visited:active, button:visited:checked { text-shadow: none; }

button:link > label, button:visited > label { text-decoration-line: underline; }

/***************** GtkSpinButton * */
spinbutton { font-feature-settings: "tnum"; }

spinbutton:not(.vertical) { padding: 0; }

spinbutton:not(.vertical) entry, .osd spinbutton:not(.vertical) entry { min-width: 28px; margin: 0; background: none; background-color: transparent; border: none; border-radius: 0; box-shadow: none; }

spinbutton:not(.vertical) entry:backdrop:disabled { background-color: transparent; }

spinbutton:not(.vertical) button { min-height: 16px; margin: 0; padding-bottom: 0; padding-top: 0; color: #1a1a1a; background-image: none; border-style: none none none solid; border-color: rgba(162, 158, 155, 0.3); border-radius: 0; box-shadow: none; }

spinbutton:not(.vertical) button:dir(rtl) { border-style: none solid none none; }

spinbutton:not(.vertical) button:hover { color: #000000; background-color: rgba(0, 0, 0, 0.05); }

spinbutton:not(.vertical) button:disabled { color: rgba(169, 165, 162, 0.3); background-color: transparent; }

spinbutton:not(.vertical) button:active { background-color: rgba(0, 0, 0, 0.1); box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.2); }

spinbutton:not(.vertical) button:backdrop { color: #444444; background-color: transparent; border-color: rgba(177, 174, 171, 0.3); transition: 200ms ease-out; }

spinbutton:not(.vertical) button:backdrop:disabled { color: rgba(201, 198, 195, 0.3); background-color: transparent; background-image: none; border-style: none none none solid; }

spinbutton:not(.vertical) button:backdrop:disabled:dir(rtl) { border-style: none solid none none; }

spinbutton:not(.vertical) button:dir(ltr):last-child { border-radius: 0 4px 4px 0; }

spinbutton:not(.vertical) button:dir(rtl):first-child { border-radius: 4px 0 0 4px; }

.osd spinbutton:not(.vertical) button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeec; border-style: none none none solid; border-color: rgba(0, 0, 0, 0.4); border-radius: 0; box-shadow: none; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:not(.vertical) button:dir(rtl) { border-style: none solid none none; }

.osd spinbutton:not(.vertical) button:hover { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeec; border-color: rgba(0, 0, 0, 0.5); background-color: rgba(238, 238, 236, 0.1); -gtk-icon-shadow: 0 1px black; box-shadow: none; }

.osd spinbutton:not(.vertical) button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeec; border-color: rgba(0, 0, 0, 0.5); -gtk-icon-shadow: none; box-shadow: none; }

.osd spinbutton:not(.vertical) button:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeec; border-color: rgba(0, 0, 0, 0.5); -gtk-icon-shadow: none; box-shadow: none; }

.osd spinbutton:not(.vertical) button:dir(ltr):last-child { border-radius: 0 4px 4px 0; }

.osd spinbutton:not(.vertical) button:dir(rtl):first-child { border-radius: 4px 0 0 4px; }

spinbutton.vertical:disabled { color: #a9a5a2; }

spinbutton.vertical:backdrop:disabled { color: #c9c6c3; }

spinbutton.vertical:drop(active) { border-color: transparent; box-shadow: none; }

spinbutton.vertical entry { min-height: 32px; min-width: 32px; padding: 0; border-radius: 0; }

spinbutton.vertical button { min-height: 32px; min-width: 32px; padding: 0; }

spinbutton.vertical button.up { border-radius: 4px 4px 0 0; border-style: solid solid none solid; }

spinbutton.vertical button.down { border-radius: 0 0 4px 4px; border-style: none solid solid solid; }

.osd spinbutton.vertical button:first-child { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(61, 63, 54, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd spinbutton.vertical button:first-child:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(69, 71, 61, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd spinbutton.vertical button:first-child:active { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(0, 0, 0, 0.7)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); }

.osd spinbutton.vertical button:first-child:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd spinbutton.vertical button:first-child:backdrop { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

treeview spinbutton:not(.vertical) { min-height: 0; border-style: none; border-radius: 0; }

treeview spinbutton:not(.vertical) entry { min-height: 0; padding: 1px 2px; }

/************** ComboBoxes * */
combobox arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); min-height: 16px; min-width: 16px; }

combobox:drop(active) { box-shadow: none; }

/************ Toolbars * */
toolbar, .inline-toolbar, searchbar > revealer > box, .location-bar { -GtkWidget-window-dragging: true; padding: 4px; background-color: #edeceb; }

toolbar { background-image: linear-gradient(to bottom, #f6f5f5 2px, #efeeed 50%, #edeceb 50%, #e6e5e4); padding: 2px; border-width: 1px 0 1px 0; border-radius: 0; border-style: solid; border-top-color: white; border-bottom-color: #c4c2bf; }

.osd toolbar { background-color: transparent; }

toolbar.osd { padding: 13px; border: none; border-radius: 5px; background-color: rgba(37, 38, 33, 0.8); }

toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom { border-radius: 0; }

toolbar.horizontal separator { margin: 0 7px 1px 6px; }

toolbar.vertical separator { margin: 6px 1px 7px 0; }

toolbar:not(.inline-toolbar):not(.osd) > *:not(.toggle):not(.popup) > * { margin-right: 1px; margin-bottom: 1px; }

.inline-toolbar { padding: 3px; border-width: 0 1px 1px; border-radius: 0  0 5px 5px; }

searchbar > revealer > box, .location-bar { border-width: 0 0 1px; padding: 3px; }

searchbar > revealer > box { margin: -6px; padding: 6px; }

.inline-toolbar, searchbar > revealer > box, .location-bar { border-style: solid; border-color: #a29e9b; background-color: #d6d5d3; }

.inline-toolbar:backdrop, searchbar > revealer > box:backdrop, .location-bar:backdrop { border-color: #b1aeab; background-color: #d8d6d5; box-shadow: none; transition: 200ms ease-out; }

/*************** Header bars * */
.titlebar:not(headerbar), headerbar { padding: 0 2px; min-height: 10px; border-width: 0 0 1px; border-style: solid; border-color: #b3afab; border-radius: 0; color: #000000; background-image: linear-gradient(to bottom, #9cbce5, #8eb1de 50%, #89addb 50%, #7ba2d4); /* Darken switchbuttons for headerbars. issue #1588 */ /* hide the close button separator */ }

.titlebar:backdrop:not(headerbar), headerbar:backdrop { background-image: linear-gradient(to bottom, #ebeae9, #e2e0df 50%, #dddbda 50%, #d4d2d0); }

.titlebar:backdrop:not(headerbar), headerbar:backdrop { border-color: #b1aeab; background-image: linear-gradient(to bottom, #9cbce5, #8eb1de 50%, #89addb 50%, #7ba2d4); box-shadow: inset 0 1px rgba(255, 255, 255, 0.8); transition: 200ms ease-out; }

.titlebar:backdrop:backdrop:not(headerbar), headerbar:backdrop:backdrop { background-image: linear-gradient(to bottom, #ebeae9, #e2e0df 50%, #dddbda 50%, #d4d2d0); }

.titlebar:not(headerbar) .title, headerbar .title { padding-left: 12px; padding-right: 12px; font-weight: bold; }

.titlebar:not(headerbar) .subtitle, headerbar .subtitle { font-size: smaller; padding-left: 12px; padding-right: 12px; }

.titlebar:not(headerbar) stackswitcher button:checked, .titlebar:not(headerbar) button.toggle:checked, headerbar stackswitcher button:checked, headerbar button.toggle:checked { background: image(#c4c1bd); border-color: #938f8b; }

.selection-mode .titlebar:not(headerbar), .selection-mode.titlebar:not(headerbar), .selection-mode headerbar, headerbar.selection-mode { color: #ffffff; border-color: #87a556; text-shadow: 0 -1px rgba(0, 0, 0, 0.5); background-image: linear-gradient(to bottom, #9cbce5, #8eb1de 50%, #89addb 50%, #7ba2d4); }

.selection-mode .titlebar:backdrop:not(headerbar), .selection-mode.titlebar:backdrop:not(headerbar), .selection-mode headerbar:backdrop, headerbar.selection-mode:backdrop { background-image: linear-gradient(to bottom, #ebeae9, #e2e0df 50%, #dddbda 50%, #d4d2d0); }

.selection-mode .titlebar:backdrop:not(headerbar), .selection-mode.titlebar:backdrop:not(headerbar), .selection-mode headerbar:backdrop, headerbar.selection-mode:backdrop { background-color: #93af66; background-image: none; box-shadow: inset 0 1px rgba(201, 215, 178, 0.88); }

.selection-mode .titlebar:backdrop:not(headerbar) label, .selection-mode.titlebar:backdrop:not(headerbar) label, .selection-mode headerbar:backdrop label, headerbar.selection-mode:backdrop label { text-shadow: none; color: #ffffff; }

.selection-mode .titlebar:not(headerbar) button, .selection-mode.titlebar:not(headerbar) button, .selection-mode headerbar button, headerbar.selection-mode button { color: #000000; outline-color: #a29e9b; border-color: #79944d; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); min-height: 10px; }

.selection-mode .titlebar:not(headerbar) button.flat, .selection-mode.titlebar:not(headerbar) button.flat, .selection-mode headerbar button.flat, headerbar.selection-mode button.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode .titlebar:not(headerbar) button:hover, .selection-mode.titlebar:not(headerbar) button:hover, .selection-mode headerbar button:hover, headerbar.selection-mode button:hover { color: #000000; outline-color: #a29e9b; border-color: #79944d; border-bottom-color: #5e733c; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

.selection-mode .titlebar:not(headerbar) button:active, .selection-mode .titlebar:not(headerbar) button:checked, .selection-mode .titlebar:not(headerbar) button.toggle:checked, .selection-mode .titlebar:not(headerbar) button.toggle:active, .selection-mode.titlebar:not(headerbar) button:active, .selection-mode.titlebar:not(headerbar) button:checked, .selection-mode.titlebar:not(headerbar) button.toggle:checked, .selection-mode.titlebar:not(headerbar) button.toggle:active, .selection-mode headerbar button:active, .selection-mode headerbar button:checked, .selection-mode headerbar button.toggle:checked, .selection-mode headerbar button.toggle:active, headerbar.selection-mode button:active, headerbar.selection-mode button:checked, headerbar.selection-mode button.toggle:checked, headerbar.selection-mode button.toggle:active { color: #000000; outline-color: #a29e9b; border-color: #79944d; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode .titlebar:not(headerbar) button:backdrop.flat, .selection-mode .titlebar:not(headerbar) button:backdrop, .selection-mode.titlebar:not(headerbar) button:backdrop.flat, .selection-mode.titlebar:not(headerbar) button:backdrop, .selection-mode headerbar button:backdrop.flat, .selection-mode headerbar button:backdrop, headerbar.selection-mode button:backdrop.flat, headerbar.selection-mode button:backdrop { color: #2f2f2f; border-color: #93af66; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); -gtk-icon-effect: none; border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button:backdrop.flat:active, .selection-mode .titlebar:not(headerbar) button:backdrop.flat:checked, .selection-mode .titlebar:not(headerbar) button:backdrop:active, .selection-mode .titlebar:not(headerbar) button:backdrop:checked, .selection-mode.titlebar:not(headerbar) button:backdrop.flat:active, .selection-mode.titlebar:not(headerbar) button:backdrop.flat:checked, .selection-mode.titlebar:not(headerbar) button:backdrop:active, .selection-mode.titlebar:not(headerbar) button:backdrop:checked, .selection-mode headerbar button:backdrop.flat:active, .selection-mode headerbar button:backdrop.flat:checked, .selection-mode headerbar button:backdrop:active, .selection-mode headerbar button:backdrop:checked, headerbar.selection-mode button:backdrop.flat:active, headerbar.selection-mode button:backdrop.flat:checked, headerbar.selection-mode button:backdrop:active, headerbar.selection-mode button:backdrop:checked { color: #2f2f2f; border-color: #90ad62; background-image: image(#90ad62); box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button:backdrop.flat:disabled, .selection-mode .titlebar:not(headerbar) button:backdrop:disabled, .selection-mode.titlebar:not(headerbar) button:backdrop.flat:disabled, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled, .selection-mode headerbar button:backdrop.flat:disabled, .selection-mode headerbar button:backdrop:disabled, headerbar.selection-mode button:backdrop.flat:disabled, headerbar.selection-mode button:backdrop:disabled { color: #6a7a51; border-color: #a3bb7d; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button:backdrop.flat:disabled:active, .selection-mode .titlebar:not(headerbar) button:backdrop.flat:disabled:checked, .selection-mode .titlebar:not(headerbar) button:backdrop:disabled:active, .selection-mode .titlebar:not(headerbar) button:backdrop:disabled:checked, .selection-mode.titlebar:not(headerbar) button:backdrop.flat:disabled:active, .selection-mode.titlebar:not(headerbar) button:backdrop.flat:disabled:checked, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:active, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:checked, .selection-mode headerbar button:backdrop.flat:disabled:active, .selection-mode headerbar button:backdrop.flat:disabled:checked, .selection-mode headerbar button:backdrop:disabled:active, .selection-mode headerbar button:backdrop:disabled:checked, headerbar.selection-mode button:backdrop.flat:disabled:active, headerbar.selection-mode button:backdrop.flat:disabled:checked, headerbar.selection-mode button:backdrop:disabled:active, headerbar.selection-mode button:backdrop:disabled:checked { color: #5e7040; border-color: #90ad62; background-image: image(#90ad62); box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button.flat:backdrop, .selection-mode .titlebar:not(headerbar) button.flat:disabled, .selection-mode .titlebar:not(headerbar) button.flat:backdrop:disabled, .selection-mode.titlebar:not(headerbar) button.flat:backdrop, .selection-mode.titlebar:not(headerbar) button.flat:disabled, .selection-mode.titlebar:not(headerbar) button.flat:backdrop:disabled, .selection-mode headerbar button.flat:backdrop, .selection-mode headerbar button.flat:disabled, .selection-mode headerbar button.flat:backdrop:disabled, headerbar.selection-mode button.flat:backdrop, headerbar.selection-mode button.flat:disabled, headerbar.selection-mode button.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode .titlebar:not(headerbar) button:disabled, .selection-mode.titlebar:not(headerbar) button:disabled, .selection-mode headerbar button:disabled, headerbar.selection-mode button:disabled { color: #a9a5a2; border-color: #79944d; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode .titlebar:not(headerbar) button:disabled:active, .selection-mode .titlebar:not(headerbar) button:disabled:checked, .selection-mode.titlebar:not(headerbar) button:disabled:active, .selection-mode.titlebar:not(headerbar) button:disabled:checked, .selection-mode headerbar button:disabled:active, .selection-mode headerbar button:disabled:checked, headerbar.selection-mode button:disabled:active, headerbar.selection-mode button:disabled:checked { color: #3a4527; border-color: #79944d; background-image: linear-gradient(to bottom, #e9e7e6, #f1f1f0 3px, #f4f3f2 4px, #efeeed 50%, #ebeae9 50%, #e4e3e1); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode .titlebar:not(headerbar) button.suggested-action, .selection-mode.titlebar:not(headerbar) button.suggested-action, .selection-mode headerbar button.suggested-action, headerbar.selection-mode button.suggested-action { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button.suggested-action:hover, .selection-mode.titlebar:not(headerbar) button.suggested-action:hover, .selection-mode headerbar button.suggested-action:hover, headerbar.selection-mode button.suggested-action:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button.suggested-action:active, .selection-mode.titlebar:not(headerbar) button.suggested-action:active, .selection-mode headerbar button.suggested-action:active, headerbar.selection-mode button.suggested-action:active { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button.suggested-action:disabled, .selection-mode.titlebar:not(headerbar) button.suggested-action:disabled, .selection-mode headerbar button.suggested-action:disabled, headerbar.selection-mode button.suggested-action:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button.suggested-action:backdrop, .selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop, .selection-mode headerbar button.suggested-action:backdrop, headerbar.selection-mode button.suggested-action:backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) button.suggested-action:backdrop:disabled, .selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop:disabled, .selection-mode headerbar button.suggested-action:backdrop:disabled, headerbar.selection-mode button.suggested-action:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode .titlebar:not(headerbar) .selection-menu:backdrop, .selection-mode .titlebar:not(headerbar) .selection-menu, .selection-mode.titlebar:not(headerbar) .selection-menu:backdrop, .selection-mode.titlebar:not(headerbar) .selection-menu, .selection-mode headerbar .selection-menu:backdrop, .selection-mode headerbar .selection-menu, headerbar.selection-mode .selection-menu:backdrop, headerbar.selection-mode .selection-menu { border-color: rgba(147, 175, 102, 0); background-color: rgba(147, 175, 102, 0); background-image: none; box-shadow: none; min-height: 20px; padding: 6px 10px; }

.selection-mode .titlebar:not(headerbar) .selection-menu:backdrop arrow, .selection-mode .titlebar:not(headerbar) .selection-menu arrow, .selection-mode.titlebar:not(headerbar) .selection-menu:backdrop arrow, .selection-mode.titlebar:not(headerbar) .selection-menu arrow, .selection-mode headerbar .selection-menu:backdrop arrow, .selection-mode headerbar .selection-menu arrow, headerbar.selection-mode .selection-menu:backdrop arrow, headerbar.selection-mode .selection-menu arrow { -GtkArrow-arrow-scaling: 1; }

.selection-mode .titlebar:not(headerbar) .selection-menu:backdrop .arrow, .selection-mode .titlebar:not(headerbar) .selection-menu .arrow, .selection-mode.titlebar:not(headerbar) .selection-menu:backdrop .arrow, .selection-mode.titlebar:not(headerbar) .selection-menu .arrow, .selection-mode headerbar .selection-menu:backdrop .arrow, .selection-mode headerbar .selection-menu .arrow, headerbar.selection-mode .selection-menu:backdrop .arrow, headerbar.selection-mode .selection-menu .arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); color: rgba(255, 255, 255, 0.5); -gtk-icon-shadow: none; }

.tiled .titlebar:backdrop:not(headerbar), .tiled .titlebar:not(headerbar), .tiled-top .titlebar:backdrop:not(headerbar), .tiled-top .titlebar:not(headerbar), .tiled-right .titlebar:backdrop:not(headerbar), .tiled-right .titlebar:not(headerbar), .tiled-bottom .titlebar:backdrop:not(headerbar), .tiled-bottom .titlebar:not(headerbar), .tiled-left .titlebar:backdrop:not(headerbar), .tiled-left .titlebar:not(headerbar), .maximized .titlebar:backdrop:not(headerbar), .maximized .titlebar:not(headerbar), .fullscreen .titlebar:backdrop:not(headerbar), .fullscreen .titlebar:not(headerbar), .tiled headerbar:backdrop, .tiled headerbar, .tiled-top headerbar:backdrop, .tiled-top headerbar, .tiled-right headerbar:backdrop, .tiled-right headerbar, .tiled-bottom headerbar:backdrop, .tiled-bottom headerbar, .tiled-left headerbar:backdrop, .tiled-left headerbar, .maximized headerbar:backdrop, .maximized headerbar, .fullscreen headerbar:backdrop, .fullscreen headerbar { border-radius: 0; }

.default-decoration.titlebar:not(headerbar), headerbar.default-decoration { min-height: 28px; padding: 4px; }

.default-decoration.titlebar:not(headerbar) button.titlebutton, headerbar.default-decoration button.titlebutton { min-height: 26px; min-width: 26px; margin: 0; padding: 0; }

.titlebar:not(headerbar) separator.titlebutton, headerbar separator.titlebutton { opacity: 0; }

.solid-csd .titlebar:backdrop:dir(rtl):not(headerbar), .solid-csd .titlebar:backdrop:dir(ltr):not(headerbar), .solid-csd .titlebar:dir(rtl):not(headerbar), .solid-csd .titlebar:dir(ltr):not(headerbar), .solid-csd headerbar:backdrop:dir(rtl), .solid-csd headerbar:backdrop:dir(ltr), .solid-csd headerbar:dir(rtl), .solid-csd headerbar:dir(ltr) { margin-left: -1px; margin-right: -1px; margin-top: -1px; border-radius: 0; box-shadow: none; }

headerbar { color: #000000; }

headerbar entry, headerbar spinbutton, headerbar separator:not(.sidebar), headerbar button { margin-top: 2px; margin-bottom: 2px; }

headerbar switch { margin-top: 10px; margin-bottom: 10px; }

headerbar.titlebar headerbar:not(.titlebar) { background: none; box-shadow: none; }

.background .titlebar:backdrop, .background .titlebar { border-top-left-radius: 7px; border-top-right-radius: 7px; }

.background.tiled .titlebar:backdrop, .background.tiled .titlebar, .background.tiled-top .titlebar:backdrop, .background.tiled-top .titlebar, .background.tiled-right .titlebar:backdrop, .background.tiled-right .titlebar, .background.tiled-bottom .titlebar:backdrop, .background.tiled-bottom .titlebar, .background.tiled-left .titlebar:backdrop, .background.tiled-left .titlebar, .background.maximized .titlebar:backdrop, .background.maximized .titlebar, .background.solid-csd .titlebar:backdrop, .background.solid-csd .titlebar { border-top-left-radius: 0; border-top-right-radius: 0; }

window separator:first-child + headerbar:backdrop, window separator:first-child + headerbar, window headerbar:first-child:backdrop, window headerbar:first-child { border-top-left-radius: 7px; }

window headerbar:last-child:backdrop, window headerbar:last-child { border-top-right-radius: 7px; }

window stack headerbar:first-child:backdrop, window stack headerbar:first-child, window stack headerbar:last-child:backdrop, window stack headerbar:last-child { border-top-left-radius: 7px; border-top-right-radius: 7px; }

window.tiled headerbar, window.tiled headerbar:first-child, window.tiled headerbar:last-child, window.tiled headerbar:only-child, window.tiled headerbar:backdrop, window.tiled headerbar:backdrop:first-child, window.tiled headerbar:backdrop:last-child, window.tiled headerbar:backdrop:only-child, window.tiled-top headerbar, window.tiled-top headerbar:first-child, window.tiled-top headerbar:last-child, window.tiled-top headerbar:only-child, window.tiled-top headerbar:backdrop, window.tiled-top headerbar:backdrop:first-child, window.tiled-top headerbar:backdrop:last-child, window.tiled-top headerbar:backdrop:only-child, window.tiled-right headerbar, window.tiled-right headerbar:first-child, window.tiled-right headerbar:last-child, window.tiled-right headerbar:only-child, window.tiled-right headerbar:backdrop, window.tiled-right headerbar:backdrop:first-child, window.tiled-right headerbar:backdrop:last-child, window.tiled-right headerbar:backdrop:only-child, window.tiled-bottom headerbar, window.tiled-bottom headerbar:first-child, window.tiled-bottom headerbar:last-child, window.tiled-bottom headerbar:only-child, window.tiled-bottom headerbar:backdrop, window.tiled-bottom headerbar:backdrop:first-child, window.tiled-bottom headerbar:backdrop:last-child, window.tiled-bottom headerbar:backdrop:only-child, window.tiled-left headerbar, window.tiled-left headerbar:first-child, window.tiled-left headerbar:last-child, window.tiled-left headerbar:only-child, window.tiled-left headerbar:backdrop, window.tiled-left headerbar:backdrop:first-child, window.tiled-left headerbar:backdrop:last-child, window.tiled-left headerbar:backdrop:only-child, window.maximized headerbar, window.maximized headerbar:first-child, window.maximized headerbar:last-child, window.maximized headerbar:only-child, window.maximized headerbar:backdrop, window.maximized headerbar:backdrop:first-child, window.maximized headerbar:backdrop:last-child, window.maximized headerbar:backdrop:only-child, window.fullscreen headerbar, window.fullscreen headerbar:first-child, window.fullscreen headerbar:last-child, window.fullscreen headerbar:only-child, window.fullscreen headerbar:backdrop, window.fullscreen headerbar:backdrop:first-child, window.fullscreen headerbar:backdrop:last-child, window.fullscreen headerbar:backdrop:only-child, window.solid-csd headerbar, window.solid-csd headerbar:first-child, window.solid-csd headerbar:last-child, window.solid-csd headerbar:only-child, window.solid-csd headerbar:backdrop, window.solid-csd headerbar:backdrop:first-child, window.solid-csd headerbar:backdrop:last-child, window.solid-csd headerbar:backdrop:only-child { border-top-left-radius: 0; border-top-right-radius: 0; }

window.csd > .titlebar:not(headerbar) { padding: 0; background-color: transparent; background-image: none; border-style: none; border-color: transparent; box-shadow: none; }

.titlebar:not(headerbar) separator { background-color: #a29e9b; }

window.devel headerbar.titlebar:not(.selection-mode) { background: #edeceb cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, linear-gradient(to right, transparent 65%, rgba(137, 173, 219, 0.2)), linear-gradient(to top, #cecbc8, #d5d3d0 3px, #e3e2e0); }

window.devel headerbar.titlebar:not(.selection-mode):backdrop { background: #edeceb cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, image(#edeceb); /* background-color would flash */ }

/************ Pathbars * */
.path-bar button.text-button, .path-bar button.image-button, .path-bar button { padding-left: 4px; padding-right: 4px; }

.path-bar button.text-button.image-button label { padding-left: 0; padding-right: 0; }

.path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child { padding-right: 8px; }

.path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child { padding-left: 8px; }

.path-bar button image { padding-left: 4px; padding-right: 4px; }

.path-bar button.slider-button { padding-left: 0; padding-right: 0; }

/************** Tree Views * */
treeview.view { border-left-color: gray; border-top-color: #edeceb; }

* { -GtkTreeView-horizontal-separator: 4; -GtkTreeView-grid-line-width: 1; -GtkTreeView-grid-line-pattern: ''; -GtkTreeView-tree-line-width: 1; -GtkTreeView-tree-line-pattern: ''; -GtkTreeView-expander-size: 16; }

treeview.view:selected:focus, treeview.view:selected { border-radius: 0; color: #ffffff; }

treeview.view:selected:backdrop, treeview.view:selected { border-left-color: #c4d6ed; border-top-color: rgba(0, 0, 0, 0.1); }

treeview.view:disabled { color: #a9a5a2; }

treeview.view:disabled:selected { color: #b8ceea; }

treeview.view:disabled:selected:backdrop { color: #acc5e5; }

treeview.view:disabled:backdrop { color: #c9c6c3; }

treeview.view.separator { min-height: 2px; color: #edeceb; }

treeview.view.separator:backdrop { color: rgba(237, 236, 235, 0.1); }

treeview.view:backdrop { border-left-color: #8e8e8d; border-top: #edeceb; }

treeview.view:drop(active) { border-style: solid none; border-width: 1px; border-color: #5a85bb; }

treeview.view:drop(active).after { border-top-style: none; }

treeview.view:drop(active).before { border-bottom-style: none; }

treeview.view.expander { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); color: #5f5f5f; }

treeview.view.expander:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

treeview.view.expander:hover { color: #1a1a1a; }

treeview.view.expander:selected { color: #dce7f4; }

treeview.view.expander:selected:hover { color: #ffffff; }

treeview.view.expander:selected:backdrop { color: #dae5f3; }

treeview.view.expander:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

treeview.view.expander:backdrop { color: #6d6d6d; }

treeview.view.progressbar { color: #ffffff; background-color: #4893f2; background-image: image(#4893f2); box-shadow: none; }

treeview.view.progressbar:selected:focus, treeview.view.progressbar:selected { color: #89addb; background-image: image(#ffffff); }

treeview.view.progressbar:selected:focus:backdrop, treeview.view.progressbar:selected:backdrop { color: #89addb; background-color: #fcfcfc; }

treeview.view.progressbar:backdrop { color: #fcfcfc; background-image: none; box-shadow: none; }

treeview.view.trough { background-color: rgba(0, 0, 0, 0.1); }

treeview.view.trough:selected:focus, treeview.view.trough:selected { background-color: rgba(255, 255, 255, 0.3); }

treeview.view header button { color: #4d4d4d; background-color: #ffffff; font-weight: bold; text-shadow: none; box-shadow: none; }

treeview.view header button:hover { color: #272727; box-shadow: none; transition: none; }

treeview.view header button:active { color: #000000; transition: none; }

treeview.view button.dnd:active, treeview.view button.dnd:selected, treeview.view button.dnd:hover, treeview.view button.dnd, treeview.view header.button.dnd:active, treeview.view header.button.dnd:selected, treeview.view header.button.dnd:hover, treeview.view header.button.dnd { padding: 0 6px; color: #ffffff; background-image: none; background-color: #89addb; border-style: none; border-radius: 0; box-shadow: inset 0 0 0 1px #ffffff; text-shadow: none; transition: none; }

treeview.view acceleditor > label { background-color: #89addb; }

treeview.view header button, treeview.view header button:hover, treeview.view header button:active { padding: 0 6px; background-image: linear-gradient(to bottom, #f8f8f7, #f1f1f0 50%, #edeceb 50%, #e4e3e1); border-style: none solid solid none; border-color: #a29e9b; border-radius: 0; text-shadow: none; background-color: #f8f8f7; }

treeview.view header button:disabled { border-color: #edeceb; background-image: none; }

treeview.view header button:backdrop { color: #8e8e8d; border-color: #edeceb; border-style: none solid solid none; background-image: none; background-color: #fcfcfc; }

treeview.view header button:backdrop:disabled { border-color: #edeceb; background-image: none; }

treeview.view header button:last-child:backdrop, treeview.view header button:last-child { border-right-style: none; }

/********* Menus * */
menubar, .menubar { -GtkWidget-window-dragging: true; padding: 0px; box-shadow: inset 0 -1px rgba(0, 0, 0, 0.1); background-image: linear-gradient(to bottom, #ebeae9, #e9e7e6 50%, #e4e3e1); }

menubar:backdrop, .menubar:backdrop { background-color: #edeceb; }

menubar > menuitem, .menubar > menuitem { min-height: 16px; padding: 4px 8px; border-width: 1px 1px 0px; border-color: transparent; border-style: solid; }

menubar > menuitem menu:dir(rtl), menubar > menuitem menu:dir(ltr), .menubar > menuitem menu:dir(rtl), .menubar > menuitem menu:dir(ltr) { border-radius: 0; padding: 0; }

menubar > menuitem:hover, .menubar > menuitem:hover { border-width: 1px 1px 0px; border-color: #4b6e9b; border-style: solid; color: #0000ee; background-image: linear-gradient(to bottom, #a4c2e8, #96b8e2 50%, #91b4df 50%, #84a9d9); }

menubar > menuitem:disabled, .menubar > menuitem:disabled { color: #a9a5a2; box-shadow: none; }

menubar .csd.popup decoration, .menubar .csd.popup decoration { border-radius: 0; }

.background.popup { background-color: transparent; }

menu, .menu, .context-menu { margin: 4px; padding: 4px 0px; background-color: white; border: 1px solid #a29e9b; }

.csd menu, .csd .menu, .csd .context-menu { border: none; border-radius: 2px; }

menu:backdrop, .menu:backdrop, .context-menu:backdrop { background-color: #fcfcfc; }

menu menuitem, .menu menuitem, .context-menu menuitem { min-height: 16px; min-width: 40px; padding: 4px 6px; text-shadow: none; }

menu menuitem:hover, .menu menuitem:hover, .context-menu menuitem:hover { color: #ffffff; background-color: #89addb; box-shadow: inset 0px 1px #4b6e9b, inset 0px -1px #4b6e9b; border-style: solid; background-image: linear-gradient(to bottom, #a4c2e8, #96b8e2 50%, #91b4df 50%, #84a9d9); }

menu menuitem:disabled, .menu menuitem:disabled, .context-menu menuitem:disabled { color: #a9a5a2; }

menu menuitem:disabled:backdrop, .menu menuitem:disabled:backdrop, .context-menu menuitem:disabled:backdrop { color: #c9c6c3; }

menu menuitem:backdrop, menu menuitem:backdrop:hover, .menu menuitem:backdrop, .menu menuitem:backdrop:hover, .context-menu menuitem:backdrop, .context-menu menuitem:backdrop:hover { color: #2f2f2f; background-color: transparent; }

menu menuitem arrow, .menu menuitem arrow, .context-menu menuitem arrow { min-height: 16px; min-width: 16px; }

menu menuitem arrow:dir(ltr), .menu menuitem arrow:dir(ltr), .context-menu menuitem arrow:dir(ltr) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); margin-left: 10px; }

menu menuitem arrow:dir(rtl), .menu menuitem arrow:dir(rtl), .context-menu menuitem arrow:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); margin-right: 10px; }

menu menuitem label:dir(rtl), menu menuitem label:dir(ltr), .menu menuitem label:dir(rtl), .menu menuitem label:dir(ltr), .context-menu menuitem label:dir(rtl), .context-menu menuitem label:dir(ltr) { color: inherit; }

menu > arrow, .menu > arrow, .context-menu > arrow { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; min-height: 16px; min-width: 16px; padding: 4px; background-color: white; border-radius: 0; }

menu > arrow.top, .menu > arrow.top, .context-menu > arrow.top { margin-top: -4px; border-bottom: 1px solid #e6e6e6; border-top-right-radius: 2px; border-top-left-radius: 2px; -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

menu > arrow.bottom, .menu > arrow.bottom, .context-menu > arrow.bottom { margin-top: 8px; margin-bottom: -12px; border-top: 1px solid #e6e6e6; border-bottom-right-radius: 2px; border-bottom-left-radius: 2px; -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

menu > arrow:hover, .menu > arrow:hover, .context-menu > arrow:hover { background-color: #e6e6e6; }

menu > arrow:backdrop, .menu > arrow:backdrop, .context-menu > arrow:backdrop { background-color: #fcfcfc; }

menu > arrow:disabled, .menu > arrow:disabled, .context-menu > arrow:disabled { color: transparent; background-color: transparent; border-color: transparent; }

menuitem accelerator { color: alpha(currentColor,0.55); }

menuitem check, menuitem radio { min-height: 16px; min-width: 16px; }

menuitem check:dir(ltr), menuitem radio:dir(ltr) { margin-right: 7px; }

menuitem check:dir(rtl), menuitem radio:dir(rtl) { margin-left: 7px; }

/*************** Popovers   * */
popover.background { padding: 2px; background-color: white; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3); }

.csd popover.background, popover.background { border: 1px solid #a29e9b; border-radius: 2px; }

.csd popover.background { background-clip: padding-box; border-color: #a29e9b; }

popover.background:backdrop { background-color: #edeceb; box-shadow: none; }

popover.background > list, popover.background > .view, popover.background > iconview, popover.background > toolbar { border-style: none; background-color: transparent; }

.csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier { border: 1px solid rgba(255, 255, 255, 0.1); }

popover.background separator { margin: 3px; }

popover.background list separator { margin: 0px; }

/************* Notebooks * */
notebook > header.top { padding-top: 1px; box-shadow: 0px -1px #edeceb, 0px -2px #edeceb, 1px 0px #edeceb, -1px 0px #edeceb; border-top-color: #edeceb; }

notebook > header.bottom { padding-bottom: 2px; box-shadow: 0px 1px #edeceb, 0px 2px #edeceb, 1px 0px #edeceb, -1px 0px #edeceb; border-bottom-color: #edeceb; }

notebook > header.left { padding-left: 3px; box-shadow: 0px 1px #edeceb, 0px -1px #edeceb, 1px 0px #edeceb, -1px 0px #edeceb; border-left-color: #edeceb; }

notebook > header.right { padding-right: 3px; box-shadow: 0px 1px #edeceb, 0px -1px #edeceb, 1px 0px #edeceb, -1px 0px #edeceb; border-right-color: #edeceb; }

notebook > header { padding: 1px; border-color: #a29e9b; border-width: 1px; background-color: #c7c5c3; }

notebook > header:backdrop { border-color: #b1aeab; background-color: #d8d6d5; }

notebook > header tabs { margin: -1px; }

notebook > header.top { border-bottom-style: solid; }

notebook > header.top > tabs { margin-bottom: -2px; margin-top: 2px; }

notebook > header.top > tabs > tab { background-image: linear-gradient(to bottom, #f1f1f0, #c0bdba); box-shadow: 0px -1px #a29e9b, 1px 0px #a29e9b, -1px 0px #a29e9b, inset 0px -1px #a29e9b; border-top-left-radius: 3px; border-top-right-radius: 3px; }

notebook > header.top > tabs > tab:checked { background-image: linear-gradient(to bottom, #5a85bb, #a4c2e8 3px, #4373b0 5px, #fefefe 5px, #f4f4f3); box-shadow: 0px -1px #4373b0, 1px 0px #a29e9b, -1px 0px #a29e9b; }

notebook > header.bottom { border-top-style: solid; }

notebook > header.bottom > tabs { margin-top: -2px; margin-bottom: 2px; }

notebook > header.bottom > tabs > tab { background-image: linear-gradient(to top, #f1f1f0, #c0bdba); box-shadow: 0px 1px #a29e9b, 1px 0px #a29e9b, -1px 0px #a29e9b, inset 0px 1px #a29e9b; border-bottom-left-radius: 3px; border-bottom-right-radius: 3px; }

notebook > header.bottom > tabs > tab:checked { background-image: linear-gradient(to top, #5a85bb, #a4c2e8 3px, #4373b0 5px, #fefefe 5px, #f4f4f3); box-shadow: 0px 1px #4373b0, 1px 0px #a29e9b, -1px 0px #a29e9b; }

notebook > header.left { border-right-style: solid; }

notebook > header.left > tabs { margin-right: -2px; }

notebook > header.left > tabs > tab { background-image: linear-gradient(to right, #f1f1f0, #c0bdba); box-shadow: 0px 1px #a29e9b, 0px -1px #a29e9b, -1px 0px #a29e9b, inset -1px 0px #a29e9b; border-top-left-radius: 3px; border-bottom-left-radius: 3px; }

notebook > header.left > tabs > tab:checked { background-image: linear-gradient(to right, #5a85bb, #a4c2e8 3px, #4373b0 5px, #fefefe 5px, #f4f4f3); box-shadow: -1px 0px #4373b0, 0px -1px #a29e9b, 0px 1px #a29e9b; }

notebook > header.right { border-left-style: solid; }

notebook > header.right > tabs { margin-left: -2px; }

notebook > header.right > tabs > tab { background-image: linear-gradient(to left, #f1f1f0, #c0bdba); box-shadow: 0px 1px #a29e9b, 0px -1px #a29e9b, 1px 0px #a29e9b, inset 1px 0px #a29e9b; border-top-right-radius: 3px; border-bottom-right-radius: 3px; }

notebook > header.right > tabs > tab:checked { background-image: linear-gradient(to left, #5a85bb, #a4c2e8 3px, #4373b0 5px, #fefefe 5px, #f4f4f3); box-shadow: 1px 0px #4373b0, 0px -1px #a29e9b, 0px 1px #a29e9b; }

notebook > header.top > tabs > arrow { border-top-style: none; }

notebook > header.bottom > tabs > arrow { border-bottom-style: none; }

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow { margin-left: -5px; margin-right: -5px; padding-left: 4px; padding-right: 4px; }

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

notebook > header.left > tabs > arrow { border-left-style: none; }

notebook > header.right > tabs > arrow { border-right-style: none; }

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow { margin-top: -5px; margin-bottom: -5px; padding-top: 4px; padding-bottom: 4px; }

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

notebook > header > tabs > arrow { min-height: 16px; min-width: 16px; border-radius: 0; }

notebook > header > tabs > arrow:hover:not(:active):not(:backdrop) { background-clip: padding-box; background-image: none; background-color: rgba(255, 255, 255, 0.3); border-color: transparent; box-shadow: none; }

notebook > header > tabs > arrow:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

notebook > header tab { min-height: 22px; min-width: 22px; padding: 3px 12px; outline-offset: -5px; color: #000000; font-weight: normal; border-width: 0px; border-color: transparent; }

notebook > header tab:hover { color: #000000; background-color: #e3e2e0; }

notebook > header tab:hover.reorderable-page { border-color: rgba(162, 158, 155, 0.3); background-color: rgba(237, 236, 235, 0.2); }

notebook > header tab:backdrop { color: #7b7b7a; }

notebook > header tab:backdrop.reorderable-page { border-color: transparent; background-color: transparent; }

notebook > header tab:checked { color: #000000; }

notebook > header tab:checked.reorderable-page { border-color: rgba(162, 158, 155, 0.5); background-color: rgba(237, 236, 235, 0.5); }

notebook > header tab:checked.reorderable-page:hover { background-color: rgba(237, 236, 235, 0.7); }

notebook > header tab:backdrop:checked { color: #2f2f2f; }

notebook > header tab:backdrop:checked.reorderable-page { border-color: #b1aeab; background-color: #edeceb; }

notebook > header tab button.flat { padding: 0; margin-top: 4px; margin-bottom: 4px; min-width: 20px; min-height: 20px; }

notebook > header tab button.flat:hover { color: currentColor; }

notebook > header tab button.flat, notebook > header tab button.flat:backdrop { color: alpha(currentColor,0.3); }

notebook > header tab button.flat:last-child { margin-left: 4px; margin-right: -4px; }

notebook > header tab button.flat:first-child { margin-left: -4px; margin-right: 4px; }

notebook > header.top tabs, notebook > header.bottom tabs { padding-left: 0px; padding-right: 0px; }

notebook > header.top tabs:not(:only-child), notebook > header.bottom tabs:not(:only-child) { margin-left: 1px; margin-right: 1px; }

notebook > header.top tabs:not(:only-child):first-child, notebook > header.bottom tabs:not(:only-child):first-child { margin-left: 0px; }

notebook > header.top tabs:not(:only-child):last-child, notebook > header.bottom tabs:not(:only-child):last-child { margin-right: -1px; }

notebook > header.top tabs tab, notebook > header.bottom tabs tab { margin-left: 0px; margin-right: 0px; }

notebook > header.top tabs tab.reorderable-page, notebook > header.bottom tabs tab.reorderable-page { border-style: none solid; }

notebook > header.left tabs, notebook > header.right tabs { padding-top: 0px; padding-bottom: 0px; }

notebook > header.left tabs:not(:only-child), notebook > header.right tabs:not(:only-child) { margin-top: 0px; margin-bottom: 0px; }

notebook > header.left tabs:not(:only-child):first-child, notebook > header.right tabs:not(:only-child):first-child { margin-top: 0px; }

notebook > header.left tabs:not(:only-child):last-child, notebook > header.right tabs:not(:only-child):last-child { margin-bottom: -1px; }

notebook > header.left tabs tab, notebook > header.right tabs tab { margin-top: 0px; margin-bottom: 0px; }

notebook > header.left tabs tab.reorderable-page, notebook > header.right tabs tab.reorderable-page { border-style: solid none; }

notebook > header.top tab { padding-bottom: 4px; }

notebook > header.bottom tab { padding-top: 4px; }

notebook > stack:not(:only-child) { background-color: #f4f4f3; }

notebook > stack:not(:only-child):backdrop { background-color: #f4f4f3; }

/************** Scrollbars * */
scrollbar { background-color: #bebdbc; transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

* { -GtkScrollbar-has-backward-stepper: true; -GtkScrollbar-has-forward-stepper: true; }

scrollbar.top { border-bottom: 1px solid #a29e9b; }

scrollbar.bottom { border-top: 1px solid #a29e9b; }

scrollbar.left { border-right: 1px solid #a29e9b; }

scrollbar.right { border-left: 1px solid #a29e9b; }

scrollbar:backdrop { background-color: #e6e4e3; border-color: #b1aeab; transition: 200ms ease-out; }

scrollbar.horizontal trough { min-height: 14px; border-radius: 0px; border-width: 0px 1px 0px 1px; border-image: none; background-image: linear-gradient(to bottom, #cdcbc9, #d6d4d2 50%); }

scrollbar.vertical trough { min-height: 14px; border-radius: 0px; border-width: 0px 1px 0px 1px; border-image: none; background-image: linear-gradient(to right, #cdcbc9, #d6d4d2 50%); }

scrollbar.horizontal slider { background-position: center center; background-image: url("assets/slider-horz-grip.png"), linear-gradient(to bottom, rgba(161, 192, 231, 0.99) 1px, rgba(153, 186, 227, 0.99) 50%, rgba(142, 177, 222, 0.99) 50%, rgba(132, 169, 217, 0.99) 95%); }

scrollbar.vertical slider { background-position: center center; background-image: url("assets/slider-vert-grip.png"), linear-gradient(to right, rgba(161, 192, 231, 0.99) 1px, rgba(153, 186, 227, 0.99) 50%, rgba(142, 177, 222, 0.99) 50%, rgba(132, 169, 217, 0.99) 95%); }

scrollbar.vertical slider:hover { background-position: center center; background-image: url("assets/slider-vert-grip.png"), linear-gradient(to right, #afcaec, #adc8eb 1px, #a1c0e7 50%, #99bae3 50%, #8cafdd 95%, #afcaec); }

scrollbar.horizontal slider:hover { background-position: center center; background-image: url("assets/slider-horz-grip.png"), linear-gradient(to bottom, #afcaec, #adc8eb 1px, #a1c0e7 50%, #99bae3 50%, #8cafdd 95%, #afcaec); }

scrollbar slider { background-repeat: no-repeat; background-position: center center; min-width: 14px; min-height: 14px; border: 1px solid #2c65ae; border-radius: 0px; }

scrollbar slider:hover { background-color: #2f2f2f; }

scrollbar slider:hover:active { background-color: #6292d0; }

scrollbar slider:backdrop { background-color: #a1a0a0; }

scrollbar slider:disabled { background-color: transparent; }

scrollbar.fine-tune slider { min-width: 4px; min-height: 4px; }

scrollbar.fine-tune.horizontal slider { border-width: 5px 4px; }

scrollbar.fine-tune.vertical slider { border-width: 4px 5px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) { border-color: transparent; opacity: 0.4; background-color: transparent; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider { margin: 0; min-width: 3px; min-height: 3px; background-color: #000000; border: 1px solid white; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button { min-width: 5px; min-height: 5px; background-color: #000000; background-clip: padding-box; border-radius: 100%; border: 1px solid white; -gtk-icon-source: none; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider { margin: 0 0px; min-width: 40px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button { margin: 1px 2px; min-width: 5px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider { margin: 0px 0; min-height: 40px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button { margin: 2px 1px; min-height: 5px; }

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering { opacity: 0.8; }

scrollbar.horizontal slider { min-width: 40px; }

scrollbar.vertical slider { min-height: 40px; }

scrollbar button { padding: 0; min-width: 13px; min-height: 13px; border-style: none; border-radius: 0; transition-property: min-height, min-width, color; border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #5f5e5e; }

scrollbar button:hover { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #2f2f2f; }

scrollbar button:active, scrollbar button:checked { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #6292d0; }

scrollbar button:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(95, 94, 94, 0.2); }

scrollbar button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #a1a0a0; }

scrollbar button:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(161, 160, 160, 0.2); }

scrollbar.vertical button.down { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

scrollbar.vertical button.up { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

scrollbar.horizontal button.down { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

scrollbar.horizontal button.up { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

treeview ~ scrollbar.vertical { border-top: 1px solid #a29e9b; margin-top: -1px; }

/********** Switch * */
switch { outline-offset: -4px; border: 1px solid #a29e9b; border-radius: 14px; color: #000000; background-color: #c7c5c3; text-shadow: 0 1px rgba(0, 0, 0, 0.1); /* only show i / o for the accessible theme */ }

switch:checked { color: #ffffff; border-color: #a29e9b; background-color: #538bd3; text-shadow: 0 1px rgba(90, 133, 187, 0.5), 0 0 2px rgba(255, 255, 255, 0.6); }

switch:disabled { color: #a9a5a2; border-color: #a29e9b; background-color: #edeceb; text-shadow: none; }

switch:backdrop { color: #2f2f2f; border-color: #b1aeab; background-color: #d8d6d5; text-shadow: none; transition: 200ms ease-out; }

switch:backdrop:checked { color: #edeceb; border-color: #a29e9b; background-color: #538bd3; }

switch:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-color: #edeceb; }

switch slider { margin: -1px; min-width: 24px; min-height: 24px; border: 1px solid; border-radius: 50%; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-outline-radius: 20px; color: #000000; outline-color: #a29e9b; border-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); background-image: linear-gradient(to bottom, #f9f9f8 20%, #edeceb 90%); box-shadow: inset 0 1px white, 0 1px rgba(0, 0, 0, 0.1), 0 1px 2px rgba(0, 0, 0, 0.07); box-shadow: 0 1px rgba(0, 0, 0, 0.05); background-image: image(white); background-clip: padding-box; }

switch image { color: transparent; }

switch:hover slider { color: #000000; outline-color: #a29e9b; border-color: #b3afab; box-shadow: inset 0 1px white, 0 1px rgba(0, 0, 0, 0.1), 0 1px 2px rgba(0, 0, 0, 0.07); background-image: image(white); box-shadow: 0 1px rgba(0, 0, 0, 0.15); }

switch:checked > slider { border: 1px solid #a29e9b; }

switch:disabled slider { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:backdrop slider { transition: 200ms ease-out; color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:backdrop:checked > slider { border-color: #a29e9b; }

switch:backdrop:disabled slider { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

row:selected switch { box-shadow: none; border-color: #a29e9b; }

row:selected switch:backdrop { border-color: #a29e9b; }

row:selected switch > slider:checked, row:selected switch > slider { border-color: #a29e9b; }

/************************* Check and Radio items * */
.view.content-view.check:not(list), iconview.content-view.check:not(list), .content-view:not(list) check { margin: 4px; min-width: 32px; min-height: 32px; color: transparent; background-color: #538bd3; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: none; -gtk-icon-shadow: none; }

.view.content-view.check:hover:not(list), iconview.content-view.check:hover:not(list), .content-view:not(list) check:hover { margin: 4px; min-width: 32px; min-height: 32px; color: transparent; background-color: #538bd3; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: none; -gtk-icon-shadow: none; }

.view.content-view.check:active:not(list), iconview.content-view.check:active:not(list), .content-view:not(list) check:active { margin: 4px; min-width: 32px; min-height: 32px; color: transparent; background-color: #538bd3; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: none; -gtk-icon-shadow: none; }

.view.content-view.check:backdrop:not(list), iconview.content-view.check:backdrop:not(list), .content-view:not(list) check:backdrop { margin: 4px; min-width: 32px; min-height: 32px; color: transparent; background-color: #939393; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: none; -gtk-icon-shadow: none; }

.view.content-view.check:checked:not(list), iconview.content-view.check:checked:not(list), .content-view:not(list) check:checked { margin: 4px; min-width: 32px; min-height: 32px; color: #eeeeec; background-color: #538bd3; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: -gtk-icontheme('object-select-symbolic'); -gtk-icon-shadow: none; }

.view.content-view.check:checked:hover:not(list), iconview.content-view.check:checked:hover:not(list), .content-view:not(list) check:checked:hover { margin: 4px; min-width: 32px; min-height: 32px; color: #eeeeec; background-color: #538bd3; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: -gtk-icontheme('object-select-symbolic'); -gtk-icon-shadow: none; }

.view.content-view.check:checked:active:not(list), iconview.content-view.check:checked:active:not(list), .content-view:not(list) check:checked:active { margin: 4px; min-width: 32px; min-height: 32px; color: #eeeeec; background-color: #538bd3; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: -gtk-icontheme('object-select-symbolic'); -gtk-icon-shadow: none; }

.view.content-view.check:backdrop:checked:not(list), iconview.content-view.check:backdrop:checked:not(list), .content-view:not(list) check:backdrop:checked { margin: 4px; min-width: 32px; min-height: 32px; color: rgba(238, 238, 236, 0.8); background-color: #939393; border-radius: 5px; background-image: none; transition: 200ms; box-shadow: none; border-width: 0; -gtk-icon-source: -gtk-icontheme('object-select-symbolic'); -gtk-icon-shadow: none; }

checkbutton.text-button, radiobutton.text-button { padding: 2px 0; outline-offset: 0; }

checkbutton.text-button label:not(:only-child):first-child, radiobutton.text-button label:not(:only-child):first-child { margin-left: 4px; }

checkbutton.text-button label:not(:only-child):last-child, radiobutton.text-button label:not(:only-child):last-child { margin-right: 4px; }

check, radio { margin: 0 4px; min-height: 14px; min-width: 14px; border: 1px solid; -gtk-icon-source: none; }

check:only-child, radio:only-child { margin: 0; }

popover check.left:dir(rtl), popover radio.left:dir(rtl) { margin-left: 0; margin-right: 12px; }

popover check.right:dir(ltr), popover radio.right:dir(ltr) { margin-left: 12px; margin-right: 0; }

check, radio { background-clip: padding-box; background-image: image(white); border-color: #b3afab; box-shadow: 0 1px rgba(0, 0, 0, 0.05); color: #000000; }

check:hover, radio:hover { background-image: image(#a4c2e8); border-color: #538bd3; }

check:active, radio:active { border-color: #a29e9b; background-image: image(white); box-shadow: none; color: #000000; }

check:disabled, radio:disabled { box-shadow: none; color: #a9a5a2; border-color: #bdbab8; background-image: image(#edeceb); }

check:backdrop, radio:backdrop { background-image: image(white); border-color: #b3afab; box-shadow: 0 1px rgba(0, 0, 0, 0.05); color: #000000; }

check:backdrop:disabled, radio:backdrop:disabled { box-shadow: none; color: #2f2f2f; border-color: #bdbab8; background-image: image(#edeceb); }

check:checked, radio:checked { background-clip: border-box; background-image: image(white); border-color: #538bd3; box-shadow: 0 1px rgba(0, 0, 0, 0.05); color: #000000; }

check:checked:hover, radio:checked:hover { background-image: image(#a4c2e8); border-color: #538bd3; }

check:checked:active, radio:checked:active { border-color: #a29e9b; background-image: image(white); box-shadow: none; color: #000000; }

check:checked:disabled, radio:checked:disabled { box-shadow: none; color: #a9a5a2; border-color: #bdbab8; background-image: image(#edeceb); }

check:checked:backdrop, radio:checked:backdrop { background-image: image(white); border-color: #538bd3; box-shadow: 0 1px rgba(0, 0, 0, 0.05); color: #000000; }

check:checked:backdrop:disabled, radio:checked:backdrop:disabled { box-shadow: none; color: #2f2f2f; border-color: #bdbab8; background-image: image(#edeceb); }

check:indeterminate, radio:indeterminate { background-clip: border-box; background-image: image(white); border-color: #538bd3; box-shadow: 0 1px rgba(0, 0, 0, 0.05); color: #000000; }

check:indeterminate:hover, radio:indeterminate:hover { background-image: image(#a4c2e8); border-color: #538bd3; }

check:indeterminate:active, radio:indeterminate:active { border-color: #a29e9b; background-image: image(white); box-shadow: none; color: #000000; }

check:indeterminate:disabled, radio:indeterminate:disabled { box-shadow: none; color: #a9a5a2; border-color: #bdbab8; background-image: image(#edeceb); }

check:indeterminate:backdrop, radio:indeterminate:backdrop { background-image: image(white); border-color: #538bd3; box-shadow: 0 1px rgba(0, 0, 0, 0.05); color: #000000; }

check:indeterminate:backdrop:disabled, radio:indeterminate:backdrop:disabled { box-shadow: none; color: #2f2f2f; border-color: #bdbab8; background-image: image(#edeceb); }

check:backdrop, radio:backdrop { transition: 200ms ease-out; }

.osd check, .osd radio { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(61, 63, 54, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd check:hover, .osd radio:hover { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(61, 63, 54, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); }

.osd check:active, .osd radio:active { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(0, 0, 0, 0.7)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); }

.osd check:backdrop, .osd radio:backdrop { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd check:disabled, .osd radio:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

menu menuitem check, menu menuitem radio { margin: 0; }

menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem check:checked, menu menuitem check:checked:hover, menu menuitem check:checked:disabled, menu menuitem check:indeterminate, menu menuitem check:indeterminate:hover, menu menuitem check:indeterminate:disabled, menu menuitem radio, menu menuitem radio:hover, menu menuitem radio:disabled, menu menuitem radio:checked, menu menuitem radio:checked:hover, menu menuitem radio:checked:disabled, menu menuitem radio:indeterminate, menu menuitem radio:indeterminate:hover, menu menuitem radio:indeterminate:disabled { min-height: 14px; min-width: 14px; background-image: none; background-color: transparent; box-shadow: none; -gtk-icon-shadow: none; color: inherit; border-color: currentColor; }

check { border-radius: 1px; }

check:checked { -gtk-icon-source: image(-gtk-recolor(url("assets/check-symbolic.svg")), -gtk-recolor(url("assets/check-symbolic.symbolic.png"))); }

check:indeterminate { -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }

treeview.view radio:selected:focus, treeview.view radio:selected, radio { border-radius: 100%; }

treeview.view radio:checked:selected, radio:checked { -gtk-icon-source: image(-gtk-recolor(url("assets/bullet-symbolic.svg")), -gtk-recolor(url("assets/bullet-symbolic.symbolic.png"))); }

treeview.view radio:indeterminate:selected, radio:indeterminate { -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }

radio:not(:indeterminate):not(:checked):active:not(:backdrop) { -gtk-icon-transform: scale(0); }

check:not(:indeterminate):not(:checked):active:not(:backdrop) { -gtk-icon-transform: translate(6px, -3px) rotate(-45deg) scaleY(0.2) rotate(45deg) scaleX(0); }

radio:active, check:active { -gtk-icon-transform: scale(0, 1); border-color: #a29e9b; }

radio:checked:not(:backdrop), radio:indeterminate:not(:backdrop), check:checked:not(:backdrop), check:indeterminate:not(:backdrop) { -gtk-icon-transform: unset; transition: 400ms; }

menu menuitem radio:checked:not(:backdrop), menu menuitem radio:indeterminate:not(:backdrop), menu menuitem check:checked:not(:backdrop), menu menuitem check:indeterminate:not(:backdrop) { transition: none; }

treeview.view check:selected:focus, treeview.view check:selected, treeview.view radio:selected:focus, treeview.view radio:selected { color: #a29e9b; border-color: #5a85bb; }

/************ GtkScale * */
scale trough, scale fill, progressbar trough { border: 1px solid #a29e9b; border-radius: 3px; background-color: #d6d4d2; }

scale trough:disabled, scale fill:disabled, progressbar trough:disabled { background-color: #edeceb; }

scale trough:backdrop, scale fill:backdrop, progressbar trough:backdrop { background-color: #d8d6d5; border-color: #b1aeab; transition: 200ms ease-out; }

scale trough:backdrop:disabled, scale fill:backdrop:disabled, progressbar trough:backdrop:disabled { background-color: #edeceb; }

row:selected scale trough:disabled, scale row:selected trough:disabled, row:selected scale fill:disabled, scale row:selected fill:disabled, row:selected progressbar trough:disabled, progressbar row:selected trough:disabled, row:selected scale trough, scale row:selected trough, row:selected scale fill, scale row:selected fill, row:selected progressbar trough, progressbar row:selected trough { border-color: #5a85bb; }

.osd scale trough, scale .osd trough, .osd scale fill, scale .osd fill, .osd progressbar trough, progressbar .osd trough { border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); }

.osd scale trough:disabled, scale .osd trough:disabled, .osd scale fill:disabled, scale .osd fill:disabled, .osd progressbar trough:disabled, progressbar .osd trough:disabled { background-color: rgba(37, 38, 33, 0.8); }

scale highlight, progressbar progress { border: 1px solid #5a85bb; border-radius: 3px; background-color: #89addb; }

scale highlight:disabled, progressbar progress:disabled { background-color: transparent; border-color: transparent; }

scale highlight:backdrop, progressbar progress:backdrop { border-color: #5a85bb; }

scale highlight:backdrop:disabled, progressbar progress:backdrop:disabled { background-color: transparent; border-color: transparent; }

row:selected scale highlight:disabled, scale row:selected highlight:disabled, row:selected progressbar progress:disabled, progressbar row:selected progress:disabled, row:selected scale highlight, scale row:selected highlight, row:selected progressbar progress, progressbar row:selected progress { border-color: #5a85bb; }

.osd scale highlight, scale .osd highlight, .osd progressbar progress, progressbar .osd progress { border-color: rgba(0, 0, 0, 0.7); }

.osd scale highlight:disabled, scale .osd highlight:disabled, .osd progressbar progress:disabled, progressbar .osd progress:disabled { border-color: transparent; }

scale { min-height: 10px; min-width: 10px; padding: 11px; }

scale fill, scale highlight { margin: -1px; }

scale slider { min-height: 18px; min-width: 18px; margin: -9px; }

scale.fine-tune.horizontal { padding-top: 9px; padding-bottom: 9px; min-height: 16px; }

scale.fine-tune.vertical { padding-left: 9px; padding-right: 9px; min-width: 16px; }

scale.fine-tune slider { margin: -6px; }

scale.fine-tune fill, scale.fine-tune highlight, scale.fine-tune trough { border-radius: 5px; -gtk-outline-radius: 7px; }

scale trough { outline-offset: 2px; -gtk-outline-radius: 5px; }

scale fill:backdrop, scale fill { background-color: #a29e9b; }

scale fill:disabled:backdrop, scale fill:disabled { border-color: transparent; background-color: transparent; }

.osd scale fill { background-color: rgba(91, 91, 90, 0.775); }

.osd scale fill:disabled:backdrop, .osd scale fill:disabled { border-color: transparent; background-color: transparent; }

scale.horizontal slider { min-width: 20px; }

scale.vertical slider { min-height: 20px; }

scale slider { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); min-height: 12px; min-width: 12px; margin: -5px; border: 1px solid #aca7a3; border-radius: 3px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-property: background, border, box-shadow; }

scale slider:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px rgba(0, 0, 0, 0.1), 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

scale slider:active { border-color: #5a85bb; }

scale slider:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:backdrop { transition: 200ms ease-out; color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

row:selected scale slider:disabled, row:selected scale slider { border-color: #5a85bb; }

.osd scale slider { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(61, 63, 54, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); border-color: rgba(0, 0, 0, 0.7); background-color: #252621; }

.osd scale slider:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(69, 71, 61, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); background-color: #252621; }

.osd scale slider:active { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(0, 0, 0, 0.7)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 236, 0.3); background-color: #252621; }

.osd scale slider:disabled { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; background-color: #252621; }

.osd scale slider:backdrop { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(37, 38, 33, 0.8)); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; background-color: #252621; }

.osd scale slider:backdrop:disabled { background-color: #252621; }

scale marks, scale value { color: alpha(currentColor,0.55); font-feature-settings: "tnum"; }

scale.horizontal marks.top { margin-bottom: 6px; margin-top: -12px; }

scale.horizontal.fine-tune marks.top { margin-bottom: 6px; margin-top: -9px; }

scale.horizontal marks.bottom { margin-top: 6px; margin-bottom: -12px; }

scale.horizontal.fine-tune marks.bottom { margin-top: 6px; margin-bottom: -9px; }

scale.vertical marks.top { margin-right: 6px; margin-left: -12px; }

scale.vertical.fine-tune marks.top { margin-right: 6px; margin-left: -9px; }

scale.vertical marks.bottom { margin-left: 6px; margin-right: -12px; }

scale.vertical.fine-tune marks.bottom { margin-left: 6px; margin-right: -9px; }

scale.horizontal indicator { min-height: 6px; min-width: 1px; }

scale.horizontal.fine-tune indicator { min-height: 3px; }

scale.vertical indicator { min-height: 1px; min-width: 6px; }

scale.vertical.fine-tune indicator { min-width: 3px; }

scale.horizontal.marks-before:not(.marks-after) slider { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above.png"), url("assets/slider-horz-scale-has-marks-above@2.png")); min-height: 26px; min-width: 22px; margin-top: -14px; background-position: top; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-top: -11px; }

scale.horizontal.marks-before:not(.marks-after) slider:hover { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover.png"), url("assets/slider-horz-scale-has-marks-above-hover@2.png")); min-height: 26px; min-width: 22px; margin-top: -14px; background-position: top; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-top: -11px; }

scale.horizontal.marks-before:not(.marks-after) slider:active { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active.png"), url("assets/slider-horz-scale-has-marks-above-active@2.png")); min-height: 26px; min-width: 22px; margin-top: -14px; background-position: top; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-top: -11px; }

scale.horizontal.marks-before:not(.marks-after) slider:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-insensitive.png"), url("assets/slider-horz-scale-has-marks-above-insensitive@2.png")); min-height: 26px; min-width: 22px; margin-top: -14px; background-position: top; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-top: -11px; }

scale.horizontal.marks-before:not(.marks-after) slider:backdrop { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-backdrop.png"), url("assets/slider-horz-scale-has-marks-above-backdrop@2.png")); min-height: 26px; min-width: 22px; margin-top: -14px; background-position: top; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-top: -11px; }

scale.horizontal.marks-before:not(.marks-after) slider:backdrop:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-backdrop-insensitive.png"), url("assets/slider-horz-scale-has-marks-above-backdrop-insensitive@2.png")); min-height: 26px; min-width: 22px; margin-top: -14px; background-position: top; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-top: -11px; }

scale.horizontal.marks-after:not(.marks-before) slider { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below.png"), url("assets/slider-horz-scale-has-marks-below@2.png")); min-height: 26px; min-width: 22px; margin-bottom: -14px; background-position: bottom; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-bottom: -11px; }

scale.horizontal.marks-after:not(.marks-before) slider:hover { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-hover.png"), url("assets/slider-horz-scale-has-marks-below-hover@2.png")); min-height: 26px; min-width: 22px; margin-bottom: -14px; background-position: bottom; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-bottom: -11px; }

scale.horizontal.marks-after:not(.marks-before) slider:active { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-active.png"), url("assets/slider-horz-scale-has-marks-below-active@2.png")); min-height: 26px; min-width: 22px; margin-bottom: -14px; background-position: bottom; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-bottom: -11px; }

scale.horizontal.marks-after:not(.marks-before) slider:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-insensitive.png"), url("assets/slider-horz-scale-has-marks-below-insensitive@2.png")); min-height: 26px; min-width: 22px; margin-bottom: -14px; background-position: bottom; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-bottom: -11px; }

scale.horizontal.marks-after:not(.marks-before) slider:backdrop { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-backdrop.png"), url("assets/slider-horz-scale-has-marks-below-backdrop@2.png")); min-height: 26px; min-width: 22px; margin-bottom: -14px; background-position: bottom; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-bottom: -11px; }

scale.horizontal.marks-after:not(.marks-before) slider:backdrop:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-backdrop-insensitive.png"), url("assets/slider-horz-scale-has-marks-below-backdrop-insensitive@2.png")); min-height: 26px; min-width: 22px; margin-bottom: -14px; background-position: bottom; background-repeat: no-repeat; box-shadow: none; }

scale.horizontal.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-bottom: -11px; }

scale.vertical.marks-before:not(.marks-after) slider { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above.png"), url("assets/slider-vert-scale-has-marks-above@2.png")); min-height: 22px; min-width: 26px; margin-left: -14px; background-position: left bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-left: -11px; }

scale.vertical.marks-before:not(.marks-after) slider:hover { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-hover.png"), url("assets/slider-vert-scale-has-marks-above-hover@2.png")); min-height: 22px; min-width: 26px; margin-left: -14px; background-position: left bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-left: -11px; }

scale.vertical.marks-before:not(.marks-after) slider:active { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-active.png"), url("assets/slider-vert-scale-has-marks-above-active@2.png")); min-height: 22px; min-width: 26px; margin-left: -14px; background-position: left bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-left: -11px; }

scale.vertical.marks-before:not(.marks-after) slider:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-insensitive.png"), url("assets/slider-vert-scale-has-marks-above-insensitive@2.png")); min-height: 22px; min-width: 26px; margin-left: -14px; background-position: left bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-left: -11px; }

scale.vertical.marks-before:not(.marks-after) slider:backdrop { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-backdrop.png"), url("assets/slider-vert-scale-has-marks-above-backdrop@2.png")); min-height: 22px; min-width: 26px; margin-left: -14px; background-position: left bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-left: -11px; }

scale.vertical.marks-before:not(.marks-after) slider:backdrop:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-backdrop-insensitive.png"), url("assets/slider-vert-scale-has-marks-above-backdrop-insensitive@2.png")); min-height: 22px; min-width: 26px; margin-left: -14px; background-position: left bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-before:not(.marks-after).fine-tune slider { margin: -7px; margin-left: -11px; }

scale.vertical.marks-after:not(.marks-before) slider { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below.png"), url("assets/slider-vert-scale-has-marks-below@2.png")); min-height: 22px; min-width: 26px; margin-right: -14px; background-position: right bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-right: -11px; }

scale.vertical.marks-after:not(.marks-before) slider:hover { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-hover.png"), url("assets/slider-vert-scale-has-marks-below-hover@2.png")); min-height: 22px; min-width: 26px; margin-right: -14px; background-position: right bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-right: -11px; }

scale.vertical.marks-after:not(.marks-before) slider:active { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-active.png"), url("assets/slider-vert-scale-has-marks-below-active@2.png")); min-height: 22px; min-width: 26px; margin-right: -14px; background-position: right bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-right: -11px; }

scale.vertical.marks-after:not(.marks-before) slider:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-insensitive.png"), url("assets/slider-vert-scale-has-marks-below-insensitive@2.png")); min-height: 22px; min-width: 26px; margin-right: -14px; background-position: right bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-right: -11px; }

scale.vertical.marks-after:not(.marks-before) slider:backdrop { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-backdrop.png"), url("assets/slider-vert-scale-has-marks-below-backdrop@2.png")); min-height: 22px; min-width: 26px; margin-right: -14px; background-position: right bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-right: -11px; }

scale.vertical.marks-after:not(.marks-before) slider:backdrop:disabled { margin: -10px; border-style: none; border-radius: 0; background-color: transparent; background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-backdrop-insensitive.png"), url("assets/slider-vert-scale-has-marks-below-backdrop-insensitive@2.png")); min-height: 22px; min-width: 26px; margin-right: -14px; background-position: right bottom; background-repeat: no-repeat; box-shadow: none; }

scale.vertical.marks-after:not(.marks-before).fine-tune slider { margin: -7px; margin-right: -11px; }

scale.color { min-height: 0; min-width: 0; }

scale.color trough { background-image: image(#a29e9b); background-repeat: no-repeat; }

scale.color.horizontal { padding: 0 0 15px 0; }

scale.color.horizontal trough { padding-bottom: 4px; background-position: 0 -3px; border-top-left-radius: 0; border-top-right-radius: 0; }

scale.color.horizontal slider:dir(ltr):hover, scale.color.horizontal slider:dir(ltr):backdrop, scale.color.horizontal slider:dir(ltr):disabled, scale.color.horizontal slider:dir(ltr):backdrop:disabled, scale.color.horizontal slider:dir(ltr), scale.color.horizontal slider:dir(rtl):hover, scale.color.horizontal slider:dir(rtl):backdrop, scale.color.horizontal slider:dir(rtl):disabled, scale.color.horizontal slider:dir(rtl):backdrop:disabled, scale.color.horizontal slider:dir(rtl) { margin-bottom: -15px; margin-top: 6px; }

scale.color.vertical:dir(ltr) { padding: 0 0 0 15px; }

scale.color.vertical:dir(ltr) trough { padding-left: 4px; background-position: 3px 0; border-bottom-right-radius: 0; border-top-right-radius: 0; }

scale.color.vertical:dir(ltr) slider:hover, scale.color.vertical:dir(ltr) slider:backdrop, scale.color.vertical:dir(ltr) slider:disabled, scale.color.vertical:dir(ltr) slider:backdrop:disabled, scale.color.vertical:dir(ltr) slider { margin-left: -15px; margin-right: 6px; }

scale.color.vertical:dir(rtl) { padding: 0 15px 0 0; }

scale.color.vertical:dir(rtl) trough { padding-right: 4px; background-position: -3px 0; border-bottom-left-radius: 0; border-top-left-radius: 0; }

scale.color.vertical:dir(rtl) slider:hover, scale.color.vertical:dir(rtl) slider:backdrop, scale.color.vertical:dir(rtl) slider:disabled, scale.color.vertical:dir(rtl) slider:backdrop:disabled, scale.color.vertical:dir(rtl) slider { margin-right: -15px; margin-left: 6px; }

scale.color.fine-tune.horizontal:dir(ltr), scale.color.fine-tune.horizontal:dir(rtl) { padding: 0 0 12px 0; }

scale.color.fine-tune.horizontal:dir(ltr) trough, scale.color.fine-tune.horizontal:dir(rtl) trough { padding-bottom: 7px; background-position: 0 -6px; }

scale.color.fine-tune.horizontal:dir(ltr) slider, scale.color.fine-tune.horizontal:dir(rtl) slider { margin-bottom: -15px; margin-top: 6px; }

scale.color.fine-tune.vertical:dir(ltr) { padding: 0 0 0 12px; }

scale.color.fine-tune.vertical:dir(ltr) trough { padding-left: 7px; background-position: 6px 0; }

scale.color.fine-tune.vertical:dir(ltr) slider { margin-left: -15px; margin-right: 6px; }

scale.color.fine-tune.vertical:dir(rtl) { padding: 0 12px 0 0; }

scale.color.fine-tune.vertical:dir(rtl) trough { padding-right: 7px; background-position: -6px 0; }

scale.color.fine-tune.vertical:dir(rtl) slider { margin-right: -15px; margin-left: 6px; }

/***************** Progress bars * */
progressbar { font-size: smaller; color: rgba(0, 0, 0, 0.4); font-feature-settings: "tnum"; }

progressbar.horizontal trough, progressbar.horizontal progress { min-height: 16px; }

progressbar.vertical trough, progressbar.vertical progress { min-width: 16px; }

progressbar.horizontal progress { margin: 0 -1px; background-image: repeating-linear-gradient(135deg, alpha(#658fc3,0), alpha(#658fc3,0) 12px, alpha(#658fc3,0.5) 12px, alpha(#658fc3,0.5) 24px), linear-gradient(to bottom, alpha(#a4c2e8,0.7), alpha(#96b8e2,0.7) 50%, alpha(#91b4df,0.7) 50%, alpha(#84a9d9,0.7)); }

progressbar.vertical progress { margin: -1px 0; background-image: repeating-linear-gradient(45deg, alpha(#658fc3,0), alpha(#658fc3,0) 12px, alpha(#658fc3,0.5) 12px, alpha(#658fc3,0.5) 24px), linear-gradient(to right, alpha(#a4c2e8,0.7), alpha(#96b8e2,0.7) 50%, alpha(#91b4df,0.7) 50%, alpha(#84a9d9,0.7)); }

progressbar:backdrop { box-shadow: none; transition: 200ms ease-out; }

progressbar progress { border-radius: 1.5px; }

progressbar progress.left { border-top-left-radius: 2px; border-bottom-left-radius: 2px; }

progressbar progress.right { border-top-right-radius: 2px; border-bottom-right-radius: 2px; }

progressbar progress.top { border-top-right-radius: 2px; border-top-left-radius: 2px; }

progressbar progress.bottom { border-bottom-right-radius: 2px; border-bottom-left-radius: 2px; }

progressbar.osd { min-width: 3px; min-height: 3px; background-color: transparent; }

progressbar.osd trough { border-style: none; border-radius: 0; background-color: transparent; box-shadow: none; }

progressbar.osd progress { border-style: none; border-radius: 0; }

progressbar trough.empty progress { all: unset; }

/************* Level Bar * */
levelbar.horizontal block { min-height: 1px; }

levelbar.horizontal.discrete block { margin: 0 1px; min-width: 32px; }

levelbar.vertical block { min-width: 1px; }

levelbar.vertical.discrete block { margin: 1px 0; min-height: 32px; }

levelbar:backdrop { transition: 200ms ease-out; }

levelbar trough { border: 1px solid; padding: 2px; border-radius: 3px; color: #1a1a1a; border-color: #a29e9b; background-color: #ffffff; box-shadow: inset 0 0 0 1px rgba(162, 158, 155, 0); }

levelbar trough:backdrop { color: rgba(26, 26, 26, 0.69); border-color: #b1aeab; background-color: #fcfcfc; box-shadow: none; }

levelbar block { border: 1px solid; border-radius: 1px; }

levelbar block.low { border-color: #a06104; background-color: #f99b11; }

levelbar block.low:backdrop { border-color: #f99b11; }

levelbar block.high, levelbar block:not(.empty) { border-color: #0f5fc5; background-color: #4893f2; }

levelbar block.high:backdrop, levelbar block:not(.empty):backdrop { border-color: #4893f2; }

levelbar block.full { border-color: #5e733c; background-color: #93af66; }

levelbar block.full:backdrop { border-color: #93af66; }

levelbar block.empty { background-color: transparent; border-color: rgba(0, 0, 0, 0.2); }

levelbar block.empty:backdrop { border-color: rgba(47, 47, 47, 0.15); }

/**************** Print dialog * */
printdialog paper { color: #000000; border: 1px solid #a29e9b; background: white; padding: 0; }

printdialog paper:backdrop { color: #2f2f2f; border-color: #b1aeab; }

printdialog .dialog-action-box { margin: 12px; }

/********** Frames * */
frame > border, .frame { box-shadow: none; margin: 0; padding: 0; border-radius: 0; border: 1px solid #a29e9b; }

frame > border.flat, .frame.flat { border-style: none; }

frame > border:backdrop, .frame:backdrop { border-color: #b1aeab; }

actionbar > revealer > box { padding: 6px; border-top: 1px solid #a29e9b; }

actionbar > revealer > box:backdrop { border-color: #b1aeab; }

scrolledwindow viewport.frame { border-style: none; }

scrolledwindow overshoot.top { background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#898580), to(rgba(137, 133, 128, 0))), -gtk-gradient(radial, center top, 0, center top, 0.6, from(rgba(0, 0, 0, 0.07)), to(transparent)); background-size: 100% 5%, 100% 100%; background-repeat: no-repeat; background-position: center top; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.top:backdrop { background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#b1aeab), to(rgba(177, 174, 171, 0))); background-size: 100% 5%; background-repeat: no-repeat; background-position: center top; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.bottom { background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#898580), to(rgba(137, 133, 128, 0))), -gtk-gradient(radial, center bottom, 0, center bottom, 0.6, from(rgba(0, 0, 0, 0.07)), to(transparent)); background-size: 100% 5%, 100% 100%; background-repeat: no-repeat; background-position: center bottom; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.bottom:backdrop { background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#b1aeab), to(rgba(177, 174, 171, 0))); background-size: 100% 5%; background-repeat: no-repeat; background-position: center bottom; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.left { background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#898580), to(rgba(137, 133, 128, 0))), -gtk-gradient(radial, left center, 0, left center, 0.6, from(rgba(0, 0, 0, 0.07)), to(transparent)); background-size: 5% 100%, 100% 100%; background-repeat: no-repeat; background-position: left center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.left:backdrop { background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#b1aeab), to(rgba(177, 174, 171, 0))); background-size: 5% 100%; background-repeat: no-repeat; background-position: left center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.right { background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#898580), to(rgba(137, 133, 128, 0))), -gtk-gradient(radial, right center, 0, right center, 0.6, from(rgba(0, 0, 0, 0.07)), to(transparent)); background-size: 5% 100%, 100% 100%; background-repeat: no-repeat; background-position: right center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.right:backdrop { background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#b1aeab), to(rgba(177, 174, 171, 0))); background-size: 5% 100%; background-repeat: no-repeat; background-position: right center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow junction { border-color: transparent; border-image: linear-gradient(to bottom, #a29e9b 1px, transparent 1px) 0 0 0 1/0 1px stretch; background-color: #bebdbc; }

scrolledwindow junction:dir(rtl) { border-image-slice: 0 1 0 0; }

scrolledwindow junction:backdrop { border-image-source: linear-gradient(to bottom, #b1aeab 1px, transparent 1px); background-color: #e6e4e3; transition: 200ms ease-out; }

separator { background: rgba(0, 0, 0, 0.1); min-width: 1px; min-height: 1px; }

/********* Lists * */
list { color: #1a1a1a; background-color: #ffffff; border-color: #a29e9b; }

list:backdrop { color: rgba(26, 26, 26, 0.69); background-color: #fcfcfc; border-color: #b1aeab; }

list row { padding: 2px; }

row { transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row:hover { transition: none; }

row:backdrop { transition: 200ms ease-out; }

row.activatable.has-open-popup, row.activatable:hover { background-color: #89addb; }

row.activatable:active { box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2); }

row.activatable:backdrop:hover { background-color: transparent; }

row.activatable:selected:active { box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5); }

row.activatable:selected.has-open-popup, row.activatable:selected:hover { background-color: #89addb; }

row.activatable:selected:backdrop { background-color: #89addb; }

/********************* App Notifications * */
.app-notification, .app-notification.frame { padding: 10px; border-radius: 0 0 5px 5px; background-color: rgba(37, 38, 33, 0.8); background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.2), transparent 2px); background-clip: padding-box; }

.app-notification:backdrop, .app-notification.frame:backdrop { background-image: none; transition: 200ms ease-out; }

.app-notification border, .app-notification.frame border { border: none; }

/************* Expanders * */
expander title > arrow { min-width: 16px; min-height: 16px; -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

expander title > arrow:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

expander title > arrow:hover { color: #4d4d4d; }

expander title > arrow:disabled { color: #a9a5a2; }

expander title > arrow:disabled:backdrop { color: #c9c6c3; }

expander title > arrow:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

/************ Calendar * */
calendar { color: #1a1a1a; border: 1px solid #a29e9b; }

calendar:selected { border-radius: 3px; }

calendar.header { border-bottom-color: rgba(0, 0, 0, 0.1); }

calendar.header:backdrop { border-bottom-color: rgba(0, 0, 0, 0.1); }

calendar.button { color: rgba(0, 0, 0, 0.45); }

calendar.button:hover { color: #000000; }

calendar.button:backdrop { color: rgba(47, 47, 47, 0.45); }

calendar.button:disabled { color: rgba(169, 165, 162, 0.45); }

calendar.highlight { color: #a9a5a2; }

calendar.highlight:backdrop { color: #c9c6c3; }

calendar:backdrop { color: rgba(26, 26, 26, 0.69); border-color: #b1aeab; }

calendar:indeterminate { color: alpha(currentColor,0.1); }

/*********** Dialogs * */
messagedialog .titlebar { min-height: 20px; background-image: none; background-color: #edeceb; border-style: none; border-top-left-radius: 7px; border-top-right-radius: 7px; }

messagedialog.csd.background { border-bottom-left-radius: 8px; border-bottom-right-radius: 8px; }

messagedialog.csd .dialog-action-area button { padding: 10px 14px; border-right-style: none; border-bottom-style: none; border-radius: 0; -gtk-outline-radius: 0; }

messagedialog.csd .dialog-action-area button:first-child { border-left-style: none; border-bottom-left-radius: 6px; -gtk-outline-bottom-left-radius: 6px; }

messagedialog.csd .dialog-action-area button:last-child { border-bottom-right-radius: 6px; -gtk-outline-bottom-right-radius: 6px; }

filechooser .dialog-action-box { border-top: 1px solid #a29e9b; }

filechooser .dialog-action-box:backdrop { border-top-color: #b1aeab; }

filechooser #pathbarbox { border-bottom: 1px solid #edeceb; }

filechooserbutton:drop(active) { box-shadow: none; border-color: transparent; }

/*********** Sidebar * */
.sidebar { border-style: none; background-color: #f6f6f5; }

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:not(separator):dir(ltr), .sidebar:not(separator).left, .sidebar:not(separator).left:dir(rtl) { border-right: 1px solid #a29e9b; border-left-style: none; }

stacksidebar.sidebar:dir(rtl) list, stacksidebar.sidebar.right list, .sidebar:not(separator):dir(rtl), .sidebar:not(separator).right { border-left: 1px solid #a29e9b; border-right-style: none; }

.sidebar:backdrop { background-color: #f5f4f4; border-color: #b1aeab; transition: 200ms ease-out; }

.sidebar list { background-color: transparent; }

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar { border-style: none; }

stacksidebar row { padding: 10px 4px; }

stacksidebar row > label { padding-left: 6px; padding-right: 6px; }

stacksidebar row.needs-attention > label { background-size: 6px 6px, 0 0; }

separator.sidebar { background-color: #a29e9b; }

separator.sidebar:backdrop { background-color: #b1aeab; }

separator.sidebar.selection-mode, .selection-mode separator.sidebar { background-color: #5e733c; }

/**************** File chooser * */
row image.sidebar-icon { opacity: 0.7; }

placessidebar > viewport.frame { border-style: none; }

placessidebar row { min-height: 36px; padding: 0px; }

placessidebar row > revealer { padding: 0 14px; }

placessidebar row:selected { color: #ffffff; }

placessidebar row:disabled { color: #a9a5a2; }

placessidebar row:backdrop { color: #2f2f2f; }

placessidebar row:backdrop:selected { color: #fcfcfc; }

placessidebar row:backdrop:disabled { color: #c9c6c3; }

placessidebar row image.sidebar-icon:dir(ltr) { padding-right: 8px; }

placessidebar row image.sidebar-icon:dir(rtl) { padding-left: 8px; }

placessidebar row label.sidebar-label:dir(ltr) { padding-right: 2px; }

placessidebar row label.sidebar-label:dir(rtl) { padding-left: 2px; }

button.sidebar-button { min-height: 26px; min-width: 26px; margin-top: 3px; margin-bottom: 3px; padding: 0; border-radius: 100%; -gtk-outline-radius: 100%; }

button.sidebar-button:not(:hover):not(:active) > image, button.sidebar-button:backdrop > image { opacity: 0.7; }

placessidebar row:selected:active { box-shadow: none; }

placessidebar row.sidebar-placeholder-row { padding: 0 8px; min-height: 2px; background-image: image(#93af66); background-clip: content-box; }

placessidebar row.sidebar-new-bookmark-row { color: #89addb; }

placessidebar row:drop(active):not(:disabled) { color: #93af66; box-shadow: inset 0 1px #93af66, inset 0 -1px #93af66; }

placessidebar row:drop(active):not(:disabled):selected { color: #ffffff; background-color: #93af66; }

placesview .server-list-button > image { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-icon-transform: rotate(0turn); }

placesview .server-list-button:checked > image { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-icon-transform: rotate(-0.5turn); }

placesview row.activatable:hover { background-color: transparent; }

placesview > actionbar > revealer > box > label { padding-left: 8px; padding-right: 8px; }

/********* Paned * */
paned > separator { min-width: 1px; min-height: 1px; -gtk-icon-source: none; border-style: none; background-color: transparent; background-image: image(#a29e9b); background-size: 1px 1px; }

paned > separator:selected { background-image: image(#89addb); }

paned > separator:backdrop { background-image: image(#b1aeab); }

paned > separator.wide { min-width: 5px; min-height: 5px; background-color: #edeceb; background-image: image(#a29e9b), image(#a29e9b); background-size: 1px 1px, 1px 1px; }

paned > separator.wide:backdrop { background-color: #edeceb; background-image: image(#b1aeab), image(#b1aeab); }

paned.horizontal > separator { background-repeat: repeat-y; }

paned.horizontal > separator:dir(ltr) { margin: 0 -8px 0 0; padding: 0 8px 0 0; background-position: left; }

paned.horizontal > separator:dir(rtl) { margin: 0 0 0 -8px; padding: 0 0 0 8px; background-position: right; }

paned.horizontal > separator.wide { margin: 0; padding: 0; background-repeat: repeat-y, repeat-y; background-position: left, right; }

paned.vertical > separator { margin: 0 0 -8px 0; padding: 0 0 8px 0; background-repeat: repeat-x; background-position: top; }

paned.vertical > separator.wide { margin: 0; padding: 0; background-repeat: repeat-x, repeat-x; background-position: bottom, top; }

/************** GtkInfoBar * */
infobar { border-style: none; }

infobar.action:hover > revealer > box { background-color: #d2c6b7; border-bottom: 1px solid #aeaba8; }

infobar.info, infobar.question, infobar.warning, infobar.error { text-shadow: none; }

infobar.info:backdrop > revealer > box, infobar.info > revealer > box, infobar.question:backdrop > revealer > box, infobar.question > revealer > box, infobar.warning:backdrop > revealer > box, infobar.warning > revealer > box, infobar.error:backdrop > revealer > box, infobar.error > revealer > box { background-color: #cfc1b1; border-bottom: 1px solid #aeaba8; }

infobar.info:backdrop > revealer > box label, infobar.info:backdrop > revealer > box, infobar.info > revealer > box label, infobar.info > revealer > box, infobar.question:backdrop > revealer > box label, infobar.question:backdrop > revealer > box, infobar.question > revealer > box label, infobar.question > revealer > box, infobar.warning:backdrop > revealer > box label, infobar.warning:backdrop > revealer > box, infobar.warning > revealer > box label, infobar.warning > revealer > box, infobar.error:backdrop > revealer > box label, infobar.error:backdrop > revealer > box, infobar.error > revealer > box label, infobar.error > revealer > box { color: #000000; }

infobar.info:backdrop, infobar.question:backdrop, infobar.warning:backdrop, infobar.error:backdrop { text-shadow: none; }

infobar.info button, infobar.question button, infobar.warning button, infobar.error button { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

infobar.info button:hover, infobar.question button:hover, infobar.warning button:hover, infobar.error button:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

infobar.info button:active, infobar.info button:checked, infobar.question button:active, infobar.question button:checked, infobar.warning button:active, infobar.warning button:checked, infobar.error button:active, infobar.error button:checked { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

infobar.info button:disabled, infobar.question button:disabled, infobar.warning button:disabled, infobar.error button:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

infobar.info button:backdrop, infobar.question button:backdrop, infobar.warning button:backdrop, infobar.error button:backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #d5d3d0; }

infobar.info button:backdrop:disabled, infobar.question button:backdrop:disabled, infobar.warning button:backdrop:disabled, infobar.error button:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #d5d3d0; }

infobar.info button:backdrop label, infobar.info button:backdrop, infobar.info button label, infobar.info button, infobar.question button:backdrop label, infobar.question button:backdrop, infobar.question button label, infobar.question button, infobar.warning button:backdrop label, infobar.warning button:backdrop, infobar.warning button label, infobar.warning button, infobar.error button:backdrop label, infobar.error button:backdrop, infobar.error button label, infobar.error button { color: #000000; }

infobar.info selection, infobar.question selection, infobar.warning selection, infobar.error selection { background-color: #d5d3d0; }

infobar.info *:link, infobar.question *:link, infobar.warning *:link, infobar.error *:link { color: #0000ee; }

/************ Tooltips * */
tooltip { padding: 4px; /* not working */ border-radius: 5px; box-shadow: none; text-shadow: 0 1px black; }

tooltip.background { background-color: rgba(0, 0, 0, 0.8); background-clip: padding-box; border: 1px solid rgba(255, 255, 255, 0.1); }

tooltip decoration { background-color: transparent; }

tooltip * { padding: 4px; background-color: transparent; color: white; }

/***************** Color Chooser * */
colorswatch:drop(active), colorswatch { border-style: none; }

colorswatch.top { border-top-left-radius: 5.5px; border-top-right-radius: 5.5px; }

colorswatch.top overlay { border-top-left-radius: 5px; border-top-right-radius: 5px; }

colorswatch.bottom { border-bottom-left-radius: 5.5px; border-bottom-right-radius: 5.5px; }

colorswatch.bottom overlay { border-bottom-left-radius: 5px; border-bottom-right-radius: 5px; }

colorswatch.left, colorswatch:first-child:not(.top) { border-top-left-radius: 5.5px; border-bottom-left-radius: 5.5px; }

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay { border-top-left-radius: 5px; border-bottom-left-radius: 5px; }

colorswatch.right, colorswatch:last-child:not(.bottom) { border-top-right-radius: 5.5px; border-bottom-right-radius: 5.5px; }

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay { border-top-right-radius: 5px; border-bottom-right-radius: 5px; }

colorswatch.dark { outline-color: rgba(255, 255, 255, 0.6); }

colorswatch.dark overlay { color: white; }

colorswatch.dark overlay:hover { border-color: rgba(0, 0, 0, 0.8); }

colorswatch.dark overlay:backdrop { color: rgba(255, 255, 255, 0.5); }

colorswatch.light { outline-color: rgba(0, 0, 0, 0.6); }

colorswatch.light overlay { color: black; }

colorswatch.light overlay:hover { border-color: rgba(0, 0, 0, 0.5); }

colorswatch.light overlay:backdrop { color: rgba(0, 0, 0, 0.5); }

colorswatch:drop(active) { box-shadow: none; }

colorswatch:drop(active).light overlay { border-color: #93af66; box-shadow: inset 0 0 0 2px #829e53, inset 0 0 0 1px #93af66; }

colorswatch:drop(active).dark overlay { border-color: #93af66; box-shadow: inset 0 0 0 2px rgba(0, 0, 0, 0.3), inset 0 0 0 1px #93af66; }

colorswatch overlay { border: 1px solid rgba(0, 0, 0, 0.3); }

colorswatch overlay:hover { box-shadow: inset 0 1px rgba(255, 255, 255, 0.4), inset 0 -1px rgba(0, 0, 0, 0.2); }

colorswatch overlay:backdrop, colorswatch overlay:backdrop:hover { border-color: rgba(0, 0, 0, 0.3); box-shadow: none; }

colorswatch#add-color-button { border-radius: 5px 5px 0 0; }

colorswatch#add-color-button:only-child { border-radius: 5px; }

colorswatch#add-color-button overlay { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

colorswatch#add-color-button overlay:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

colorswatch#add-color-button overlay:backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

colorswatch:disabled { opacity: 0.5; }

colorswatch:disabled overlay { border-color: rgba(0, 0, 0, 0.6); box-shadow: none; }

row:selected colorswatch { box-shadow: 0 0 0 2px #ffffff; }

colorswatch#editor-color-sample { border-radius: 4px; }

colorswatch#editor-color-sample overlay { border-radius: 4.5px; }

colorchooser .popover.osd { border-radius: 5px; }

/******** Misc * */
.content-view { background-color: #dcdad8; }

.content-view:hover { -gtk-icon-effect: highlight; }

.content-view:backdrop { background-color: #dcdad8; }

.osd .scale-popup button.flat { border-style: none; border-radius: 5px; }

.scale-popup button:hover { background-color: rgba(0, 0, 0, 0.1); border-radius: 5px; }

/********************** Window Decorations * */
decoration { border-radius: 7px 7px 0 0; border-width: 0px; box-shadow: 1px 1px 0px #000000, -1px 1px 0px #000000, 1px -1px 0px #000000, -1px -1px 0px #000000; margin: 10px; }

decoration:backdrop { box-shadow: 1px 1px 0px #000000, -1px 1px 0px #000000, 1px -1px 0px #000000, -1px -1px 0px #000000; transition: 200ms ease-out; }

.maximized decoration, .fullscreen decoration, .tiled decoration, .tiled-top decoration, .tiled-right decoration, .tiled-bottom decoration, .tiled-left decoration { border-radius: 0; }

.popup decoration { box-shadow: none; }

.ssd decoration { box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.23); }

.csd.popup decoration { border-radius: 2px; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.13); }

tooltip.csd decoration { border-radius: 5px; box-shadow: none; }

messagedialog.csd decoration { border-radius: 7px; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.13); }

.solid-csd decoration { margin: 0; padding: 4px; background-color: #a29e9b; border: solid 1px #a29e9b; border-radius: 0; box-shadow: inset 0 0 0 3px #f9f9f8, inset 0 1px rgba(255, 255, 255, 0.8); }

.solid-csd decoration:backdrop { box-shadow: inset 0 0 0 3px #edeceb, inset 0 1px rgba(255, 255, 255, 0.8); }

button.titlebutton { border-width: 1px; border-style: solid; }

button.titlebutton:not(.appmenu) { border-radius: 4px; padding: 2px; margin: 0 2px; min-width: 0; min-height: 0; }

.view:selected:focus, .view:selected, iconview:selected, .view text:selected, iconview text:selected, textview text:selected, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection, textview text selection:focus, textview text selection, flowbox flowboxchild:selected, spinbutton:not(.vertical) selection, entry selection, modelbutton.flat:selected, .menuitem.button.flat:selected, treeview.view:selected:focus, treeview.view:selected, row:selected, calendar:selected { background-color: #89addb; }

iconview.hover:selected:focus, .hover.view:selected, iconview.hover:selected, iconview text.hover:selected:focus, textview text.hover:selected:focus, .view text.hover:selected, iconview text.hover:selected, textview text.hover:selected, iconview text selection.hover:focus, .view text selection.hover, iconview text selection.hover, textview text selection.hover, flowbox flowboxchild.hover:selected, spinbutton:not(.vertical) selection.hover, entry selection.hover, modelbutton.hover.flat:selected, .hover.menuitem.button.flat:selected, row.hover:selected, calendar.hover:selected { color: #ffffff; }

label:selected, .view:selected:focus, .view:selected, iconview:selected, .view text:selected, iconview text:selected, textview text:selected, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection, textview text selection:focus, textview text selection, flowbox flowboxchild:selected, spinbutton:not(.vertical) selection, entry selection, modelbutton.flat:selected, .menuitem.button.flat:selected, treeview.view:selected:focus, treeview.view:selected, row:selected, calendar:selected { color: #ffffff; }

label:disabled selection, label:disabled:selected, iconview:disabled:selected:focus, .view:disabled:selected, iconview:disabled:selected, iconview text:disabled:selected:focus, textview text:disabled:selected:focus, .view text:disabled:selected, iconview text:disabled:selected, textview text:disabled:selected, iconview text selection:disabled:focus, .view text selection:disabled, iconview text selection:disabled, textview text selection:disabled, flowbox flowboxchild:disabled:selected, spinbutton:not(.vertical) selection:disabled, entry selection:disabled, modelbutton.flat:disabled:selected, .menuitem.button.flat:disabled:selected, row:disabled:selected, calendar:disabled:selected { color: #c4d6ed; }

label:backdrop selection, label:backdrop:selected, iconview:backdrop:selected:focus, .view:backdrop:selected, iconview:backdrop:selected, iconview text:backdrop:selected:focus, textview text:backdrop:selected:focus, .view text:backdrop:selected, iconview text:backdrop:selected, textview text:backdrop:selected, iconview text selection:backdrop:focus, .view text selection:backdrop, iconview text selection:backdrop, textview text selection:backdrop, flowbox flowboxchild:backdrop:selected, spinbutton:not(.vertical) selection:backdrop, entry selection:backdrop, modelbutton.flat:backdrop:selected, .menuitem.button.flat:backdrop:selected, row:backdrop:selected, calendar:backdrop:selected { color: #fcfcfc; }

label:backdrop selection:disabled, label:backdrop:disabled:selected, .view:backdrop:disabled:selected, iconview:backdrop:disabled:selected, .view text:backdrop:disabled:selected, iconview text:backdrop:disabled:selected, textview text:backdrop:disabled:selected, .view text selection:backdrop:disabled, iconview text selection:backdrop:disabled, textview text selection:backdrop:disabled, flowbox flowboxchild:backdrop:disabled:selected, spinbutton:not(.vertical) selection:backdrop:disabled, entry selection:backdrop:disabled, modelbutton.flat:backdrop:disabled:selected, .menuitem.button.flat:backdrop:disabled:selected, row:backdrop:disabled:selected, calendar:backdrop:disabled:selected { color: #acc5e5; }

.monospace { font-family: monospace; }

/********************** Touch Copy & Paste * */
cursor-handle { background-color: transparent; background-image: none; box-shadow: none; border-style: none; }

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start.png"), url("assets/text-select-start@2.png")); padding-left: 10px; }

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end.png"), url("assets/text-select-end@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above.png"), url("assets/slider-horz-scale-has-marks-above@2.png")); }

cursor-handle.top:hover:dir(ltr), cursor-handle.bottom:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-hover.png"), url("assets/text-select-start-hover@2.png")); padding-left: 10px; }

cursor-handle.bottom:hover:dir(ltr), cursor-handle.top:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-hover.png"), url("assets/text-select-end-hover@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:hover:dir(ltr), cursor-handle.insertion-cursor:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover.png"), url("assets/slider-horz-scale-has-marks-above-hover@2.png")); }

cursor-handle.top:active:dir(ltr), cursor-handle.bottom:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-active.png"), url("assets/text-select-start-active@2.png")); padding-left: 10px; }

cursor-handle.bottom:active:dir(ltr), cursor-handle.top:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-active.png"), url("assets/text-select-end-active@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:active:dir(ltr), cursor-handle.insertion-cursor:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active.png"), url("assets/slider-horz-scale-has-marks-above-active@2.png")); }

.context-menu { font: initial; }

.keycap { min-width: 20px; min-height: 25px; margin-top: 2px; padding-bottom: 3px; padding-left: 6px; padding-right: 6px; color: #000000; background-color: #ffffff; border: 1px solid; border-color: #c7c5c3; border-radius: 5px; box-shadow: inset 0 -3px #f1f0ef; font-size: smaller; }

.keycap:backdrop { background-color: #fcfcfc; color: #2f2f2f; transition: 200ms ease-out; }

:not(decoration):not(window):drop(active):focus, :not(decoration):not(window):drop(active) { border-color: #93af66; box-shadow: inset 0 0 0 1px #93af66; caret-color: #93af66; }

stackswitcher button.text-button { min-width: 100px; }

stackswitcher button.circular, stackswitcher button.text-button.circular { min-width: 32px; min-height: 32px; padding: 0; }

/************* App Icons * */
/* Outline for low res icons */
.lowres-icon { -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/* Dropshadow for large icons */
.icon-dropshadow { -gtk-icon-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/********* Emoji * */
popover.emoji-picker { padding-left: 0; padding-right: 0; }

popover.emoji-picker entry.search { margin: 3px 5px 5px 5px; }

button.emoji-section { border-color: transparent; border-width: 3px; border-style: none none solid; border-radius: 0; margin: 2px 4px 2px 4px; padding: 3px 0 0; min-width: 32px; min-height: 28px; /* reset props inherited from the button style */ background: none; box-shadow: none; text-shadow: none; outline-offset: -5px; }

button.emoji-section:first-child { margin-left: 7px; }

button.emoji-section:last-child { margin-right: 7px; }

button.emoji-section:backdrop:not(:checked) { border-color: transparent; }

button.emoji-section:hover { border-color: #a29e9b; }

button.emoji-section:checked { border-color: #89addb; }

button.emoji-section label { padding: 0; opacity: 0.55; }

button.emoji-section:hover label { opacity: 0.775; }

button.emoji-section:checked label { opacity: 1; }

popover.emoji-picker .emoji { font-size: x-large; padding: 6px; }

popover.emoji-picker .emoji :hover { background: #89addb; border-radius: 6px; }

popover.emoji-completion arrow { border: none; background: none; }

popover.emoji-completion contents row box { padding: 2px 10px; }

popover.emoji-completion .emoji:hover { background: #000000; }

/*************** core colors * */
/* Core colors are only used in the current file, as bases for other color declarations. */
/* Core color for blue widgets in TraditionalOK. */
/* Core color for gray widgets in TraditionalOK. */
/* set $ambiance to null, unless already defined */
/*********** Tweak Tool * */
list.tweak-categories separator { background: transparent; }

/*********** Nautilus * */
.nautilus-window { background-image: none; background-color: white; /* .path-bar-box { border-radius: 5px; border: 1px solid if($ambiance, darken($headerbar_bg_color, 9%), $borders_color); &:backdrop { border-color: if($ambiance, $headerbar_bg_color, $backdrop_borders_color);} background-color: if($ambiance, lighten($headerbar_bg_color, 6.5%), $bg_color); padding-right: 6px; &:backdrop { border-color: if($ambiance, darken($inkstone, 9%), $backdrop_borders_color); } } .nautilus-path-bar button { margin: 0px; } .nautilus-path-bar button:first-child { border-width: 0px 1px 0px 0px; border-radius: 3.5px 0px 0px 3.5px; } .nautilus-path-bar button:not(:first-child) { border-width: 0px 1px 0px 1px; border-radius: 0px 0px 0px 0px; } */ /* dim the icon when not checked */ }

.nautilus-window .nautilus-canvas-item.dim-label, .nautilus-window label.nautilus-canvas-item.separator, .nautilus-window .titlebar:not(headerbar) .nautilus-canvas-item.subtitle, .titlebar:not(headerbar) .nautilus-window .nautilus-canvas-item.subtitle, .nautilus-window headerbar .nautilus-canvas-item.subtitle, headerbar .nautilus-window .nautilus-canvas-item.subtitle, .nautilus-window .nautilus-list-dim-label { color: #8d8d8d; }

.nautilus-window:backdrop { background-color: #fcfcfc; }

.nautilus-window placessidebar { background-color: #edeceb; }

.nautilus-window placessidebar:backdrop { background-color: #edeceb; }

.nemo-window .view:backdrop, .nemo-window iconview:backdrop, .nautilus-window *scrolledwindow:backdrop { opacity: 0.9; }

.nautilus-window infobar { background-color: #e6e6e6; }

.nautilus-window infobar:backdrop { background-color: #edeceb; }

.nautilus-window paned box.floating-bar { background-color: #edeceb; border-style: solid; border-color: #b6b3b1; border-width: 1px 0 0 1px; border-radius: 4px 0 0 0; }

.nautilus-window paned box.floating-bar button:dir(ltr).circular.flat.image-button { background: radial-gradient(circle at 50%, white 35%, #edeceb 1%); color: #c7162b; }

.nautilus-window paned box.floating-bar button:dir(ltr).circular.flat.image-button:hover { border: 1px solid #a29e9b; background: radial-gradient(circle at 50%, white 30%, rgba(0, 0, 0, 0.05) 16%); color: #de1930; }

.nautilus-window .searchbar-container searchbar { background: transparent; border-color: transparent; }

.nautilus-window treeview:drop(active):focus { border-bottom: 1px solid #93af66; }

.nautilus-window treeview.view header button { background-color: #ffffff; background-image: none; border-color: rgba(162, 158, 155, 0.4); border-left: 1px; }

.nautilus-window treeview.view header button:hover { background-color: #edeceb; }

.nautilus-window treeview.view header button:backdrop { background-color: #fcfcfc; }

.nautilus-window .nautilus-list-view .view, .nautilus-window .nautilus-list-view iconview { border-bottom: 1px solid rgba(162, 158, 155, 0.2); }

.nautilus-window .nautilus-list-view .view.dnd, .nautilus-window .nautilus-list-view iconview.dnd { border-style: none; }

.nautilus-window .nautilus-list-view .view treeview:selected, .nautilus-window .nautilus-list-view iconview treeview:selected { background-color: #e1dfde; color: #000000; }

.nautilus-window .nautilus-list-view .view treeview:selected:hover, .nautilus-window .nautilus-list-view iconview treeview:selected:hover { background-color: #d5d3d0; }

.nautilus-window .nautilus-list-view .view treeview:selected:backdrop, .nautilus-window .nautilus-list-view iconview treeview:selected:backdrop { color: #2f2f2f; background-color: #e1dfde; }

.nautilus-window notebook > header { background: #edeceb; }

.nautilus-window paned > separator { background-image: image(rgba(162, 158, 155, 0.4)); }

.nautilus-window paned > separator:backdrop { background-image: image(rgba(162, 158, 155, 0.3)); }

.nautilus-window entry.search > * { margin: 5px; }

.nautilus-window .nautilus-path-bar button:not(:checked) image { opacity: 0.8; }

.nautilus-window .nautilus-canvas-item { outline-width: 0; background-color: rgba(255, 255, 255, 0.1); }

.nautilus-window .nautilus-canvas-item:selected:not(:backdrop) { color: #ffffff; }

.nautilus-window .nautilus-canvas-item:selected:not(:backdrop):dir(ltr) { background-color: #89addb; }

.nautilus-window .nautilus-canvas-item:selected:not(:backdrop):not(:dir(ltr)) { background-color: rgba(175, 175, 175, 0.5); }

.nautilus-window .nautilus-canvas-item:backdrop:selected { background-color: #89addb; color: #fcfcfc; }

.disk-space-display { border-style: solid; border-width: 2px; }

.disk-space-display.unknown { background-color: #edeceb; border-color: rgba(237, 236, 235, 0.3); color: #edeceb; }

.disk-space-display.unknown.border { color: rgba(237, 236, 235, 0.3); }

.disk-space-display.used { background-color: #4893f2; border-color: rgba(72, 147, 242, 0.3); color: #4893f2; }

.disk-space-display.used.border { color: rgba(72, 147, 242, 0.3); }

.disk-space-display.free { background-color: #d5d3d0; border-color: rgba(213, 211, 208, 0.3); color: #d5d3d0; }

.disk-space-display.free.border { color: rgba(213, 211, 208, 0.3); }

/************ Terminal * */
terminal-window .terminal-screen { background-color: #300A24; color: white; }

terminal-window .terminal-screen:backdrop { background-color: #380c2a; color: #fcfcfc; }

terminal-window notebook scrollbar { background-color: transparent; border-color: transparent; }

terminal-window notebook scrollbar:backdrop { background-color: transparent; border-color: transparent; }

terminal-window notebook scrollbar slider { margin: 0; border-width: 3px; }

terminal-window notebook scrollbar slider:backdrop { background-color: alpha(currentColor,0.1); }

terminal-window notebook scrollbar slider:disabled { background-color: transparent; }

terminal-window notebook scrollbar.dragging, terminal-window notebook scrollbar.hovering { background-color: transparent; }

/****************** GNOME Software * */
.review-row { margin-bottom: 10px; padding: 6px 12px; box-shadow: 0 1px 2.5px rgba(0, 0, 0, 0.25); outline-offset: -1px; }

.review-row, .review-row:not(:selected):not(:backdrop):hover, .review-row:not(:selected):not(:backdrop):active { background-color: #ffffff; }

.review-row:backdrop { background-color: #fcfcfc; }

.review-row:last-child { margin-bottom: 0; }

.review-row > grid { margin-top: -24px; }

.app-listbox-header { background: #c7c5c3; }

.list-box-app-row { border-radius: 0; border-color: #a29e9b; border-style: none solid solid solid; border-width: 0 1px 1px 1px; margin: -1px 0 0 0; }

.list-box-app-row ~ separator { background-color: #edeceb; border: none; min-height: 0px; }

box > list row.list-box-app-row { border: none; }

.counter-label { margin-top: 2px; margin-bottom: 2px; border-width: 0px; padding-left: 2px; padding-right: 2px; box-shadow: inset 0 0 10px 10px #93af66; }

/********* Gedit * */
.gedit-bottom-panel-paned notebook > header { background: #F7F7F7; }

.gedit-bottom-panel-paned ~ statusbar { border-top: 1px solid #a29e9b; }

.gedit-bottom-panel-paned ~ statusbar:backdrop { border-color: #b1aeab; }

.gedit-search-slider { background: #edeceb; border: 1px solid #a29e9b; border-top-style: none; padding: 4px 8px; border-radius: 0 0 5px 5px; }

.gedit-search-slider:backdrop { background-color: #edeceb; border-color: #b1aeab; }

.gedit-search-entry-occurrences-tag { color: rgba(0, 0, 0, 0.35); border: none; box-shadow: none; margin: 2px; padding: 2px; }

.gedit-document-panel { background-color: #edeceb; }

.gedit-document-panel row.activatable { padding: 6px; }

.gedit-document-panel row button { min-width: 22px; min-height: 22px; padding: 0; margin: 0; border: none; }

.gedit-document-panel row:hover button:hover { background-color: rgba(0, 0, 0, 0.15); }

.gedit-document-panel row:hover button:active { background-color: rgba(0, 0, 0, 0.25); }

.gedit-document-panel row:hover:selected button:hover { color: #ffffff; }

/*************** GNOME Disks * */
headerbar button image ~ window decoration ~ menu separator { background: #a29e9b; }

/******** Nemo * */
.nemo-properties-dialog .dialog-action-box .dialog-action-area { margin: 2px 6px 4px; }

.nemo-properties-dialog toolbar stackswitcher.linked button { margin-right: 0; }

.nemo-properties-dialog toolbar stackswitcher.linked button:backdrop { color: #2f2f2f; background-color: #edeceb; }

.nemo-window .sidebar scrolledwindow.frame.nemo-places-sidebar { border: none; }

.nemo-window .sidebar viewport.frame box.vertical treeview.view.places-treeview { background-image: image(#f6f6f5); border-radius: 0; }

.nemo-window .sidebar viewport.frame box.vertical treeview.view.places-treeview:backdrop { background-image: image(#f5f4f4); }

.nemo-window .sidebar viewport.frame box.vertical treeview.view.places-treeview:selected { background: #89addb; }

.nemo-window .sidebar viewport.frame box.vertical treeview.view.places-treeview:not(:selected):not(:backdrop):hover { background-image: image(rgba(0, 0, 0, 0.05)); }

.nemo-window .nemo-inactive-pane .view, .nemo-window .nemo-inactive-pane iconview, .nemo-window .nemo-inactive-pane iconview { background-color: #edeceb; }

.nemo-window .nemo-window-pane widget.entry { border: 1px solid; border-radius: 3px; color: #000000; border-color: #89addb; background-color: #edeceb; }

.nemo-window .nemo-window-pane widget.entry:selected { border: 1px solid; border-radius: 3px; color: #ffffff; border-color: #89addb; background-color: #89addb; }

.nemo-window toolbar.horizontal.primary-toolbar { border-bottom: 1px solid #a29e9b; }

.nemo-window toolbar.horizontal.primary-toolbar widget.linked.raised button:first-child widget { -gtk-icon-source: -gtk-icontheme("go-previous-symbolic"); }

.nemo-window toolbar.horizontal.primary-toolbar widget.linked.raised button:last-child widget { -gtk-icon-source: -gtk-icontheme("go-next-symbolic"); }

.nemo-window toolbar.horizontal.primary-toolbar toolitem box widget * { min-height: 0; min-width: 0; }

.nemo-window toolbar.horizontal.primary-toolbar .linked button { margin-right: 0; }

.nemo-window toolbar.horizontal.primary-toolbar button { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

.nemo-window toolbar.horizontal.primary-toolbar button:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

.nemo-window toolbar.horizontal.primary-toolbar button:active, .nemo-window toolbar.horizontal.primary-toolbar button:checked { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.nemo-window toolbar.horizontal.primary-toolbar button:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.nemo-window toolbar.horizontal.primary-toolbar button:disabled:active, .nemo-window toolbar.horizontal.primary-toolbar button:disabled:checked { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #e9e7e6, #f1f1f0 3px, #f4f3f2 4px, #efeeed 50%, #ebeae9 50%, #e4e3e1); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.nemo-window toolbar.horizontal.primary-toolbar button:backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.nemo-window toolbar.horizontal.primary-toolbar button:backdrop:active, .nemo-window toolbar.horizontal.primary-toolbar button:backdrop:checked { color: #2f2f2f; border-color: #b1aeab; background-image: image(#dddbd8); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.nemo-window toolbar.horizontal.primary-toolbar button:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.nemo-window toolbar.horizontal.primary-toolbar button:backdrop:disabled:active, .nemo-window toolbar.horizontal.primary-toolbar button:backdrop:disabled:checked { color: #c9c6c3; border-color: #b1aeab; background-image: image(#dddbd8); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

/************* GNOME ToDo * */
.org-gnome-Todo taskrow.activatable.new-task-row button.popup.toggle { border-radius: 0px; border: none; border-left: 1px solid #a29e9b; padding-left: 10px; padding-right: 10px; -gtk-outline-radius: 0px; }

.org-gnome-Todo viewport.view, .org-gnome-Todo listbox.transparent { background-color: #f2f2f2; }

.org-gnome-Todo viewport.view:backdrop, .org-gnome-Todo listbox.transparent:backdrop { background-color: #fcfcfc; }

/*********** Firefox * */
#MozillaGtkWidget.background menu, #MozillaGtkWidget.background .menu, #MozillaGtkWidget.background .context-menu { border-radius: 0; }

#MozillaGtkWidget.background scrollbar { background-color: transparent; border-color: transparent; }

#MozillaGtkWidget.background scrollbar slider { background-color: #454545; }

#MozillaGtkWidget.background scrollbar slider:hover { background-color: #161616; }

#MozillaGtkWidget.background scrollbar slider:hover:active { background-color: #6292d0; }

#MozillaGtkWidget.background scrollbar slider:backdrop { background-color: #a1a0a0; }

#MozillaGtkWidget.background scrollbar slider:disabled { background-color: transparent; }

#MozillaGtkWidget.background scrollbar trough { background-color: rgba(237, 236, 235, 0.2); }

normal-button { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

normal-button:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

normal-button:active { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

normal-button:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

/*********** Ubiquity * */
#live_installer #title_eventbox { background-color: #edeceb; color: #000000; }

#live_installer #title_eventbox:backdrop { background-color: #edeceb; color: #2f2f2f; }

#live_installer #dot_grid progressbar { border-radius: 100%; padding: 1px; padding-top: 2px; background-color: white; border: 1px solid #4893f2; }

#live_installer #dot_grid progressbar .empty { border-radius: 100%; background-color: white; padding: 0px; }

#live_installer #dot_grid progressbar .full progress { border-radius: 100%; padding: 1px; padding-top: 2px; margin-bottom: 2px; }

#dialog-action_area1 { padding-bottom: 5px; padding-right: 5px; }

/*********** Geary * */
.geary-expanded headerbar { border: none; }

/*********** usb-creator-gtk * */
#dialog-action_area3 { margin: 5px; }

/*********** Evolution * */
assistant.background scrolledwindow .vertical checkbutton { margin-left: 1px; }

/*********** Mate * */
/************** Mate-Panel * */
/* the panel bar itself */
#PanelPlug, .mate-panel-menu-bar, PanelToplevel.background { background-color: #edeceb; background-image: none; color: #000000; text-shadow: none; }

#PanelPlug menu, .mate-panel-menu-bar menu, PanelToplevel.background menu { border-radius: 2px; padding: 4px 0px; }

.csd #PanelPlug menu, .csd .mate-panel-menu-bar menu, .csd PanelToplevel.background menu { border: none; border-radius: 2px; }

#PanelPlug menubar { box-shadow: none; }

/* workaround to avoid unwanted black frames behind menus if switching compositor on/off */
.mate-panel-menu-bar .window-frame.csd.popup { box-shadow: none; }

menubar > menuitem menu:dir(rtl), menubar > menuitem menu:dir(ltr), .menubar > menuitem menu:dir(rtl), .menubar > menuitem menu:dir(ltr) { border-radius: 2px; }

menubar .csd.popup decoration, .menubar .csd.popup decoration { border-radius: 2px; }

/* hide buttons */
PanelToplevel > widget > button { border-image: none; background-image: none; background: transparent; border-style: none; border-radius: 0px; padding: 0px; box-shadow: none; color: #000000; }

#PanelApplet { border-radius: 2px; }

PanelWidget > PanelSeparator { border-width: 0; background-color: transparent; color: #a29e9b; }

/* the grid left from wnckpager and wncktasklist */
MatePanelAppletFrameDBus > MatePanelAppletFrameDBus { background-image: none; background-color: transparent; background-repeat: no-repeat; background-position: left; }

/* this makes text readable with all kind of wallpapers if using a transparent panel */
#PanelApplet label, .mate-panel-menu-bar menubar > menuitem { color: #000000; text-shadow: none; }

#PanelApplet label:hover, .mate-panel-menu-bar menubar > menuitem:hover { color: #000000; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); }

/* outlines */
window.background, .mate-panel-menu-bar menubar, .mate-panel-menu-bar button, .mate-panel-menu-bar PanelApplet { outline-style: solid; outline-offset: -2px; outline-color: #a29e9b; }

PanelApplet.wnck-applet .wnck-pager { outline-style: solid; outline-offset: -1px; outline-color: #a29e9b; }

/* main menu */
/* set normal menubar menuitem */
.mate-panel-menu-bar menubar > menuitem { background-image: none; box-shadow: none; }

/* set selected menubar menuitem */
.mate-panel-menu-bar menubar > menuitem:hover { background-color: transparent; background-clip: border-box; background-image: image(#f7f6f6); }

/* set normal menubar menu menuitem */
.mate-panel-menu-bar menubar > menuitem > .popup.csd > menu > menuitem { padding: 4px 5px 4px 5px; border-width: 0px; }

/* set Mate menu menuitem */
.mate-panel-menu-bar menu menuitem { padding: 4px 5px 4px 5px; border-width: 0px; }

/* all applets */
.mate-panel-menu-bar #PanelApplet button.toggle, .mate-panel-menu-bar #PanelApplet button.flat.toggle { background-color: transparent; color: #000000; border-radius: 4px; border-color: #a29e9b; border-right-width: 1px; border-left-width: 1px; border-color: transparent; box-shadow: inset 0px 1px #a29e9b, inset 0px -1px #a29e9b, inset 1px 0px #a29e9b, inset -1px 0px #a29e9b; border-image: none; text-shadow: none; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); }

.mate-panel-menu-bar #PanelApplet button.toggle:hover, .mate-panel-menu-bar #PanelApplet button.toggle:active:hover, .mate-panel-menu-bar #PanelApplet button.toggle:checked:hover, .mate-panel-menu-bar #PanelApplet button.flat.toggle:hover, .mate-panel-menu-bar #PanelApplet button.flat.toggle:active:hover, .mate-panel-menu-bar #PanelApplet button.flat.toggle:checked:hover { background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); border-color: #a4c2e8; }

.mate-panel-menu-bar #PanelApplet button.toggle:checked, .mate-panel-menu-bar #PanelApplet button.flat.toggle:checked { background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); }

/* charpick */
.mate-panel-menu-bar #PanelApplet button.flat.text-button { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); background-color: transparent; color: #000000; border-radius: 4px; border-color: #a29e9b; border-right-width: 1px; border-left-width: 1px; border-color: transparent; box-shadow: inset 0px 1px #a29e9b, inset 0px -1px #a29e9b, inset 1px 0px #a29e9b, inset -1px 0px #a29e9b; padding-left: 2px; padding-right: 2px; }

.mate-panel-menu-bar #PanelApplet button.flat.text-button:checked, .mate-panel-menu-bar #PanelApplet button.flat.text-button:checked:hover, .mate-panel-menu-bar #PanelApplet button.flat.text-button:hover:active { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; background-color: transparent; color: #000000; border-radius: 4px; border-color: #a29e9b; border-right-width: 1px; border-left-width: 1px; border-color: transparent; box-shadow: inset 0px 1px #a29e9b, inset 0px -1px #a29e9b, inset 1px 0px #a29e9b, inset -1px 0px #a29e9b; padding-left: 2px; padding-right: 2px; }

.mate-panel-menu-bar #PanelApplet button.flat.text-button:hover { border-color: #a4c2e8; }

/* clock window */
#MatePanelPopupWindow { border-radius: 4px; }

#PanelApplet > #clock-applet-button.flat.toggle { background-color: transparent; background-image: none; border-color: transparent; border-width: 0px; box-shadow: none; }

#PanelApplet > #clock-applet-button.flat.toggle:hover { box-shadow: inset 0px 1px #a29e9b, inset 0px -1px #a29e9b, inset 1px 0px #a29e9b, inset -1px 0px #a29e9b; background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

#PanelApplet > #clock-applet-button.flat.toggle:checked { box-shadow: inset 0px 1px #a29e9b, inset 0px -1px #a29e9b, inset 1px 0px #a29e9b, inset -1px 0px #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); }

/* volume applet */
.mate-panel-applet-slider, .mate-panel-applet-slider.background { border-radius: 2px; border: 1px solid rgba(0, 0, 0, 0.23); background: transparent; }

.mate-panel-applet-slider frame, .mate-panel-applet-slider.background frame { background-color: #edeceb; border-radius: 2px; padding: 1px; margin: 1px; /* brightness applet */ }

.mate-panel-applet-slider frame border, .mate-panel-applet-slider.background frame border { border-image: none; border-style: none; border-radius: 2px; }

.mate-panel-applet-slider frame frame, .mate-panel-applet-slider.background frame frame { background-color: transparent; padding: 3px; }

.mate-panel-applet-slider frame button, .mate-panel-applet-slider.background frame button { padding: 4px 5px 4px 0px; background-image: none; background-color: transparent; border-style: none; border-image: none; color: #000000; margin: 0px; }

/* mate-indicator-applet */
/* needed for a transparent panel */
#fast-user-switch-applet > #fast-user-switch-menubar { background-color: transparent; }

/* Classic icon style */
.mate-panel-menu-bar { -PanelMenuBar-icon-visible: true; }

/* system-monitor-applet, kill light frame border */
.multiload-applet > box.horizontal > box.vertical > frame > border { border-color: transparent; }

.multiload-applet > box.horizontal > box.vertical > frame { box-shadow: 0 3px 9px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(0, 0, 0, 0.23); }

/***************** Mate-terminal * */
/* override for pavu-control */
window.background.mate-terminal > box.vertical > notebook > header.top, window.background.mate-terminal > box.vertical > notebook > stack > box { border-style: none; border-width: 0px; }

/* vte use hardcoded colors as upstream, ubuntu is patched */
window.background.mate-terminal scrollbar, window.background.mate-terminal scrollbar:backdrop, window.background.mate-terminal scrollbar.vertical, window.background.mate-terminal scrollbar.vertical:backdrop { background-color: transparent; }

/****************** multimedia OSD * */
MsdOsdWindow.background.osd { border-radius: 7px; border: 1px solid rgba(255, 255, 255, 0.15); background-color: rgba(37, 38, 33, 0.8); color: #eeeeec; }

MsdOsdWindow.background.osd .trough { border-radius: 4px; border: none; background: #3e3e37; }

MsdOsdWindow.background.osd .progressbar { border-radius: 4px; background-color: #eeeeec; border: none; }

.background.osd { color: #eeeeec; background-image: none; background-color: rgba(37, 38, 33, 0.8); border-radius: 7px; border: 1px solid rgba(255, 255, 255, 0.15); }

.background.osd :selected { background-color: #89addb; }

/************** Brisk-menu * */
.brisk-menu { /* classic session button */ }

.brisk-menu .apps-list, .brisk-menu .categories-list, .brisk-menu entry { margin: 4px; }

.brisk-menu .apps-list, .brisk-menu .categories-list { border-radius: 2px; }

.brisk-menu .apps-list row:selected, .brisk-menu .categories-list row:selected { background-color: #89addb; color: #ffffff; }

.brisk-menu button.flat.session-button { padding: 5px 6px; min-width: 24px; }

.brisk-menu scrolledwindow { border-width: 1px; border-style: solid; border-color: transparent; margin: 4px; }

.brisk-menu scrollbar { background-image: none; background-color: transparent; border-style: solid; border-color: transparent; }

iconview { border-radius: 4px; }

iconview:hover { background-color: #b0c8e7; }

/* mate-keyboard-layout-view, mate-keyboard-layout-chooser */
/* this way it styles only the border of the keys, the bg of the map itself use the .view class */
matekbd-keyboard-drawing { background-color: #edeceb; }

matekbd-keyboard-drawing:selected { background-color: #89addb; color: #ffffff; }

#xkb-layout-chooser > box.dialog-vbox > box.vertical > box.vertical > frame > border { border-radius: 0px; }

scrollbar { background-image: none; background-color: transparent; }

messagedialog.background:not(.csd) .dialog-action-area button { border-radius: 4px; -gtk-outline-radius: 4px; border: 1px solid #a29e9b; margin: 4px; margin-bottom: 6px; }

messagedialog.background:not(.csd) .dialog-action-area button:first-child { margin-left: 6px; }

messagedialog.background:not(.csd) .dialog-action-area button:last-child { margin-right: 6px; }

/************** Caja * */
window.background.caja-navigation-window #Toolbar:backdrop { background-color: #edeceb; }

.caja-pathbar button { min-width: 24px; border-radius: 0; border-right-width: 0; margin-right: -3px; }

.caja-pathbar button.slider-button:nth-child(odd) { border-radius: 4px 0px 0px 4px; }

.caja-pathbar button.slider-button:nth-child(even) { border-radius: 0 4px 4px 0; border-right-width: 1px; }

.background:not(.csd) headerbar:not(.titlebar) { border-radius: 0; box-shadow: none; }

#slab_section_style2.vertical:dir(ltr) { background-color: #ffffff; }

#slab_section_style2.vertical:dir(ltr), #slab_section_style2.vertical:dir(ltr):dir(ltr), #slab_section_style2.vertical:dir(ltr) label, #slab_section_style2.vertical:dir(ltr) label:dir(ltr) { color: #1a1a1a; }

#slab_section_style2.vertical:dir(ltr):backdrop, #slab_section_style2.vertical:dir(ltr):dir(ltr):backdrop, #slab_section_style2.vertical:dir(ltr) label:backdrop, #slab_section_style2.vertical:dir(ltr) label:dir(ltr):backdrop { color: rgba(26, 26, 26, 0.69); }

window#Main.background #search { background: #ffffff; color: #000000; box-shadow: inset 100px 100px #ffffff; border-bottom: 1px solid #a29e9b; }

window#Main.background #search entry { border-color: #a29e9b; }

window > box.vertical > box.vertical > box.vertical button.text-button { padding-left: 0px; padding-right: 0px; min-width: 2px; margin: 0px; }

MatePanelAppletFrameDBus > MatePanelAppletFrameDBus { background-image: -gtk-scaled(url("assets/panel-grid.svg")); background-color: transparent; color: #8f8f8f; background-repeat: no-repeat; background-position: left; }

/* for firefox and probably other apps */
label:selected, label selection, label selection:focus, label selection:hover { color: #ffffff; }

headerbar *, button * { text-shadow: none; }

spinner:not(:backdrop) { color: #19B6EE; }

button.suggested-action spinner, button.destructive-action spinner { color: #ffffff; }

button.suggested-action spinner:backdrop, button.destructive-action spinner:backdrop { color: #fcfcfc; }

button.titlebutton:not(.appmenu) { min-height: 24px; min-width: 24px; padding: 2px; }

headerbar button.titlebutton:not(.appmenu).maximize, headerbar button.titlebutton:not(.appmenu).minimize, headerbar button.titlebutton:not(.appmenu).close, .titlebar button.titlebutton:not(.appmenu).maximize, .titlebar button.titlebutton:not(.appmenu).minimize, .titlebar button.titlebutton:not(.appmenu).close, headerbar.selection-mode button.titlebutton:not(.appmenu).maximize, headerbar.selection-mode button.titlebutton:not(.appmenu).minimize, headerbar.selection-mode button.titlebutton:not(.appmenu).close, button.titlebutton:not(.appmenu).maximize, button.titlebutton:not(.appmenu).minimize, button.titlebutton:not(.appmenu).close { color: white; -gtk-icon-shadow: 0 -1px black,  0 1px black,  -1px 0px black,  1px 0px black; background-image: linear-gradient(to bottom, #a4c2e8, #96b8e2 50%, #91b4df 50%, #84a9d9); box-shadow: inset 0px 1px rgba(255, 255, 255, 0.1), inset 0px -1px rgba(255, 255, 255, 0.1), inset 1px 0px rgba(255, 255, 255, 0.1), inset -1px 0px rgba(255, 255, 255, 0.1); border-color: #48668a; }

headerbar button.titlebutton:not(.appmenu).maximize:backdrop, headerbar button.titlebutton:not(.appmenu).minimize:backdrop, headerbar button.titlebutton:not(.appmenu).close:backdrop, .titlebar button.titlebutton:not(.appmenu).maximize:backdrop, .titlebar button.titlebutton:not(.appmenu).minimize:backdrop, .titlebar button.titlebutton:not(.appmenu).close:backdrop, headerbar.selection-mode button.titlebutton:not(.appmenu).maximize:backdrop, headerbar.selection-mode button.titlebutton:not(.appmenu).minimize:backdrop, headerbar.selection-mode button.titlebutton:not(.appmenu).close:backdrop, button.titlebutton:not(.appmenu).maximize:backdrop, button.titlebutton:not(.appmenu).minimize:backdrop, button.titlebutton:not(.appmenu).close:backdrop { background-image: none; box-shadow: inset 0px 1px rgba(255, 255, 255, 0.5), inset 0px -1px rgba(255, 255, 255, 0.5), inset 1px 0px rgba(255, 255, 255, 0.5), inset -1px 0px rgba(255, 255, 255, 0.5); border-color: #a29e9b; }

headerbar button.titlebutton:not(.appmenu).maximize:hover, headerbar button.titlebutton:not(.appmenu).maximize:backdrop:hover, headerbar button.titlebutton:not(.appmenu).minimize:hover, headerbar button.titlebutton:not(.appmenu).minimize:backdrop:hover, headerbar button.titlebutton:not(.appmenu).close:hover, headerbar button.titlebutton:not(.appmenu).close:backdrop:hover, .titlebar button.titlebutton:not(.appmenu).maximize:hover, .titlebar button.titlebutton:not(.appmenu).maximize:backdrop:hover, .titlebar button.titlebutton:not(.appmenu).minimize:hover, .titlebar button.titlebutton:not(.appmenu).minimize:backdrop:hover, .titlebar button.titlebutton:not(.appmenu).close:hover, .titlebar button.titlebutton:not(.appmenu).close:backdrop:hover, headerbar.selection-mode button.titlebutton:not(.appmenu).maximize:hover, headerbar.selection-mode button.titlebutton:not(.appmenu).maximize:backdrop:hover, headerbar.selection-mode button.titlebutton:not(.appmenu).minimize:hover, headerbar.selection-mode button.titlebutton:not(.appmenu).minimize:backdrop:hover, headerbar.selection-mode button.titlebutton:not(.appmenu).close:hover, headerbar.selection-mode button.titlebutton:not(.appmenu).close:backdrop:hover, button.titlebutton:not(.appmenu).maximize:hover, button.titlebutton:not(.appmenu).maximize:backdrop:hover, button.titlebutton:not(.appmenu).minimize:hover, button.titlebutton:not(.appmenu).minimize:backdrop:hover, button.titlebutton:not(.appmenu).close:hover, button.titlebutton:not(.appmenu).close:backdrop:hover { background-image: linear-gradient(to bottom, #a4c2e8, #96b8e2); }

headerbar button.titlebutton:not(.appmenu).maximize:active, headerbar button.titlebutton:not(.appmenu).maximize:backdrop:active, headerbar button.titlebutton:not(.appmenu).minimize:active, headerbar button.titlebutton:not(.appmenu).minimize:backdrop:active, headerbar button.titlebutton:not(.appmenu).close:active, headerbar button.titlebutton:not(.appmenu).close:backdrop:active, .titlebar button.titlebutton:not(.appmenu).maximize:active, .titlebar button.titlebutton:not(.appmenu).maximize:backdrop:active, .titlebar button.titlebutton:not(.appmenu).minimize:active, .titlebar button.titlebutton:not(.appmenu).minimize:backdrop:active, .titlebar button.titlebutton:not(.appmenu).close:active, .titlebar button.titlebutton:not(.appmenu).close:backdrop:active, headerbar.selection-mode button.titlebutton:not(.appmenu).maximize:active, headerbar.selection-mode button.titlebutton:not(.appmenu).maximize:backdrop:active, headerbar.selection-mode button.titlebutton:not(.appmenu).minimize:active, headerbar.selection-mode button.titlebutton:not(.appmenu).minimize:backdrop:active, headerbar.selection-mode button.titlebutton:not(.appmenu).close:active, headerbar.selection-mode button.titlebutton:not(.appmenu).close:backdrop:active, button.titlebutton:not(.appmenu).maximize:active, button.titlebutton:not(.appmenu).maximize:backdrop:active, button.titlebutton:not(.appmenu).minimize:active, button.titlebutton:not(.appmenu).minimize:backdrop:active, button.titlebutton:not(.appmenu).close:active, button.titlebutton:not(.appmenu).close:backdrop:active { background-image: linear-gradient(to bottom, #6b9cda, #6799d9); }

headerbar button.titlebutton:not(.appmenu).close, .titlebar button.titlebutton:not(.appmenu).close, headerbar.selection-mode button.titlebutton:not(.appmenu).close, button.titlebutton:not(.appmenu).close { -gtk-icon-shadow: 0 -2px black, 0 2px black, 2px 0px black, -2px 0px black, 0 -1px white, 0 1px white, -1px 0px white, 1px 0px white; }

menu menuitem:hover, .menu menuitem:hover, .context-menu menuitem:hover { color: #ffffff; background-color: #89addb; }

menubar > menuitem:hover, .menubar > menuitem:hover { color: #ffffff; background-color: #89addb; }

.app-notification, .app-notification.frame { padding: 10px; margin: 12px; color: #1a1a1a; border-radius: 2px; background: none; background-color: white; border: 1px solid #a29e9b; box-shadow: 0 2px 5px rgba(0, 0, 0, 0.2); text-shadow: none; }

.app-notification button.text-button, .app-notification button.image-button, .app-notification button, .app-notification button:dir(ltr).text-button, .app-notification button:dir(ltr).image-button, .app-notification button:dir(ltr), .app-notification button:dir(rtl).text-button, .app-notification button:dir(rtl).image-button, .app-notification button:dir(rtl), .app-notification.frame button.text-button, .app-notification.frame button.image-button, .app-notification.frame button, .app-notification.frame button:dir(ltr).text-button, .app-notification.frame button:dir(ltr).image-button, .app-notification.frame button:dir(ltr), .app-notification.frame button:dir(rtl).text-button, .app-notification.frame button:dir(rtl).image-button, .app-notification.frame button:dir(rtl) { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

.app-notification button.text-button.flat, .app-notification button.image-button.flat, .app-notification button.flat, .app-notification button:dir(ltr).text-button.flat, .app-notification button:dir(ltr).image-button.flat, .app-notification button:dir(ltr).flat, .app-notification button:dir(rtl).text-button.flat, .app-notification button:dir(rtl).image-button.flat, .app-notification button:dir(rtl).flat, .app-notification.frame button.text-button.flat, .app-notification.frame button.image-button.flat, .app-notification.frame button.flat, .app-notification.frame button:dir(ltr).text-button.flat, .app-notification.frame button:dir(ltr).image-button.flat, .app-notification.frame button:dir(ltr).flat, .app-notification.frame button:dir(rtl).text-button.flat, .app-notification.frame button:dir(rtl).image-button.flat, .app-notification.frame button:dir(rtl).flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button.text-button:hover, .app-notification button.image-button:hover, .app-notification button:hover, .app-notification button:dir(ltr).text-button:hover, .app-notification button:dir(ltr).image-button:hover, .app-notification button:dir(ltr):hover, .app-notification button:dir(rtl).text-button:hover, .app-notification button:dir(rtl).image-button:hover, .app-notification button:dir(rtl):hover, .app-notification.frame button.text-button:hover, .app-notification.frame button.image-button:hover, .app-notification.frame button:hover, .app-notification.frame button:dir(ltr).text-button:hover, .app-notification.frame button:dir(ltr).image-button:hover, .app-notification.frame button:dir(ltr):hover, .app-notification.frame button:dir(rtl).text-button:hover, .app-notification.frame button:dir(rtl).image-button:hover, .app-notification.frame button:dir(rtl):hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

.app-notification button.text-button:active, .app-notification button.image-button:active, .app-notification button:active, .app-notification button:dir(ltr).text-button:active, .app-notification button:dir(ltr).image-button:active, .app-notification button:dir(ltr):active, .app-notification button:dir(rtl).text-button:active, .app-notification button:dir(rtl).image-button:active, .app-notification button:dir(rtl):active, .app-notification.frame button.text-button:active, .app-notification.frame button.image-button:active, .app-notification.frame button:active, .app-notification.frame button:dir(ltr).text-button:active, .app-notification.frame button:dir(ltr).image-button:active, .app-notification.frame button:dir(ltr):active, .app-notification.frame button:dir(rtl).text-button:active, .app-notification.frame button:dir(rtl).image-button:active, .app-notification.frame button:dir(rtl):active { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button.text-button:backdrop, .app-notification button.image-button:backdrop, .app-notification button:backdrop, .app-notification button:dir(ltr).text-button:backdrop, .app-notification button:dir(ltr).image-button:backdrop, .app-notification button:dir(ltr):backdrop, .app-notification button:dir(rtl).text-button:backdrop, .app-notification button:dir(rtl).image-button:backdrop, .app-notification button:dir(rtl):backdrop, .app-notification.frame button.text-button:backdrop, .app-notification.frame button.image-button:backdrop, .app-notification.frame button:backdrop, .app-notification.frame button:dir(ltr).text-button:backdrop, .app-notification.frame button:dir(ltr).image-button:backdrop, .app-notification.frame button:dir(ltr):backdrop, .app-notification.frame button:dir(rtl).text-button:backdrop, .app-notification.frame button:dir(rtl).image-button:backdrop, .app-notification.frame button:dir(rtl):backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.app-notification button.text-button:backdrop.flat, .app-notification button.image-button:backdrop.flat, .app-notification button:backdrop.flat, .app-notification button:dir(ltr).text-button:backdrop.flat, .app-notification button:dir(ltr).image-button:backdrop.flat, .app-notification button:dir(ltr):backdrop.flat, .app-notification button:dir(rtl).text-button:backdrop.flat, .app-notification button:dir(rtl).image-button:backdrop.flat, .app-notification button:dir(rtl):backdrop.flat, .app-notification.frame button.text-button:backdrop.flat, .app-notification.frame button.image-button:backdrop.flat, .app-notification.frame button:backdrop.flat, .app-notification.frame button:dir(ltr).text-button:backdrop.flat, .app-notification.frame button:dir(ltr).image-button:backdrop.flat, .app-notification.frame button:dir(ltr):backdrop.flat, .app-notification.frame button:dir(rtl).text-button:backdrop.flat, .app-notification.frame button:dir(rtl).image-button:backdrop.flat, .app-notification.frame button:dir(rtl):backdrop.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button.text-button:disabled, .app-notification button.image-button:disabled, .app-notification button:disabled, .app-notification button:dir(ltr).text-button:disabled, .app-notification button:dir(ltr).image-button:disabled, .app-notification button:dir(ltr):disabled, .app-notification button:dir(rtl).text-button:disabled, .app-notification button:dir(rtl).image-button:disabled, .app-notification button:dir(rtl):disabled, .app-notification.frame button.text-button:disabled, .app-notification.frame button.image-button:disabled, .app-notification.frame button:disabled, .app-notification.frame button:dir(ltr).text-button:disabled, .app-notification.frame button:dir(ltr).image-button:disabled, .app-notification.frame button:dir(ltr):disabled, .app-notification.frame button:dir(rtl).text-button:disabled, .app-notification.frame button:dir(rtl).image-button:disabled, .app-notification.frame button:dir(rtl):disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.app-notification:backdrop, .app-notification.frame:backdrop { background-color: #edeceb; color: rgba(26, 26, 26, 0.69); box-shadow: none; transition: 200ms ease-out; }

.app-notification border, .app-notification.frame border { border: none; }

*:not(button) { outline-color: #a29e9b; outline-style: solid; outline-offset: -2px; outline-width: 2px; -gtk-outline-radius: 4px; }

:selected *:not(button) { outline-color: rgba(255, 255, 255, 0.7); }

button { outline-color: #a29e9b; outline-style: solid; outline-offset: -2px; outline-width: 2px; -gtk-outline-radius: 4px; }

button.suggested-action, button.suggested-action:hover, button.suggested-action:active, button.destructive-action, button.destructive-action:hover, button.destructive-action:active { outline-color: rgba(255, 255, 255, 0.7); }

switch slider, switch:hover slider { outline-color: transparent; }

switch:focus { box-shadow: 0 0 0 3px #d3d1d0; }

checkbutton, radiobutton { outline-color: #a29e9b; outline-offset: 1px; outline-width: 2px; }

row:selected checkbutton, treeview:selected checkbutton, row:selected radiobutton, treeview:selected radiobutton { outline-color: rgba(255, 255, 255, 0.7); }

treeview { outline-color: #a29e9b; -gtk-outline-radius: 0px; }

treeview:selected { outline-color: rgba(255, 255, 255, 0.7); }

notebook > header, notebook > header:backdrop { background: transparent; }

notebook > header tabs, notebook > header tabs.right, notebook > header tabs.left, notebook > header tabs.top, notebook > header tabs.bottom, notebook > header tabs:hover, notebook > header tabs:hover.right, notebook > header tabs:hover.left, notebook > header tabs:hover.top, notebook > header tabs:hover.bottom, notebook > header tabs:backdrop, notebook > header tabs:backdrop.right, notebook > header tabs:backdrop.left, notebook > header tabs:backdrop.top, notebook > header tabs:backdrop.bottom { background-color: transparent; }

notebook > header tabs tab, notebook > header tabs.right tab, notebook > header tabs.left tab, notebook > header tabs.top tab, notebook > header tabs.bottom tab, notebook > header tabs:hover tab, notebook > header tabs:hover.right tab, notebook > header tabs:hover.left tab, notebook > header tabs:hover.top tab, notebook > header tabs:hover.bottom tab, notebook > header tabs:backdrop tab, notebook > header tabs:backdrop.right tab, notebook > header tabs:backdrop.left tab, notebook > header tabs:backdrop.top tab, notebook > header tabs:backdrop.bottom tab { outline-width: 1px; outline-offset: -2px; }

notebook > header tabs tab, notebook > header tabs tab:hover, notebook > header tabs tab:active, notebook > header tabs tab:checked, notebook > header tabs tab:checked:hover, notebook > header tabs tab:checked:active, notebook > header tabs tab:backdrop, notebook > header tabs tab:backdrop:hover, notebook > header tabs tab:backdrop:active, notebook > header tabs tab:backdrop:checked, notebook > header tabs tab:backdrop:checked:hover, notebook > header tabs tab:backdrop:checked:active, notebook > header tabs tab:dir(ltr), notebook > header tabs tab:dir(ltr):hover, notebook > header tabs tab:dir(ltr):active, notebook > header tabs tab:dir(ltr):checked, notebook > header tabs tab:dir(ltr):checked:hover, notebook > header tabs tab:dir(ltr):checked:active, notebook > header tabs tab:dir(ltr):backdrop, notebook > header tabs tab:dir(ltr):backdrop:hover, notebook > header tabs tab:dir(ltr):backdrop:active, notebook > header tabs tab:dir(ltr):backdrop:checked, notebook > header tabs tab:dir(ltr):backdrop:checked:hover, notebook > header tabs tab:dir(ltr):backdrop:checked:active, notebook > header tabs tab:dir(rtl), notebook > header tabs tab:dir(rtl):hover, notebook > header tabs tab:dir(rtl):active, notebook > header tabs tab:dir(rtl):checked, notebook > header tabs tab:dir(rtl):checked:hover, notebook > header tabs tab:dir(rtl):checked:active, notebook > header tabs tab:dir(rtl):backdrop, notebook > header tabs tab:dir(rtl):backdrop:hover, notebook > header tabs tab:dir(rtl):backdrop:active, notebook > header tabs tab:dir(rtl):backdrop:checked, notebook > header tabs tab:dir(rtl):backdrop:checked:hover, notebook > header tabs tab:dir(rtl):backdrop:checked:active, notebook > header tabs.right tab, notebook > header tabs.right tab:hover, notebook > header tabs.right tab:active, notebook > header tabs.right tab:checked, notebook > header tabs.right tab:checked:hover, notebook > header tabs.right tab:checked:active, notebook > header tabs.right tab:backdrop, notebook > header tabs.right tab:backdrop:hover, notebook > header tabs.right tab:backdrop:active, notebook > header tabs.right tab:backdrop:checked, notebook > header tabs.right tab:backdrop:checked:hover, notebook > header tabs.right tab:backdrop:checked:active, notebook > header tabs.right tab:dir(ltr), notebook > header tabs.right tab:dir(ltr):hover, notebook > header tabs.right tab:dir(ltr):active, notebook > header tabs.right tab:dir(ltr):checked, notebook > header tabs.right tab:dir(ltr):checked:hover, notebook > header tabs.right tab:dir(ltr):checked:active, notebook > header tabs.right tab:dir(ltr):backdrop, notebook > header tabs.right tab:dir(ltr):backdrop:hover, notebook > header tabs.right tab:dir(ltr):backdrop:active, notebook > header tabs.right tab:dir(ltr):backdrop:checked, notebook > header tabs.right tab:dir(ltr):backdrop:checked:hover, notebook > header tabs.right tab:dir(ltr):backdrop:checked:active, notebook > header tabs.right tab:dir(rtl), notebook > header tabs.right tab:dir(rtl):hover, notebook > header tabs.right tab:dir(rtl):active, notebook > header tabs.right tab:dir(rtl):checked, notebook > header tabs.right tab:dir(rtl):checked:hover, notebook > header tabs.right tab:dir(rtl):checked:active, notebook > header tabs.right tab:dir(rtl):backdrop, notebook > header tabs.right tab:dir(rtl):backdrop:hover, notebook > header tabs.right tab:dir(rtl):backdrop:active, notebook > header tabs.right tab:dir(rtl):backdrop:checked, notebook > header tabs.right tab:dir(rtl):backdrop:checked:hover, notebook > header tabs.right tab:dir(rtl):backdrop:checked:active, notebook > header tabs.left tab, notebook > header tabs.left tab:hover, notebook > header tabs.left tab:active, notebook > header tabs.left tab:checked, notebook > header tabs.left tab:checked:hover, notebook > header tabs.left tab:checked:active, notebook > header tabs.left tab:backdrop, notebook > header tabs.left tab:backdrop:hover, notebook > header tabs.left tab:backdrop:active, notebook > header tabs.left tab:backdrop:checked, notebook > header tabs.left tab:backdrop:checked:hover, notebook > header tabs.left tab:backdrop:checked:active, notebook > header tabs.left tab:dir(ltr), notebook > header tabs.left tab:dir(ltr):hover, notebook > header tabs.left tab:dir(ltr):active, notebook > header tabs.left tab:dir(ltr):checked, notebook > header tabs.left tab:dir(ltr):checked:hover, notebook > header tabs.left tab:dir(ltr):checked:active, notebook > header tabs.left tab:dir(ltr):backdrop, notebook > header tabs.left tab:dir(ltr):backdrop:hover, notebook > header tabs.left tab:dir(ltr):backdrop:active, notebook > header tabs.left tab:dir(ltr):backdrop:checked, notebook > header tabs.left tab:dir(ltr):backdrop:checked:hover, notebook > header tabs.left tab:dir(ltr):backdrop:checked:active, notebook > header tabs.left tab:dir(rtl), notebook > header tabs.left tab:dir(rtl):hover, notebook > header tabs.left tab:dir(rtl):active, notebook > header tabs.left tab:dir(rtl):checked, notebook > header tabs.left tab:dir(rtl):checked:hover, notebook > header tabs.left tab:dir(rtl):checked:active, notebook > header tabs.left tab:dir(rtl):backdrop, notebook > header tabs.left tab:dir(rtl):backdrop:hover, notebook > header tabs.left tab:dir(rtl):backdrop:active, notebook > header tabs.left tab:dir(rtl):backdrop:checked, notebook > header tabs.left tab:dir(rtl):backdrop:checked:hover, notebook > header tabs.left tab:dir(rtl):backdrop:checked:active, notebook > header tabs.top tab, notebook > header tabs.top tab:hover, notebook > header tabs.top tab:active, notebook > header tabs.top tab:checked, notebook > header tabs.top tab:checked:hover, notebook > header tabs.top tab:checked:active, notebook > header tabs.top tab:backdrop, notebook > header tabs.top tab:backdrop:hover, notebook > header tabs.top tab:backdrop:active, notebook > header tabs.top tab:backdrop:checked, notebook > header tabs.top tab:backdrop:checked:hover, notebook > header tabs.top tab:backdrop:checked:active, notebook > header tabs.top tab:dir(ltr), notebook > header tabs.top tab:dir(ltr):hover, notebook > header tabs.top tab:dir(ltr):active, notebook > header tabs.top tab:dir(ltr):checked, notebook > header tabs.top tab:dir(ltr):checked:hover, notebook > header tabs.top tab:dir(ltr):checked:active, notebook > header tabs.top tab:dir(ltr):backdrop, notebook > header tabs.top tab:dir(ltr):backdrop:hover, notebook > header tabs.top tab:dir(ltr):backdrop:active, notebook > header tabs.top tab:dir(ltr):backdrop:checked, notebook > header tabs.top tab:dir(ltr):backdrop:checked:hover, notebook > header tabs.top tab:dir(ltr):backdrop:checked:active, notebook > header tabs.top tab:dir(rtl), notebook > header tabs.top tab:dir(rtl):hover, notebook > header tabs.top tab:dir(rtl):active, notebook > header tabs.top tab:dir(rtl):checked, notebook > header tabs.top tab:dir(rtl):checked:hover, notebook > header tabs.top tab:dir(rtl):checked:active, notebook > header tabs.top tab:dir(rtl):backdrop, notebook > header tabs.top tab:dir(rtl):backdrop:hover, notebook > header tabs.top tab:dir(rtl):backdrop:active, notebook > header tabs.top tab:dir(rtl):backdrop:checked, notebook > header tabs.top tab:dir(rtl):backdrop:checked:hover, notebook > header tabs.top tab:dir(rtl):backdrop:checked:active, notebook > header tabs.bottom tab, notebook > header tabs.bottom tab:hover, notebook > header tabs.bottom tab:active, notebook > header tabs.bottom tab:checked, notebook > header tabs.bottom tab:checked:hover, notebook > header tabs.bottom tab:checked:active, notebook > header tabs.bottom tab:backdrop, notebook > header tabs.bottom tab:backdrop:hover, notebook > header tabs.bottom tab:backdrop:active, notebook > header tabs.bottom tab:backdrop:checked, notebook > header tabs.bottom tab:backdrop:checked:hover, notebook > header tabs.bottom tab:backdrop:checked:active, notebook > header tabs.bottom tab:dir(ltr), notebook > header tabs.bottom tab:dir(ltr):hover, notebook > header tabs.bottom tab:dir(ltr):active, notebook > header tabs.bottom tab:dir(ltr):checked, notebook > header tabs.bottom tab:dir(ltr):checked:hover, notebook > header tabs.bottom tab:dir(ltr):checked:active, notebook > header tabs.bottom tab:dir(ltr):backdrop, notebook > header tabs.bottom tab:dir(ltr):backdrop:hover, notebook > header tabs.bottom tab:dir(ltr):backdrop:active, notebook > header tabs.bottom tab:dir(ltr):backdrop:checked, notebook > header tabs.bottom tab:dir(ltr):backdrop:checked:hover, notebook > header tabs.bottom tab:dir(ltr):backdrop:checked:active, notebook > header tabs.bottom tab:dir(rtl), notebook > header tabs.bottom tab:dir(rtl):hover, notebook > header tabs.bottom tab:dir(rtl):active, notebook > header tabs.bottom tab:dir(rtl):checked, notebook > header tabs.bottom tab:dir(rtl):checked:hover, notebook > header tabs.bottom tab:dir(rtl):checked:active, notebook > header tabs.bottom tab:dir(rtl):backdrop, notebook > header tabs.bottom tab:dir(rtl):backdrop:hover, notebook > header tabs.bottom tab:dir(rtl):backdrop:active, notebook > header tabs.bottom tab:dir(rtl):backdrop:checked, notebook > header tabs.bottom tab:dir(rtl):backdrop:checked:hover, notebook > header tabs.bottom tab:dir(rtl):backdrop:checked:active, notebook > header tabs:hover tab, notebook > header tabs:hover tab:hover, notebook > header tabs:hover tab:active, notebook > header tabs:hover tab:checked, notebook > header tabs:hover tab:checked:hover, notebook > header tabs:hover tab:checked:active, notebook > header tabs:hover tab:backdrop, notebook > header tabs:hover tab:backdrop:hover, notebook > header tabs:hover tab:backdrop:active, notebook > header tabs:hover tab:backdrop:checked, notebook > header tabs:hover tab:backdrop:checked:hover, notebook > header tabs:hover tab:backdrop:checked:active, notebook > header tabs:hover tab:dir(ltr), notebook > header tabs:hover tab:dir(ltr):hover, notebook > header tabs:hover tab:dir(ltr):active, notebook > header tabs:hover tab:dir(ltr):checked, notebook > header tabs:hover tab:dir(ltr):checked:hover, notebook > header tabs:hover tab:dir(ltr):checked:active, notebook > header tabs:hover tab:dir(ltr):backdrop, notebook > header tabs:hover tab:dir(ltr):backdrop:hover, notebook > header tabs:hover tab:dir(ltr):backdrop:active, notebook > header tabs:hover tab:dir(ltr):backdrop:checked, notebook > header tabs:hover tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:hover tab:dir(ltr):backdrop:checked:active, notebook > header tabs:hover tab:dir(rtl), notebook > header tabs:hover tab:dir(rtl):hover, notebook > header tabs:hover tab:dir(rtl):active, notebook > header tabs:hover tab:dir(rtl):checked, notebook > header tabs:hover tab:dir(rtl):checked:hover, notebook > header tabs:hover tab:dir(rtl):checked:active, notebook > header tabs:hover tab:dir(rtl):backdrop, notebook > header tabs:hover tab:dir(rtl):backdrop:hover, notebook > header tabs:hover tab:dir(rtl):backdrop:active, notebook > header tabs:hover tab:dir(rtl):backdrop:checked, notebook > header tabs:hover tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:hover tab:dir(rtl):backdrop:checked:active, notebook > header tabs:hover.right tab, notebook > header tabs:hover.right tab:hover, notebook > header tabs:hover.right tab:active, notebook > header tabs:hover.right tab:checked, notebook > header tabs:hover.right tab:checked:hover, notebook > header tabs:hover.right tab:checked:active, notebook > header tabs:hover.right tab:backdrop, notebook > header tabs:hover.right tab:backdrop:hover, notebook > header tabs:hover.right tab:backdrop:active, notebook > header tabs:hover.right tab:backdrop:checked, notebook > header tabs:hover.right tab:backdrop:checked:hover, notebook > header tabs:hover.right tab:backdrop:checked:active, notebook > header tabs:hover.right tab:dir(ltr), notebook > header tabs:hover.right tab:dir(ltr):hover, notebook > header tabs:hover.right tab:dir(ltr):active, notebook > header tabs:hover.right tab:dir(ltr):checked, notebook > header tabs:hover.right tab:dir(ltr):checked:hover, notebook > header tabs:hover.right tab:dir(ltr):checked:active, notebook > header tabs:hover.right tab:dir(ltr):backdrop, notebook > header tabs:hover.right tab:dir(ltr):backdrop:hover, notebook > header tabs:hover.right tab:dir(ltr):backdrop:active, notebook > header tabs:hover.right tab:dir(ltr):backdrop:checked, notebook > header tabs:hover.right tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:hover.right tab:dir(ltr):backdrop:checked:active, notebook > header tabs:hover.right tab:dir(rtl), notebook > header tabs:hover.right tab:dir(rtl):hover, notebook > header tabs:hover.right tab:dir(rtl):active, notebook > header tabs:hover.right tab:dir(rtl):checked, notebook > header tabs:hover.right tab:dir(rtl):checked:hover, notebook > header tabs:hover.right tab:dir(rtl):checked:active, notebook > header tabs:hover.right tab:dir(rtl):backdrop, notebook > header tabs:hover.right tab:dir(rtl):backdrop:hover, notebook > header tabs:hover.right tab:dir(rtl):backdrop:active, notebook > header tabs:hover.right tab:dir(rtl):backdrop:checked, notebook > header tabs:hover.right tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:hover.right tab:dir(rtl):backdrop:checked:active, notebook > header tabs:hover.left tab, notebook > header tabs:hover.left tab:hover, notebook > header tabs:hover.left tab:active, notebook > header tabs:hover.left tab:checked, notebook > header tabs:hover.left tab:checked:hover, notebook > header tabs:hover.left tab:checked:active, notebook > header tabs:hover.left tab:backdrop, notebook > header tabs:hover.left tab:backdrop:hover, notebook > header tabs:hover.left tab:backdrop:active, notebook > header tabs:hover.left tab:backdrop:checked, notebook > header tabs:hover.left tab:backdrop:checked:hover, notebook > header tabs:hover.left tab:backdrop:checked:active, notebook > header tabs:hover.left tab:dir(ltr), notebook > header tabs:hover.left tab:dir(ltr):hover, notebook > header tabs:hover.left tab:dir(ltr):active, notebook > header tabs:hover.left tab:dir(ltr):checked, notebook > header tabs:hover.left tab:dir(ltr):checked:hover, notebook > header tabs:hover.left tab:dir(ltr):checked:active, notebook > header tabs:hover.left tab:dir(ltr):backdrop, notebook > header tabs:hover.left tab:dir(ltr):backdrop:hover, notebook > header tabs:hover.left tab:dir(ltr):backdrop:active, notebook > header tabs:hover.left tab:dir(ltr):backdrop:checked, notebook > header tabs:hover.left tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:hover.left tab:dir(ltr):backdrop:checked:active, notebook > header tabs:hover.left tab:dir(rtl), notebook > header tabs:hover.left tab:dir(rtl):hover, notebook > header tabs:hover.left tab:dir(rtl):active, notebook > header tabs:hover.left tab:dir(rtl):checked, notebook > header tabs:hover.left tab:dir(rtl):checked:hover, notebook > header tabs:hover.left tab:dir(rtl):checked:active, notebook > header tabs:hover.left tab:dir(rtl):backdrop, notebook > header tabs:hover.left tab:dir(rtl):backdrop:hover, notebook > header tabs:hover.left tab:dir(rtl):backdrop:active, notebook > header tabs:hover.left tab:dir(rtl):backdrop:checked, notebook > header tabs:hover.left tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:hover.left tab:dir(rtl):backdrop:checked:active, notebook > header tabs:hover.top tab, notebook > header tabs:hover.top tab:hover, notebook > header tabs:hover.top tab:active, notebook > header tabs:hover.top tab:checked, notebook > header tabs:hover.top tab:checked:hover, notebook > header tabs:hover.top tab:checked:active, notebook > header tabs:hover.top tab:backdrop, notebook > header tabs:hover.top tab:backdrop:hover, notebook > header tabs:hover.top tab:backdrop:active, notebook > header tabs:hover.top tab:backdrop:checked, notebook > header tabs:hover.top tab:backdrop:checked:hover, notebook > header tabs:hover.top tab:backdrop:checked:active, notebook > header tabs:hover.top tab:dir(ltr), notebook > header tabs:hover.top tab:dir(ltr):hover, notebook > header tabs:hover.top tab:dir(ltr):active, notebook > header tabs:hover.top tab:dir(ltr):checked, notebook > header tabs:hover.top tab:dir(ltr):checked:hover, notebook > header tabs:hover.top tab:dir(ltr):checked:active, notebook > header tabs:hover.top tab:dir(ltr):backdrop, notebook > header tabs:hover.top tab:dir(ltr):backdrop:hover, notebook > header tabs:hover.top tab:dir(ltr):backdrop:active, notebook > header tabs:hover.top tab:dir(ltr):backdrop:checked, notebook > header tabs:hover.top tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:hover.top tab:dir(ltr):backdrop:checked:active, notebook > header tabs:hover.top tab:dir(rtl), notebook > header tabs:hover.top tab:dir(rtl):hover, notebook > header tabs:hover.top tab:dir(rtl):active, notebook > header tabs:hover.top tab:dir(rtl):checked, notebook > header tabs:hover.top tab:dir(rtl):checked:hover, notebook > header tabs:hover.top tab:dir(rtl):checked:active, notebook > header tabs:hover.top tab:dir(rtl):backdrop, notebook > header tabs:hover.top tab:dir(rtl):backdrop:hover, notebook > header tabs:hover.top tab:dir(rtl):backdrop:active, notebook > header tabs:hover.top tab:dir(rtl):backdrop:checked, notebook > header tabs:hover.top tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:hover.top tab:dir(rtl):backdrop:checked:active, notebook > header tabs:hover.bottom tab, notebook > header tabs:hover.bottom tab:hover, notebook > header tabs:hover.bottom tab:active, notebook > header tabs:hover.bottom tab:checked, notebook > header tabs:hover.bottom tab:checked:hover, notebook > header tabs:hover.bottom tab:checked:active, notebook > header tabs:hover.bottom tab:backdrop, notebook > header tabs:hover.bottom tab:backdrop:hover, notebook > header tabs:hover.bottom tab:backdrop:active, notebook > header tabs:hover.bottom tab:backdrop:checked, notebook > header tabs:hover.bottom tab:backdrop:checked:hover, notebook > header tabs:hover.bottom tab:backdrop:checked:active, notebook > header tabs:hover.bottom tab:dir(ltr), notebook > header tabs:hover.bottom tab:dir(ltr):hover, notebook > header tabs:hover.bottom tab:dir(ltr):active, notebook > header tabs:hover.bottom tab:dir(ltr):checked, notebook > header tabs:hover.bottom tab:dir(ltr):checked:hover, notebook > header tabs:hover.bottom tab:dir(ltr):checked:active, notebook > header tabs:hover.bottom tab:dir(ltr):backdrop, notebook > header tabs:hover.bottom tab:dir(ltr):backdrop:hover, notebook > header tabs:hover.bottom tab:dir(ltr):backdrop:active, notebook > header tabs:hover.bottom tab:dir(ltr):backdrop:checked, notebook > header tabs:hover.bottom tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:hover.bottom tab:dir(ltr):backdrop:checked:active, notebook > header tabs:hover.bottom tab:dir(rtl), notebook > header tabs:hover.bottom tab:dir(rtl):hover, notebook > header tabs:hover.bottom tab:dir(rtl):active, notebook > header tabs:hover.bottom tab:dir(rtl):checked, notebook > header tabs:hover.bottom tab:dir(rtl):checked:hover, notebook > header tabs:hover.bottom tab:dir(rtl):checked:active, notebook > header tabs:hover.bottom tab:dir(rtl):backdrop, notebook > header tabs:hover.bottom tab:dir(rtl):backdrop:hover, notebook > header tabs:hover.bottom tab:dir(rtl):backdrop:active, notebook > header tabs:hover.bottom tab:dir(rtl):backdrop:checked, notebook > header tabs:hover.bottom tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:hover.bottom tab:dir(rtl):backdrop:checked:active, notebook > header tabs:backdrop tab, notebook > header tabs:backdrop tab:hover, notebook > header tabs:backdrop tab:active, notebook > header tabs:backdrop tab:checked, notebook > header tabs:backdrop tab:checked:hover, notebook > header tabs:backdrop tab:checked:active, notebook > header tabs:backdrop tab:backdrop, notebook > header tabs:backdrop tab:backdrop:hover, notebook > header tabs:backdrop tab:backdrop:active, notebook > header tabs:backdrop tab:backdrop:checked, notebook > header tabs:backdrop tab:backdrop:checked:hover, notebook > header tabs:backdrop tab:backdrop:checked:active, notebook > header tabs:backdrop tab:dir(ltr), notebook > header tabs:backdrop tab:dir(ltr):hover, notebook > header tabs:backdrop tab:dir(ltr):active, notebook > header tabs:backdrop tab:dir(ltr):checked, notebook > header tabs:backdrop tab:dir(ltr):checked:hover, notebook > header tabs:backdrop tab:dir(ltr):checked:active, notebook > header tabs:backdrop tab:dir(ltr):backdrop, notebook > header tabs:backdrop tab:dir(ltr):backdrop:hover, notebook > header tabs:backdrop tab:dir(ltr):backdrop:active, notebook > header tabs:backdrop tab:dir(ltr):backdrop:checked, notebook > header tabs:backdrop tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:backdrop tab:dir(ltr):backdrop:checked:active, notebook > header tabs:backdrop tab:dir(rtl), notebook > header tabs:backdrop tab:dir(rtl):hover, notebook > header tabs:backdrop tab:dir(rtl):active, notebook > header tabs:backdrop tab:dir(rtl):checked, notebook > header tabs:backdrop tab:dir(rtl):checked:hover, notebook > header tabs:backdrop tab:dir(rtl):checked:active, notebook > header tabs:backdrop tab:dir(rtl):backdrop, notebook > header tabs:backdrop tab:dir(rtl):backdrop:hover, notebook > header tabs:backdrop tab:dir(rtl):backdrop:active, notebook > header tabs:backdrop tab:dir(rtl):backdrop:checked, notebook > header tabs:backdrop tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:backdrop tab:dir(rtl):backdrop:checked:active, notebook > header tabs:backdrop.right tab, notebook > header tabs:backdrop.right tab:hover, notebook > header tabs:backdrop.right tab:active, notebook > header tabs:backdrop.right tab:checked, notebook > header tabs:backdrop.right tab:checked:hover, notebook > header tabs:backdrop.right tab:checked:active, notebook > header tabs:backdrop.right tab:backdrop, notebook > header tabs:backdrop.right tab:backdrop:hover, notebook > header tabs:backdrop.right tab:backdrop:active, notebook > header tabs:backdrop.right tab:backdrop:checked, notebook > header tabs:backdrop.right tab:backdrop:checked:hover, notebook > header tabs:backdrop.right tab:backdrop:checked:active, notebook > header tabs:backdrop.right tab:dir(ltr), notebook > header tabs:backdrop.right tab:dir(ltr):hover, notebook > header tabs:backdrop.right tab:dir(ltr):active, notebook > header tabs:backdrop.right tab:dir(ltr):checked, notebook > header tabs:backdrop.right tab:dir(ltr):checked:hover, notebook > header tabs:backdrop.right tab:dir(ltr):checked:active, notebook > header tabs:backdrop.right tab:dir(ltr):backdrop, notebook > header tabs:backdrop.right tab:dir(ltr):backdrop:hover, notebook > header tabs:backdrop.right tab:dir(ltr):backdrop:active, notebook > header tabs:backdrop.right tab:dir(ltr):backdrop:checked, notebook > header tabs:backdrop.right tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:backdrop.right tab:dir(ltr):backdrop:checked:active, notebook > header tabs:backdrop.right tab:dir(rtl), notebook > header tabs:backdrop.right tab:dir(rtl):hover, notebook > header tabs:backdrop.right tab:dir(rtl):active, notebook > header tabs:backdrop.right tab:dir(rtl):checked, notebook > header tabs:backdrop.right tab:dir(rtl):checked:hover, notebook > header tabs:backdrop.right tab:dir(rtl):checked:active, notebook > header tabs:backdrop.right tab:dir(rtl):backdrop, notebook > header tabs:backdrop.right tab:dir(rtl):backdrop:hover, notebook > header tabs:backdrop.right tab:dir(rtl):backdrop:active, notebook > header tabs:backdrop.right tab:dir(rtl):backdrop:checked, notebook > header tabs:backdrop.right tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:backdrop.right tab:dir(rtl):backdrop:checked:active, notebook > header tabs:backdrop.left tab, notebook > header tabs:backdrop.left tab:hover, notebook > header tabs:backdrop.left tab:active, notebook > header tabs:backdrop.left tab:checked, notebook > header tabs:backdrop.left tab:checked:hover, notebook > header tabs:backdrop.left tab:checked:active, notebook > header tabs:backdrop.left tab:backdrop, notebook > header tabs:backdrop.left tab:backdrop:hover, notebook > header tabs:backdrop.left tab:backdrop:active, notebook > header tabs:backdrop.left tab:backdrop:checked, notebook > header tabs:backdrop.left tab:backdrop:checked:hover, notebook > header tabs:backdrop.left tab:backdrop:checked:active, notebook > header tabs:backdrop.left tab:dir(ltr), notebook > header tabs:backdrop.left tab:dir(ltr):hover, notebook > header tabs:backdrop.left tab:dir(ltr):active, notebook > header tabs:backdrop.left tab:dir(ltr):checked, notebook > header tabs:backdrop.left tab:dir(ltr):checked:hover, notebook > header tabs:backdrop.left tab:dir(ltr):checked:active, notebook > header tabs:backdrop.left tab:dir(ltr):backdrop, notebook > header tabs:backdrop.left tab:dir(ltr):backdrop:hover, notebook > header tabs:backdrop.left tab:dir(ltr):backdrop:active, notebook > header tabs:backdrop.left tab:dir(ltr):backdrop:checked, notebook > header tabs:backdrop.left tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:backdrop.left tab:dir(ltr):backdrop:checked:active, notebook > header tabs:backdrop.left tab:dir(rtl), notebook > header tabs:backdrop.left tab:dir(rtl):hover, notebook > header tabs:backdrop.left tab:dir(rtl):active, notebook > header tabs:backdrop.left tab:dir(rtl):checked, notebook > header tabs:backdrop.left tab:dir(rtl):checked:hover, notebook > header tabs:backdrop.left tab:dir(rtl):checked:active, notebook > header tabs:backdrop.left tab:dir(rtl):backdrop, notebook > header tabs:backdrop.left tab:dir(rtl):backdrop:hover, notebook > header tabs:backdrop.left tab:dir(rtl):backdrop:active, notebook > header tabs:backdrop.left tab:dir(rtl):backdrop:checked, notebook > header tabs:backdrop.left tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:backdrop.left tab:dir(rtl):backdrop:checked:active, notebook > header tabs:backdrop.top tab, notebook > header tabs:backdrop.top tab:hover, notebook > header tabs:backdrop.top tab:active, notebook > header tabs:backdrop.top tab:checked, notebook > header tabs:backdrop.top tab:checked:hover, notebook > header tabs:backdrop.top tab:checked:active, notebook > header tabs:backdrop.top tab:backdrop, notebook > header tabs:backdrop.top tab:backdrop:hover, notebook > header tabs:backdrop.top tab:backdrop:active, notebook > header tabs:backdrop.top tab:backdrop:checked, notebook > header tabs:backdrop.top tab:backdrop:checked:hover, notebook > header tabs:backdrop.top tab:backdrop:checked:active, notebook > header tabs:backdrop.top tab:dir(ltr), notebook > header tabs:backdrop.top tab:dir(ltr):hover, notebook > header tabs:backdrop.top tab:dir(ltr):active, notebook > header tabs:backdrop.top tab:dir(ltr):checked, notebook > header tabs:backdrop.top tab:dir(ltr):checked:hover, notebook > header tabs:backdrop.top tab:dir(ltr):checked:active, notebook > header tabs:backdrop.top tab:dir(ltr):backdrop, notebook > header tabs:backdrop.top tab:dir(ltr):backdrop:hover, notebook > header tabs:backdrop.top tab:dir(ltr):backdrop:active, notebook > header tabs:backdrop.top tab:dir(ltr):backdrop:checked, notebook > header tabs:backdrop.top tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:backdrop.top tab:dir(ltr):backdrop:checked:active, notebook > header tabs:backdrop.top tab:dir(rtl), notebook > header tabs:backdrop.top tab:dir(rtl):hover, notebook > header tabs:backdrop.top tab:dir(rtl):active, notebook > header tabs:backdrop.top tab:dir(rtl):checked, notebook > header tabs:backdrop.top tab:dir(rtl):checked:hover, notebook > header tabs:backdrop.top tab:dir(rtl):checked:active, notebook > header tabs:backdrop.top tab:dir(rtl):backdrop, notebook > header tabs:backdrop.top tab:dir(rtl):backdrop:hover, notebook > header tabs:backdrop.top tab:dir(rtl):backdrop:active, notebook > header tabs:backdrop.top tab:dir(rtl):backdrop:checked, notebook > header tabs:backdrop.top tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:backdrop.top tab:dir(rtl):backdrop:checked:active, notebook > header tabs:backdrop.bottom tab, notebook > header tabs:backdrop.bottom tab:hover, notebook > header tabs:backdrop.bottom tab:active, notebook > header tabs:backdrop.bottom tab:checked, notebook > header tabs:backdrop.bottom tab:checked:hover, notebook > header tabs:backdrop.bottom tab:checked:active, notebook > header tabs:backdrop.bottom tab:backdrop, notebook > header tabs:backdrop.bottom tab:backdrop:hover, notebook > header tabs:backdrop.bottom tab:backdrop:active, notebook > header tabs:backdrop.bottom tab:backdrop:checked, notebook > header tabs:backdrop.bottom tab:backdrop:checked:hover, notebook > header tabs:backdrop.bottom tab:backdrop:checked:active, notebook > header tabs:backdrop.bottom tab:dir(ltr), notebook > header tabs:backdrop.bottom tab:dir(ltr):hover, notebook > header tabs:backdrop.bottom tab:dir(ltr):active, notebook > header tabs:backdrop.bottom tab:dir(ltr):checked, notebook > header tabs:backdrop.bottom tab:dir(ltr):checked:hover, notebook > header tabs:backdrop.bottom tab:dir(ltr):checked:active, notebook > header tabs:backdrop.bottom tab:dir(ltr):backdrop, notebook > header tabs:backdrop.bottom tab:dir(ltr):backdrop:hover, notebook > header tabs:backdrop.bottom tab:dir(ltr):backdrop:active, notebook > header tabs:backdrop.bottom tab:dir(ltr):backdrop:checked, notebook > header tabs:backdrop.bottom tab:dir(ltr):backdrop:checked:hover, notebook > header tabs:backdrop.bottom tab:dir(ltr):backdrop:checked:active, notebook > header tabs:backdrop.bottom tab:dir(rtl), notebook > header tabs:backdrop.bottom tab:dir(rtl):hover, notebook > header tabs:backdrop.bottom tab:dir(rtl):active, notebook > header tabs:backdrop.bottom tab:dir(rtl):checked, notebook > header tabs:backdrop.bottom tab:dir(rtl):checked:hover, notebook > header tabs:backdrop.bottom tab:dir(rtl):checked:active, notebook > header tabs:backdrop.bottom tab:dir(rtl):backdrop, notebook > header tabs:backdrop.bottom tab:dir(rtl):backdrop:hover, notebook > header tabs:backdrop.bottom tab:dir(rtl):backdrop:active, notebook > header tabs:backdrop.bottom tab:dir(rtl):backdrop:checked, notebook > header tabs:backdrop.bottom tab:dir(rtl):backdrop:checked:hover, notebook > header tabs:backdrop.bottom tab:dir(rtl):backdrop:checked:active { background-color: transparent; border-color: transparent; }

scrolledwindow undershoot.top { background-color: transparent; padding-top: 1px; background-size: 10px 1px; background-repeat: repeat-x; background-origin: content-box; background-position: center top; border: none; box-shadow: inset 0 2px 0 0 rgba(204, 204, 204, 0.2), inset 0 1px 0 0 rgba(153, 153, 153, 0.2); }

scrolledwindow undershoot.bottom { background-color: transparent; padding-bottom: 1px; background-size: 10px 1px; background-repeat: repeat-x; background-origin: content-box; background-position: center bottom; border: none; box-shadow: inset 0 -2px 0 0 rgba(204, 204, 204, 0.2), inset 0 -1px 0 0 rgba(153, 153, 153, 0.2); }

scrolledwindow undershoot.left { background-color: transparent; padding-left: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: left center; border: none; box-shadow: inset 2px 0 0 rgba(204, 204, 204, 0.2), inset 1px 0 0 rgba(153, 153, 153, 0.2); }

scrolledwindow undershoot.right { background-color: transparent; padding-right: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: right center; border: none; box-shadow: inset -2px 0 0 rgba(204, 204, 204, 0.2), inset -1px 0 0 rgba(153, 153, 153, 0.2); }

menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem check:checked, menu menuitem check:checked:hover, menu menuitem check:checked:disabled, menu menuitem check:indeterminate, menu menuitem check:indeterminate:hover, menu menuitem check:indeterminate:disabled, menu menuitem radio, menu menuitem radio:hover, menu menuitem radio:disabled, menu menuitem radio:checked, menu menuitem radio:checked:hover, menu menuitem radio:checked:disabled, menu menuitem radio:indeterminate, menu menuitem radio:indeterminate:hover, menu menuitem radio:indeterminate:disabled { border-color: transparent; }

treeview.view check:selected:focus:disabled, treeview.view check:selected:disabled, treeview.view radio:selected:focus:disabled, treeview.view radio:selected:disabled { color: #a9a5a2; }

.sidebar { background-color: #edeceb; }

treeview:hover { background: #89addb; }

.osd scale slider { color: #eeeeec; border-color: rgba(0, 0, 0, 0.7); background-color: transparent; background-image: image(rgba(61, 63, 54, 0.8)); background-clip: padding-box; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 236, 0.3); background-image: image(#e9e9e7); }

.osd scale slider:hover { background-image: image(#d6d6d1); }

.osd scale slider:active { background-image: image(#b2b2a9); }

.rubberband, rubberband, flowbox rubberband, treeview.view rubberband, .content-view rubberband, .content-view .rubberband { background-color: rgba(135, 135, 135, 0.2); border: 1px solid rgba(204, 204, 204, 0.8); }

button.color { min-height: 5px; }

levelbar block.high, levelbar block:not(.empty) { border-color: #5e733c; background-color: #93af66; }

levelbar block.high:backdrop, levelbar block:not(.empty):backdrop { border-color: #93af66; }

.csd.popup decoration { box-shadow: 0 1px 2px 1px rgba(0, 0, 0, 0.3), 0 0 0 1px rgba(0, 0, 0, 0.23); }

.csd popover.background, popover.background { border-color: rgba(0, 0, 0, 0.23); }

.csd popover.background:backdrop, popover.background:backdrop { border-color: #b1aeab; }

switch:backdrop:checked:not(:disabled), switch:backdrop:checked:not(:disabled) slider { border-color: #a29e9b; }

list row:selected.activatable, list row:selected.activatable:hover, list row:selected, list row:selected:hover, placessidebar row:selected.activatable, placessidebar row:selected.activatable:hover, placessidebar row:selected, placessidebar row:selected:hover, sidebar row:selected.activatable, sidebar row:selected.activatable:hover, sidebar row:selected, sidebar row:selected:hover, .sidebar row:selected.activatable, .sidebar row:selected.activatable:hover, .sidebar row:selected, .sidebar row:selected:hover { color: #ffffff; background-color: #e1dfde; box-shadow: inset 4px 0 0 #89addb; }

list row:selected.activatable, list row:selected.activatable image, list row:selected.activatable button, list row:selected.activatable button image, list row:selected.activatable:hover, list row:selected.activatable:hover image, list row:selected.activatable:hover button, list row:selected.activatable:hover button image, list row:selected, list row:selected image, list row:selected button, list row:selected button image, list row:selected:hover, list row:selected:hover image, list row:selected:hover button, list row:selected:hover button image, placessidebar row:selected.activatable, placessidebar row:selected.activatable image, placessidebar row:selected.activatable button, placessidebar row:selected.activatable button image, placessidebar row:selected.activatable:hover, placessidebar row:selected.activatable:hover image, placessidebar row:selected.activatable:hover button, placessidebar row:selected.activatable:hover button image, placessidebar row:selected, placessidebar row:selected image, placessidebar row:selected button, placessidebar row:selected button image, placessidebar row:selected:hover, placessidebar row:selected:hover image, placessidebar row:selected:hover button, placessidebar row:selected:hover button image, sidebar row:selected.activatable, sidebar row:selected.activatable image, sidebar row:selected.activatable button, sidebar row:selected.activatable button image, sidebar row:selected.activatable:hover, sidebar row:selected.activatable:hover image, sidebar row:selected.activatable:hover button, sidebar row:selected.activatable:hover button image, sidebar row:selected, sidebar row:selected image, sidebar row:selected button, sidebar row:selected button image, sidebar row:selected:hover, sidebar row:selected:hover image, sidebar row:selected:hover button, sidebar row:selected:hover button image, .sidebar row:selected.activatable, .sidebar row:selected.activatable image, .sidebar row:selected.activatable button, .sidebar row:selected.activatable button image, .sidebar row:selected.activatable:hover, .sidebar row:selected.activatable:hover image, .sidebar row:selected.activatable:hover button, .sidebar row:selected.activatable:hover button image, .sidebar row:selected, .sidebar row:selected image, .sidebar row:selected button, .sidebar row:selected button image, .sidebar row:selected:hover, .sidebar row:selected:hover image, .sidebar row:selected:hover button, .sidebar row:selected:hover button image { color: #1a1a1a; }

list row:selected.activatable:backdrop, list row:selected.activatable:hover:backdrop, list row:selected:backdrop, list row:selected:hover:backdrop, placessidebar row:selected.activatable:backdrop, placessidebar row:selected.activatable:hover:backdrop, placessidebar row:selected:backdrop, placessidebar row:selected:hover:backdrop, sidebar row:selected.activatable:backdrop, sidebar row:selected.activatable:hover:backdrop, sidebar row:selected:backdrop, sidebar row:selected:hover:backdrop, .sidebar row:selected.activatable:backdrop, .sidebar row:selected.activatable:hover:backdrop, .sidebar row:selected:backdrop, .sidebar row:selected:hover:backdrop { background-color: #e1dfde; }

list row:selected.activatable:backdrop, list row:selected.activatable:backdrop image, list row:selected.activatable:backdrop button, list row:selected.activatable:backdrop button image, list row:selected.activatable:hover:backdrop, list row:selected.activatable:hover:backdrop image, list row:selected.activatable:hover:backdrop button, list row:selected.activatable:hover:backdrop button image, list row:selected:backdrop, list row:selected:backdrop image, list row:selected:backdrop button, list row:selected:backdrop button image, list row:selected:hover:backdrop, list row:selected:hover:backdrop image, list row:selected:hover:backdrop button, list row:selected:hover:backdrop button image, placessidebar row:selected.activatable:backdrop, placessidebar row:selected.activatable:backdrop image, placessidebar row:selected.activatable:backdrop button, placessidebar row:selected.activatable:backdrop button image, placessidebar row:selected.activatable:hover:backdrop, placessidebar row:selected.activatable:hover:backdrop image, placessidebar row:selected.activatable:hover:backdrop button, placessidebar row:selected.activatable:hover:backdrop button image, placessidebar row:selected:backdrop, placessidebar row:selected:backdrop image, placessidebar row:selected:backdrop button, placessidebar row:selected:backdrop button image, placessidebar row:selected:hover:backdrop, placessidebar row:selected:hover:backdrop image, placessidebar row:selected:hover:backdrop button, placessidebar row:selected:hover:backdrop button image, sidebar row:selected.activatable:backdrop, sidebar row:selected.activatable:backdrop image, sidebar row:selected.activatable:backdrop button, sidebar row:selected.activatable:backdrop button image, sidebar row:selected.activatable:hover:backdrop, sidebar row:selected.activatable:hover:backdrop image, sidebar row:selected.activatable:hover:backdrop button, sidebar row:selected.activatable:hover:backdrop button image, sidebar row:selected:backdrop, sidebar row:selected:backdrop image, sidebar row:selected:backdrop button, sidebar row:selected:backdrop button image, sidebar row:selected:hover:backdrop, sidebar row:selected:hover:backdrop image, sidebar row:selected:hover:backdrop button, sidebar row:selected:hover:backdrop button image, .sidebar row:selected.activatable:backdrop, .sidebar row:selected.activatable:backdrop image, .sidebar row:selected.activatable:backdrop button, .sidebar row:selected.activatable:backdrop button image, .sidebar row:selected.activatable:hover:backdrop, .sidebar row:selected.activatable:hover:backdrop image, .sidebar row:selected.activatable:hover:backdrop button, .sidebar row:selected.activatable:hover:backdrop button image, .sidebar row:selected:backdrop, .sidebar row:selected:backdrop image, .sidebar row:selected:backdrop button, .sidebar row:selected:backdrop button image, .sidebar row:selected:hover:backdrop, .sidebar row:selected:hover:backdrop image, .sidebar row:selected:hover:backdrop button, .sidebar row:selected:hover:backdrop button image { color: #2f2f2f; }

check:checked, radio:checked { border-color: #a29e9b; color: #000000; }

check:selected, radio:selected { color: #000000; }

XfdesktopIconView.view { background-color: transparent; }

XfdesktopIconView.view.label { color: white; text-shadow: 1px 1px 2px black; }

XfdesktopIconView.view:active { color: white; background-color: rgba(137, 173, 219, 0.5); }

XfdesktopIconView.view.label:active { color: white; text-shadow: 1px 1px 2px black; }

headerbar, .titlebar { background-image: linear-gradient(to bottom, #9cbce5, #8eb1de 50%, #89addb 50%, #7ba2d4); color: #000000; border-color: #a29e9b; }

headerbar:backdrop, .titlebar:backdrop { background-image: linear-gradient(to bottom, #ebeae9, #e2e0df 50%, #dddbda 50%, #d4d2d0); }

headerbar .title, headerbar label.title, .titlebar .title, .titlebar label.title { color: #ffffff; text-shadow: 0 1px #455d7c,0 -1px #455d7c, -1px 0px #455d7c,  1px 0px #455d7c; }

headerbar .title:backdrop, headerbar label.title:backdrop, .titlebar .title:backdrop, .titlebar label.title:backdrop { color: #7c7874; text-shadow: none; }

.maximized headerbar, .fullscreen headerbar, .maximized .titlebar, .fullscreen .titlebar { box-shadow: none; }

headerbar entry, headerbar entry:backdrop, .titlebar entry, .titlebar entry:backdrop { border-color: #1d1c1c; }

headerbar entry:focus, .titlebar entry:focus { box-shadow: inset 0px 1px #e1ecfa, inset 1px 0px #e1ecfa, inset -1px 0px #e1ecfa, inset 0px -1px #e1ecfa; border-color: #456081; }

headerbar separator, .titlebar separator { background: image(#282626); }

headerbar separator:backdrop, .titlebar separator:backdrop { background: image(#262626); }

headerbar switch, .titlebar switch { border-color: #1b1a1a; color: #000000; background-color: #464343; }

headerbar switch:hover, .titlebar switch:hover { background-color: #4b4848; }

headerbar switch:backdrop, .titlebar switch:backdrop { background-color: #444141; }

headerbar switch:backdrop, headerbar switch:backdrop:checked, .titlebar switch:backdrop, .titlebar switch:backdrop:checked { border-color: #1c1c1c; }

headerbar switch:backdrop:disabled, .titlebar switch:backdrop:disabled { background-color: #3f3c3c; border-color: #262626; }

headerbar switch:disabled, .titlebar switch:disabled { background-color: #323030; border-color: #1b1a1a; }

headerbar switch:checked, .titlebar switch:checked { color: #ffffff; border-color: #1b1a1a; background-color: #538bd3; }

headerbar switch slider:checked, headerbar scale slider:checked, .titlebar switch slider:checked, .titlebar scale slider:checked { border-color: #a29e9b; }

headerbar switch slider:backdrop, headerbar switch slider:backdrop:checked, headerbar switch slider:backdrop:disabled, headerbar switch slider:backdrop:checked:disabled, headerbar scale slider:backdrop, headerbar scale slider:backdrop:checked, headerbar scale slider:backdrop:disabled, headerbar scale slider:backdrop:checked:disabled, .titlebar switch slider:backdrop, .titlebar switch slider:backdrop:checked, .titlebar switch slider:backdrop:disabled, .titlebar switch slider:backdrop:checked:disabled, .titlebar scale slider:backdrop, .titlebar scale slider:backdrop:checked, .titlebar scale slider:backdrop:disabled, .titlebar scale slider:backdrop:checked:disabled { border-color: #1c1c1c; box-shadow: none; }

headerbar switch slider:not(:checked), headerbar scale slider:not(:checked), .titlebar switch slider:not(:checked), .titlebar scale slider:not(:checked) { border-color: #1b1a1a; }

headerbar switch slider:disabled, headerbar scale slider:disabled, .titlebar switch slider:disabled, .titlebar scale slider:disabled { color: #a9a5a2; border-color: #030303; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode headerbar, headerbar.selection-mode, .selection-mode .titlebar, .titlebar.selection-mode { color: #ffffff; border-color: #87a556; background-image: linear-gradient(to bottom, #9cbce5, #8eb1de 50%, #89addb 50%, #7ba2d4); }

.selection-mode headerbar:backdrop, headerbar.selection-mode:backdrop, .selection-mode .titlebar:backdrop, .titlebar.selection-mode:backdrop { background-image: linear-gradient(to bottom, #ebeae9, #e2e0df 50%, #dddbda 50%, #d4d2d0); }

.selection-mode headerbar separator, headerbar.selection-mode separator, .selection-mode .titlebar separator, .titlebar.selection-mode separator { background: image(#9fb876); }

.selection-mode headerbar:backdrop, headerbar.selection-mode:backdrop, .selection-mode .titlebar:backdrop, .titlebar.selection-mode:backdrop { background-color: #93af66; background-image: none; box-shadow: inset 0 1px rgba(201, 215, 178, 0.88); }

.selection-mode headerbar:backdrop label, headerbar.selection-mode:backdrop label, .selection-mode .titlebar:backdrop label, .titlebar.selection-mode:backdrop label { text-shadow: none; color: #ffffff; }

.selection-mode headerbar button, .selection-mode headerbar button.image-button, .selection-mode headerbar button.image-button.toggle, .selection-mode headerbar button.text.button, .selection-mode headerbar button.toggle, .selection-mode headerbar box button.toggle, .selection-mode headerbar buttonbox.toggle, .selection-mode headerbar stackswitcher button, .selection-mode headerbar filechooser .path-bar.linked > button, .selection-mode headerbar .path-bar button, headerbar.selection-mode button, headerbar.selection-mode button.image-button, headerbar.selection-mode button.image-button.toggle, headerbar.selection-mode button.text.button, headerbar.selection-mode button.toggle, headerbar.selection-mode box button.toggle, headerbar.selection-mode buttonbox.toggle, headerbar.selection-mode stackswitcher button, headerbar.selection-mode filechooser .path-bar.linked > button, headerbar.selection-mode .path-bar button, .selection-mode .titlebar button, .selection-mode .titlebar button.image-button, .selection-mode .titlebar button.image-button.toggle, .selection-mode .titlebar button.text.button, .selection-mode .titlebar button.toggle, .selection-mode .titlebar box button.toggle, .selection-mode .titlebar buttonbox.toggle, .selection-mode .titlebar stackswitcher button, .selection-mode .titlebar filechooser .path-bar.linked > button, .selection-mode .titlebar .path-bar button, .titlebar.selection-mode button, .titlebar.selection-mode button.image-button, .titlebar.selection-mode button.image-button.toggle, .titlebar.selection-mode button.text.button, .titlebar.selection-mode button.toggle, .titlebar.selection-mode box button.toggle, .titlebar.selection-mode buttonbox.toggle, .titlebar.selection-mode stackswitcher button, .titlebar.selection-mode filechooser .path-bar.linked > button, .titlebar.selection-mode .path-bar button { color: #ffffff; outline-color: #a29e9b; border-color: #79944d; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 -1px rgba(0, 0, 0, 0.566275); -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.566275); box-shadow: 0 1px rgba(0, 0, 0, 0.05); }

.selection-mode headerbar button.flat, .selection-mode headerbar button.image-button.flat, .selection-mode headerbar button.image-button.toggle.flat, .selection-mode headerbar button.text.button.flat, .selection-mode headerbar button.toggle.flat, .selection-mode headerbar box button.toggle.flat, .selection-mode headerbar buttonbox.toggle.flat, .selection-mode headerbar stackswitcher button.flat, .selection-mode headerbar filechooser .path-bar.linked > button.flat, .selection-mode headerbar .path-bar button.flat, headerbar.selection-mode button.flat, headerbar.selection-mode button.image-button.flat, headerbar.selection-mode button.image-button.toggle.flat, headerbar.selection-mode button.text.button.flat, headerbar.selection-mode button.toggle.flat, headerbar.selection-mode box button.toggle.flat, headerbar.selection-mode buttonbox.toggle.flat, headerbar.selection-mode stackswitcher button.flat, headerbar.selection-mode filechooser .path-bar.linked > button.flat, headerbar.selection-mode .path-bar button.flat, .selection-mode .titlebar button.flat, .selection-mode .titlebar button.image-button.flat, .selection-mode .titlebar button.image-button.toggle.flat, .selection-mode .titlebar button.text.button.flat, .selection-mode .titlebar button.toggle.flat, .selection-mode .titlebar box button.toggle.flat, .selection-mode .titlebar buttonbox.toggle.flat, .selection-mode .titlebar stackswitcher button.flat, .selection-mode .titlebar filechooser .path-bar.linked > button.flat, .selection-mode .titlebar .path-bar button.flat, .titlebar.selection-mode button.flat, .titlebar.selection-mode button.image-button.flat, .titlebar.selection-mode button.image-button.toggle.flat, .titlebar.selection-mode button.text.button.flat, .titlebar.selection-mode button.toggle.flat, .titlebar.selection-mode box button.toggle.flat, .titlebar.selection-mode buttonbox.toggle.flat, .titlebar.selection-mode stackswitcher button.flat, .titlebar.selection-mode filechooser .path-bar.linked > button.flat, .titlebar.selection-mode .path-bar button.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode headerbar button:hover, .selection-mode headerbar button.image-button:hover, .selection-mode headerbar button.image-button.toggle:hover, .selection-mode headerbar button.text.button:hover, .selection-mode headerbar button.toggle:hover, .selection-mode headerbar box button.toggle:hover, .selection-mode headerbar buttonbox.toggle:hover, .selection-mode headerbar stackswitcher button:hover, .selection-mode headerbar filechooser .path-bar.linked > button:hover, .selection-mode headerbar .path-bar button:hover, headerbar.selection-mode button:hover, headerbar.selection-mode button.image-button:hover, headerbar.selection-mode button.image-button.toggle:hover, headerbar.selection-mode button.text.button:hover, headerbar.selection-mode button.toggle:hover, headerbar.selection-mode box button.toggle:hover, headerbar.selection-mode buttonbox.toggle:hover, headerbar.selection-mode stackswitcher button:hover, headerbar.selection-mode filechooser .path-bar.linked > button:hover, headerbar.selection-mode .path-bar button:hover, .selection-mode .titlebar button:hover, .selection-mode .titlebar button.image-button:hover, .selection-mode .titlebar button.image-button.toggle:hover, .selection-mode .titlebar button.text.button:hover, .selection-mode .titlebar button.toggle:hover, .selection-mode .titlebar box button.toggle:hover, .selection-mode .titlebar buttonbox.toggle:hover, .selection-mode .titlebar stackswitcher button:hover, .selection-mode .titlebar filechooser .path-bar.linked > button:hover, .selection-mode .titlebar .path-bar button:hover, .titlebar.selection-mode button:hover, .titlebar.selection-mode button.image-button:hover, .titlebar.selection-mode button.image-button.toggle:hover, .titlebar.selection-mode button.text.button:hover, .titlebar.selection-mode button.toggle:hover, .titlebar.selection-mode box button.toggle:hover, .titlebar.selection-mode buttonbox.toggle:hover, .titlebar.selection-mode stackswitcher button:hover, .titlebar.selection-mode filechooser .path-bar.linked > button:hover, .titlebar.selection-mode .path-bar button:hover { color: #ffffff; outline-color: #a29e9b; border-color: #79944d; border-bottom-color: #5e733c; text-shadow: 0 -1px rgba(0, 0, 0, 0.518275); -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.518275); box-shadow: inset 0 1px rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); }

.selection-mode headerbar button:active, .selection-mode headerbar button:checked, .selection-mode headerbar button.toggle:checked, .selection-mode headerbar button.toggle:active, .selection-mode headerbar button.image-button:active, .selection-mode headerbar button.image-button:checked, .selection-mode headerbar button.image-button.toggle:checked, .selection-mode headerbar button.image-button.toggle:active, .selection-mode headerbar button.image-button.toggle:active, .selection-mode headerbar button.image-button.toggle:checked, .selection-mode headerbar button.image-button.toggle.toggle:checked, .selection-mode headerbar button.image-button.toggle.toggle:active, .selection-mode headerbar button.text.button:active, .selection-mode headerbar button.text.button:checked, .selection-mode headerbar button.text.button.toggle:checked, .selection-mode headerbar button.text.button.toggle:active, .selection-mode headerbar button.toggle:active, .selection-mode headerbar button.toggle:checked, .selection-mode headerbar button.toggle.toggle:checked, .selection-mode headerbar button.toggle.toggle:active, .selection-mode headerbar box button.toggle:active, .selection-mode headerbar box button.toggle:checked, .selection-mode headerbar box button.toggle.toggle:checked, .selection-mode headerbar box button.toggle.toggle:active, .selection-mode headerbar buttonbox.toggle:active, .selection-mode headerbar buttonbox.toggle:checked, .selection-mode headerbar buttonbox.toggle.toggle:checked, .selection-mode headerbar buttonbox.toggle.toggle:active, .selection-mode headerbar stackswitcher button:active, .selection-mode headerbar stackswitcher button:checked, .selection-mode headerbar stackswitcher button.toggle:checked, .selection-mode headerbar stackswitcher button.toggle:active, .selection-mode headerbar filechooser .path-bar.linked > button:active, .selection-mode headerbar filechooser .path-bar.linked > button:checked, .selection-mode headerbar filechooser .path-bar.linked > button.toggle:checked, .selection-mode headerbar filechooser .path-bar.linked > button.toggle:active, .selection-mode headerbar .path-bar button:active, .selection-mode headerbar .path-bar button:checked, .selection-mode headerbar .path-bar button.toggle:checked, .selection-mode headerbar .path-bar button.toggle:active, headerbar.selection-mode button:active, headerbar.selection-mode button:checked, headerbar.selection-mode button.toggle:checked, headerbar.selection-mode button.toggle:active, headerbar.selection-mode button.image-button:active, headerbar.selection-mode button.image-button:checked, headerbar.selection-mode button.image-button.toggle:checked, headerbar.selection-mode button.image-button.toggle:active, headerbar.selection-mode button.image-button.toggle:active, headerbar.selection-mode button.image-button.toggle:checked, headerbar.selection-mode button.image-button.toggle.toggle:checked, headerbar.selection-mode button.image-button.toggle.toggle:active, headerbar.selection-mode button.text.button:active, headerbar.selection-mode button.text.button:checked, headerbar.selection-mode button.text.button.toggle:checked, headerbar.selection-mode button.text.button.toggle:active, headerbar.selection-mode button.toggle:active, headerbar.selection-mode button.toggle:checked, headerbar.selection-mode button.toggle.toggle:checked, headerbar.selection-mode button.toggle.toggle:active, headerbar.selection-mode box button.toggle:active, headerbar.selection-mode box button.toggle:checked, headerbar.selection-mode box button.toggle.toggle:checked, headerbar.selection-mode box button.toggle.toggle:active, headerbar.selection-mode buttonbox.toggle:active, headerbar.selection-mode buttonbox.toggle:checked, headerbar.selection-mode buttonbox.toggle.toggle:checked, headerbar.selection-mode buttonbox.toggle.toggle:active, headerbar.selection-mode stackswitcher button:active, headerbar.selection-mode stackswitcher button:checked, headerbar.selection-mode stackswitcher button.toggle:checked, headerbar.selection-mode stackswitcher button.toggle:active, headerbar.selection-mode filechooser .path-bar.linked > button:active, headerbar.selection-mode filechooser .path-bar.linked > button:checked, headerbar.selection-mode filechooser .path-bar.linked > button.toggle:checked, headerbar.selection-mode filechooser .path-bar.linked > button.toggle:active, headerbar.selection-mode .path-bar button:active, headerbar.selection-mode .path-bar button:checked, headerbar.selection-mode .path-bar button.toggle:checked, headerbar.selection-mode .path-bar button.toggle:active, .selection-mode .titlebar button:active, .selection-mode .titlebar button:checked, .selection-mode .titlebar button.toggle:checked, .selection-mode .titlebar button.toggle:active, .selection-mode .titlebar button.image-button:active, .selection-mode .titlebar button.image-button:checked, .selection-mode .titlebar button.image-button.toggle:checked, .selection-mode .titlebar button.image-button.toggle:active, .selection-mode .titlebar button.image-button.toggle:active, .selection-mode .titlebar button.image-button.toggle:checked, .selection-mode .titlebar button.image-button.toggle.toggle:checked, .selection-mode .titlebar button.image-button.toggle.toggle:active, .selection-mode .titlebar button.text.button:active, .selection-mode .titlebar button.text.button:checked, .selection-mode .titlebar button.text.button.toggle:checked, .selection-mode .titlebar button.text.button.toggle:active, .selection-mode .titlebar button.toggle:active, .selection-mode .titlebar button.toggle:checked, .selection-mode .titlebar button.toggle.toggle:checked, .selection-mode .titlebar button.toggle.toggle:active, .selection-mode .titlebar box button.toggle:active, .selection-mode .titlebar box button.toggle:checked, .selection-mode .titlebar box button.toggle.toggle:checked, .selection-mode .titlebar box button.toggle.toggle:active, .selection-mode .titlebar buttonbox.toggle:active, .selection-mode .titlebar buttonbox.toggle:checked, .selection-mode .titlebar buttonbox.toggle.toggle:checked, .selection-mode .titlebar buttonbox.toggle.toggle:active, .selection-mode .titlebar stackswitcher button:active, .selection-mode .titlebar stackswitcher button:checked, .selection-mode .titlebar stackswitcher button.toggle:checked, .selection-mode .titlebar stackswitcher button.toggle:active, .selection-mode .titlebar filechooser .path-bar.linked > button:active, .selection-mode .titlebar filechooser .path-bar.linked > button:checked, .selection-mode .titlebar filechooser .path-bar.linked > button.toggle:checked, .selection-mode .titlebar filechooser .path-bar.linked > button.toggle:active, .selection-mode .titlebar .path-bar button:active, .selection-mode .titlebar .path-bar button:checked, .selection-mode .titlebar .path-bar button.toggle:checked, .selection-mode .titlebar .path-bar button.toggle:active, .titlebar.selection-mode button:active, .titlebar.selection-mode button:checked, .titlebar.selection-mode button.toggle:checked, .titlebar.selection-mode button.toggle:active, .titlebar.selection-mode button.image-button:active, .titlebar.selection-mode button.image-button:checked, .titlebar.selection-mode button.image-button.toggle:checked, .titlebar.selection-mode button.image-button.toggle:active, .titlebar.selection-mode button.image-button.toggle:active, .titlebar.selection-mode button.image-button.toggle:checked, .titlebar.selection-mode button.image-button.toggle.toggle:checked, .titlebar.selection-mode button.image-button.toggle.toggle:active, .titlebar.selection-mode button.text.button:active, .titlebar.selection-mode button.text.button:checked, .titlebar.selection-mode button.text.button.toggle:checked, .titlebar.selection-mode button.text.button.toggle:active, .titlebar.selection-mode button.toggle:active, .titlebar.selection-mode button.toggle:checked, .titlebar.selection-mode button.toggle.toggle:checked, .titlebar.selection-mode button.toggle.toggle:active, .titlebar.selection-mode box button.toggle:active, .titlebar.selection-mode box button.toggle:checked, .titlebar.selection-mode box button.toggle.toggle:checked, .titlebar.selection-mode box button.toggle.toggle:active, .titlebar.selection-mode buttonbox.toggle:active, .titlebar.selection-mode buttonbox.toggle:checked, .titlebar.selection-mode buttonbox.toggle.toggle:checked, .titlebar.selection-mode buttonbox.toggle.toggle:active, .titlebar.selection-mode stackswitcher button:active, .titlebar.selection-mode stackswitcher button:checked, .titlebar.selection-mode stackswitcher button.toggle:checked, .titlebar.selection-mode stackswitcher button.toggle:active, .titlebar.selection-mode filechooser .path-bar.linked > button:active, .titlebar.selection-mode filechooser .path-bar.linked > button:checked, .titlebar.selection-mode filechooser .path-bar.linked > button.toggle:checked, .titlebar.selection-mode filechooser .path-bar.linked > button.toggle:active, .titlebar.selection-mode .path-bar button:active, .titlebar.selection-mode .path-bar button:checked, .titlebar.selection-mode .path-bar button.toggle:checked, .titlebar.selection-mode .path-bar button.toggle:active { color: #ffffff; outline-color: #a29e9b; border-color: #79944d; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode headerbar button:backdrop.flat, .selection-mode headerbar button:backdrop, .selection-mode headerbar button.image-button:backdrop.flat, .selection-mode headerbar button.image-button:backdrop, .selection-mode headerbar button.image-button.toggle:backdrop.flat, .selection-mode headerbar button.image-button.toggle:backdrop, .selection-mode headerbar button.text.button:backdrop.flat, .selection-mode headerbar button.text.button:backdrop, .selection-mode headerbar button.toggle:backdrop.flat, .selection-mode headerbar button.toggle:backdrop, .selection-mode headerbar box button.toggle:backdrop.flat, .selection-mode headerbar box button.toggle:backdrop, .selection-mode headerbar buttonbox.toggle:backdrop.flat, .selection-mode headerbar buttonbox.toggle:backdrop, .selection-mode headerbar stackswitcher button:backdrop.flat, .selection-mode headerbar stackswitcher button:backdrop, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop.flat, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop, .selection-mode headerbar .path-bar button:backdrop.flat, .selection-mode headerbar .path-bar button:backdrop, headerbar.selection-mode button:backdrop.flat, headerbar.selection-mode button:backdrop, headerbar.selection-mode button.image-button:backdrop.flat, headerbar.selection-mode button.image-button:backdrop, headerbar.selection-mode button.image-button.toggle:backdrop.flat, headerbar.selection-mode button.image-button.toggle:backdrop, headerbar.selection-mode button.text.button:backdrop.flat, headerbar.selection-mode button.text.button:backdrop, headerbar.selection-mode button.toggle:backdrop.flat, headerbar.selection-mode button.toggle:backdrop, headerbar.selection-mode box button.toggle:backdrop.flat, headerbar.selection-mode box button.toggle:backdrop, headerbar.selection-mode buttonbox.toggle:backdrop.flat, headerbar.selection-mode buttonbox.toggle:backdrop, headerbar.selection-mode stackswitcher button:backdrop.flat, headerbar.selection-mode stackswitcher button:backdrop, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop.flat, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop, headerbar.selection-mode .path-bar button:backdrop.flat, headerbar.selection-mode .path-bar button:backdrop, .selection-mode .titlebar button:backdrop.flat, .selection-mode .titlebar button:backdrop, .selection-mode .titlebar button.image-button:backdrop.flat, .selection-mode .titlebar button.image-button:backdrop, .selection-mode .titlebar button.image-button.toggle:backdrop.flat, .selection-mode .titlebar button.image-button.toggle:backdrop, .selection-mode .titlebar button.text.button:backdrop.flat, .selection-mode .titlebar button.text.button:backdrop, .selection-mode .titlebar button.toggle:backdrop.flat, .selection-mode .titlebar button.toggle:backdrop, .selection-mode .titlebar box button.toggle:backdrop.flat, .selection-mode .titlebar box button.toggle:backdrop, .selection-mode .titlebar buttonbox.toggle:backdrop.flat, .selection-mode .titlebar buttonbox.toggle:backdrop, .selection-mode .titlebar stackswitcher button:backdrop.flat, .selection-mode .titlebar stackswitcher button:backdrop, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop.flat, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop, .selection-mode .titlebar .path-bar button:backdrop.flat, .selection-mode .titlebar .path-bar button:backdrop, .titlebar.selection-mode button:backdrop.flat, .titlebar.selection-mode button:backdrop, .titlebar.selection-mode button.image-button:backdrop.flat, .titlebar.selection-mode button.image-button:backdrop, .titlebar.selection-mode button.image-button.toggle:backdrop.flat, .titlebar.selection-mode button.image-button.toggle:backdrop, .titlebar.selection-mode button.text.button:backdrop.flat, .titlebar.selection-mode button.text.button:backdrop, .titlebar.selection-mode button.toggle:backdrop.flat, .titlebar.selection-mode button.toggle:backdrop, .titlebar.selection-mode box button.toggle:backdrop.flat, .titlebar.selection-mode box button.toggle:backdrop, .titlebar.selection-mode buttonbox.toggle:backdrop.flat, .titlebar.selection-mode buttonbox.toggle:backdrop, .titlebar.selection-mode stackswitcher button:backdrop.flat, .titlebar.selection-mode stackswitcher button:backdrop, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop.flat, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop, .titlebar.selection-mode .path-bar button:backdrop.flat, .titlebar.selection-mode .path-bar button:backdrop { color: #e9efe0; border-color: #93af66; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #9fb876; }

.selection-mode headerbar button:backdrop.flat:active, .selection-mode headerbar button:backdrop.flat:checked, .selection-mode headerbar button:backdrop:active, .selection-mode headerbar button:backdrop:checked, .selection-mode headerbar button.image-button:backdrop.flat:active, .selection-mode headerbar button.image-button:backdrop.flat:checked, .selection-mode headerbar button.image-button:backdrop:active, .selection-mode headerbar button.image-button:backdrop:checked, .selection-mode headerbar button.image-button.toggle:backdrop.flat:active, .selection-mode headerbar button.image-button.toggle:backdrop.flat:checked, .selection-mode headerbar button.image-button.toggle:backdrop:active, .selection-mode headerbar button.image-button.toggle:backdrop:checked, .selection-mode headerbar button.text.button:backdrop.flat:active, .selection-mode headerbar button.text.button:backdrop.flat:checked, .selection-mode headerbar button.text.button:backdrop:active, .selection-mode headerbar button.text.button:backdrop:checked, .selection-mode headerbar button.toggle:backdrop.flat:active, .selection-mode headerbar button.toggle:backdrop.flat:checked, .selection-mode headerbar button.toggle:backdrop:active, .selection-mode headerbar button.toggle:backdrop:checked, .selection-mode headerbar box button.toggle:backdrop.flat:active, .selection-mode headerbar box button.toggle:backdrop.flat:checked, .selection-mode headerbar box button.toggle:backdrop:active, .selection-mode headerbar box button.toggle:backdrop:checked, .selection-mode headerbar buttonbox.toggle:backdrop.flat:active, .selection-mode headerbar buttonbox.toggle:backdrop.flat:checked, .selection-mode headerbar buttonbox.toggle:backdrop:active, .selection-mode headerbar buttonbox.toggle:backdrop:checked, .selection-mode headerbar stackswitcher button:backdrop.flat:active, .selection-mode headerbar stackswitcher button:backdrop.flat:checked, .selection-mode headerbar stackswitcher button:backdrop:active, .selection-mode headerbar stackswitcher button:backdrop:checked, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop.flat:active, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop.flat:checked, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop:active, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop:checked, .selection-mode headerbar .path-bar button:backdrop.flat:active, .selection-mode headerbar .path-bar button:backdrop.flat:checked, .selection-mode headerbar .path-bar button:backdrop:active, .selection-mode headerbar .path-bar button:backdrop:checked, headerbar.selection-mode button:backdrop.flat:active, headerbar.selection-mode button:backdrop.flat:checked, headerbar.selection-mode button:backdrop:active, headerbar.selection-mode button:backdrop:checked, headerbar.selection-mode button.image-button:backdrop.flat:active, headerbar.selection-mode button.image-button:backdrop.flat:checked, headerbar.selection-mode button.image-button:backdrop:active, headerbar.selection-mode button.image-button:backdrop:checked, headerbar.selection-mode button.image-button.toggle:backdrop.flat:active, headerbar.selection-mode button.image-button.toggle:backdrop.flat:checked, headerbar.selection-mode button.image-button.toggle:backdrop:active, headerbar.selection-mode button.image-button.toggle:backdrop:checked, headerbar.selection-mode button.text.button:backdrop.flat:active, headerbar.selection-mode button.text.button:backdrop.flat:checked, headerbar.selection-mode button.text.button:backdrop:active, headerbar.selection-mode button.text.button:backdrop:checked, headerbar.selection-mode button.toggle:backdrop.flat:active, headerbar.selection-mode button.toggle:backdrop.flat:checked, headerbar.selection-mode button.toggle:backdrop:active, headerbar.selection-mode button.toggle:backdrop:checked, headerbar.selection-mode box button.toggle:backdrop.flat:active, headerbar.selection-mode box button.toggle:backdrop.flat:checked, headerbar.selection-mode box button.toggle:backdrop:active, headerbar.selection-mode box button.toggle:backdrop:checked, headerbar.selection-mode buttonbox.toggle:backdrop.flat:active, headerbar.selection-mode buttonbox.toggle:backdrop.flat:checked, headerbar.selection-mode buttonbox.toggle:backdrop:active, headerbar.selection-mode buttonbox.toggle:backdrop:checked, headerbar.selection-mode stackswitcher button:backdrop.flat:active, headerbar.selection-mode stackswitcher button:backdrop.flat:checked, headerbar.selection-mode stackswitcher button:backdrop:active, headerbar.selection-mode stackswitcher button:backdrop:checked, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:active, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:checked, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop:active, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop:checked, headerbar.selection-mode .path-bar button:backdrop.flat:active, headerbar.selection-mode .path-bar button:backdrop.flat:checked, headerbar.selection-mode .path-bar button:backdrop:active, headerbar.selection-mode .path-bar button:backdrop:checked, .selection-mode .titlebar button:backdrop.flat:active, .selection-mode .titlebar button:backdrop.flat:checked, .selection-mode .titlebar button:backdrop:active, .selection-mode .titlebar button:backdrop:checked, .selection-mode .titlebar button.image-button:backdrop.flat:active, .selection-mode .titlebar button.image-button:backdrop.flat:checked, .selection-mode .titlebar button.image-button:backdrop:active, .selection-mode .titlebar button.image-button:backdrop:checked, .selection-mode .titlebar button.image-button.toggle:backdrop.flat:active, .selection-mode .titlebar button.image-button.toggle:backdrop.flat:checked, .selection-mode .titlebar button.image-button.toggle:backdrop:active, .selection-mode .titlebar button.image-button.toggle:backdrop:checked, .selection-mode .titlebar button.text.button:backdrop.flat:active, .selection-mode .titlebar button.text.button:backdrop.flat:checked, .selection-mode .titlebar button.text.button:backdrop:active, .selection-mode .titlebar button.text.button:backdrop:checked, .selection-mode .titlebar button.toggle:backdrop.flat:active, .selection-mode .titlebar button.toggle:backdrop.flat:checked, .selection-mode .titlebar button.toggle:backdrop:active, .selection-mode .titlebar button.toggle:backdrop:checked, .selection-mode .titlebar box button.toggle:backdrop.flat:active, .selection-mode .titlebar box button.toggle:backdrop.flat:checked, .selection-mode .titlebar box button.toggle:backdrop:active, .selection-mode .titlebar box button.toggle:backdrop:checked, .selection-mode .titlebar buttonbox.toggle:backdrop.flat:active, .selection-mode .titlebar buttonbox.toggle:backdrop.flat:checked, .selection-mode .titlebar buttonbox.toggle:backdrop:active, .selection-mode .titlebar buttonbox.toggle:backdrop:checked, .selection-mode .titlebar stackswitcher button:backdrop.flat:active, .selection-mode .titlebar stackswitcher button:backdrop.flat:checked, .selection-mode .titlebar stackswitcher button:backdrop:active, .selection-mode .titlebar stackswitcher button:backdrop:checked, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop.flat:active, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop.flat:checked, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop:active, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop:checked, .selection-mode .titlebar .path-bar button:backdrop.flat:active, .selection-mode .titlebar .path-bar button:backdrop.flat:checked, .selection-mode .titlebar .path-bar button:backdrop:active, .selection-mode .titlebar .path-bar button:backdrop:checked, .titlebar.selection-mode button:backdrop.flat:active, .titlebar.selection-mode button:backdrop.flat:checked, .titlebar.selection-mode button:backdrop:active, .titlebar.selection-mode button:backdrop:checked, .titlebar.selection-mode button.image-button:backdrop.flat:active, .titlebar.selection-mode button.image-button:backdrop.flat:checked, .titlebar.selection-mode button.image-button:backdrop:active, .titlebar.selection-mode button.image-button:backdrop:checked, .titlebar.selection-mode button.image-button.toggle:backdrop.flat:active, .titlebar.selection-mode button.image-button.toggle:backdrop.flat:checked, .titlebar.selection-mode button.image-button.toggle:backdrop:active, .titlebar.selection-mode button.image-button.toggle:backdrop:checked, .titlebar.selection-mode button.text.button:backdrop.flat:active, .titlebar.selection-mode button.text.button:backdrop.flat:checked, .titlebar.selection-mode button.text.button:backdrop:active, .titlebar.selection-mode button.text.button:backdrop:checked, .titlebar.selection-mode button.toggle:backdrop.flat:active, .titlebar.selection-mode button.toggle:backdrop.flat:checked, .titlebar.selection-mode button.toggle:backdrop:active, .titlebar.selection-mode button.toggle:backdrop:checked, .titlebar.selection-mode box button.toggle:backdrop.flat:active, .titlebar.selection-mode box button.toggle:backdrop.flat:checked, .titlebar.selection-mode box button.toggle:backdrop:active, .titlebar.selection-mode box button.toggle:backdrop:checked, .titlebar.selection-mode buttonbox.toggle:backdrop.flat:active, .titlebar.selection-mode buttonbox.toggle:backdrop.flat:checked, .titlebar.selection-mode buttonbox.toggle:backdrop:active, .titlebar.selection-mode buttonbox.toggle:backdrop:checked, .titlebar.selection-mode stackswitcher button:backdrop.flat:active, .titlebar.selection-mode stackswitcher button:backdrop.flat:checked, .titlebar.selection-mode stackswitcher button:backdrop:active, .titlebar.selection-mode stackswitcher button:backdrop:checked, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:active, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:checked, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop:active, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop:checked, .titlebar.selection-mode .path-bar button:backdrop.flat:active, .titlebar.selection-mode .path-bar button:backdrop.flat:checked, .titlebar.selection-mode .path-bar button:backdrop:active, .titlebar.selection-mode .path-bar button:backdrop:checked { color: #e9efe0; border-color: #90ad62; background-image: image(#90ad62); box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode headerbar button:backdrop.flat:disabled, .selection-mode headerbar button:backdrop:disabled, .selection-mode headerbar button.image-button:backdrop.flat:disabled, .selection-mode headerbar button.image-button:backdrop:disabled, .selection-mode headerbar button.image-button.toggle:backdrop.flat:disabled, .selection-mode headerbar button.image-button.toggle:backdrop:disabled, .selection-mode headerbar button.text.button:backdrop.flat:disabled, .selection-mode headerbar button.text.button:backdrop:disabled, .selection-mode headerbar button.toggle:backdrop.flat:disabled, .selection-mode headerbar button.toggle:backdrop:disabled, .selection-mode headerbar box button.toggle:backdrop.flat:disabled, .selection-mode headerbar box button.toggle:backdrop:disabled, .selection-mode headerbar buttonbox.toggle:backdrop.flat:disabled, .selection-mode headerbar buttonbox.toggle:backdrop:disabled, .selection-mode headerbar stackswitcher button:backdrop.flat:disabled, .selection-mode headerbar stackswitcher button:backdrop:disabled, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop.flat:disabled, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop:disabled, .selection-mode headerbar .path-bar button:backdrop.flat:disabled, .selection-mode headerbar .path-bar button:backdrop:disabled, headerbar.selection-mode button:backdrop.flat:disabled, headerbar.selection-mode button:backdrop:disabled, headerbar.selection-mode button.image-button:backdrop.flat:disabled, headerbar.selection-mode button.image-button:backdrop:disabled, headerbar.selection-mode button.image-button.toggle:backdrop.flat:disabled, headerbar.selection-mode button.image-button.toggle:backdrop:disabled, headerbar.selection-mode button.text.button:backdrop.flat:disabled, headerbar.selection-mode button.text.button:backdrop:disabled, headerbar.selection-mode button.toggle:backdrop.flat:disabled, headerbar.selection-mode button.toggle:backdrop:disabled, headerbar.selection-mode box button.toggle:backdrop.flat:disabled, headerbar.selection-mode box button.toggle:backdrop:disabled, headerbar.selection-mode buttonbox.toggle:backdrop.flat:disabled, headerbar.selection-mode buttonbox.toggle:backdrop:disabled, headerbar.selection-mode stackswitcher button:backdrop.flat:disabled, headerbar.selection-mode stackswitcher button:backdrop:disabled, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:disabled, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop:disabled, headerbar.selection-mode .path-bar button:backdrop.flat:disabled, headerbar.selection-mode .path-bar button:backdrop:disabled, .selection-mode .titlebar button:backdrop.flat:disabled, .selection-mode .titlebar button:backdrop:disabled, .selection-mode .titlebar button.image-button:backdrop.flat:disabled, .selection-mode .titlebar button.image-button:backdrop:disabled, .selection-mode .titlebar button.image-button.toggle:backdrop.flat:disabled, .selection-mode .titlebar button.image-button.toggle:backdrop:disabled, .selection-mode .titlebar button.text.button:backdrop.flat:disabled, .selection-mode .titlebar button.text.button:backdrop:disabled, .selection-mode .titlebar button.toggle:backdrop.flat:disabled, .selection-mode .titlebar button.toggle:backdrop:disabled, .selection-mode .titlebar box button.toggle:backdrop.flat:disabled, .selection-mode .titlebar box button.toggle:backdrop:disabled, .selection-mode .titlebar buttonbox.toggle:backdrop.flat:disabled, .selection-mode .titlebar buttonbox.toggle:backdrop:disabled, .selection-mode .titlebar stackswitcher button:backdrop.flat:disabled, .selection-mode .titlebar stackswitcher button:backdrop:disabled, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop.flat:disabled, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop:disabled, .selection-mode .titlebar .path-bar button:backdrop.flat:disabled, .selection-mode .titlebar .path-bar button:backdrop:disabled, .titlebar.selection-mode button:backdrop.flat:disabled, .titlebar.selection-mode button:backdrop:disabled, .titlebar.selection-mode button.image-button:backdrop.flat:disabled, .titlebar.selection-mode button.image-button:backdrop:disabled, .titlebar.selection-mode button.image-button.toggle:backdrop.flat:disabled, .titlebar.selection-mode button.image-button.toggle:backdrop:disabled, .titlebar.selection-mode button.text.button:backdrop.flat:disabled, .titlebar.selection-mode button.text.button:backdrop:disabled, .titlebar.selection-mode button.toggle:backdrop.flat:disabled, .titlebar.selection-mode button.toggle:backdrop:disabled, .titlebar.selection-mode box button.toggle:backdrop.flat:disabled, .titlebar.selection-mode box button.toggle:backdrop:disabled, .titlebar.selection-mode buttonbox.toggle:backdrop.flat:disabled, .titlebar.selection-mode buttonbox.toggle:backdrop:disabled, .titlebar.selection-mode stackswitcher button:backdrop.flat:disabled, .titlebar.selection-mode stackswitcher button:backdrop:disabled, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:disabled, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop:disabled, .titlebar.selection-mode .path-bar button:backdrop.flat:disabled, .titlebar.selection-mode .path-bar button:backdrop:disabled { color: #c3d3ab; border-color: #a3bb7d; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode headerbar button:backdrop.flat:disabled:active, .selection-mode headerbar button:backdrop.flat:disabled:checked, .selection-mode headerbar button:backdrop:disabled:active, .selection-mode headerbar button:backdrop:disabled:checked, .selection-mode headerbar button.image-button:backdrop.flat:disabled:active, .selection-mode headerbar button.image-button:backdrop.flat:disabled:checked, .selection-mode headerbar button.image-button:backdrop:disabled:active, .selection-mode headerbar button.image-button:backdrop:disabled:checked, .selection-mode headerbar button.image-button.toggle:backdrop.flat:disabled:active, .selection-mode headerbar button.image-button.toggle:backdrop.flat:disabled:checked, .selection-mode headerbar button.image-button.toggle:backdrop:disabled:active, .selection-mode headerbar button.image-button.toggle:backdrop:disabled:checked, .selection-mode headerbar button.text.button:backdrop.flat:disabled:active, .selection-mode headerbar button.text.button:backdrop.flat:disabled:checked, .selection-mode headerbar button.text.button:backdrop:disabled:active, .selection-mode headerbar button.text.button:backdrop:disabled:checked, .selection-mode headerbar button.toggle:backdrop.flat:disabled:active, .selection-mode headerbar button.toggle:backdrop.flat:disabled:checked, .selection-mode headerbar button.toggle:backdrop:disabled:active, .selection-mode headerbar button.toggle:backdrop:disabled:checked, .selection-mode headerbar box button.toggle:backdrop.flat:disabled:active, .selection-mode headerbar box button.toggle:backdrop.flat:disabled:checked, .selection-mode headerbar box button.toggle:backdrop:disabled:active, .selection-mode headerbar box button.toggle:backdrop:disabled:checked, .selection-mode headerbar buttonbox.toggle:backdrop.flat:disabled:active, .selection-mode headerbar buttonbox.toggle:backdrop.flat:disabled:checked, .selection-mode headerbar buttonbox.toggle:backdrop:disabled:active, .selection-mode headerbar buttonbox.toggle:backdrop:disabled:checked, .selection-mode headerbar stackswitcher button:backdrop.flat:disabled:active, .selection-mode headerbar stackswitcher button:backdrop.flat:disabled:checked, .selection-mode headerbar stackswitcher button:backdrop:disabled:active, .selection-mode headerbar stackswitcher button:backdrop:disabled:checked, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop.flat:disabled:active, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop.flat:disabled:checked, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop:disabled:active, .selection-mode headerbar filechooser .path-bar.linked > button:backdrop:disabled:checked, .selection-mode headerbar .path-bar button:backdrop.flat:disabled:active, .selection-mode headerbar .path-bar button:backdrop.flat:disabled:checked, .selection-mode headerbar .path-bar button:backdrop:disabled:active, .selection-mode headerbar .path-bar button:backdrop:disabled:checked, headerbar.selection-mode button:backdrop.flat:disabled:active, headerbar.selection-mode button:backdrop.flat:disabled:checked, headerbar.selection-mode button:backdrop:disabled:active, headerbar.selection-mode button:backdrop:disabled:checked, headerbar.selection-mode button.image-button:backdrop.flat:disabled:active, headerbar.selection-mode button.image-button:backdrop.flat:disabled:checked, headerbar.selection-mode button.image-button:backdrop:disabled:active, headerbar.selection-mode button.image-button:backdrop:disabled:checked, headerbar.selection-mode button.image-button.toggle:backdrop.flat:disabled:active, headerbar.selection-mode button.image-button.toggle:backdrop.flat:disabled:checked, headerbar.selection-mode button.image-button.toggle:backdrop:disabled:active, headerbar.selection-mode button.image-button.toggle:backdrop:disabled:checked, headerbar.selection-mode button.text.button:backdrop.flat:disabled:active, headerbar.selection-mode button.text.button:backdrop.flat:disabled:checked, headerbar.selection-mode button.text.button:backdrop:disabled:active, headerbar.selection-mode button.text.button:backdrop:disabled:checked, headerbar.selection-mode button.toggle:backdrop.flat:disabled:active, headerbar.selection-mode button.toggle:backdrop.flat:disabled:checked, headerbar.selection-mode button.toggle:backdrop:disabled:active, headerbar.selection-mode button.toggle:backdrop:disabled:checked, headerbar.selection-mode box button.toggle:backdrop.flat:disabled:active, headerbar.selection-mode box button.toggle:backdrop.flat:disabled:checked, headerbar.selection-mode box button.toggle:backdrop:disabled:active, headerbar.selection-mode box button.toggle:backdrop:disabled:checked, headerbar.selection-mode buttonbox.toggle:backdrop.flat:disabled:active, headerbar.selection-mode buttonbox.toggle:backdrop.flat:disabled:checked, headerbar.selection-mode buttonbox.toggle:backdrop:disabled:active, headerbar.selection-mode buttonbox.toggle:backdrop:disabled:checked, headerbar.selection-mode stackswitcher button:backdrop.flat:disabled:active, headerbar.selection-mode stackswitcher button:backdrop.flat:disabled:checked, headerbar.selection-mode stackswitcher button:backdrop:disabled:active, headerbar.selection-mode stackswitcher button:backdrop:disabled:checked, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:disabled:active, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:disabled:checked, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop:disabled:active, headerbar.selection-mode filechooser .path-bar.linked > button:backdrop:disabled:checked, headerbar.selection-mode .path-bar button:backdrop.flat:disabled:active, headerbar.selection-mode .path-bar button:backdrop.flat:disabled:checked, headerbar.selection-mode .path-bar button:backdrop:disabled:active, headerbar.selection-mode .path-bar button:backdrop:disabled:checked, .selection-mode .titlebar button:backdrop.flat:disabled:active, .selection-mode .titlebar button:backdrop.flat:disabled:checked, .selection-mode .titlebar button:backdrop:disabled:active, .selection-mode .titlebar button:backdrop:disabled:checked, .selection-mode .titlebar button.image-button:backdrop.flat:disabled:active, .selection-mode .titlebar button.image-button:backdrop.flat:disabled:checked, .selection-mode .titlebar button.image-button:backdrop:disabled:active, .selection-mode .titlebar button.image-button:backdrop:disabled:checked, .selection-mode .titlebar button.image-button.toggle:backdrop.flat:disabled:active, .selection-mode .titlebar button.image-button.toggle:backdrop.flat:disabled:checked, .selection-mode .titlebar button.image-button.toggle:backdrop:disabled:active, .selection-mode .titlebar button.image-button.toggle:backdrop:disabled:checked, .selection-mode .titlebar button.text.button:backdrop.flat:disabled:active, .selection-mode .titlebar button.text.button:backdrop.flat:disabled:checked, .selection-mode .titlebar button.text.button:backdrop:disabled:active, .selection-mode .titlebar button.text.button:backdrop:disabled:checked, .selection-mode .titlebar button.toggle:backdrop.flat:disabled:active, .selection-mode .titlebar button.toggle:backdrop.flat:disabled:checked, .selection-mode .titlebar button.toggle:backdrop:disabled:active, .selection-mode .titlebar button.toggle:backdrop:disabled:checked, .selection-mode .titlebar box button.toggle:backdrop.flat:disabled:active, .selection-mode .titlebar box button.toggle:backdrop.flat:disabled:checked, .selection-mode .titlebar box button.toggle:backdrop:disabled:active, .selection-mode .titlebar box button.toggle:backdrop:disabled:checked, .selection-mode .titlebar buttonbox.toggle:backdrop.flat:disabled:active, .selection-mode .titlebar buttonbox.toggle:backdrop.flat:disabled:checked, .selection-mode .titlebar buttonbox.toggle:backdrop:disabled:active, .selection-mode .titlebar buttonbox.toggle:backdrop:disabled:checked, .selection-mode .titlebar stackswitcher button:backdrop.flat:disabled:active, .selection-mode .titlebar stackswitcher button:backdrop.flat:disabled:checked, .selection-mode .titlebar stackswitcher button:backdrop:disabled:active, .selection-mode .titlebar stackswitcher button:backdrop:disabled:checked, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop.flat:disabled:active, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop.flat:disabled:checked, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop:disabled:active, .selection-mode .titlebar filechooser .path-bar.linked > button:backdrop:disabled:checked, .selection-mode .titlebar .path-bar button:backdrop.flat:disabled:active, .selection-mode .titlebar .path-bar button:backdrop.flat:disabled:checked, .selection-mode .titlebar .path-bar button:backdrop:disabled:active, .selection-mode .titlebar .path-bar button:backdrop:disabled:checked, .titlebar.selection-mode button:backdrop.flat:disabled:active, .titlebar.selection-mode button:backdrop.flat:disabled:checked, .titlebar.selection-mode button:backdrop:disabled:active, .titlebar.selection-mode button:backdrop:disabled:checked, .titlebar.selection-mode button.image-button:backdrop.flat:disabled:active, .titlebar.selection-mode button.image-button:backdrop.flat:disabled:checked, .titlebar.selection-mode button.image-button:backdrop:disabled:active, .titlebar.selection-mode button.image-button:backdrop:disabled:checked, .titlebar.selection-mode button.image-button.toggle:backdrop.flat:disabled:active, .titlebar.selection-mode button.image-button.toggle:backdrop.flat:disabled:checked, .titlebar.selection-mode button.image-button.toggle:backdrop:disabled:active, .titlebar.selection-mode button.image-button.toggle:backdrop:disabled:checked, .titlebar.selection-mode button.text.button:backdrop.flat:disabled:active, .titlebar.selection-mode button.text.button:backdrop.flat:disabled:checked, .titlebar.selection-mode button.text.button:backdrop:disabled:active, .titlebar.selection-mode button.text.button:backdrop:disabled:checked, .titlebar.selection-mode button.toggle:backdrop.flat:disabled:active, .titlebar.selection-mode button.toggle:backdrop.flat:disabled:checked, .titlebar.selection-mode button.toggle:backdrop:disabled:active, .titlebar.selection-mode button.toggle:backdrop:disabled:checked, .titlebar.selection-mode box button.toggle:backdrop.flat:disabled:active, .titlebar.selection-mode box button.toggle:backdrop.flat:disabled:checked, .titlebar.selection-mode box button.toggle:backdrop:disabled:active, .titlebar.selection-mode box button.toggle:backdrop:disabled:checked, .titlebar.selection-mode buttonbox.toggle:backdrop.flat:disabled:active, .titlebar.selection-mode buttonbox.toggle:backdrop.flat:disabled:checked, .titlebar.selection-mode buttonbox.toggle:backdrop:disabled:active, .titlebar.selection-mode buttonbox.toggle:backdrop:disabled:checked, .titlebar.selection-mode stackswitcher button:backdrop.flat:disabled:active, .titlebar.selection-mode stackswitcher button:backdrop.flat:disabled:checked, .titlebar.selection-mode stackswitcher button:backdrop:disabled:active, .titlebar.selection-mode stackswitcher button:backdrop:disabled:checked, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:disabled:active, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop.flat:disabled:checked, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop:disabled:active, .titlebar.selection-mode filechooser .path-bar.linked > button:backdrop:disabled:checked, .titlebar.selection-mode .path-bar button:backdrop.flat:disabled:active, .titlebar.selection-mode .path-bar button:backdrop.flat:disabled:checked, .titlebar.selection-mode .path-bar button:backdrop:disabled:active, .titlebar.selection-mode .path-bar button:backdrop:disabled:checked { color: #b7ca99; border-color: #90ad62; background-image: image(#90ad62); box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode headerbar button.flat:backdrop, .selection-mode headerbar button.flat:disabled, .selection-mode headerbar button.flat:backdrop:disabled, .selection-mode headerbar button.image-button.flat:backdrop, .selection-mode headerbar button.image-button.flat:disabled, .selection-mode headerbar button.image-button.flat:backdrop:disabled, .selection-mode headerbar button.image-button.toggle.flat:backdrop, .selection-mode headerbar button.image-button.toggle.flat:disabled, .selection-mode headerbar button.image-button.toggle.flat:backdrop:disabled, .selection-mode headerbar button.text.button.flat:backdrop, .selection-mode headerbar button.text.button.flat:disabled, .selection-mode headerbar button.text.button.flat:backdrop:disabled, .selection-mode headerbar button.toggle.flat:backdrop, .selection-mode headerbar button.toggle.flat:disabled, .selection-mode headerbar button.toggle.flat:backdrop:disabled, .selection-mode headerbar box button.toggle.flat:backdrop, .selection-mode headerbar box button.toggle.flat:disabled, .selection-mode headerbar box button.toggle.flat:backdrop:disabled, .selection-mode headerbar buttonbox.toggle.flat:backdrop, .selection-mode headerbar buttonbox.toggle.flat:disabled, .selection-mode headerbar buttonbox.toggle.flat:backdrop:disabled, .selection-mode headerbar stackswitcher button.flat:backdrop, .selection-mode headerbar stackswitcher button.flat:disabled, .selection-mode headerbar stackswitcher button.flat:backdrop:disabled, .selection-mode headerbar filechooser .path-bar.linked > button.flat:backdrop, .selection-mode headerbar filechooser .path-bar.linked > button.flat:disabled, .selection-mode headerbar filechooser .path-bar.linked > button.flat:backdrop:disabled, .selection-mode headerbar .path-bar button.flat:backdrop, .selection-mode headerbar .path-bar button.flat:disabled, .selection-mode headerbar .path-bar button.flat:backdrop:disabled, headerbar.selection-mode button.flat:backdrop, headerbar.selection-mode button.flat:disabled, headerbar.selection-mode button.flat:backdrop:disabled, headerbar.selection-mode button.image-button.flat:backdrop, headerbar.selection-mode button.image-button.flat:disabled, headerbar.selection-mode button.image-button.flat:backdrop:disabled, headerbar.selection-mode button.image-button.toggle.flat:backdrop, headerbar.selection-mode button.image-button.toggle.flat:disabled, headerbar.selection-mode button.image-button.toggle.flat:backdrop:disabled, headerbar.selection-mode button.text.button.flat:backdrop, headerbar.selection-mode button.text.button.flat:disabled, headerbar.selection-mode button.text.button.flat:backdrop:disabled, headerbar.selection-mode button.toggle.flat:backdrop, headerbar.selection-mode button.toggle.flat:disabled, headerbar.selection-mode button.toggle.flat:backdrop:disabled, headerbar.selection-mode box button.toggle.flat:backdrop, headerbar.selection-mode box button.toggle.flat:disabled, headerbar.selection-mode box button.toggle.flat:backdrop:disabled, headerbar.selection-mode buttonbox.toggle.flat:backdrop, headerbar.selection-mode buttonbox.toggle.flat:disabled, headerbar.selection-mode buttonbox.toggle.flat:backdrop:disabled, headerbar.selection-mode stackswitcher button.flat:backdrop, headerbar.selection-mode stackswitcher button.flat:disabled, headerbar.selection-mode stackswitcher button.flat:backdrop:disabled, headerbar.selection-mode filechooser .path-bar.linked > button.flat:backdrop, headerbar.selection-mode filechooser .path-bar.linked > button.flat:disabled, headerbar.selection-mode filechooser .path-bar.linked > button.flat:backdrop:disabled, headerbar.selection-mode .path-bar button.flat:backdrop, headerbar.selection-mode .path-bar button.flat:disabled, headerbar.selection-mode .path-bar button.flat:backdrop:disabled, .selection-mode .titlebar button.flat:backdrop, .selection-mode .titlebar button.flat:disabled, .selection-mode .titlebar button.flat:backdrop:disabled, .selection-mode .titlebar button.image-button.flat:backdrop, .selection-mode .titlebar button.image-button.flat:disabled, .selection-mode .titlebar button.image-button.flat:backdrop:disabled, .selection-mode .titlebar button.image-button.toggle.flat:backdrop, .selection-mode .titlebar button.image-button.toggle.flat:disabled, .selection-mode .titlebar button.image-button.toggle.flat:backdrop:disabled, .selection-mode .titlebar button.text.button.flat:backdrop, .selection-mode .titlebar button.text.button.flat:disabled, .selection-mode .titlebar button.text.button.flat:backdrop:disabled, .selection-mode .titlebar button.toggle.flat:backdrop, .selection-mode .titlebar button.toggle.flat:disabled, .selection-mode .titlebar button.toggle.flat:backdrop:disabled, .selection-mode .titlebar box button.toggle.flat:backdrop, .selection-mode .titlebar box button.toggle.flat:disabled, .selection-mode .titlebar box button.toggle.flat:backdrop:disabled, .selection-mode .titlebar buttonbox.toggle.flat:backdrop, .selection-mode .titlebar buttonbox.toggle.flat:disabled, .selection-mode .titlebar buttonbox.toggle.flat:backdrop:disabled, .selection-mode .titlebar stackswitcher button.flat:backdrop, .selection-mode .titlebar stackswitcher button.flat:disabled, .selection-mode .titlebar stackswitcher button.flat:backdrop:disabled, .selection-mode .titlebar filechooser .path-bar.linked > button.flat:backdrop, .selection-mode .titlebar filechooser .path-bar.linked > button.flat:disabled, .selection-mode .titlebar filechooser .path-bar.linked > button.flat:backdrop:disabled, .selection-mode .titlebar .path-bar button.flat:backdrop, .selection-mode .titlebar .path-bar button.flat:disabled, .selection-mode .titlebar .path-bar button.flat:backdrop:disabled, .titlebar.selection-mode button.flat:backdrop, .titlebar.selection-mode button.flat:disabled, .titlebar.selection-mode button.flat:backdrop:disabled, .titlebar.selection-mode button.image-button.flat:backdrop, .titlebar.selection-mode button.image-button.flat:disabled, .titlebar.selection-mode button.image-button.flat:backdrop:disabled, .titlebar.selection-mode button.image-button.toggle.flat:backdrop, .titlebar.selection-mode button.image-button.toggle.flat:disabled, .titlebar.selection-mode button.image-button.toggle.flat:backdrop:disabled, .titlebar.selection-mode button.text.button.flat:backdrop, .titlebar.selection-mode button.text.button.flat:disabled, .titlebar.selection-mode button.text.button.flat:backdrop:disabled, .titlebar.selection-mode button.toggle.flat:backdrop, .titlebar.selection-mode button.toggle.flat:disabled, .titlebar.selection-mode button.toggle.flat:backdrop:disabled, .titlebar.selection-mode box button.toggle.flat:backdrop, .titlebar.selection-mode box button.toggle.flat:disabled, .titlebar.selection-mode box button.toggle.flat:backdrop:disabled, .titlebar.selection-mode buttonbox.toggle.flat:backdrop, .titlebar.selection-mode buttonbox.toggle.flat:disabled, .titlebar.selection-mode buttonbox.toggle.flat:backdrop:disabled, .titlebar.selection-mode stackswitcher button.flat:backdrop, .titlebar.selection-mode stackswitcher button.flat:disabled, .titlebar.selection-mode stackswitcher button.flat:backdrop:disabled, .titlebar.selection-mode filechooser .path-bar.linked > button.flat:backdrop, .titlebar.selection-mode filechooser .path-bar.linked > button.flat:disabled, .titlebar.selection-mode filechooser .path-bar.linked > button.flat:backdrop:disabled, .titlebar.selection-mode .path-bar button.flat:backdrop, .titlebar.selection-mode .path-bar button.flat:disabled, .titlebar.selection-mode .path-bar button.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode headerbar button:disabled, .selection-mode headerbar button.image-button:disabled, .selection-mode headerbar button.image-button.toggle:disabled, .selection-mode headerbar button.text.button:disabled, .selection-mode headerbar button.toggle:disabled, .selection-mode headerbar box button.toggle:disabled, .selection-mode headerbar buttonbox.toggle:disabled, .selection-mode headerbar stackswitcher button:disabled, .selection-mode headerbar filechooser .path-bar.linked > button:disabled, .selection-mode headerbar .path-bar button:disabled, headerbar.selection-mode button:disabled, headerbar.selection-mode button.image-button:disabled, headerbar.selection-mode button.image-button.toggle:disabled, headerbar.selection-mode button.text.button:disabled, headerbar.selection-mode button.toggle:disabled, headerbar.selection-mode box button.toggle:disabled, headerbar.selection-mode buttonbox.toggle:disabled, headerbar.selection-mode stackswitcher button:disabled, headerbar.selection-mode filechooser .path-bar.linked > button:disabled, headerbar.selection-mode .path-bar button:disabled, .selection-mode .titlebar button:disabled, .selection-mode .titlebar button.image-button:disabled, .selection-mode .titlebar button.image-button.toggle:disabled, .selection-mode .titlebar button.text.button:disabled, .selection-mode .titlebar button.toggle:disabled, .selection-mode .titlebar box button.toggle:disabled, .selection-mode .titlebar buttonbox.toggle:disabled, .selection-mode .titlebar stackswitcher button:disabled, .selection-mode .titlebar filechooser .path-bar.linked > button:disabled, .selection-mode .titlebar .path-bar button:disabled, .titlebar.selection-mode button:disabled, .titlebar.selection-mode button.image-button:disabled, .titlebar.selection-mode button.image-button.toggle:disabled, .titlebar.selection-mode button.text.button:disabled, .titlebar.selection-mode button.toggle:disabled, .titlebar.selection-mode box button.toggle:disabled, .titlebar.selection-mode buttonbox.toggle:disabled, .titlebar.selection-mode stackswitcher button:disabled, .titlebar.selection-mode filechooser .path-bar.linked > button:disabled, .titlebar.selection-mode .path-bar button:disabled { color: #d1ddbe; border-color: #79944d; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode headerbar button:disabled:active, .selection-mode headerbar button:disabled:checked, .selection-mode headerbar button.image-button:disabled:active, .selection-mode headerbar button.image-button:disabled:checked, .selection-mode headerbar button.image-button.toggle:disabled:active, .selection-mode headerbar button.image-button.toggle:disabled:checked, .selection-mode headerbar button.text.button:disabled:active, .selection-mode headerbar button.text.button:disabled:checked, .selection-mode headerbar button.toggle:disabled:active, .selection-mode headerbar button.toggle:disabled:checked, .selection-mode headerbar box button.toggle:disabled:active, .selection-mode headerbar box button.toggle:disabled:checked, .selection-mode headerbar buttonbox.toggle:disabled:active, .selection-mode headerbar buttonbox.toggle:disabled:checked, .selection-mode headerbar stackswitcher button:disabled:active, .selection-mode headerbar stackswitcher button:disabled:checked, .selection-mode headerbar filechooser .path-bar.linked > button:disabled:active, .selection-mode headerbar filechooser .path-bar.linked > button:disabled:checked, .selection-mode headerbar .path-bar button:disabled:active, .selection-mode headerbar .path-bar button:disabled:checked, headerbar.selection-mode button:disabled:active, headerbar.selection-mode button:disabled:checked, headerbar.selection-mode button.image-button:disabled:active, headerbar.selection-mode button.image-button:disabled:checked, headerbar.selection-mode button.image-button.toggle:disabled:active, headerbar.selection-mode button.image-button.toggle:disabled:checked, headerbar.selection-mode button.text.button:disabled:active, headerbar.selection-mode button.text.button:disabled:checked, headerbar.selection-mode button.toggle:disabled:active, headerbar.selection-mode button.toggle:disabled:checked, headerbar.selection-mode box button.toggle:disabled:active, headerbar.selection-mode box button.toggle:disabled:checked, headerbar.selection-mode buttonbox.toggle:disabled:active, headerbar.selection-mode buttonbox.toggle:disabled:checked, headerbar.selection-mode stackswitcher button:disabled:active, headerbar.selection-mode stackswitcher button:disabled:checked, headerbar.selection-mode filechooser .path-bar.linked > button:disabled:active, headerbar.selection-mode filechooser .path-bar.linked > button:disabled:checked, headerbar.selection-mode .path-bar button:disabled:active, headerbar.selection-mode .path-bar button:disabled:checked, .selection-mode .titlebar button:disabled:active, .selection-mode .titlebar button:disabled:checked, .selection-mode .titlebar button.image-button:disabled:active, .selection-mode .titlebar button.image-button:disabled:checked, .selection-mode .titlebar button.image-button.toggle:disabled:active, .selection-mode .titlebar button.image-button.toggle:disabled:checked, .selection-mode .titlebar button.text.button:disabled:active, .selection-mode .titlebar button.text.button:disabled:checked, .selection-mode .titlebar button.toggle:disabled:active, .selection-mode .titlebar button.toggle:disabled:checked, .selection-mode .titlebar box button.toggle:disabled:active, .selection-mode .titlebar box button.toggle:disabled:checked, .selection-mode .titlebar buttonbox.toggle:disabled:active, .selection-mode .titlebar buttonbox.toggle:disabled:checked, .selection-mode .titlebar stackswitcher button:disabled:active, .selection-mode .titlebar stackswitcher button:disabled:checked, .selection-mode .titlebar filechooser .path-bar.linked > button:disabled:active, .selection-mode .titlebar filechooser .path-bar.linked > button:disabled:checked, .selection-mode .titlebar .path-bar button:disabled:active, .selection-mode .titlebar .path-bar button:disabled:checked, .titlebar.selection-mode button:disabled:active, .titlebar.selection-mode button:disabled:checked, .titlebar.selection-mode button.image-button:disabled:active, .titlebar.selection-mode button.image-button:disabled:checked, .titlebar.selection-mode button.image-button.toggle:disabled:active, .titlebar.selection-mode button.image-button.toggle:disabled:checked, .titlebar.selection-mode button.text.button:disabled:active, .titlebar.selection-mode button.text.button:disabled:checked, .titlebar.selection-mode button.toggle:disabled:active, .titlebar.selection-mode button.toggle:disabled:checked, .titlebar.selection-mode box button.toggle:disabled:active, .titlebar.selection-mode box button.toggle:disabled:checked, .titlebar.selection-mode buttonbox.toggle:disabled:active, .titlebar.selection-mode buttonbox.toggle:disabled:checked, .titlebar.selection-mode stackswitcher button:disabled:active, .titlebar.selection-mode stackswitcher button:disabled:checked, .titlebar.selection-mode filechooser .path-bar.linked > button:disabled:active, .titlebar.selection-mode filechooser .path-bar.linked > button:disabled:checked, .titlebar.selection-mode .path-bar button:disabled:active, .titlebar.selection-mode .path-bar button:disabled:checked { color: #d3dec0; border-color: #79944d; background-image: linear-gradient(to bottom, #e9e7e6, #f1f1f0 3px, #f4f3f2 4px, #efeeed 50%, #ebeae9 50%, #e4e3e1); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode headerbar button.suggested-action, .selection-mode headerbar button.image-button.suggested-action, .selection-mode headerbar button.image-button.toggle.suggested-action, .selection-mode headerbar button.text.button.suggested-action, .selection-mode headerbar button.toggle.suggested-action, .selection-mode headerbar box button.toggle.suggested-action, .selection-mode headerbar buttonbox.toggle.suggested-action, .selection-mode headerbar stackswitcher button.suggested-action, .selection-mode headerbar filechooser .path-bar.linked > button.suggested-action, .selection-mode headerbar .path-bar button.suggested-action, headerbar.selection-mode button.suggested-action, headerbar.selection-mode button.image-button.suggested-action, headerbar.selection-mode button.image-button.toggle.suggested-action, headerbar.selection-mode button.text.button.suggested-action, headerbar.selection-mode button.toggle.suggested-action, headerbar.selection-mode box button.toggle.suggested-action, headerbar.selection-mode buttonbox.toggle.suggested-action, headerbar.selection-mode stackswitcher button.suggested-action, headerbar.selection-mode filechooser .path-bar.linked > button.suggested-action, headerbar.selection-mode .path-bar button.suggested-action, .selection-mode .titlebar button.suggested-action, .selection-mode .titlebar button.image-button.suggested-action, .selection-mode .titlebar button.image-button.toggle.suggested-action, .selection-mode .titlebar button.text.button.suggested-action, .selection-mode .titlebar button.toggle.suggested-action, .selection-mode .titlebar box button.toggle.suggested-action, .selection-mode .titlebar buttonbox.toggle.suggested-action, .selection-mode .titlebar stackswitcher button.suggested-action, .selection-mode .titlebar filechooser .path-bar.linked > button.suggested-action, .selection-mode .titlebar .path-bar button.suggested-action, .titlebar.selection-mode button.suggested-action, .titlebar.selection-mode button.image-button.suggested-action, .titlebar.selection-mode button.image-button.toggle.suggested-action, .titlebar.selection-mode button.text.button.suggested-action, .titlebar.selection-mode button.toggle.suggested-action, .titlebar.selection-mode box button.toggle.suggested-action, .titlebar.selection-mode buttonbox.toggle.suggested-action, .titlebar.selection-mode stackswitcher button.suggested-action, .titlebar.selection-mode filechooser .path-bar.linked > button.suggested-action, .titlebar.selection-mode .path-bar button.suggested-action { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: 0 1px rgba(0, 0, 0, 0.05); border-color: #87a556; }

.selection-mode headerbar button.suggested-action:hover, .selection-mode headerbar button.image-button.suggested-action:hover, .selection-mode headerbar button.image-button.toggle.suggested-action:hover, .selection-mode headerbar button.text.button.suggested-action:hover, .selection-mode headerbar button.toggle.suggested-action:hover, .selection-mode headerbar box button.toggle.suggested-action:hover, .selection-mode headerbar buttonbox.toggle.suggested-action:hover, .selection-mode headerbar stackswitcher button.suggested-action:hover, .selection-mode headerbar filechooser .path-bar.linked > button.suggested-action:hover, .selection-mode headerbar .path-bar button.suggested-action:hover, headerbar.selection-mode button.suggested-action:hover, headerbar.selection-mode button.image-button.suggested-action:hover, headerbar.selection-mode button.image-button.toggle.suggested-action:hover, headerbar.selection-mode button.text.button.suggested-action:hover, headerbar.selection-mode button.toggle.suggested-action:hover, headerbar.selection-mode box button.toggle.suggested-action:hover, headerbar.selection-mode buttonbox.toggle.suggested-action:hover, headerbar.selection-mode stackswitcher button.suggested-action:hover, headerbar.selection-mode filechooser .path-bar.linked > button.suggested-action:hover, headerbar.selection-mode .path-bar button.suggested-action:hover, .selection-mode .titlebar button.suggested-action:hover, .selection-mode .titlebar button.image-button.suggested-action:hover, .selection-mode .titlebar button.image-button.toggle.suggested-action:hover, .selection-mode .titlebar button.text.button.suggested-action:hover, .selection-mode .titlebar button.toggle.suggested-action:hover, .selection-mode .titlebar box button.toggle.suggested-action:hover, .selection-mode .titlebar buttonbox.toggle.suggested-action:hover, .selection-mode .titlebar stackswitcher button.suggested-action:hover, .selection-mode .titlebar filechooser .path-bar.linked > button.suggested-action:hover, .selection-mode .titlebar .path-bar button.suggested-action:hover, .titlebar.selection-mode button.suggested-action:hover, .titlebar.selection-mode button.image-button.suggested-action:hover, .titlebar.selection-mode button.image-button.toggle.suggested-action:hover, .titlebar.selection-mode button.text.button.suggested-action:hover, .titlebar.selection-mode button.toggle.suggested-action:hover, .titlebar.selection-mode box button.toggle.suggested-action:hover, .titlebar.selection-mode buttonbox.toggle.suggested-action:hover, .titlebar.selection-mode stackswitcher button.suggested-action:hover, .titlebar.selection-mode filechooser .path-bar.linked > button.suggested-action:hover, .titlebar.selection-mode .path-bar button.suggested-action:hover { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; border-bottom-color: #b3afab; text-shadow: 0 1px rgba(255, 255, 255, 0.769231); -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); box-shadow: inset 0 1px white, 0 1px 2px rgba(0, 0, 0, 0.07); background-color: #89addb; box-shadow: 0 1px rgba(0, 0, 0, 0.15); background-image: linear-gradient(to bottom, #ffffff 5%, #f8f8f7 95%, #edeceb); border-color: #87a556; }

.selection-mode headerbar button.suggested-action:active, .selection-mode headerbar button.image-button.suggested-action:active, .selection-mode headerbar button.image-button.toggle.suggested-action:active, .selection-mode headerbar button.text.button.suggested-action:active, .selection-mode headerbar button.toggle.suggested-action:active, .selection-mode headerbar box button.toggle.suggested-action:active, .selection-mode headerbar buttonbox.toggle.suggested-action:active, .selection-mode headerbar stackswitcher button.suggested-action:active, .selection-mode headerbar filechooser .path-bar.linked > button.suggested-action:active, .selection-mode headerbar .path-bar button.suggested-action:active, headerbar.selection-mode button.suggested-action:active, headerbar.selection-mode button.image-button.suggested-action:active, headerbar.selection-mode button.image-button.toggle.suggested-action:active, headerbar.selection-mode button.text.button.suggested-action:active, headerbar.selection-mode button.toggle.suggested-action:active, headerbar.selection-mode box button.toggle.suggested-action:active, headerbar.selection-mode buttonbox.toggle.suggested-action:active, headerbar.selection-mode stackswitcher button.suggested-action:active, headerbar.selection-mode filechooser .path-bar.linked > button.suggested-action:active, headerbar.selection-mode .path-bar button.suggested-action:active, .selection-mode .titlebar button.suggested-action:active, .selection-mode .titlebar button.image-button.suggested-action:active, .selection-mode .titlebar button.image-button.toggle.suggested-action:active, .selection-mode .titlebar button.text.button.suggested-action:active, .selection-mode .titlebar button.toggle.suggested-action:active, .selection-mode .titlebar box button.toggle.suggested-action:active, .selection-mode .titlebar buttonbox.toggle.suggested-action:active, .selection-mode .titlebar stackswitcher button.suggested-action:active, .selection-mode .titlebar filechooser .path-bar.linked > button.suggested-action:active, .selection-mode .titlebar .path-bar button.suggested-action:active, .titlebar.selection-mode button.suggested-action:active, .titlebar.selection-mode button.image-button.suggested-action:active, .titlebar.selection-mode button.image-button.toggle.suggested-action:active, .titlebar.selection-mode button.text.button.suggested-action:active, .titlebar.selection-mode button.toggle.suggested-action:active, .titlebar.selection-mode box button.toggle.suggested-action:active, .titlebar.selection-mode buttonbox.toggle.suggested-action:active, .titlebar.selection-mode stackswitcher button.suggested-action:active, .titlebar.selection-mode filechooser .path-bar.linked > button.suggested-action:active, .titlebar.selection-mode .path-bar button.suggested-action:active { color: #000000; outline-color: #a29e9b; border-color: #a29e9b; background-image: linear-gradient(to bottom, #cbc9c6, #d6d4d2 3px, #d9d7d5 4px, #cdcbc9 50%, #c9c6c4 50%, #c0bdba); box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; border-color: #6c8345; }

.selection-mode headerbar button.suggested-action:disabled, .selection-mode headerbar button.image-button.suggested-action:disabled, .selection-mode headerbar button.image-button.toggle.suggested-action:disabled, .selection-mode headerbar button.text.button.suggested-action:disabled, .selection-mode headerbar button.toggle.suggested-action:disabled, .selection-mode headerbar box button.toggle.suggested-action:disabled, .selection-mode headerbar buttonbox.toggle.suggested-action:disabled, .selection-mode headerbar stackswitcher button.suggested-action:disabled, .selection-mode headerbar filechooser .path-bar.linked > button.suggested-action:disabled, .selection-mode headerbar .path-bar button.suggested-action:disabled, headerbar.selection-mode button.suggested-action:disabled, headerbar.selection-mode button.image-button.suggested-action:disabled, headerbar.selection-mode button.image-button.toggle.suggested-action:disabled, headerbar.selection-mode button.text.button.suggested-action:disabled, headerbar.selection-mode button.toggle.suggested-action:disabled, headerbar.selection-mode box button.toggle.suggested-action:disabled, headerbar.selection-mode buttonbox.toggle.suggested-action:disabled, headerbar.selection-mode stackswitcher button.suggested-action:disabled, headerbar.selection-mode filechooser .path-bar.linked > button.suggested-action:disabled, headerbar.selection-mode .path-bar button.suggested-action:disabled, .selection-mode .titlebar button.suggested-action:disabled, .selection-mode .titlebar button.image-button.suggested-action:disabled, .selection-mode .titlebar button.image-button.toggle.suggested-action:disabled, .selection-mode .titlebar button.text.button.suggested-action:disabled, .selection-mode .titlebar button.toggle.suggested-action:disabled, .selection-mode .titlebar box button.toggle.suggested-action:disabled, .selection-mode .titlebar buttonbox.toggle.suggested-action:disabled, .selection-mode .titlebar stackswitcher button.suggested-action:disabled, .selection-mode .titlebar filechooser .path-bar.linked > button.suggested-action:disabled, .selection-mode .titlebar .path-bar button.suggested-action:disabled, .titlebar.selection-mode button.suggested-action:disabled, .titlebar.selection-mode button.image-button.suggested-action:disabled, .titlebar.selection-mode button.image-button.toggle.suggested-action:disabled, .titlebar.selection-mode button.text.button.suggested-action:disabled, .titlebar.selection-mode button.toggle.suggested-action:disabled, .titlebar.selection-mode box button.toggle.suggested-action:disabled, .titlebar.selection-mode buttonbox.toggle.suggested-action:disabled, .titlebar.selection-mode stackswitcher button.suggested-action:disabled, .titlebar.selection-mode filechooser .path-bar.linked > button.suggested-action:disabled, .titlebar.selection-mode .path-bar button.suggested-action:disabled { color: #a9a5a2; border-color: #bdbab8; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode headerbar button.suggested-action:backdrop, .selection-mode headerbar button.image-button.suggested-action:backdrop, .selection-mode headerbar button.image-button.toggle.suggested-action:backdrop, .selection-mode headerbar button.text.button.suggested-action:backdrop, .selection-mode headerbar button.toggle.suggested-action:backdrop, .selection-mode headerbar box button.toggle.suggested-action:backdrop, .selection-mode headerbar buttonbox.toggle.suggested-action:backdrop, .selection-mode headerbar stackswitcher button.suggested-action:backdrop, .selection-mode headerbar filechooser .path-bar.linked > button.suggested-action:backdrop, .selection-mode headerbar .path-bar button.suggested-action:backdrop, headerbar.selection-mode button.suggested-action:backdrop, headerbar.selection-mode button.image-button.suggested-action:backdrop, headerbar.selection-mode button.image-button.toggle.suggested-action:backdrop, headerbar.selection-mode button.text.button.suggested-action:backdrop, headerbar.selection-mode button.toggle.suggested-action:backdrop, headerbar.selection-mode box button.toggle.suggested-action:backdrop, headerbar.selection-mode buttonbox.toggle.suggested-action:backdrop, headerbar.selection-mode stackswitcher button.suggested-action:backdrop, headerbar.selection-mode filechooser .path-bar.linked > button.suggested-action:backdrop, headerbar.selection-mode .path-bar button.suggested-action:backdrop, .selection-mode .titlebar button.suggested-action:backdrop, .selection-mode .titlebar button.image-button.suggested-action:backdrop, .selection-mode .titlebar button.image-button.toggle.suggested-action:backdrop, .selection-mode .titlebar button.text.button.suggested-action:backdrop, .selection-mode .titlebar button.toggle.suggested-action:backdrop, .selection-mode .titlebar box button.toggle.suggested-action:backdrop, .selection-mode .titlebar buttonbox.toggle.suggested-action:backdrop, .selection-mode .titlebar stackswitcher button.suggested-action:backdrop, .selection-mode .titlebar filechooser .path-bar.linked > button.suggested-action:backdrop, .selection-mode .titlebar .path-bar button.suggested-action:backdrop, .titlebar.selection-mode button.suggested-action:backdrop, .titlebar.selection-mode button.image-button.suggested-action:backdrop, .titlebar.selection-mode button.image-button.toggle.suggested-action:backdrop, .titlebar.selection-mode button.text.button.suggested-action:backdrop, .titlebar.selection-mode button.toggle.suggested-action:backdrop, .titlebar.selection-mode box button.toggle.suggested-action:backdrop, .titlebar.selection-mode buttonbox.toggle.suggested-action:backdrop, .titlebar.selection-mode stackswitcher button.suggested-action:backdrop, .titlebar.selection-mode filechooser .path-bar.linked > button.suggested-action:backdrop, .titlebar.selection-mode .path-bar button.suggested-action:backdrop { color: #2f2f2f; border-color: #b1aeab; background-image: linear-gradient(to bottom, #fdfdfc, #fafafa 50%, #f6f5f5 50%, #e9e7e6); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode headerbar button.suggested-action:backdrop:disabled, .selection-mode headerbar button.image-button.suggested-action:backdrop:disabled, .selection-mode headerbar button.image-button.toggle.suggested-action:backdrop:disabled, .selection-mode headerbar button.text.button.suggested-action:backdrop:disabled, .selection-mode headerbar button.toggle.suggested-action:backdrop:disabled, .selection-mode headerbar box button.toggle.suggested-action:backdrop:disabled, .selection-mode headerbar buttonbox.toggle.suggested-action:backdrop:disabled, .selection-mode headerbar stackswitcher button.suggested-action:backdrop:disabled, .selection-mode headerbar filechooser .path-bar.linked > button.suggested-action:backdrop:disabled, .selection-mode headerbar .path-bar button.suggested-action:backdrop:disabled, headerbar.selection-mode button.suggested-action:backdrop:disabled, headerbar.selection-mode button.image-button.suggested-action:backdrop:disabled, headerbar.selection-mode button.image-button.toggle.suggested-action:backdrop:disabled, headerbar.selection-mode button.text.button.suggested-action:backdrop:disabled, headerbar.selection-mode button.toggle.suggested-action:backdrop:disabled, headerbar.selection-mode box button.toggle.suggested-action:backdrop:disabled, headerbar.selection-mode buttonbox.toggle.suggested-action:backdrop:disabled, headerbar.selection-mode stackswitcher button.suggested-action:backdrop:disabled, headerbar.selection-mode filechooser .path-bar.linked > button.suggested-action:backdrop:disabled, headerbar.selection-mode .path-bar button.suggested-action:backdrop:disabled, .selection-mode .titlebar button.suggested-action:backdrop:disabled, .selection-mode .titlebar button.image-button.suggested-action:backdrop:disabled, .selection-mode .titlebar button.image-button.toggle.suggested-action:backdrop:disabled, .selection-mode .titlebar button.text.button.suggested-action:backdrop:disabled, .selection-mode .titlebar button.toggle.suggested-action:backdrop:disabled, .selection-mode .titlebar box button.toggle.suggested-action:backdrop:disabled, .selection-mode .titlebar buttonbox.toggle.suggested-action:backdrop:disabled, .selection-mode .titlebar stackswitcher button.suggested-action:backdrop:disabled, .selection-mode .titlebar filechooser .path-bar.linked > button.suggested-action:backdrop:disabled, .selection-mode .titlebar .path-bar button.suggested-action:backdrop:disabled, .titlebar.selection-mode button.suggested-action:backdrop:disabled, .titlebar.selection-mode button.image-button.suggested-action:backdrop:disabled, .titlebar.selection-mode button.image-button.toggle.suggested-action:backdrop:disabled, .titlebar.selection-mode button.text.button.suggested-action:backdrop:disabled, .titlebar.selection-mode button.toggle.suggested-action:backdrop:disabled, .titlebar.selection-mode box button.toggle.suggested-action:backdrop:disabled, .titlebar.selection-mode buttonbox.toggle.suggested-action:backdrop:disabled, .titlebar.selection-mode stackswitcher button.suggested-action:backdrop:disabled, .titlebar.selection-mode filechooser .path-bar.linked > button.suggested-action:backdrop:disabled, .titlebar.selection-mode .path-bar button.suggested-action:backdrop:disabled { color: #c9c6c3; border-color: #b1aeab; background-image: linear-gradient(to bottom, #f6f5f5, #efeeed 50%, #ebeae9 50%, #e4e3e1); text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #87a556; }

.selection-mode headerbar .selection-menu:backdrop, .selection-mode headerbar .selection-menu, headerbar.selection-mode .selection-menu:backdrop, headerbar.selection-mode .selection-menu, .selection-mode .titlebar .selection-menu:backdrop, .selection-mode .titlebar .selection-menu, .titlebar.selection-mode .selection-menu:backdrop, .titlebar.selection-mode .selection-menu { border-color: rgba(147, 175, 102, 0); background-color: rgba(147, 175, 102, 0); background-image: none; box-shadow: none; min-height: 20px; padding: 6px 10px; }

.selection-mode headerbar .selection-menu:backdrop arrow, .selection-mode headerbar .selection-menu arrow, headerbar.selection-mode .selection-menu:backdrop arrow, headerbar.selection-mode .selection-menu arrow, .selection-mode .titlebar .selection-menu:backdrop arrow, .selection-mode .titlebar .selection-menu arrow, .titlebar.selection-mode .selection-menu:backdrop arrow, .titlebar.selection-mode .selection-menu arrow { -GtkArrow-arrow-scaling: 1; }

.selection-mode headerbar .selection-menu:backdrop .arrow, .selection-mode headerbar .selection-menu .arrow, headerbar.selection-mode .selection-menu:backdrop .arrow, headerbar.selection-mode .selection-menu .arrow, .selection-mode .titlebar .selection-menu:backdrop .arrow, .selection-mode .titlebar .selection-menu .arrow, .titlebar.selection-mode .selection-menu:backdrop .arrow, .titlebar.selection-mode .selection-menu .arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); color: rgba(255, 255, 255, 0.5); -gtk-icon-shadow: none; }

headerbar button { background-image: linear-gradient(to bottom, #d6e2f2, #c8d8ec 50%, #c2d4ea 50%, #b2c7e2); border-color: #58708d; }

headerbar button:hover { background-image: linear-gradient(to bottom, #f5f7fa, #e7edf4 50%, #e5ebf2 50%, #d3dce9); border-color: #58708d; }

headerbar button:backdrop { background-image: linear-gradient(to bottom, #f8f8f8, #eeeeee 50%, #eaeaea 50%, #dedede); }

headerbar button:backdrop:hover { background-image: linear-gradient(to bottom, white, #f8f8f8 50%, #f4f4f4 50%, #e8e8e8); border-color: #868686; }

/* GTK NAMED COLORS ---------------- use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color #000000;
/*
text color for entries, views and content in general */
@define-color theme_text_color #1a1a1a;
/*
widget base background color */
@define-color theme_bg_color #edeceb;
/*
text widgets and the like base background color */
@define-color theme_base_color #ffffff;
/*
base background color of selections */
@define-color theme_selected_bg_color #89addb;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #ffffff;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #edeceb;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color #a9a5a2;
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #ffffff;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #2f2f2f;
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color #1a1a1a;
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #edeceb;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #fcfcfc;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #89addb;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #ffffff;
/*
insensitive color on backdrop windows*/
@define-color unfocused_insensitive_color #c9c6c3;
/*
widgets main borders color */
@define-color borders #a29e9b;
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #b1aeab;
/*
these are pretty self explicative */
@define-color warning_color #f99b11;
@define-color error_color #c7162b;
@define-color success_color #93af66;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title shade(#000000, 1.8);
@define-color wm_unfocused_title #2f2f2f;
@define-color wm_highlight rgba(255, 255, 255, 0.8);
@define-color wm_borders_edge rgba(255, 255, 255, 0.8);
@define-color wm_bg_a shade(#edeceb, 1.2);
@define-color wm_bg_b #edeceb;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border alpha(black, 0.18);
@define-color wm_button_hover_color_a shade(#edeceb, 1.3);
@define-color wm_button_hover_color_b #edeceb;
@define-color wm_button_active_color_a shade(#edeceb, 0.85);
@define-color wm_button_active_color_b shade(#edeceb, 0.89);
@define-color wm_button_active_color_c shade(#edeceb, 0.9);
/* content view background such as thumbnails view in Photos or Boxes */
@define-color content_view_bg #ffffff;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #ffffff;
row label.subtitle { font-size: smaller; opacity: 0.55; text-shadow: none; }

row > box.header { margin-left: 12px; margin-right: 12px; min-height: 50px; }

row > box.header > box.title { margin-top: 8px; margin-bottom: 8px; }

row.expander { background-color: transparent; }

row.expander list.nested > row { background-color: alpha(#edeceb, 0.5); border-color: alpha(#a29e9b, 0.7); border-style: solid; border-width: 1px 0px 0px 0px; }

row.expander image.expander-row-arrow { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row.expander:checked image.expander-row-arrow { -gtk-icon-transform: rotate(0turn); }

row.expander:not(:checked) image.expander-row-arrow { opacity: 0.55; text-shadow: none; }

row.expander:not(:checked) image.expander-row-arrow:dir(ltr) { -gtk-icon-transform: rotate(-0.25turn); }

row.expander:not(:checked) image.expander-row-arrow:dir(rtl) { -gtk-icon-transform: rotate(0.25turn); }

row.expander:checked image.expander-row-arrow:not(:disabled) { color: #89addb; }

row.expander image.expander-row-arrow:disabled { color: #a9a5a2; }

flap > dimming, deck > dimming, leaflet > dimming { background: rgba(0, 0, 0, 0.12); }

flap > border, deck > border, leaflet > border { min-width: 1px; min-height: 1px; background: rgba(0, 0, 0, 0.05); }

flap > shadow, deck > shadow, leaflet > shadow { min-width: 56px; min-height: 56px; }

flap > shadow.left, deck > shadow.left, leaflet > shadow.left { background-image: linear-gradient(to right, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, transparent 56px), linear-gradient(to right, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, transparent 24px); }

flap > shadow.right, deck > shadow.right, leaflet > shadow.right { background-image: linear-gradient(to left, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, transparent 56px), linear-gradient(to left, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, transparent 24px); }

flap > shadow.up, deck > shadow.up, leaflet > shadow.up { background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, transparent 56px), linear-gradient(to bottom, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, transparent 24px); }

flap > shadow.down, deck > shadow.down, leaflet > shadow.down { background-image: linear-gradient(to top, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, transparent 56px), linear-gradient(to top, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, transparent 24px); }

flap > outline, deck > outline, leaflet > outline { min-width: 1px; min-height: 1px; background: rgba(255, 255, 255, 0.2); }

avatar { border-radius: 9999px; -gtk-outline-radius: 9999px; font-weight: bold; }

avatar.color1 { background-image: linear-gradient(#83b6ec, #337fdc); color: #cfe1f5; }

avatar.color2 { background-image: linear-gradient(#7ad9f1, #0f9ac8); color: #caeaf2; }

avatar.color3 { background-image: linear-gradient(#8de6b1, #29ae74); color: #cef8d8; }

avatar.color4 { background-image: linear-gradient(#b5e98a, #6ab85b); color: #e6f9d7; }

avatar.color5 { background-image: linear-gradient(#f8e359, #d29d09); color: #f9f4e1; }

avatar.color6 { background-image: linear-gradient(#ffcb62, #d68400); color: #ffead1; }

avatar.color7 { background-image: linear-gradient(#ffa95a, #ed5b00); color: #ffe5c5; }

avatar.color8 { background-image: linear-gradient(#f78773, #e62d42); color: #f8d2ce; }

avatar.color9 { background-image: linear-gradient(#e973ab, #e33b6a); color: #fac7de; }

avatar.color10 { background-image: linear-gradient(#cb78d4, #9945b5); color: #e7c2e8; }

avatar.color11 { background-image: linear-gradient(#9e91e8, #7a59ca); color: #d5d2f5; }

avatar.color12 { background-image: linear-gradient(#e3cf9c, #b08952); color: #f2eade; }

avatar.color13 { background-image: linear-gradient(#be916d, #785336); color: #e5d6ca; }

avatar.color14 { background-image: linear-gradient(#c0bfbc, #6e6d71); color: #d8d7d3; }

avatar.contrasted { color: #fff; }

avatar.image { background: none; }

viewswitchertitle viewswitcher { margin-left: 12px; margin-right: 12px; }

statuspage > scrolledwindow > viewport > box { margin: 36px 12px; }

statuspage > scrolledwindow > viewport > box > clamp > box > .icon { margin-bottom: 36px; opacity: 0.5; }

statuspage > scrolledwindow > viewport > box > clamp > box > .title { margin-bottom: 12px; }

statuspage > scrolledwindow > viewport > box > clamp > box > .description { margin-bottom: 36px; }

popover.combo list { min-width: 200px; }

window.csd.unified:not(.solid-csd) headerbar { border-radius: 0; }

.windowhandle, .windowhandle * { -GtkWidget-window-dragging: true; }

popover.combo { padding: 0px; }

popover.combo list { border-style: none; background-color: transparent; }

popover.combo list > row { padding: 0px 12px 0px 12px; min-height: 50px; }

popover.combo list > row:not(:last-child) { border-bottom: 1px solid alpha(#a29e9b, 0.5); }

popover.combo list > row:first-child { border-top-left-radius: 8px; -gtk-outline-top-left-radius: 7px; border-top-right-radius: 8px; -gtk-outline-top-right-radius: 7px; }

popover.combo list > row:last-child { border-bottom-left-radius: 8px; -gtk-outline-bottom-left-radius: 7px; border-bottom-right-radius: 8px; -gtk-outline-bottom-right-radius: 7px; }

popover.combo overshoot.top { border-top-left-radius: 8px; -gtk-outline-top-left-radius: 7px; border-top-right-radius: 8px; -gtk-outline-top-right-radius: 7px; }

popover.combo overshoot.bottom { border-bottom-left-radius: 8px; -gtk-outline-bottom-left-radius: 7px; border-bottom-right-radius: 8px; -gtk-outline-bottom-right-radius: 7px; }

popover.combo scrollbar.vertical { padding-top: 2px; padding-bottom: 2px; }

popover.combo scrollbar.vertical:dir(ltr) { border-top-right-radius: 8px; -gtk-outline-top-right-radius: 7px; border-bottom-right-radius: 8px; -gtk-outline-bottom-right-radius: 7px; }

popover.combo scrollbar.vertical:dir(rtl) { border-top-left-radius: 8px; -gtk-outline-top-left-radius: 7px; border-bottom-left-radius: 8px; -gtk-outline-bottom-left-radius: 7px; }

row.expander { padding: 0px; }

row.expander image.expander-row-arrow:dir(ltr) { margin-left: 6px; }

row.expander image.expander-row-arrow:dir(rtl) { margin-right: 6px; }

keypad .digit { font-size: 200%; font-weight: bold; }

keypad .letters { font-size: 70%; }

keypad .symbol { font-size: 160%; }

viewswitcher, viewswitcher button { margin: 0; padding: 0; }

viewswitcher button { border-radius: 0; border-top: 0; border-bottom: 0; box-shadow: none; font-size: 1rem; border-width: 0; }

viewswitcher button:not(:checked):not(:hover) { background: transparent; }

viewswitcher button:not(:only-child):not(:last-child) { border-right-width: 0px; }

viewswitcher button:not(only-child):first-child:not(:checked):not(:hover), viewswitcher button:not(:checked):not(:hover) + button:not(:checked):not(:hover) { border-left-color: transparent; }

viewswitcher button:not(only-child):last-child:not(:checked):not(:hover) { border-right-color: transparent; }

viewswitcher button:not(:checked):hover:not(:backdrop) { background-image: image(lighter(#edeceb)); }

viewswitcher button:not(only-child):first-child:not(:checked):hover, viewswitcher button:not(:checked):hover + button:not(:checked):not(:hover), viewswitcher button:not(:checked):not(:hover) + button:not(:checked):hover { border-left-color: shade(#a29e9b, 1.15); }

viewswitcher button:not(only-child):last-child:not(:checked):hover { border-right-color: shade(#a29e9b, 1.15); }

viewswitcher button:not(:checked):hover:backdrop { background-image: image(#edeceb); }

headerbar viewswitcher button:not(:checked):hover:not(:backdrop) { background-image: linear-gradient(to top, shade(alpha(#edeceb, 0.7), 0.96) 2px, alpha(#edeceb, 0.7)); }

headerbar viewswitcher button:not(:checked):not(only-child):first-child:hover, headerbar viewswitcher button:not(:checked):hover + button:not(:checked):not(:hover), headerbar viewswitcher button:not(:checked):not(:hover) + button:not(:checked):hover { border-left-color: #a29e9b; }

headerbar viewswitcher button:not(:checked):not(only-child):last-child:hover { border-right-color: #a29e9b; }

headerbar viewswitcher button:not(:checked):hover:backdrop { background-image: image(#edeceb); }

viewswitcher button > stack > box.narrow { font-size: 0.75rem; padding-top: 7px; padding-bottom: 5px; }

viewswitcher button > stack > box.narrow image, viewswitcher button > stack > box.narrow label { padding-left: 8px; padding-right: 8px; }

viewswitcher button > stack > box.wide { padding: 8px 12px; }

viewswitcher button > stack > box.wide label:dir(ltr) { padding-right: 7px; }

viewswitcher button > stack > box.wide label:dir(rtl) { padding-left: 7px; }

viewswitcher button > stack > box label.active { font-weight: bold; }

viewswitcher button.needs-attention:active > stack > box label, viewswitcher button.needs-attention:checked > stack > box label { animation: none; background-image: none; }

viewswitcher button.needs-attention > stack > box label { animation: needs_attention 150ms ease-in; background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#1977ee), to(transparent)); background-size: 6px 6px, 6px 6px; background-repeat: no-repeat; background-position: right 0px, right 1px; }

viewswitcher button.needs-attention > stack > box label:backdrop { background-size: 6px 6px, 0 0; }

viewswitcher button.needs-attention > stack > box label:dir(rtl) { background-position: left 0px, left 1px; }

viewswitcherbar actionbar > revealer > box { padding: 0; }

list.content, list.content list { background-color: transparent; }

list.content list.nested > row:not(:active):not(:hover):not(:selected), list.content list.nested > row:not(:active):hover:not(.activatable):not(:selected) { background-color: mix(#edeceb, #ffffff, 0.5); }

list.content list.nested > row:not(:active):hover.activatable:not(:selected) { background-color: mix(#000000, #ffffff, 0.95); }

list.content > row:not(.expander):not(:active):not(:hover):not(:selected), list.content > row:not(.expander):not(:active):hover:not(.activatable):not(:selected), list.content > row.expander row.header:not(:active):not(:hover):not(:selected), list.content > row.expander row.header:not(:active):hover:not(.activatable):not(:selected) { background-color: #ffffff; }

list.content > row:not(.expander):not(:active):hover.activatable:not(:selected), list.content > row.expander row.header:not(:active):hover.activatable:not(:selected) { background-color: mix(#000000, #ffffff, 0.95); }

list.content > row, list.content > row list > row { border-color: alpha(#a29e9b, 0.7); border-style: solid; transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

list.content > row:not(:last-child) { border-width: 1px 1px 0px 1px; }

list.content > row:first-child, list.content > row.expander:first-child row.header, list.content > row.expander:checked, list.content > row.expander:checked row.header, list.content > row.expander:checked + row, list.content > row.expander:checked + row.expander row.header { border-top-left-radius: 8px; -gtk-outline-top-left-radius: 7px; border-top-right-radius: 8px; -gtk-outline-top-right-radius: 7px; }

list.content > row:last-child, list.content > row.checked-expander-row-previous-sibling, list.content > row.expander:checked { border-width: 1px; }

list.content > row:last-child, list.content > row.checked-expander-row-previous-sibling, list.content > row.expander:checked, list.content > row.expander:not(:checked):last-child row.header, list.content > row.expander:not(:checked).checked-expander-row-previous-sibling row.header, list.content > row.expander.empty:checked row.header, list.content > row.expander list.nested > row:last-child { border-bottom-left-radius: 8px; -gtk-outline-bottom-left-radius: 7px; border-bottom-right-radius: 8px; -gtk-outline-bottom-right-radius: 7px; }

list.content > row.expander:checked:not(:first-child), list.content > row.expander:checked + row { margin-top: 6px; }

button.list-button:not(:active):not(:checked):not(:hover) { background: none; border: 1px solid alpha(#a29e9b, 0.5); box-shadow: none; }

window.csd.unified:not(.solid-csd):not(.fullscreen) headerbar.selection-mode { box-shadow: none; }

window.csd.unified:not(.solid-csd):not(.fullscreen):not(.tiled):not(.tiled-top):not(.tiled-bottom):not(.tiled-left):not(.tiled-right):not(.maximized), window.csd.unified:not(.solid-csd):not(.fullscreen):not(.tiled):not(.tiled-top):not(.tiled-bottom):not(.tiled-left):not(.tiled-right):not(.maximized) > decoration, window.csd.unified:not(.solid-csd):not(.fullscreen):not(.tiled):not(.tiled-top):not(.tiled-bottom):not(.tiled-left):not(.tiled-right):not(.maximized) > decoration-overlay { border-radius: 8px; }
